var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Link_Constraint - superclass: Matrix3Controller</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Link_Constraint - superclass: Matrix3Controller</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"link_constraint---superclass-matrix3controller\"></a></div>\n\
<div class=\'codeBlock\'><pre>Link_Constraint - superclass: Matrix3Controller; super-superclass:MAXWrapper - 2:1 - classID: #(-2025855132, -1430354431) \n\
</pre></div><p>A Link constraint is used to animate an object linking from one target object to another.</p>\n\
<p>The Link constraint causes an object to inherit the position, rotation, and scale of its target object.</p>\n\
<p><strong>Constructor</strong></p>\n\
<div class=\'codeBlock\'><pre>Link_Constraint...   \n\
Link ... \n\
</pre></div><p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;Link_Constraint&gt;.key_mode Integer default: 0 -- integer; Link_KeyMode \n\
</pre></div><p>You can choose between three different Key Modes that will determine how keyframes are written on the linked objects as part of the link constraint. These options will provide the following:</p>\n\
<p><strong>0:</strong> No Key Mode: No keys are created in any of the objects involved.</p>\n\
<p><strong>1:</strong> Key Nodes: Sets keys for some of the objects.</p>\n\
<p><strong>2:</strong> Child: Applied keys to the child object only.</p>\n\
<p><strong>3:</strong> Parents: Applies keys to both parents and the child object.</p>\n\
<p><strong>4:</strong> Key Entire Hierarchy: This applies keyframes to the chosen nodes and their entire hierarchies.</p>\n\
<p><strong>5:</strong> Child: Keys the chosen object and the nodes in its hierarchy up to the world.</p>\n\
<p><strong>6:</strong> Parents: Keys both parents and the child and all three hierarchies up to the world.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Link_Constraint&gt;.link_params SubAnim default: SubAnim:Link_Params -- transform \n\
</pre></div><p>Contains the Link Params Transforms sub-anim, which in turn has three properties - <span class=\'code\'>.Position</span> , <span class=\'code\'>.Rotation</span> , and <span class=\'code\'>.Scale</span> . It contains the offset transform in parent space. This controller will contain keys depending on the <span class=\'code\'>.key_mode</span> settings described above.</p>\n\
<p><strong>Link_Constraint interfaces:</strong></p>\n\
<div class=\'codeBlock\'><pre>Interface: constraints \n\
</pre></div><p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;&lt;Link_Constraint&gt;.getNode &lt;index&gt;nodeNumber \n\
</pre></div><p>Returns the indexed target.</p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;&lt;Link_Constraint&gt;.getFrameNo &lt;index&gt;targetNumber \n\
</pre></div><p>Returns the linking start frame number of the indexed target.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;&lt;Link_Constraint&gt;.setFrameNo &lt;index&gt;targetNumber &lt;integer&gt;frameNo \n\
</pre></div><p>Sets the linking start frame number of the indexed target. Returns <span class=\'code\'>true</span> on success.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;&lt;Link_Constraint&gt;.getNumTargets()\n\
</pre></div><p>Returns the number of targets.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;&lt;Link_Constraint&gt;.addTarget &lt;node&gt;target &lt;integer&gt;frameNo \n\
</pre></div><p>Appends the specified node to the target list at the specified frame. Returns <span class=\'code\'>true</span> on success.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;&lt;Link_Constraint&gt;.DeleteTarget &lt;integer&gt;targetNumber \n\
</pre></div><p>Deletes the indexed node from the target list. Returns <span class=\'code\'>true</span> on success.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;&lt;Link_Constraint&gt;.addWorld frameNo:&lt;integer&gt; \n\
</pre></div><p><span class=\'code\'>frameNo</span> default value: -99999.</p>\n\
<p>This method sets &quot;World&quot; as a target at the specified frame.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` s = sphere() --create a sphere at time 100 with animate on s.pos = [200,0,0] --animate sphere 200 units along X over 100 frames b = box() --create a box at time 100 with animate on b.pos = [0,500,0] --animate box 500 units along Y over 100 frames t = teapot() --create a teapot lc = link_constraint() --create a Link Constraint instance t.transform.controller = lc --assign the constraint to the transform controller of the teapot lc.key_mode = 0 --set the key mode to 0 (it is the default anyway) lc.addWorld frameNo:29 --add a World key on frame 29 lc.addTarget s 30 --add the sphere as link target on frame 30 lc.addWorld frameNo:60 --add a World key on frame 60 lc.addTarget b 70 --add the box as link target on frame 70 lc.addWorld frameNo:80 --add a World key on frame 80 lc.setFrameNo 5 90 --changed my mind, move the last (fifth) world key to frame 90!</p>\n\
<p>for i = 1 to lc.getNumTargets() do --print all keys&#39; index, time and target format &quot;%: Frame:% - Target:% \\n&quot; i (lc.getFrameNo i) (lc.getNode i)</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT</strong></p>\n\
<p><span class=\'code\'>$Sphere:Sphere001 @ [0.000000,0.000000,0.000000]   [200,0,0]   $Box:Box001 @ [0.000000,0.000000,0.000000]   [0,500,0]   $Teapot:Teapot001 @ [0.000000,0.000000,0.000000]   Controller:Link_Constraint   Controller:Link_Constraint   0   1   true   1   true   1   true   1: Frame:29 - Target:undefined    2: Frame:30 - Target:$Sphere:Sphere001 @ [0.000000,0.000000,0.000000]    3: Frame:60 - Target:undefined    4: Frame:70 - Target:$Box:Box001 @ [0.000000,0.000000,0.000000]    5: Frame:90 - Target:undefined    OK</span></p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";