var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Controller Common Properties, Operators, and Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Controller Common Properties, Operators, and Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"controller-common-properties-operators-and-methods\"></a></div>\n\
<p><strong>Properties</strong></p>\n\
<p>All controllers have the following properties:</p>\n\
<div class=\'codeBlock\'><pre>&lt;controller&gt;.keys MAXKeyArray -- read-only, the controller’s key array \n\
&lt;controller&gt;.value varies -- get or set the current controller value     \n\
</pre></div><p>The <span class=\'code\'>keys</span> and <span class=\'code\'>value</span> properties provide access to the value and keys in a free-standing controller. It is useful when working with the global tracks controllers that are accessible in MAXScript. The controllers that are not keyframeable return an empty KeyArray for their <span class=\'code\'>keys</span> property.</p>\n\
<p>The <span class=\'code\'>value</span> property is sensitive to the current time and animate contexts, so you can use it to evaluate a controller at various times or to plant keyframes in the controllers that support keys.</p>\n\
<p>You can only assign a value to a controller’s <span class=\'code\'>value</span> property if the controller is a key-based controller. The only exception to this is that you can assign a Matrix3 value to a PRS controller’s <span class=\'code\'>value</span> property. MAXScript automatically sets the individual position, rotation, and scale values to the values represented in the Matrix3 value.</p>\n\
<p>If an Ease Curve is assigned to a controller, the following controller-related sub-property is available:</p>\n\
<div class=\'codeBlock\'><pre>&lt;controller&gt;.Ease_Curve Float -- the controller’s ease curve value   \n\
</pre></div><p>If a MultiplierCurve is assigned to a controller, the following controller-related sub-property is available:</p>\n\
<div class=\'codeBlock\'><pre>&lt;controller&gt;.Multiplier_Curve Float -- the controller’s multiplier curve value \n\
</pre></div><p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Common-Properties/Controller-Ease-and-Multiplier.html\' title=\'\'>Ease and Multiplier Curve Functions</a> for methods and notes related to Ease and Multiplier curves.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` globaltracks.float.mycontroller.value globaltracks.float.mycontroller.keys[2]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Associated Properties</strong></p>\n\
<p>All animatable properties in <strong>3ds Max</strong> objects let you reference several controller-related sub-properties. These are:</p>\n\
<div class=\'codeBlock\'><pre>&lt;property&gt;.controller \n\
</pre></div><p>The property’s controller.</p>\n\
<div class=\'codeBlock\'><pre>&lt;property&gt;.track \n\
</pre></div><p>A synonym for .controller.</p>\n\
<div class=\'codeBlock\'><pre>&lt;property&gt;.isAnimated \n\
</pre></div><p>A boolean indicating whether the property is animated.</p>\n\
<div class=\'codeBlock\'><pre>&lt;property&gt;.keys \n\
</pre></div><p>Read-only, gets the property’s controller’s key array</p>\n\
<div class=\'codeBlock\'><pre>&lt;property&gt;.supportsKeys \n\
</pre></div><p>Read-only, boolean, true if controller is key-framable</p>\n\
<div class=\'codeBlock\'><pre>&lt;property&gt;.keyable \n\
</pre></div><p>Boolean, true if controller is keyable, false if set to unkeyable</p>\n\
<div class=\'codeBlock\'><pre>&lt;property&gt;.isHSV \n\
</pre></div><p>Read-only, boolean, true if controller&#39;s value represent HSV colors</p>\n\
<p>The <span class=\'code\'>track</span> property is a simple synonym for <span class=\'code\'>controller</span> . If an animatable property does not have an assigned controller, the <span class=\'code\'>isAnimated</span> property returns <span class=\'code\'>false</span> and the <span class=\'code\'>controller</span> , <span class=\'code\'>track</span> , and <span class=\'code\'>keys</span> properties return <span class=\'code\'>undefined</span> .</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` $foo.pos.controller bend_mod1.angle.isAnimated $bar.taper.gizmo.scale.keys[2]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>You can create controllers like other <strong>3ds Max</strong> objects by calling the class&#39; constructor function:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` c = bezier_position()</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>and assign them to animatable properties by assigning to the controller property in those animatables.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` $foo.pos.controller = c $baz.bend.gizmo.rotation.controller = tcb_rotation() $box01.length = linear_float()</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>getPointControllers {&lt;editable_mesh_node&gt; | &lt;editable_spline_node&gt;} \n\
</pre></div><p>Returns an array of controllers assigned to the vertices in the mesh or spline. If no controller is assigned to a vertex, the array element value will be undefined. For editable splines, each knot consists of three vertices: the in vector, knot, and out vector. The array of controllers returned is a &quot;snapshot&quot; of the current controllers. If controllers are assigned or changed for a vertex, this change is not reflected in the array. If a vertex is added/deleted, the array is not resized to reflect the change in number of vertices.</p>\n\
<div class=\'codeBlock\'><pre>getPointController &lt;editable_mesh_node&gt; &lt;vertex_index_integer&gt; \n\
</pre></div><p>Returns the controller currently assigned to the vertex, undefined if no controller is assigned.</p>\n\
<div class=\'codeBlock\'><pre>getPointController &lt;editable_spline_node&gt; &lt;spline_index_integer&gt; &lt;vertex_index_integer&gt; \n\
</pre></div><p>Returns the controller for specified vertex in the specified spline, undefined if no controller is assigned. Each spline knot consists of three vertices: the in vector, knot, and out vector.</p>\n\
<p>Note:</p>\n\
<p>Applying a controller to a property causes the controller to take on the properties value at frame 0. If keys are present for the controller before the assignment to the property, all keys will be adjusted by the difference between the controller’s value at frame 0 and the property’s value. This is shown in the following example.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` a=bezier_float () addnewkey a 0 addnewkey a 10 a.keys[1].value=10 a.keys[2].value=100 b=box() b.height b.height.controller=a b.height at time 10 b.height</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT</strong></p>\n\
<p>``` Controller:Bezier_Float-- result line 1 #Bezier Float key(1 @ 0f)-- result line 2 #Bezier Float key(2 @ 10f)-- result line 3 10-- result line 4, key value at time 0 100-- result line 5, key value at time 10 $Box:Box006 @ [0.000000,0.000000,0.000000]-- result line 6 25.0-- result line 7, default property value Controller:Bezier_Float-- result line 8 10.0-- result line 9, key value changed from 10 to 25 (delta= +15) 100.0-- result line 10, key value changed by delta = +15</p>\n\
<p>```</p>\n\
<p>An issue can occur when a single controller is assigned to multiple object properties. The value actually stored in a controller might not necessarily be the same value seen in Track View or in the command panels, nor the same value returned by accessing the property value in MAXScript. Part of a MAXWrapper property definition is scaling value that is applied when reading or setting the true value stored in a controller. For example, the <span class=\'code\'>slice_to</span> and <span class=\'code\'>slice_from</span> properties associated with many of the geometry primitives is displayed in degrees. The actual value stored in the controller associated with these properties are in radians. This scaling factor is an internal property of the MAXWrapper property, and not an internal property of the controller. Both <strong>3ds Max</strong> and MAXScript automatically apply the specified scaling factor when accessing properties, so this scaling is normally invisible to the user. If the same controller is assigned to two properties that have different scaling factors, the question arises as to which scaling factor to apply to the output of the controller. If you are accessing the controller’s value through a MAXWrapper property, the scaling factor associated with that property is applied to the controller’s value. MAXScript also internally stores the last scaling factor applied to the controller’s value. If you are directly accessing the <span class=\'code\'>value</span> property of the controller, or the <span class=\'code\'>value</span> property of a key in the controller, the stored scaling factor is used. This can result in a controller’s <span class=\'code\'>value</span> property returning different values at different times in a script, based on how the controller was last accessed. Because of this, it is highly recommended that you do not instance a controller onto multiple MAXWrapper properties that have different scaling factors. The scaling factor, if any, is listed for each MAXWrapper property in the documentation of the MAXWrapper classes.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>displayControlDialog &lt;controller&gt; &lt;string&gt; \n\
</pre></div><p>Displays the modal controller dialog, if any. The string will be in the dialog title bar. If the controller is a keyframe controller, the key info dialog is displayed for the selected keys. If no keys are selected, no dialog is displayed.</p>\n\
<div class=\'codeBlock\'><pre>clearControllerNewFlag &lt;controller&gt; \n\
</pre></div><p>Clears the &#39;new&#39; flag on the MAXScript wrapper for the controller.</p>\n\
<p>When this flag is set, when you assign the controller to a property, the initial value of the controller is set to the property value.</p>\n\
<p>When you create an instance of a controller, this flag is set.</p>\n\
<p>It is normally cleared only after the controller is assigned to a property.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously, it was available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a> .</p>\n\
<div class=\'codeBlock\'><pre>isController &lt;value&gt; \n\
</pre></div><p>Returns true if the value wraps a controller.</p>\n\
<p>Controllers that can be keyframed support several time and key-related functions as described in the following topics:</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Common-Properties/Controller-Time-Functions.html\' title=\'\'>Controller Time Functions</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Common-Properties/Controller-Key-Functions.html\' title=\'\'>Controller Key Functions</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Common-Properties/Controller-Out-Of-Range.html\' title=\'\'>Controller Out-Of-Range Functions</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Common-Properties/Controller-Ease-and-Multiplier.html\' title=\'\'>Controller Ease and Multiplier Curve Functions</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Common-Properties/Controller-Key-Reducer.html\' title=\'\'>Controller Key Reducer</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Common-Properties/ControllermapKeys-Method.html\' title=\'\'>ControllermapKeys() method</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";