var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Set Controller Value Functions</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Set Controller Value Functions</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"set-controller-value-functions\"></a></div>\n\
<p>The following functions can be used to adjust the value of a controller using either absolute or relative values, and set an animation key or shift the whole animation curve, with the ability to commit or discard the animation curve changes after setting the value. Available in <strong>3ds Max 2017 and higher</strong>.</p>\n\
<p><strong>Functions:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;value&gt;SetControllerValue &lt;controller&gt;target &lt;value&gt;newValue &lt;boolean&gt;setKey &lt;enum&gt;{mode:#absolute|#relative}\n\
</pre></div><p>Sets the controller specified by the first argument to the absolute value specified by the second argument when the fourth argument is <span class=\'code\'>#absolute</span>, or increments the existing value by the second argument if the fourth argument is <span class=\'code\'>#relative</span>.</p>\n\
<p>When the third argument is set to True and the function is called while in Auto-Key mode, or inside an Animate context, a new animation key will be created at the current time in the controller.</p>\n\
<p>When the third argument is set to False and the function is called while in Auto-Key mode, or inside an Animate context, and there is an existing key at the current slider time, the existing key will be set to the new value and the animation curve will be shifted temporarily in relation to it. Changing the current time or calling <span class=\'code\'>RestoreControllerValue()</span> will discard the value changes.</p>\n\
<p>Calling the <span class=\'code\'>CommitControllerValue()</span> function will commit the changes, updating all existing keys to their new values, unless the changes have already been discarded.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;CommitControllerValue &lt;controller&gt;target\n\
</pre></div><p>Makes the temporary changes to a controller&#39;s value applied using <span class=\'code\'>SetControllerValue()</span> with third argument set to False permanent.</p>\n\
<p>If this function is not called, the changes will be discarded as soon as the current time is changed.</p>\n\
<p>If the <span class=\'code\'>RestoreControllerValue()</span> function has been called after the <span class=\'code\'>SetControllerValue()</span> and the <span class=\'code\'>CommitControllerValue()</span> calls, the function will have no effect.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;RestoreControllerValue &lt;controller&gt;target\n\
</pre></div><p>Discards the temporary changes to a controller&#39;s value applied using <span class=\'code\'>SetControllerValue()</span> with third argument set to False permanent.</p>\n\
<p>It can be used to programmatically achive a similar result to moving the time slider after a <span class=\'code\'>SetControllerValue()</span> call, however the UI will not be updated to reset the value.</p>\n\
<p>It has no effect if the changes have been already committed using <span class=\'code\'>CommitControllerValue()</span>, or if the third argument of <span class=\'code\'>SetControllerValue()</span> was set to True to set an animation key.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` b = box() --&gt; $Box:Box001 @ [0.000000,0.000000,0.000000] c = b.height.controller = newDefaultFloatController() --&gt; Controller:Bezier_Float setControllerValue c 100 true #absolute --&gt; 100 c.value --&gt; 100.0 setControllerValue c -10 true #relative --&gt; -10 c.value --&gt; 90.0</p>\n\
<p>sliderTime = 0 --make sure the time slider is on frame 0 --&gt; 0 select b --select the box --&gt; OK max modify mode --show the box in the modify panel --&gt; OK</p>\n\
<p>--Try to set an animation key with value 90+50=140 on frame 50 with the third argument set to false with animate on at time 100 setControllerValue c 50 false #relative --&gt; 50 c.keys --there are no keys created, and the box is now 140 units tall --&gt; #keys() c.value --&gt; 140</p>\n\
<p>--Now let&#39;s set the third argument to true to create animation keys: with animate on at time 100 setControllerValue c -40 true #relative --&gt; -40</p>\n\
<p>--Checking the keys, the first key has the previous controller value 140 on frame 0 --The second key has the new value of 100 at frame 100: for k in c.keys do format &quot;% = %\\n&quot; k (k.value) --&gt; #Bezier Float key(1 @ 0f) = 140.0 --&gt; #Bezier Float key(2 @ 100f) = 100.0</p>\n\
<p>sliderTime = 100<br> --Now let&#39;s try to temporarily modify the second key on frame 100 to an absolute value of 200: with animate on at time 100 setControllerValue c 200 false #absolute --&gt; 200 --The command panel shows Height: 200.0 on frame 50, however --checking the keys, they still show the original values of 140.0 and 100.0: for k in c.keys do format &quot;% = %\\n&quot; k (k.value) --&gt; #Bezier Float key(1 @ 0f) = 140.0 --&gt; #Bezier Float key(2 @ 100f) = 100.0 sliderTime -= 1 --&gt; 49 sliderTime += 1 --&gt; 50 --At this point, the Modify Panel will show 100.0 again, as the uncommited value was reset back.</p>\n\
<p>--Let&#39;s do this again, but this time we will commit after the change: with animate on at time 100 setControllerValue c 200 false #absolute --&gt; 200 CommitControllerValue c --commit the change --&gt; OK --At this point, moving the time slider will not reset the new value anymore, it is committed to 200.0. --But in addition, the first key on frame 0 was also shifted to 240.0! for k in c.keys do format &quot;% = %\\n&quot; k (k.value) --&gt; #Bezier Float key(1 @ 0f) = 240.0 --&gt; #Bezier Float key(2 @ 100f) = 200.0</p>\n\
<p>with animate on at time 50 setControllerValue c 42 true #absolute --&gt; 42 sliderTime = 50 --&gt; 50 with animate on at time 50 setControllerValue c 24 false #absolute --&gt; 24 RestoreControllerValue c --we take back the change internally, but the Modify Panel still shows 42.0 --&gt; OK CommitControllerValue c --try to commit the change of 24.0 to the key and shift the whole animation curve --&gt; OK sliderTime = 49 --&gt; 49 sliderTime = 50 --&gt; 50 --Since we restored the controller value before the commit, the value at frame 50 remains 42 and is not shifted to 24. --The same is true for all other keys: for k in c.keys do format &quot;% = %\\n&quot; k (k.value) --&gt; #Bezier Float key(1 @ 0f) = 240.0 --&gt; #Bezier Float key(2 @ 50f) = 42.0 --&gt; #Bezier Float key(3 @ 100f) = 200.0</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";