var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>List Controllers</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>List Controllers</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"list-controllers\"></a></div>\n\
<div class=\'codeBlock\'><pre>float_list : floatController\n\
point3_list : point3Controller\n\
position_list : positionController\n\
rotation_list : rotationController\n\
scale_list : scaleController\n\
</pre></div><p><strong>Constructor</strong></p>\n\
<div class=\'codeBlock\'><pre>float_list ... point3_list ... position_list ... rotation_list ... scale_list ... \n\
</pre></div><p>The List controller combines multiple controllers into a single effect. It is a compound controller with tools for managing the order in which its internal controllers are calculated. Controllers are evaluated in a top to bottom order; the controller at the top of the list is evaluated first. The contribution of the single sub-controllers can be weighted allowing for animation mixing.</p>\n\
<p>When you assign a List controller to a parameter, the current controller is moved one level below the List controller; it becomes the first controller in the list. A second parameter is added below the List controller and is named Available. This is an empty placeholder for the next controller you add to the list.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>.weight ArrayParameter default: #() -- float array   \n\
</pre></div><p>An array of the weight values of the sub-controllers.</p>\n\
<div class=\'codeBlock\'><pre>.average Boolean default: false -- boolean; Average_Weights \n\
</pre></div><p>Controls the averaging of the Weights.</p>\n\
<div class=\'codeBlock\'><pre>.available \n\
</pre></div><p>The <span class=\'code\'>.available</span> property has a <span class=\'code\'>controller</span> property, which contains a &quot;phantom&quot; controller. To add a controller to a list controller, assign the controller to the <span class=\'code\'>available.controller</span> property. The following script shows an example of creating and adding controllers to a list controller.</p>\n\
<div class=\'codeBlock\'><pre>.&lt;subcontroller&gt;... \n\
</pre></div><p>The property list for a list controller also contains the sub-controllers in the list controller (if any). The type of these controllers depends on the type of the list controller. For example, a float_list can contain any number of bezier_float controllers.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` p=float_list ()-- create a list controller showproperties p-- show its properties p.available.controller-- the &quot;phantom&quot; controller p1=bezier_float ()-- create a new bezier float controller p.available.controller=p1-- add it to the list controller p2=bezier_float ()-- create a new bezier float controller p.available.controller=p2-- add it to the list controller getpropnames p-- show the list controller properties showproperties p-- show the list controller properties p.numSubs-- the number of list controller subAnims getsubanimnames p-- show the list controller subAnim names p[2].object-- retrieve the second bezier float controller</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT</strong></p>\n\
<p>``` Controller:Float_List-- result line 1 .weight : float array .average (Average_Weights) : boolean .available : float-- output line 2 false-- output line 2 Controller:-- result line 3 (the &quot;phantom&quot; controller) Controller:Bezier_Float-- result line 4 Controller:Bezier_Float-- result line 5 Controller:Bezier_Float-- result line 6 Controller:Bezier_Float-- result line 7 #(#weight, #average, #bezier_float, #available)-- result line 8 .weight : float array-- output line 9 .average (Average_Weights) : boolean-- output line 9 .bezier_float : float-- output line 9 .bezier_float : float-- output line 9 .available : float-- output line 9 false-- output line 9 4-- result line 10 #(#bezier_float, #bezier_float, #available, #Weights)-- result line 11 Controller:Bezier_Float-- result line 12 OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` lst = $.pos.controller-- if this is a list controller showInterfaces lst-- interface name is &quot;list&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>List Controllers Interfaces:</strong></p>\n\
<div class=\'codeBlock\'><pre>Interface:list \n\
</pre></div><p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>.count: integer : Read \n\
</pre></div><p>This property contains the number of items that appear in the List controllers list box.</p>\n\
<div class=\'codeBlock\'><pre>.active: index : Read|Write \n\
</pre></div><p>Gets/Sets the index of the currently active item.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;getCount () \n\
</pre></div><p>This method returns the number of items that appear in the List controllers list box.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;setActive &lt;index&gt;listIndex \n\
</pre></div><p>This method allows you to set the indexed item in the list active, so its parameters appear in the motion panel and any input is directed to the indexed sub controller.</p>\n\
<p><span class=\'code\'>&lt;index&gt;listIndex</span>: The index of the item to set as the active item.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;getActive ()\n\
</pre></div><p>This method returns the index of the currently active item.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;delete &lt;index&gt;listIndex \n\
</pre></div><p>This method allows you to delete the indexed sub controller from the list.</p>\n\
<p><span class=\'code\'>&lt;index&gt;listIndex</span>: The index of the item to delete from the list.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;cut &lt;index&gt;listIndex \n\
</pre></div><p>This method allows you to cut the index sub controller from the list and stores it in the buffer to paste later.</p>\n\
<p><span class=\'code\'>&lt;index&gt;listIndex:</span> The index of the item you wish to cut.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;paste &lt;index&gt;listIndex \n\
</pre></div><p>This method allows you to paste the sub-controller from the buffer into the indexed slot in the list.</p>\n\
<p><span class=\'code\'>&lt;index&gt;listIndex:</span> The index of the slot to paste into.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;getName &lt;index&gt;listIndex \n\
</pre></div><p>This method returns the class name of the indexed sub-controller if a user defined name does not exist.</p>\n\
<p><span class=\'code\'>&lt;index&gt;listIndex:</span> The index of the item for which to get the name.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;setName &lt;index&gt;listIndex&lt;string&gt;name \n\
</pre></div><p>This method allows you to set the name of an indexed item.</p>\n\
<p><span class=\'code\'>&lt;index&gt;listIndex:</span> The index of the item.</p>\n\
<p><span class=\'code\'>&lt;string&gt;name:</span> The name to set it to.</p>\n\
<p>See also Class IlistControl in the SDK Help file accompanying this product.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` b = Box lengthsegs:1 widthsegs:1 heightsegs:1 length:65.7611 width:32.0211 height:39.8261 pos:[-15.6972,-84.9615,0] isSelected:on b.pos.controller = position_list () b.pos.controller.Available.controller = Position_XYZ () b.pos.controller.Available.controller = tcb_position () b.pos.controller.Available.controller = bezier_position () lst = b.pos.controller-- the list controller showInterfaces lst-- interface name is &quot;list&quot; lst.getCount()-- count function lst.count-- count property (read only) lst.SetActive 3-- set active function lst.GetActive()-- get active function lst.active-- active property lst.cut 2-- cut the second sub-controller lst.paste 1-- paste it to the top of the list lst.delete lst.count-- delete the second to last sub-controller lst.setName 2 &quot;My Bezier&quot;-- sets the name of the second sub-controller lst.getName 2-- gets the name of the sub-controller</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>ListCtrl Methods</strong></p>\n\
<p>The following methods were available in <strong>3ds Max prior to version 4</strong>. They are still supported for backwards compatibility, but their functionality is covered by the new methods described above.</p>\n\
<div class=\'codeBlock\'><pre>listCtrl.getName &lt;list_controller&gt; &lt;index_integer&gt; \n\
</pre></div><p>Returns the name of the indexed subcontroller in the list controller.</p>\n\
<div class=\'codeBlock\'><pre>listCtrl.setName &lt;list_controller&gt; &lt;index_integer&gt; &lt;string&gt; \n\
</pre></div><p>Sets the name of the indexed subcontroller in the list controller. If the string is a null string (&quot;&quot;), the default controller name is used.</p>\n\
<div class=\'codeBlock\'><pre>listCtrl.getActive &lt;list_controller&gt; \n\
</pre></div><p>Returns the index of the active subcontroller in the list controller.</p>\n\
<div class=\'codeBlock\'><pre>listCtrl.setActive &lt;list_controller&gt; &lt;index_integer&gt; \n\
</pre></div><p>Sets the indexed subcontroller in the list controller as the active controller.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";