var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>IK_ControllerMatrix3Controller : Matrix3Controller</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>IK_ControllerMatrix3Controller : Matrix3Controller</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"ik_controllermatrix3controller-matrix3controller\"></a></div>\n\
<p>The functions described in this topic provide access to some of the Inverse Kinematics (IK) parameters of the IK controller. The IK controller is typically used by the Bones system in <strong>3ds Max</strong>. You cannot create a Bones system using MAXScript in <strong>3ds Max 3</strong>, but these methods provide access to the IK controller for existing Bones systems. An IK system actually consists of two types of controllers - the driver IK controller and driven IK controllers. The driven IK controllers are used as the transform controller for all nodes in the IK system, and the driver IK controller controls the individual driven IK controllers.</p>\n\
<p>All the IK-related methods are in the <span class=\'code\'>ik</span> structure and are associated with a parameter in the Motion panel, IK Controller Parameters rollout. These functions return <span class=\'code\'>undefined</span> if executed on an object whose controller is not an IK controller. The controller actually being accessed in these methods is the driver IK controller. Accessing the IK controller for any object in the IK system accesses the same driver IK controller.</p>\n\
<p>Note:</p>\n\
<p>The following ik structure methods are still present, but <span class=\'code\'>not applicable</span> in <strong>3ds Max 4 and higher</strong>.</p>\n\
<p>Getting/setting via these methods return a value of &#39;undefined&#39;:</p>\n\
<p><span class=\'code\'>GetRotThreshold</span></p>\n\
<p><span class=\'code\'>SetRotThreshold</span></p>\n\
<p><span class=\'code\'>GetPosThreshold</span></p>\n\
<p><span class=\'code\'>SetPosThreshold</span></p>\n\
<p><span class=\'code\'>GetIterations</span></p>\n\
<p><span class=\'code\'>SetIterations</span></p>\n\
<div class=\'codeBlock\'><pre>ik.GetPosThreshold &lt;node&gt;       \n\
ik.SetPosThreshold &lt;node&gt; &lt;float&gt;    \n\
</pre></div><p>Get and set the Position threshold value for the specified object.</p>\n\
<div class=\'codeBlock\'><pre>ik.GetRotThreshold &lt;node&gt;    \n\
ik.SetPosThreshold &lt;node&gt; &lt;float&gt;   \n\
</pre></div><p>Get and set the Rotation threshold value for the specified object.</p>\n\
<div class=\'codeBlock\'><pre>ik.GetIterations &lt;node&gt;   \n\
ik.SetIterations &lt;node&gt; &lt;integer&gt; \n\
</pre></div><p>Get and set the Iterations value for the specified object.</p>\n\
<div class=\'codeBlock\'><pre>ik.GetStartTime &lt;node&gt; \n\
ik.SetStartTime &lt;node&gt; &lt;time&gt; \n\
</pre></div><p>Get and set the Start time for the specified object</p>\n\
<div class=\'codeBlock\'><pre>ik.GetEndTime &lt;node&gt; \n\
ik.SetEndTime &lt;node&gt; &lt;time&gt; \n\
</pre></div><p>Get and set the End time for the specified object</p>\n\
<div class=\'codeBlock\'><pre>ik.getPinNode &lt;node&gt; \n\
</pre></div><p>Gets the node the specified node is bound to in the IK panel as a <span class=\'code\'>&lt;node&gt;</span> value, undefined if none.</p>\n\
<div class=\'codeBlock\'><pre>ik.setPinNode &lt;node&gt; (&lt;node&gt; | undefined) \n\
</pre></div><p>Sets the node the specified node is bound to in the IK panel. If undefined is specified, the node is unbound. Returns true if the bind was successful, false otherwise.</p>\n\
<div class=\'codeBlock\'><pre>ik.getPrecedence &lt;node&gt; \n\
</pre></div><p>Gets the precedence of the node as specified in the IK panel as an <span class=\'code\'>&lt;integer&gt;</span> value</p>\n\
<div class=\'codeBlock\'><pre>ik.setPrecedence &lt;node&gt; &lt;number&gt; \n\
</pre></div><p>Sets the precedence of the node as specified in the IK panel. Returns true if the assignment was successful, false otherwise.</p>\n\
<div class=\'codeBlock\'><pre>ik.getIsTerminator &lt;node&gt; \n\
ik.setIsTerminator &lt;node&gt; &lt;boolean&gt; \n\
</pre></div><p>Get/set whether the node is a terminator.</p>\n\
<div class=\'codeBlock\'><pre>ik.getBindPos &lt;node&gt; \n\
ik.setBindPos &lt;node&gt; &lt;boolean&gt; \n\
</pre></div><p>Get/set whether Bind Position is turned on for the node.</p>\n\
<div class=\'codeBlock\'><pre>ik.getBindOrient &lt;node&gt; \n\
ik.setBindOrient &lt;node&gt; &lt;boolean&gt; \n\
</pre></div><p>Get/set whether Bind Orientation is turned on for the node.</p>\n\
<div class=\'codeBlock\'><pre>ik.getAxisActive {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} \n\
ik.setAxisActive {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} &lt;bitarray&gt; \n\
</pre></div><p>Get/Set whether each axis is active as a 3 bit bitarray.Available in <strong>3ds Max 2008 and higher</strong>. Previously available in the free <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>ik.getAxisLimit {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} \n\
ik.setAxisLimit {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} &lt;bitarray&gt; \n\
</pre></div><p>Get/Set whether each axis is limitted as a 3 bit bitarray.Available in <strong>3ds Max 2008 and higher</strong>. Previously available in the free <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>ik.getAxisEase {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} \n\
ik.setAxisEase {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} &lt;bitarray&gt; \n\
</pre></div><p>Get/Set whether each axis is eased as a 3 bit bitarray.Available in <strong>3ds Max 2008 and higher</strong>. Previously available in the free <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>ik.getAxisMin {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} \n\
ik.setAxisMin {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} &lt;point3&gt; \n\
</pre></div><p>Get/Set min value for each axis as a Point3.Available in <strong>3ds Max 2008 and higher</strong>. Previously available in the free <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>ik.getAxisMax {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} \n\
ik.setAxisMax {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} &lt;point3&gt; \n\
</pre></div><p>Get/Set max value for each axis as a Point3.Available in <strong>3ds Max 2008 and higher</strong>. Previously available in the free <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>ik.getAxisDamping {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} \n\
ik.setAxisDamping {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} &lt;point3&gt; \n\
</pre></div><p>Get/Set damping value for each axis as a Point3.Available in <strong>3ds Max 2008 and higher</strong>. Previously available in the free <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>ik.getAxisPreferredAngle {&lt;node&gt; | &lt;controller&gt;} \n\
ik.setAxisPreferredAngle {&lt;node&gt; | &lt;controller&gt;} &lt;point3&gt; \n\
</pre></div><p>Get/Set preferred angle for each axis as a Point3.Available in 3ds Max 2008 and higher. Previously available in the free <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>ik.getAxisSpringOn {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} \n\
ik.setAxisSpringOn{&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} &lt;bitarray&gt; \n\
</pre></div><p>Get/Set whether spring is on for each axis as a 3 bit bitarray.Available in <strong>3ds Max 2008 and higher</strong>. Previously available in the free <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>ik.getAxisSpring {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} \n\
ik.setAxisSpring {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} &lt;point3&gt; \n\
</pre></div><p>Get/Set spring value for each axis as a Point3.Available in <strong>3ds Max 2008 and higher</strong>. Previously available in the free <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>ik.getAxisSpringTension {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} \n\
ik.setAxisSpringTension {&lt;node&gt; | &lt;controller&gt;} {#rotational | #sliding} &lt;point3&gt; \n\
</pre></div><p>Get/Set spring tension for each axis as a Point3.Available in <strong>3ds Max 2008 and higher</strong>. Previously available in the free <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<p>Note:</p>\n\
<p>For those controllers that don&#39;t support IK parameters via the access method used for these methods, a value of undefined is returned.</p>\n\
<p>IK controllers do not support the access method used, but access is provided as properties of the IK controller.</p>\n\
<p>If a node is specified, the node&#39;s transform controller is used.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";