var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Retimer : Controller</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Retimer : Controller</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"retimer-controller\"></a></div>\n\
<p>The Retimer Controller was introduced in <strong>3ds Max 2013</strong> as an alternative procedural EaseCurve controller.</p>\n\
<p>It can be used in the EaseCurve track of any controller or as a Global Retimer Controller affecting the whole scene, accessible through the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/R/Interface-RetimerMan.html\' title=\'\'>Interface: RetimerMan</a>.</p>\n\
<div class=\'section\'><a id=\"interface-retimer\"></a><h2 id=\"interface-retimer\">Interface: retimer</h2></div>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;RetimerController&gt;.numMarkers : integer : Read\n\
</pre></div><p>Contains the number of markers in the Retimer controller.</p>\n\
<p>Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;RetimerController&gt;.numSpans : integer : Read\n\
</pre></div><p>Contains the number of spans in the Retimer controller.</p>\n\
<p>The spans are the ranges between markers. Thus, two markers define one span.</p>\n\
<p>Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;RetimerController&gt;.active : boolean : Read|Write\n\
</pre></div><p>Get/set the active state of the Retimer controller.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;RetimerController&gt;.SetNewMarker &lt;time&gt;time\n\
</pre></div><p>Creates a new Marker at the specified time.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;RetimerController&gt;.ExpandMarker &lt;time&gt;time &lt;time&gt;newTime\n\
</pre></div><p>Expands the Marker from the time specified by the first argument to the new time specified by the second argument.</p>\n\
<p>There must be a marker at the time specified by the first argument.</p>\n\
<p>Expanding is the process of moving a marker from its original time to a new time, thus producing a retiming curve.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;RetimerController&gt;.MoveMarker &lt;time&gt;time &lt;time&gt;newTime\n\
</pre></div><p>Moves the Marker from the time specified by the first argument to the new time specified by the second argument.</p>\n\
<p>Moving a Marker changes its original position before expanding (and thus retiming) the animation.</p>\n\
<p>In other words, it adjusts the initial placement of the marker as opposed to moving the marker for retiming purposes.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;RetimerController&gt;.RemoveMarker &lt;time&gt;time\n\
</pre></div><p>Removes the Marker from the specified time.</p>\n\
<div class=\'codeBlock\'><pre>&lt;time by value array&gt;&lt;RetimerController&gt;.GetMarkerTimes()\n\
</pre></div><p>Returns an array of all Marker times.</p>\n\
<p>This is the list of the original positions of the markers before expanding them to produce animation retiming.</p>\n\
<div class=\'codeBlock\'><pre>&lt;time by value array&gt;&lt;RetimerController&gt;.GetExpandedMarkerTimes()\n\
</pre></div><p>Returns an array of all expanded Marker times.</p>\n\
<p>This is the list of the new positions of the markers that cause the retiming of the animation.</p>\n\
<div class=\'codeBlock\'><pre>&lt;enum&gt;&lt;RetimerController&gt;.GetSpanType &lt;index&gt;index\n\
\n\
GetSpanType enums: {#linear|#easeIn|#easeOut}\n\
</pre></div><p>Returns the type of the indexed Span.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;RetimerController&gt;.SetSpanType &lt;index&gt;index &lt;enum&gt;type\n\
\n\
type enums: {#linear|#easeIn|#easeOut}\n\
</pre></div><p>Sets the Type of the indexed Span to the name value provided by the second argument.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;&lt;RetimerController&gt;.GetSpanLocked &lt;index&gt;index\n\
</pre></div><p>Returns the locked state of the indexed Span as a boolean value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;RetimerController&gt;.SetSpanLocked &lt;index&gt;index &lt;boolean&gt;type\n\
</pre></div><p>Sets the locked state of the indexed Span to the boolean value provided by the second argument.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` t = teapot() --create a teapot --&gt; $Teapot:Teapot001 @ [0.000000,0.000000,0.000000] with animate on at time 100 t.pos = [200,0,0] --animate it 200 units along X over 100 frames --&gt; [200,0,0]<br> rtc =RetimerMan.GetGlobalRetimer() --get the retimer controller --&gt; Controller:Retimer addEaseCurve t.pos.controller[1].controller rtc --add the retimer as Ease Curve --&gt; OK rtc.numMarkers --check the number of markers --&gt; 0 rtc.SetNewMarker 30f --add a new marker on frame 30 --&gt; OK rtc.SetNewMarker 50f --and another one on frame 50 --&gt; OK rtc.MoveMarker 30f 20f --changed my mind, I want it on 20, not 30 --&gt; OK rtc.ExpandMarker 50f 80f --now let&#39;s retime by stretching the range 20 to 50 by 30 frames --&gt; OK rtc.GetMarkerTimes() --here are the original marker times --&gt; #(20f, 50f) rtc.GetExpandedMarkerTimes() --and the new retimed marker times --&gt; #(20f, 80f) rtc.numMarkers --now we have two markers --&gt; 2 rtc.numSpans --and we have one span between them --&gt; 1 rtc.GetSpanType 1 --let&#39;s check its type --&gt; #linear rtc.SetSpanType 1 #easeOut --we can change it to slow down over time --&gt; OK rtc.SetNewMarker 90f --but this gives us a jump on frame 80, so let&#39;s add another marker on 90 --&gt; OK rtc.SetSpanType 2 #easeIn --and set it to ease in to smooth it out --&gt; OK rtc.GetSpanLocked 1 --let&#39;s check if the first span is locked --&gt; false rtc.SetSpanLocked 1 true --and lock it --&gt; OK rtc.RemoveMarker 20f --we could remove the first marker just to show we can --&gt; OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";