var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Script Controllers</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Script Controllers</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"script-controllers\"></a></div>\n\
<div class=\'codeBlock\'><pre>float_script : floatController  point3_script : point3Controller position_script : positionController rotation_script : rotationController scale_script : scaleController \n\
</pre></div><p><strong>Constructor</strong></p>\n\
<div class=\'codeBlock\'><pre>float_script ... point3_script ... position_script ... rotation_script ... scale_script ... \n\
</pre></div><p>Script controllers have been significantly enhanced in <strong>3ds Max 8</strong>. See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Types/Script-Controllers/Using-Script-Controllers.html\' title=\'\'>Using Script Controllers</a> for details on the changes.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;script_controller&gt;.script String default: varies \n\
</pre></div><p>Lets you programmatically get and set the expression text of a script controller.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Types/Script-Controllers/Script-Controller-Assignment.html\' title=\'\'>Script Controller Assignment Behavior Changes in 3ds Max 8</a> for some history notes on the changes introduced to this property&#39;s behavior in <strong>3ds Max 8</strong>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` obj = Box ()--create a box obj.position.controller=position_script ()--assign position script obj.position.controller.script =&quot;[F,0,0]&quot;--set the expression --The box will move one unit per frame along X since --the internal controller variable F contains the current frame</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;script_controller&gt;.ThrowOnError Bool default:true \n\
</pre></div><p>Controls whether to throw when an error occurs in the expression.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<p>Note:</p>\n\
<p>There is a <strong>discontinuity</strong> between the MAXScript Debugger window, getting variable values using the Function Publishing System, and evaluating the script controller.</p>\n\
<ul>\n\
<li><p>When working with the Debugger dialog, variable values are shown based on the current slider time.</p></li>\n\
<li><p>When accessed using the Function Publishing System, the variable values returned are based on the current MXS time.</p></li>\n\
<li><p>When evaluating the controller, the result is based on the current time value as well as the range of the controller, Out-Of-Range Type set for the controller, and any Ease curves applied to the controller.</p></li>\n\
</ul>\n\
<p>This means that while &#39;NT&#39; might show one value in the Debugger dialog, its value in the evaluation might be different.</p>\n\
<p><strong>Interfaces:</strong></p>\n\
<p>All script controllers expose the <strong>IScriptCtrl</strong> Interface since <strong>3ds Max 8</strong>.</p>\n\
<p>This interface provides methods to access the controller through MAXScript.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-FB9F9A3F-5F3C-4EA4-BB04-B40275958E3E-low.gif\' title=\'\'></div>\n\
<div class=\'section\'><a id=\"interface-iscriptctrl\"></a><h2 id=\"interface-iscriptctrl\">Interface: IScriptCtrl</h2></div>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'section\'><a id=\"user-defined-variables\"></a><h2 id=\"user-defined-variables\">User-Defined Variables</h2></div>\n\
<p>A script controller supports four types of user-defined variables: Constant, Target, Object, and Node. The main difference between these variables is the type of value or reference they contain, which in turn determines the type of notification messages that will cause an update of the script controller.</p>\n\
<p>Note that in the Script Controller UI, the creation of the variable and the assignment of the value is performed in two separate steps (the Create button always creates a Constant Variable with a value of 0) while in MAXScript, the creation and assignment are performed in a single step.</p>\n\
<div class=\'section\'><a id=\"constant-variable\"></a><h3 id=\"constant-variable\">Constant Variable</h3></div>\n\
<p>A constant variable can contain a constant value.</p>\n\
<p>The MAXScript Expression assigned to the variable will be evaluated and if the return value is a constant, it will be used as the value of the variable. The constant variable creates no dependencies on other objects.</p>\n\
<p>If the expression evaluates to a <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXWrapper-Value/MAXWrapper-Value-1.html\' title=\'\'>MAXWrapper</a> (such as, a node, material, modifier, controller, and others), the result will be stored in an Object variable and will be updated dynamically. In other words, the <span class=\'code\'>.addConstant()</span> method will behave like <a href=\'Script-Controllers-1.html#objectvariable\' title=\'\'>the .addObject() method</a> and the resulting variable will not be a Constant variable, but an Object variable.</p>\n\
<p>If the result of the expression evaluation is a subAnim, it will be stored as a Target variable. In other words, in this case <span class=\'code\'>.addConstant()</span> will behave like <a href=\'Script-Controllers-1.html#target--track--variable\' title=\'\'>the .addTarget() method</a>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;AddConstant &lt;string&gt;Name &lt;value&gt;Constant\n\
</pre></div><p>Adds a constant variable to the controller. Corresponds to the &quot;Create&quot; and&quot;Assign Constant&quot; buttons in the Script Controller UI.</p>\n\
<p>A constant variable returns the value of the MAXScript expression assigned to it. The expression can be any valid MAXScript expression that evaluates to a value.</p>\n\
<p>The first argument is the name of the constant variable.</p>\n\
<p>The second argument is the expression to be assigned to the variable.</p>\n\
<p>Returns true on success, false on failure.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SetConstant &lt;value&gt;Which &lt;value&gt;Constant\n\
</pre></div><p>Sets the constant variable value.</p>\n\
<p>The first argument is either the name of the variable as string, or the index of the variable as integer.</p>\n\
<p>The second argument is the MAXScript expression providing the value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;value&gt;GetConstant &lt;value&gt;Which \n\
</pre></div><p>Returns the value of the expression assigned to the constant variable specified by name or index.</p>\n\
<p>Throws a Runtime error if the variable name does not exist or the variable does exist, but is not a constant variable.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` obj = Teapot () --&gt;$Teapot:Teapot01 @ [0.000000,0.000000,0.000000] obj.scale.controller=scale_script () --&gt;Controller:Scale_Script obj.scale.controller.addConstant &quot;test&quot; (pi*2) --&gt;true obj.scale.controller.getValue&quot;test&quot; --&gt;6.28319 obj.scale.controller.getValue&quot;test2&quot; -- Runtime error: IScriptCtrl::GetVarValue - Bad Index or name: &quot;test2&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"target-track-variable\"></a><h3 id=\"target-track-variable\">Target (Track) Variable</h3></div>\n\
<p>A target variable contains a reference to a subAnim Track.</p>\n\
<p>The script controller will be updated when a notification about subAnim changes is sent. For example, if a target variable contains a reference to the Angle subAnim of a Bend Modifier applied to a Teapot, changing any subAnim of the Teapot or Bend Modifier will cause an update of the script controller, including changing the Bend Angle, Teapot Radius, and others.</p>\n\
<p>Transformations of the Node will not cause an update of the script controller unless the Node track itself or a transform track is selected as the reference.</p>\n\
<p>While it is allowed to assign the Node as the subAnim to be stored in the variable, this will be highly inefficient since any change to any of the subAnims of the referenced node will cause an update of the controller. Use the <a href=\'Script-Controllers-1.html#node-variable\' title=\'\'>Node Variable</a> to make a dependency on a Node instead.</p>\n\
<p>See Also <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Types/Script-Controllers/Referencing-Nodes-and.html\' title=\'\'>Referencing Nodes and Controllers in Script Controllers FAQ</a> for more details.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;AddTarget &lt;string&gt;Name &lt;value&gt;Target Offset:&lt;time&gt; Owner:&lt;value&gt;\n\
       Offset default value: 0f\n\
       Owner default value: undefined\n\
</pre></div><p>Adds a target variable to the controller. Corresponds to the &quot;Create&quot; and &quot;Assign Track&quot; buttons in the Script Controller UI.</p>\n\
<p>The first argument is the name of the target variable.</p>\n\
<p>The second argument is the Track value to be assigned to the target variable.</p>\n\
<p>The optional <span class=\'code\'>Offset:</span> keyword can be used to define a time offset.</p>\n\
<p>The optional <span class=\'code\'>Owner:</span> keyword argument can be used to define the owner of the Track.</p>\n\
<p>Returns true on success, false on failure.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SetTarget &lt;value&gt;Which &lt;value&gt;Target Owner:&lt;value&gt; \n\
\n\
Owner default value: undefined \n\
</pre></div><p>Sets a target variable specified by name or index in the first argument to the target (subAnimtrack) value specified by the second argument. Corresponds to the &quot;Assign Track&quot; buttons in the Script Controller UI.</p>\n\
<p>The optional <span class=\'code\'>Owner:</span> keyword argument can be used to define the owner of the subAnim track.</p>\n\
<p>Returns true on success, false on failure.</p>\n\
<div class=\'codeBlock\'><pre>&lt;value&gt;GetTarget &lt;value&gt;Which asObject:&lt;boolean&gt; \n\
\n\
asObject default value: false \n\
</pre></div><p>Returns the reference target stored in the target variable specified by name or index in the first argument.</p>\n\
<p>If the optional <span class=\'code\'>asObject:</span> keyword argument is supplied and is true, the return value will be converted from a subAnim to a MAXObject.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` obj1 = Teapot ()--Create a teapot --&gt;\\(Teapot:Teapot001 @ [0.000000,0.000000,0.000000]  obj2 = instance obj1--Create an instance  --&gt;\\)Teapot:Teapot002 @ [0.000000,0.000000,0.000000] obj2.pos = [-100,0,0]--Place the instance 100 units along -X --&gt;[-100,0,0] obj3 = Box pos:[100,0,0]--Create abox 100 units long X --&gt; $Box:Box001 @ [100.000000,0.000000,0.000000] ctrl = float_script()--Create aFloat Script Controller --&gt;Controller:Float_Script obj3.height.controller = ctrl--Assign Controller to Height of Box --&gt;Controller:Float_Script ctrl.addTarget &quot;myTeapot&quot; obj1[4]--Add Target Var. with Teapot Obj. --&gt;true ctrl.setExpression &quot;myTeapot.Radius&quot;--Set Height to Teapot Radius --&gt;true ctrl.getTarget &quot;myTeapot&quot;--Get the Target Track as SubAnim value --&gt;SubAnim:Object__Teapot ctrl.getTarget &quot;myTeapot&quot; asObject:true--Get as Object --&gt;Teapot ctrl.PrintDetails()--Print the controller details --&gt;&quot;** Script Control Details ** --&gt;* Description: --&gt;(null) --&gt;* Expression: --&gt;myTeapot.Radius --&gt;* Variables --&gt;Members: 5 --&gt;01) T, Constant = 16000.0 --&gt;02) S, Constant = 3.33333 --&gt;03) F, Constant = 100.0 --&gt;04) NT, Constant = 1.0 --&gt;05) myTeapot, Track: $Teapot001.&#39;Object (Teapot)&#39;, tick offset = 0 --&gt;&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"objectvariable\"></a><h3 id=\"objectvariable\">ObjectVariable</h3></div>\n\
<p>An object variable can hold a <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXWrapper-Value/MAXWrapper-Value-1.html\' title=\'\'>MAXWrapper value</a> including Animation Controller, Base Object, Modifier, Material, Scene Node, and others.</p>\n\
<p>Most subAnim tracks in <strong>3ds Max</strong> do not have a controller assigned by default. A controller is assigned automatically when a keyframe animation is first created or can be assigned manually using TrackView or MAXScript. Thus, the object variable can only hold a reference to an existing animation controller and cannot reference parameter subAnim tracks without a controller. For creating a reference to a subAnim, use the <a href=\'Script-Controllers-1.html#target--track--variable\' title=\'\'>Target Variable</a> instead.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;AddObject &lt;string&gt;Name &lt;value&gt;Object\n\
</pre></div><p>Adds an object variable to the script controller. Corresponds to the &quot;Create&quot; and &quot;Assign Controller&quot; buttons in the Script Controller UI.</p>\n\
<p>The first argument is the name of the object variable.</p>\n\
<p>The second argument is the Controller to be assigned to the object variable.</p>\n\
<p>Returns true on success, false on failure.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SetObject &lt;value&gt;Which &lt;value&gt;Object \n\
</pre></div><p>Sets the object variable specified by name or index in the first argument to the controller object value specified by the second argument.</p>\n\
<p>Returns true on success, false on failure.</p>\n\
<div class=\'codeBlock\'><pre>&lt;maxObject&gt;GetObject &lt;value&gt;Which \n\
</pre></div><p>Returns the controller object referenced by the object variable specified by name or index in the first argument.</p>\n\
<div class=\'section\'><a id=\"node-variable\"></a><h3 id=\"node-variable\">Node Variable</h3></div>\n\
<p>A node variable can hold a reference to a Scene Node only.</p>\n\
<p>The script controller will be updated only when the node is changed, including changes to its Position, Rotation, and Scale transforms and deletion of the node.Changes to the object attached to the node or its sub-anims will NOT cause an update of the script controller.</p>\n\
<p>This variable type is very useful for accessing data from the object the script controller is assigned to without causing circular dependency problems. See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Types/Script-Controllers/Script-Controller-Avoiding.html\' title=\'\'>Script Controller - Avoiding Circular Dependency</a> for details.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;AddNode &lt;string&gt;Name &lt;node&gt;Node\n\
</pre></div><p>Adds a node variable to the controller. Corresponds to the &quot;Create&quot; and &quot;Add Node&quot; buttons in the Script Controller UI.</p>\n\
<p>A node variable contains a reference to a scene node. Since the reference is name-independent, changing the name of the node stored in the variable does not affect the functioning of the script controller.</p>\n\
<p>The first argument is the name of the node variable.</p>\n\
<p>The second argument is the scene node to be assigned to the variable.</p>\n\
<p>Returns true on success, false on failure.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SetNode &lt;value&gt;Which &lt;node&gt;Node \n\
</pre></div><p>Sets a given node variable to the specified scene node value. Returns true on success, false on failure.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;GetNode &lt;value&gt;Which \n\
</pre></div><p>Returns the scene node value stored in the specified node variable.</p>\n\
<div class=\'section\'><a id=\"delete-variable\"></a><h3 id=\"delete-variable\">Delete Variable</h3></div>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;DeleteVariable &lt;value&gt;Which \n\
</pre></div><p>Deletes the user-defined variable specified by name or index.</p>\n\
<p>Variables with index 1 to 4 are read-only and cannot be deleted - a Runtime error will be thrown if such an attempt is made. See <span class=\'code\'>.NumVariables()</span> method documentation below for details. Thus, the argument must be either an index greater than four or a name of an existing user-defined variable.</p>\n\
<p>Returns true on success, false on failure.</p>\n\
<div class=\'section\'><a id=\"general-variable-access\"></a><h2 id=\"general-variable-access\">General Variable Access</h2></div>\n\
<div class=\'section\'><a id=\"variableinspector-methods\"></a><h3 id=\"variableinspector-methods\">VariableInspector Methods</h3></div>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;NumVariables () \n\
</pre></div><p>Returns the number of variables defined in the controller.</p>\n\
<p>A default controller with no user-defined variables already provides four pre-defined variables for time access:</p>\n\
<p>1 - <strong>T</strong>, Current Time In <strong>T</strong>icks, Constant</p>\n\
<p>2 - <strong>S</strong>, Current Time In <strong>S</strong>econds, Constant</p>\n\
<p>3 - <strong>F</strong>, Current Time in <strong>F</strong>rames, Constant</p>\n\
<p>4 - <strong>NT</strong>, Current <strong>N</strong>ormalized <strong>T</strong>ime, Constant</p>\n\
<p>User-defined variables generally have an index higher than four.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;VariableExists &lt;string&gt;Name\n\
</pre></div><p>Returns true if the given variable name exists in the controller, false if it does not exist.</p>\n\
<div class=\'codeBlock\'><pre>&lt;enum&gt;GetType &lt;value&gt;Which \n\
\n\
GetType enums: {#unknown|#target|#constant|#object|#node} \n\
</pre></div><p>Returns the type of the variable specified by name or index.</p>\n\
<div class=\'section\'><a id=\"variable-name-and-index\"></a><h3 id=\"variable-name-and-index\">Variable Name and Index</h3></div>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;GetName &lt;index&gt;Index \n\
</pre></div><p>Returns the name of the indexed variable.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;RenameVariable &lt;value&gt;Which &lt;string&gt;Name \n\
</pre></div><p>Renames the variable specified by name or index in the first argument to the name specified by the second argument.</p>\n\
<p>Returns true on success, false on failure.</p>\n\
<div class=\'codeBlock\'><pre>&lt;index&gt;GetIndex &lt;string&gt;Name\n\
</pre></div><p>Returns the index of the variable specified by name.</p>\n\
<div class=\'section\'><a id=\"variable-value-access\"></a><h3 id=\"variable-value-access\">Variable Value Access</h3></div>\n\
<div class=\'codeBlock\'><pre>&lt;value&gt;GetValue &lt;value&gt;Which asObject:&lt;boolean&gt; \n\
\n\
asObject default value: false \n\
</pre></div><p>Returns the value stored in the specified variable.</p>\n\
<p>If the optional asObject argument is supplied as true, the return value will be converted to an object reference.</p>\n\
<div class=\'codeBlock\'><pre>&lt;value&gt;GetVarValue &lt;value&gt;Which \n\
</pre></div><p>Returns the value stored in the specified variable.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` obj = Teapot()--Create a teapot --&gt;$Teapot:Teapot001 @ [0.000000,0.000000,0.000000] obj.scale.controller = scale_script ()--Add a Scale Script Controller --&gt;Controller:Scale_Script obj.scale.controller.numVariables ()--Default Variables Count --&gt;4 obj.scale.controller.addConstant &quot;test&quot; (pi*2)--Add a Variable --&gt;true obj.scale.controller.variableExists &quot;test&quot;--See if it exists --&gt;true obj.scale.controller.variableExists &quot;someValue&quot; --This one does not --&gt;false obj.scale.controller.GetType &quot;test&quot; --Check Variable Type --&gt;#constant obj.scale.controller.numVariables ()--Check Variable Count --&gt;5 obj.scale.controller.getIndex &quot;test&quot; --Get the variable&#39;s index --&gt;5 obj.scale.controller.getName 5--Get the 5th variable&#39;s name --&gt;&quot;test&quot; sliderTime = 1f--Set the current scene time to frame 1 --&gt;1f obj.scale.controller.getValue 1--Time in Ticks --&gt;160.0 obj.scale.controller.getValue&quot;T&quot;--Time in Ticksaccessed by Name --&gt;160.0 obj.scale.controller.getValue 2--Time in Seconds --&gt;0.0333333 obj.scale.controller.getValue&quot;S&quot;--Time in Secondsaccessed by Name --&gt;0.0333333 obj.scale.controller.getValue 3--Time in Frames --&gt;1.0 obj.scale.controller.getValue&quot;F&quot;--Time in Framesaccessed by Name --&gt;1.0 obj.scale.controller.getValue 4--Normalized Time in Range 0-100 --&gt;0.01 obj.scale.controller.getValue&quot;NT&quot;--Normalized Timeby Name --&gt;0.01 obj.scale.controller.getValue 5--User Constant Variable --&gt;6.28319 obj.scale.controller.getValue&quot;test&quot;--User Constant by Name --&gt;6.28319 obj.scale.controller.getValue&quot;sunPos&quot;--User Constant by Name -- Runtime error: IScriptCtrl::GetVarValue - Bad Index or name: &quot;sunPos&quot; obj.scale.controller.renameVariable&quot;test&quot; &quot;someValue&quot;--Rename... --&gt;true obj.scale.controller.getValue&quot;someValue&quot;--User Constant by New Name --&gt;6.28319</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"variable-time-offset\"></a><h3 id=\"variable-time-offset\">Variable Time Offset</h3></div>\n\
<p>The Time Offset can be applied to any variable and defines the time context in which the variable will be evaluated. The default offset is 0. In other words, the value of a variable can be the same or different than the time at which the controller is being evaluated.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SetOffset &lt;value&gt;Which &lt;time&gt;Offset \n\
</pre></div><p>Sets the time offset of the variable specified by name or index to the given time value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;time&gt;GetOffset &lt;value&gt;Which \n\
</pre></div><p>Returns the offset time value of the specified variable.</p>\n\
<div class=\'section\'><a id=\"expression\"></a><h2 id=\"expression\">Expression</h2></div>\n\
<p>The Expression is the MAXScript Expression evaluated by the script controller to determine its final value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SetExpression &lt;string&gt;Expression\n\
</pre></div><p>Sets the expression string of the script controller to the string passed by-reference.</p>\n\
<p>Returns true on success, false otherwise.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;GetExpression () \n\
</pre></div><p>Returns the script controller&#39;s expression string.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;Update() \n\
</pre></div><p>Updates the controller by reevaluating its expression.</p>\n\
<div class=\'section\'><a id=\"description-and-details\"></a><h2 id=\"description-and-details\">Description and Details</h2></div>\n\
<p>The Description is a user-defined string value describing the features and functionality of the script to be read by other users of the 3ds Max scene containing the controller.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;GetDescription () \n\
</pre></div><p>Returns the description string.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SetDescription &lt;string&gt;Description\n\
</pre></div><p>Sets the description string.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;PrintDetails () \n\
</pre></div><p>Prints information about the script controller, including the description string, expression code, and variable details.</p>\n\
<p><strong>Related Examples</strong></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Practical-Questions/Working-with-Animation/How-do-I-keep-a-Plane-aligned-to.html\' title=\'\'>How do I keep a Plane aligned to 3 Point Helpers?</a></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Practical-Questions/Accessing-Object-Properties/How-do-I-change-the-text-in-a.html\' title=\'\'>How do I change the text in a Text Shape dynamically?</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";