var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Using Script Controllers</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Using Script Controllers</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"using-script-controllers\"></a></div>\n\
<p>Script controllers function in similar way to <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Types/Expression-Controllers.html\' title=\'\'>expression controllers</a>, providing a properties dialog in which a script can be entered that is used to compute the controller value. The primary advantages of script controllers are:</p>\n\
<ul>\n\
<li><p>They can use <strong>all the features of the MAXScript language</strong> including loops, scripted functions, pathnames, etc.</p></li>\n\
<li><p>Almost <strong>any property of any object in the scene</strong> can be used to help compute controller values, including things like mesh vertices, values of properties at arbitrary frame times, and other non-animatable properties that are not accessible in Expression controllers.</p>\n\
<p>Note: Mesh values, long strings and large bitArrays are not recommended for use in variables inside a script controller because they would <strong>use system memory</strong> and not MAXScript Heap memory and could cause Out Of Memory situations without ever getting garbage collected.</p></li>\n\
<li><p>They can use MAXScript <strong>global variables</strong> to communicate and coordinate with other controllers and scripts in <strong>3ds Max</strong>.</p></li>\n\
</ul>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-89308EDD-6E65-4335-A8B1-21625ACD453A-low.gif\' title=\'\'></div>\n\
<p>When you assign a Script controller to a parameter, a Properties dialog becomes available in Track View through the right-mouse-button menu or the Properties button on the Track View toolbar.</p>\n\
<p>The script controller dialog looks a lot like the expression controllers&#39; dialog. Both expression and script controllers now use the same code base and provide very similar features. The main difference is the language used to write the expressions.</p>\n\
<p>The new script controller dialog provides the following controls:</p>\n\
<p><strong>Create Variable group of controls:</strong></p>\n\
<ul>\n\
<li><p><strong>Name</strong> text field-lets you enter and edit the name of user variables.</p></li>\n\
<li><p><strong>Create button</strong> - used to create a variable. Enter the variable name in the Name field and press the button to add to the list of variables.</p></li>\n\
<li><p><strong>Delete button</strong> - used to delete a variable. Select an existing variable from the Variables list to get its name into the Name field OR type the name of the variable manually into the Name field, then press the Delete button.</p></li>\n\
<li><p><strong>Rename button</strong> - used to rename an existing variable. Select an existing variable from the Variables list to get its name into the Name field. Type the new name of the variable into the Name field, then press the Rename button.</p></li>\n\
</ul>\n\
<p><strong>Variable Parameters group of controls:</strong></p>\n\
<ul>\n\
<li><strong>Tick Offset value spinner</strong> - this value spinner can be used to specify a time offset in ticks for the current variable. Select a variable from the list and change the Tick Offset value - if the variable is assigned a Track, Controller or Node, (in other words it is not a Constant),when the script expression is evaluated, the variable&#39;s value will be taken from the current time plus the Tick Offset.</li>\n\
</ul>\n\
<p><strong>Variables:</strong></p>\n\
<ul>\n\
<li><p><strong>Variables list</strong> - lists all available variables in the controller. You can create any number of user variables as described above. The following pre-defined constant variables are available in every script controller and cannot be deleted or renamed:</p>\n\
<ul>\n\
<li><p><strong>F</strong> - the current time in frames.</p></li>\n\
<li><p><strong>NT</strong> - the normalized time. This variable contains the normalized time where t is the evaluation time and the time range is the range on scripted controller. The normalized time is clamped to 0-1 unless the controller&#39;s Out-of-Range Type is disabled.</p></li>\n\
<li><p><strong>S</strong> - the current time in seconds.</p></li>\n\
<li><p><strong>T</strong> - the current time in ticks.</p></li>\n\
</ul></li>\n\
<li><p><strong>Assign Constant</strong> - lets you assign a constant value to the selected variable. The constant value can be ANY MAXScript value, including integer, float, array, node etc. You can enter any valid MAXScript expression in the <strong>Value expression</strong> field. Then press the <strong>Evaluate</strong> button to evaluate the expression at the current time. Press OK to assign the <strong>value expression result</strong> to the variable, or Cancel to not assign a value. In the following screenshot, the constant value is an array containing the integer 1, the global constant value Pi and the position of the scene node Sphere01. The evaluated expression result contains only constant values - the integer 1 does not change, the float value of Pi is taken as the second array element, and the position of the Sphere01 at the current frame (at the moment of the evaluation) is taken as the third array element:<img src=\'developer/images/GUID-DC9816AC-E49B-4FBD-BDE1-45E2C2870A33-low.gif\' title=\'\'></p></li>\n\
<li><p><strong>Assign Track</strong> - lets you assign a subAnim track to the selected variable. For MAXScript methods related to this variable type, see <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Types/Script-Controllers/GUID-569BE1BC-216E-496F-9EDE-1E8D2DB42194.html#target--track--variable\' title=\'\'>Target (Track) Variables</a>.</p></li>\n\
<li><p><strong>Assign Controller</strong> - lets you assign a controller to the selected variable. The value of the controller will be taken at the current time plus the variable&#39;s Tick Offset. For MAXScript methods related to this variable type, see <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Types/Script-Controllers/GUID-569BE1BC-216E-496F-9EDE-1E8D2DB42194.html#objectvariable\' title=\'\'>Object(Controller) Variables</a></p></li>\n\
<li><p><strong>Assign Node</strong> - lets you assign a node reference to the selected variable. See Also <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Types/Script-Controllers/Weak-References-To-Nodes-in-the.html\' title=\'\'>Weak References To Nodes in the Expression/Script Controller</a></p></li>\n\
</ul>\n\
<p><strong>Expression text field</strong> - used to enter the script expression to calculate the controller value. See the section below on writing controller scripts for details.</p>\n\
<p><strong>Description text field</strong> - can be used to provide comments regarding the functionality of the controller.</p>\n\
<p><strong>Load/Save buttons</strong> - Load and save scripts to text files.</p>\n\
<p><strong>Evaluate button</strong> - Evaluates the script expression. The current time is used unless explicitly stated differently in the code using the at time context or when using controller variables with Tick Offset different than 0.</p>\n\
<p><strong>Close button</strong> - Compiles and checks the controller script for errors. If no errors are found, it closes the dialog. If an error is detected, a MAXScript error message is shown first with the description of the problem. After closing the error message, a prompt appears asking whether to revert the expression to the original value of the current track and close the dialog (OK) or to return to editing the expression (Cancel):</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-FDAF8B4C-A5DB-45B6-BC29-8F17FA2FF09E-low.gif\' title=\'\'></div>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";