var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Writing Controller Scripts</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Writing Controller Scripts</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"writing-controller-scripts\"></a></div>\n\
<p><strong>3ds Max</strong> interprets the text you type into the Script text box as the body of a MAXScript block expression, so you can type as many expressions as you want on as many lines as you want and they are evaluated in turn and the value of the <strong>last</strong> expression is taken as the controller value. This value <strong>must</strong> yield the right type for the controller, <span class=\'code\'>Float</span> for float, <span class=\'code\'>Point3</span> for position, <span class=\'code\'>Quat</span> for rotation, etc.</p>\n\
<p>The value returned from a script controller may not necessarily be the same value seen in Track View or in the command panels, nor the same value returned by accessing the property value in MAXScript. Part of a MAXWrapper property definition is a scaling value that is applied when reading or setting the true value stored in a controller. For example, the <span class=\'code\'>slice_to</span> and <span class=\'code\'>slice_from</span> properties associated with many of the geometry primitives is displayed in degrees. The actual value stored in the controller associated with these properties are in radians. This scaling factor is an internal property of the MAXWrapper property, and not an internal property of the controller. Both <strong>3ds Max</strong> and MAXScript automatically apply the specified scaling factor when accessing properties, so this scaling is normally invisible to the user. The exception is when script or expression controllers are used. For these controllers, the data value returned must be the unscaled value, as <strong>3ds Max</strong> will then apply the scaling factor to the output value. In the documentation of the MAXWrapper classes, any scaling applied to a property is shown. If there is no scaling listed, no scaling occurs for that property. For example, a portion of the Capsule documentation is:</p>\n\
<div class=\'codeBlock\'><pre>&lt;Capsule&gt;.radius Float default: 0.0 -- animatable\n\
&lt;Capsule&gt;.height Float default: 0.0 -- animatable\n\
&lt;Capsule&gt;.slice_from Float default: 0.0 -- animatable, angle\n\
&lt;Capsule&gt;.slice_to Float default: 0.0 -- animatable, angle\n\
</pre></div><p>From this, a scripted controller would return unscaled values for the <span class=\'code\'>radius</span> and <span class=\'code\'>height</span> properties, and radians for <span class=\'code\'>slice_from</span> and <span class=\'code\'>slice_to</span> . The scaling types, stored value meaning, and scaling value applied to the true controller value are as follows:</p>\n\
<p>Angle -- value stored in radians, output scaled by 57.29578</p>\n\
<p>Percentage -- value stored as fraction (0 to 1), output scaled by 100</p>\n\
<p>For properties that have a Color value type, the controller output is automatically scaled by 255. If a point3_script is assigned to one of these properties, each component value should stored as fraction (0 to 1). Remember that converting a MAXScript Color value to a Point3 value does not apply a scaling factor - <span class=\'code\'>red as point3</span> returns a value of <span class=\'code\'>\\[255,0,0\\]</span> . Therefore you must explicitly scale a Color value by dividing by 255 if it is output by the script controller.</p>\n\
<p>The body of a script controller’s script is any valid MAXScript expression that evaluates to the proper data type, and can contain global and local variables, functions, and structure definitions. The script is compiled in its own local scope, and the locals are only visible inside the scope of the script controller. Script controller local variables are heap-based locals, which are slightly different from normal (stack-based) locals. Normal locals are visible in the current scope and have a lifetime of one execution of that scope. Heap-based locals are also visible only in the current scope, but have a lifetime equal to the lifetime of the top-level expression where they are defined. A script controller’a s locals are created the first time the script is executed and are kept permanently in the heap (unless and until you redefine the script). This means you can store values in local variables during one execution of the script controller and these values will still be present at the next evaluation. You cannot access the script controller’s locals from another utility or from Listener, because they are not executing within the scope of the script controller. See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Scope-of-Variables.html\' title=\'\'>Scope of Variables</a> for more information.</p>\n\
<p>As a special case, you can exit a script controller’s script using a <span class=\'code\'>return &lt;expr&gt;</span> .</p>\n\
<p>A controller is always evaluated by <strong>3ds Max</strong> with respect to a specific animation time. This might be the current time slider or incrementing frame time if an animation is playing or a render is under way.</p>\n\
<p>In the case of Script controllers, the time being evaluated is used to establish an automatic ’at time’ context around the controller script, so any properties you access (outside of other explicit ’at time’ expressions) yield the correct values for the current controller evaluation time. This means you don’t have to do anything special in your scripts to work at the correct time. You can access the evaluation time if you need to with the standard MAXScript variable, <span class=\'code\'>currentTime</span> . You can also reference scene property values at other times by using explicit ’at time’ expressions in your scripts, as in normal MAXScript programming.</p>\n\
<p>Remember that MAXScript lets you write multiline string literals, if you need.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` -- A position script keeping the object at the center of all other objects -- in the scene as they move about: ( local pos = [0,0,0] for o in objects where o != $foo do pos += o.pos pos / (objects.count - 1) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The above script computes the average position of all objects except the current one (written as <span class=\'code\'>$foo</span> here) by setting up a local variable that iterates through all objects except <span class=\'code\'>$foo</span> , accumulates a total position vector, and computes the average in the last line, which is the final result of the script.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` -- A position script keeping the object attached to the highest vertex in a -- given object: local high_index = 1, high_z = (getVert $foo 1).z for i in 2 to $foo.numVerts do if (getVert $foo i).z &gt; high_z then ( high_index = i high_z = (getVert $foo i).z ) getVert $foo high_index</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The above script runs over the vertices in <span class=\'code\'>$foo</span> remembering the index of the vertex with the largest z and returns that vertex’s coordinates as the new position.</p>\n\
<blockquote>\n\
<p><strong>LIMITATIONS IN VERSIONS PRIOR TO 3DS MAX 8:</strong></p>\n\
<p>Script controllers were not automatically updated when you interactively modified objects that they depended on unless you defined an explicit dependency using <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Types/Script-Controllers/dependsOn-For-Scripted.html\' title=\'\'>dependsOn</a> or assigned the scene node to a variable.</p>\n\
<p>If you moved the time slider or if you animated the changes and then played the animation, the changes <strong>were</strong> reflected automatically. Because the scripts could refer to other objects in very indirect ways or conditional ways, it was not possible for MAXScript to automatically determine the objects a script depends on. These objects always had to be specified explicitly.</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";