var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Spring Controller</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Spring Controller</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"spring-controller\"></a></div>\n\
<p>The Spring controller adds secondary dynamics effects to any point or object position. The end result is secondary mass/spring dynamics similar to Flex. This constraint adds realism to generally static animations.</p>\n\
<p>When you apply Spring to an animated object, its original motion is preserved and secondary, velocity-based dynamics are applied. When you first apply the controller, it constructs a virtual spring between the object&#39;s original position and where it would end up after forces are applied to it. You can adjust spring tension and dampening. Increasing the tension creates a tighter spring, while increasing the dampening smoothes out jitters in the motion.</p>\n\
<p>Users have control over the point&#39;s Mass and Drag, the spring&#39;s Tension and Dampening, and other world space constraints. These include being able to add external forces like Wind and Gravity (spacewarps), and being able to constrain the spring effects along a given axis. This way you can add vertical dynamics while controlling the about of effect it has in the horizontal directions.</p>\n\
<p>The solution is calculated using a start time and a step size. Solutions are cached once for the last tick calculated, and once per frame. Performance should be the same one each frame as you step forward, and significantly faster after the first pass if nothing changes. Cached values will be used if going backwards in time.</p>\n\
<p>The biggest slowdown occurs when animating an object that the controller uses as a force way down the time line since this is a history dependent solver. If a lot of animation is going to occur along a long timeline you can shut off the spring solver by setting steps to 0. Set this back to the desired value when you want the solution recalculated.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;getMass ()    \n\
</pre></div><p>Returns the mass.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;setMass &lt;float&gt;mass   \n\
</pre></div><p>Sets the mass. The mass of the object to which the Spring controller is applied. Increasing the mass causes the &quot;bouncing&quot; spring motion to become more exaggerated.</p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;getDrag () \n\
</pre></div><p>Returns the drag.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;setDrag &lt;float&gt;drag \n\
</pre></div><p>Sets the drag. Acts as air friction on the spring motion. A low Drag setting results in a greater &quot;bouncing&quot; effect, while a high Drag results in subdued bouncing. Default=1. Range=0 to 10.</p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;getTension &lt;index&gt;springIndex \n\
</pre></div><p>Gets the tension for the spring corresponding to the index.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;setTension &lt;index&gt;springIndex &lt;float&gt;tension \n\
</pre></div><p>Sets the tension for the spring corresponding to the index. The &quot;stiffness&quot; of the virtual spring between the controlled object and the highlighted spring object(s).</p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;getDampening &lt;index&gt;springIndex \n\
</pre></div><p>Gets the dampening for the spring corresponding to the index.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;setDampening &lt;index&gt;springIndex &lt;float&gt;dampening \n\
</pre></div><p>Sets the dampening for the spring corresponding to the index. <strong>:</strong> Acts as a multiplier of an internal factor that determines how quickly the object comes to rest. With the Self Influence spring, changing Dampening has the same effect as changing Drag. With other springs, Dampening affects only the movement caused by that spring. Internally, the dampening value is proportional to the tension, so as you increase the tension and make the solution more stiff, the dampening is increased to maintain system stability.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;addSpring &lt;node&gt;node \n\
&lt;node&gt;node \n\
</pre></div><p>Adds the node to the spring list.</p>\n\
<p>Returns true if successful, false otherwise</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;getSpringCount () \n\
</pre></div><p>Returns the number of springs in the spring system.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;removeSpringByIndex &lt;index&gt;springIndex \n\
</pre></div><p>Removes the spring corresponding to the index.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;removeSpring &lt;node&gt;node \n\
</pre></div><p>Removes the spring if the node is in the spring list.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";