var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>New Default Controller Functions</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>New Default Controller Functions</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"new-default-controller-functions\"></a></div>\n\
<p>The following functions create instances of the default controller class for each animatable value type. If the default controller has been customized by the user, the respective function below will return an instance of the customized class. The default controller for each animatable value type can be customized in the “Assign ... Controller” dialog accessible through Track View. Available in <strong>3ds Max 2017 and higher</strong>.</p>\n\
<p><strong>Functions:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;controller&gt;NewDefaultBoolController()\n\
</pre></div><p>Returns an instance of the default controller class used for storing animated Boolean values.</p>\n\
<p>Default is a Bezier_Float controller.</p>\n\
<div class=\'codeBlock\'><pre>&lt;controller&gt;NewDefaultColorController()\n\
</pre></div><p>Returns an instance of the default controller class used for storing animated Color values.</p>\n\
<p>Default is a Bezier_Color controller.</p>\n\
<div class=\'codeBlock\'><pre>&lt;controller&gt;NewDefaultFloatController()\n\
</pre></div><p>Returns an instance of the default controller class used for storing animated Float values.</p>\n\
<p>Default is a Bezier_Float controller.</p>\n\
<div class=\'codeBlock\'><pre>&lt;controller&gt;NewDefaultFRGBAController()\n\
</pre></div><p>Returns an instance of the default controller class used for storing animated floating point Color and Alpha values.</p>\n\
<p>Default is a Bezier_RGBA_Color controller.</p>\n\
<div class=\'codeBlock\'><pre>&lt;controller&gt;NewDefaultPointControllerContainer()\n\
</pre></div><p>Returns an instance of the default controller class used for storing animated vertices.</p>\n\
<p>Default is a PointControllerContainerImp controller.</p>\n\
<blockquote>\n\
<p>Note: Prior to <em>3ds Max 2022</em> this function was called <span class=\'code\'>NewDefaultMasterPointController</span>.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;controller&gt;NewDefaultMatrix3Controller()\n\
</pre></div><p>Returns an instance of the default controller class used for storing animated Matrix3 values.</p>\n\
<p>Default is a Position_Rotation_Scale controller with a Position_XYZ sub-controller for Position containing three Bezier_Float sub-controllers for X_Position, Y_Position, and Z_Position; a Eurler_XYZ sub-controller for Rotation with three Bezier_Float sub-controllers for X_Rotation, Y_Rotation, and Z_Rotation; and a Bezier_Scale controller for scaling.</p>\n\
<div class=\'codeBlock\'><pre>&lt;controller&gt;NewDefaultPoint2Controller()\n\
</pre></div><p>Returns an instance of the default controller class used for storing animated Point2 values.</p>\n\
<p>Default is a Bezier_Point2 controller.</p>\n\
<div class=\'codeBlock\'><pre>&lt;controller&gt;NewDefaultPoint3Controller()\n\
</pre></div><p>Returns an instance of the default controller class used for storing animated Point3 values.</p>\n\
<p>Default is a Bezier_Point3 controller.</p>\n\
<div class=\'codeBlock\'><pre>&lt;controller&gt;NewDefaultPoint4Controller()\n\
</pre></div><p>Returns an instance of the default controller class used for storing animated Point4 values.</p>\n\
<p>Default is a Bezier_Point4 controller.</p>\n\
<div class=\'codeBlock\'><pre>&lt;controller&gt;NewDefaultPositionController()\n\
</pre></div><p>Returns an instance of the default controller class used for storing animated Position values.</p>\n\
<p>Default is a Position_XYZ controller with three Bezier_Float sub-controllers for X_Position, Y_Position and Z_Position.</p>\n\
<div class=\'codeBlock\'><pre>controller&gt;NewDefaultRotationController()\n\
</pre></div><p>Returns an instance of the default controller class used for storing animated Rotation values.</p>\n\
<p>Default is a Euler_XYZ controller with three Bezier_Float sub-controllers for X_Rotation, Y_Rotation and Z_Rotation.</p>\n\
<div class=\'codeBlock\'><pre>&lt;controller&gt;NewDefaultScaleController()\n\
</pre></div><p>Returns an instance of the default controller class used for storing animated Scale values.</p>\n\
<p>Default is a Bezier_Scale controller.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` ndbc = NewDefaultBoolController() --&gt; Controller:Bezier_Float</p>\n\
<p>ndcc = NewDefaultColorController() --&gt; Controller:Bezier_Color</p>\n\
<p>ndfc = NewDefaultFloatController() --&gt; Controller:Bezier_Float</p>\n\
<p>ndfrgbac = NewDefaultFRGBAController() --&gt; Controller:Bezier_RGBA_Color</p>\n\
<p>ndmpc = NewDefaultPointControllerContainer() --&gt; Controller:PointControllerContainerImp</p>\n\
<p>ndm3c = NewDefaultMatrix3Controller() --&gt; Controller:Position_Rotation_Scale ndm3c[1] --&gt; SubAnim:Position ndm3c[1].controller --&gt; Controller:Position_XYZ ndm3c[1].controller[1] --&gt; SubAnim:X_Position ndm3c[1].controller[1].controller --&gt; Controller:Bezier_Float ndm3c[2].controller --&gt; Controller:Euler_XYZ ndm3c[3].controller --&gt; Controller:Bezier_Scale</p>\n\
<p>ndp2c = NewDefaultPoint2Controller() --&gt; Controller:Bezier_Point2</p>\n\
<p>ndp3c = NewDefaultPoint3Controller() --&gt; Controller:Bezier_Point3</p>\n\
<p>ndp4c = NewDefaultPoint4Controller() --&gt; Controller:Bezier_Point4</p>\n\
<p>ndpc = NewDefaultPositionController() --&gt; Controller:Position_XYZ</p>\n\
<p>ndrc = NewDefaultRotationController() --&gt; Controller:Euler_XYZ</p>\n\
<p>ndsc = NewDefaultScaleController() --&gt; Controller:Bezier_Scale</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";