var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Adding Custom Attributes</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Adding Custom Attributes</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"adding-custom-attributes\"></a></div>\n\
<div class=\'codeBlock\'><pre>custAttributes.add &lt;object_or_collection&gt; &lt;attributes_definition&gt; [     #unique] [      BaseObject:&lt;boolean&gt;]    \n\
</pre></div><p>Adds a set of attributes to an object or a collection. You can only add one custom attribute set of a particular attributes definition to an object, but you can have as many different attribute sets from different definitions as needed.</p>\n\
<div class=\'codeBlock\'><pre>#unique \n\
</pre></div><p>When adding custom attributes to an object using the <span class=\'code\'>custAttributes.add()</span> function, you can now supply an optional <span class=\'code\'>#unique</span> keyword as the third argument. If you do this, each object being added to will have custom attributes added that have their own private copy of the definition and do <span class=\'code\'>\\*not\\*</span> share the original definition. Any later redefinitions of the original attributes definition will not update these custom attributes. To update the individual object&#39;s attributes, you would get the unique definition from the object using <span class=\'code\'>custAttributes.getDef</span> , and redefine it in one of the two ways described.</p>\n\
<p>Note: If you extract the uniquely-added definition, and use it directly in another non-unique <span class=\'code\'>custAttributes.add()</span> on some other object, a definition sharing will be set up. Using <span class=\'code\'>#unique</span> when adding a global definition will make the added custom attributes non-global, they will have their own private definition which starts out being identical to the original global definition.</p>\n\
<div class=\'codeBlock\'><pre>BaseObject:&lt;boolean&gt; \n\
</pre></div><p>If the optional keyword argument <span class=\'code\'>baseObject</span> is set to <span class=\'code\'>true</span> (the default), in case the object specified is a node, the base object will be operated on. If <span class=\'code\'>false</span> , the node itself will be operated on.</p>\n\
<p>Note: In versions priorto <strong>3ds Max 5.1</strong>, the base object was always used.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` custAttributes.add $weapon01 weaponData</p>\n\
<p>```</p>\n\
<p>Opening $weapon01 in the Modify panel will now display the &quot;Weapon Parameters&quot; rollout and allow them to be edited as can normal object parameters. You can use attribute definitions to add their defined sets of attributes to any object at any time. Any appropriate type of parameter can be animated, also, exactly as with scripted plug-ins.</p>\n\
</blockquote>\n\
<p>The <span class=\'code\'>custAttributes.add()</span> function can be applied to an object collection to add sets of attributes to a group of objects in one go.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` custAttributes.add $weapon* the_weaponData</p>\n\
<p>```</p>\n\
<p>Adds a separate set of these custom attributes to all objects whose names begin &quot;weapon&quot; in the scene.</p>\n\
</blockquote>\n\
<p>Note:</p>\n\
<p>Further, an object can have any number of separate sets of custom attributes added from different attribute definitions.</p>\n\
<p>As with <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/Scripted-Plug-ins-1.html\' title=\'\'>Scripted plug-ins</a>, an attributes definition can have any number of sets of parameter and rollout clauses, to allow you to organize added attributes into multiple rollouts as needed.</p>\n\
<p>Scripted custom attributes added to an object or modifier can be accessedviaMAXScript. They turn up directlyas properties on the objectsthey are added to. If the names of any of the custom attributes are the same as existing properties on the host object, the custom attributes <strong>are effectively hidden</strong> when accessed directly. As an alternative, you can access each added block of custom attributesby their attributes definition nameand then access individual attributes as properties within that block.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>if the following attributes were added to $box01</p>\n\
<p>``` the_weaponData = attributes weaponData ( parameters main rollout:params ( hitPoints type: #float ui:hits default:10 cost type: #float ui:cost default:100 sound type: #string ) rollout params &quot;Weapon Parameters&quot; ( spinner hits &quot;Hit Points&quot; type: #float spinner cost &quot;Cost&quot; type: #float dropdownlist sound_dd &quot;Sound&quot; items:# (&quot;boom&quot;,&quot;sparkle&quot;,&quot;zap&quot;,&quot;fizzle&quot;) ) )</p>\n\
<p>```</p>\n\
<p>the custom attributes could be accessed as</p>\n\
<p><span class=\'code\'>$box01.hitPoints    $box01.cost    $box01.sound</span></p>\n\
<p>or indirectly through the attributes block:</p>\n\
<p><span class=\'code\'>$box01.weaponData.hitPoints    $box01.weaponData.cost    $box01.weaponData.sound</span></p>\n\
</blockquote>\n\
<p><strong>Adding Custom Attributes Presets</strong></p>\n\
<p>Custom Attributes Presets can be added to an object using the pre-defined attributes definition <span class=\'code\'>CustomAttributesPresets</span>, which is defined in the [3dsmax]\\scripts\\Startup\\CustomAttributes.ms file. This corresponds to the &quot;Add Presets Options&quot; checkbox in the <strong>Parameter Editor</strong> in the 3ds Max UI.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` custAttributes.add $weapon* CustomAttributesPresets</p>\n\
<p>```</p>\n\
<p>Adds Custom Attributes Presets to all objects whose name begins with &quot;weapon&quot; in the scene.</p>\n\
<p><span class=\'code\'>custAttributes.add $weapon.modifiers[#Attribute_Holder] CustomAttributesPresets</span></p>\n\
<p>Adds Custom Attributes Presets to the Attribute Holder Modifier on the $weapon object.</p>\n\
</blockquote>\n\
<p><strong>Next Topic:</strong></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Custom-Attributes/Global-and-Private-Custom.html\' title=\'\'>Global and Private Custom Attributes Definitions</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";