var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Custom Attribute Management Functions</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Custom Attribute Management Functions</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"custom-attribute-management-functions\"></a></div>\n\
<p>The following management functions are available through the <span class=\'code\'>custAttributes</span> struct:</p>\n\
<div class=\'codeBlock\'><pre>custAttributes.count &lt;obj&gt; [BaseObject:&lt;boolean&gt;]    \n\
</pre></div><p>Returns a count of the number of separate scripted custom attribute sets have been added via the <span class=\'code\'>.add()</span> function.</p>\n\
<p>If the optional keyword argument <span class=\'code\'>baseObject</span> is set to <span class=\'code\'>true</span> (the default), in case the object specified is a node, the base object will be operated on instead. If <span class=\'code\'>false</span> , the node itself will be operated on.</p>\n\
<div class=\'codeBlock\'><pre>custAttributes.get &lt;obj&gt; (&lt;index&gt; | &lt;attrib_def&gt;)[BaseObject:&lt;boolean&gt;] \n\
</pre></div><p>Returns the custom attribute set, specified as an index or by its defining attribute definition.</p>\n\
<p>If the optional keyword argument <span class=\'code\'>baseObject</span> is set to <span class=\'code\'>true</span> (the default), in case the object specified is a node, the base object will be operated on. If <span class=\'code\'>false</span> , the node itself will be operated on. (In versions prior to <strong>3ds Max 5.1</strong>, the base object was always used.)</p>\n\
<p>Note:</p>\n\
<p>The custom attribute set values returned by the custAttributes are effectively holder values for the object&#39;s custom parameters in that attribute set. You can get at these parameter values as simple properties on the attribute set value.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p><span class=\'code\'>gp = custAttributes.get $ gameParams   gp.hitPoints= 50</span></p>\n\
<p>This is equivalent to accessing the custom attribute parameters directly on the object:</p>\n\
<p><span class=\'code\'>$.gameParams.hitPoints = 50</span></p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>custAttributes.delete &lt;obj_or_collection&gt; (&lt;index&gt; | &lt;attrib_def&gt;) [baseObject:&lt;boolean&gt;] \n\
</pre></div><p>Deletes the specified custom attribute set from the object or from all the objects in the given collection. The set to be deleted is defined by index number or by its defining attributes definition.</p>\n\
<p>If the optional keyword argument <span class=\'code\'>baseObject</span> is set to <span class=\'code\'>true</span> (the default), in case the object specified is a node, the base object will be operated on. If <span class=\'code\'>false</span>, the node itself will be operated on.(In versions prior to <strong>3ds Max 5.1</strong>, the base object was always used.)</p>\n\
<div class=\'codeBlock\'><pre>custAttributes.makeUnique &lt;obj&gt; (&lt;index&gt; | &lt;attrib_def&gt;) [baseObject:&lt;boolean&gt;] \n\
</pre></div><p>If some objects with custom attribute sets share a specific attributes definition, you can make selected objects have unique copies of the definition.</p>\n\
<p>If the optional keyword argument <span class=\'code\'>baseObject</span> is set to <span class=\'code\'>true</span> (the default), in case the object specified is a node, the base object will be operated on. If <span class=\'code\'>false</span> , the node itself will be operated on.(In versions prior to <strong>3ds Max 5.1</strong>, the base object was always used.)</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p><span class=\'code\'>custAttributes.add $box* def1</span></p>\n\
<p>You can make box01 unique with:</p>\n\
<p><span class=\'code\'>custAttributes.makeUnique $box01 def1</span></p>\n\
<p>or all of them unique with:</p>\n\
<p><span class=\'code\'>custAttributes.makeUnique $box* def1</span></p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>custAttributes.getDef (&lt;obj&gt; &lt;index&gt;) | &lt;custAttrib&gt; [baseObject:&lt;boolean&gt;] \n\
</pre></div><p>Returns the attribute definition for a given custom attribute set in an object or from a custom attribute set accessed with the <span class=\'code\'>.get()</span> method.</p>\n\
<p>If the optional keyword argument <span class=\'code\'>baseObject</span> is set to <span class=\'code\'>true</span> (the default), in case the object specified is a node, the base object will be operated on. If <span class=\'code\'>false</span> , the node itself will be operated on.(In versions prior to <strong>3ds Max 5.1</strong>, the base object was always used.)</p>\n\
<div class=\'codeBlock\'><pre>custAttributes.getDefs &lt;obj&gt; [baseObject:&lt;boolean&gt;] \n\
</pre></div><p>Returns an array of definitions in attribute set order.</p>\n\
<p>If the optional keyword argument <span class=\'code\'>baseObject</span> is set to <span class=\'code\'>true</span> (the default), in case the object specified is a node, the base object will be operated on. If <span class=\'code\'>false</span> , the node itself will be operated on.(In versions prior to <strong>3ds Max 5.1</strong>, the base object was always used.)</p>\n\
<p><strong>Next Topic:</strong></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Custom-Attributes/Custom-Attributes-Definition.html\' title=\'\'>Custom Attributes Definition Values</a></p>\n\
<div class=\'section\'><a id=\"handling-scripted-custom-attribute-definition-conflicts\"></a><h2 id=\"handling-scripted-custom-attribute-definition-conflicts\">Handling Scripted Custom Attribute Definition Conflicts</h2></div>\n\
<p>3ds Max uses the version information of scripted custom attribute definitions to decide how to manage situations where there was a conflict between an existing custom attribute and one being loaded from a scene. Starting with <strong>3ds Max 2012</strong>, the CA definition with the highest version number is used, by default. However, this behavior can be changed using the following methods in the <span class=\'code\'>custAttributes</span> struct.</p>\n\
<div class=\'codeBlock\'><pre>custAttributes.getSceneLoadVersionHandlingBehavior()\n\
</pre></div><p>Returns the current behavior for handling custom attribute definition conflicts when a scene is loaded.</p>\n\
<div class=\'codeBlock\'><pre>custAttributes.setSceneLoadVersionHandlingBehavior   {#neverUpdate | #alwaysUpdate | /\n\
 #updateWhenLoadVersionGreaterThanCurrentVersion | #updateWhenLoadVersionGreaterThanOrEqualToCurrentVersion} /\n\
 persistent:&lt;boolean&gt;\n\
</pre></div><p>Sets the behavior for handling custom attribute definition conflicts when a scene is loaded. The options are:</p>\n\
<ul>\n\
<li><span class=\'code\'>#neverUpdate</span> - never use the definition from the scene file, regardless of the version number</li>\n\
<li><span class=\'code\'>#alwaysUpdate</span> - always use the definition from the scene file, regardless of the version number</li>\n\
<li><span class=\'code\'>#updateWhenLoadVersionGreaterThanCurrentVersion</span> - only use the scene file version when its version number is greater than the existing definition version</li>\n\
<li><span class=\'code\'>#updateWhenLoadVersionGreaterThanOrEqualToCurrentVersion</span> - only use the scene file version when its version number is greater or equal to the existing definition version</li>\n\
</ul>\n\
<p>When <span class=\'code\'>persistent</span> is true, this setting is persisted between 3ds Max sessions.</p>\n\
<div class=\'codeBlock\'><pre>custAttributes.getSceneMergeVersionHandlingBehavior()\n\
</pre></div><p>Returns the current behavior for handling custom attribute definition conflicts when a scene or object is merged with the current scene.</p>\n\
<div class=\'codeBlock\'><pre>custAttributes.setSceneMergeVersionHandlingBehavior {#neverUpdate | #alwaysUpdate | /\n\
 #updateWhenLoadVersionGreaterThanCurrentVersion | #updateWhenLoadVersionGreaterThanOrEqualToCurrentVersion} /\n\
 persistent:&lt;boolean&gt;\n\
</pre></div><p>Sets the behavior for handling custom attribute definition conflicts when a scene or object is merged. The options are:</p>\n\
<ul>\n\
<li><span class=\'code\'>#neverUpdate</span> - never use the definition from the merged scene file, regardless of the verison number</li>\n\
<li><span class=\'code\'>#alwaysUpdate</span> - always use the definition from the merged scene file, regardless of the version number</li>\n\
<li><span class=\'code\'>#updateWhenLoadVersionGreaterThanCurrentVersion</span> - only use the merged scene file version when its version number is greater than the existing definition version</li>\n\
<li><span class=\'code\'>#updateWhenLoadVersionGreaterThanOrEqualToCurrentVersion</span> - only use the merged scene file version when its version number is greater or equal to the existing definition version</li>\n\
</ul>\n\
<p>When <span class=\'code\'>persistent</span> is true, this setting is persisted between 3ds Max sessions.</p>\n\
<div class=\'section\'><a id=\"scene-loading-callbacks-for-custom-attributes\"></a><h2 id=\"scene-loading-callbacks-for-custom-attributes\">Scene Loading Callbacks for Custom Attributes</h2></div>\n\
<p>There are some situations where you might want to manage how custom attribute definitions are handled when loading scene files, for example if an API changes and you need to &quot;patch&quot; the custom attributes in a new version of 3ds Max. You can register callbacks to deal with custom attributes using these methods.</p>\n\
<div class=\'codeBlock\'><pre>custAttributes.registerDefLoadCallback &lt;function&gt;\n\
</pre></div><p>Registers a callback that is called for each scripted custom attributed definition as it is loaded from the scene. The <span class=\'code\'>&lt;function&gt;</span> takes a single argument, which is the custom attribute definition as a string, and returns a string. The function can modify the string to effectively re-define the custom attribute as it is loaded. <strong>Available in 3ds Max 2021 and higher.</strong> Note: You should only make the minimum changes required to make the Custom Attribute definition successfully load, as the definition is then used to load instances of the Custom Attribute from the scene. Specifically, do not add or remove parameters, change their type, or change whether they are animatable, as all of these changes will affect the load process. If you need to make more extensive changes, you can do so after the scene has loaded using <span class=\'code\'>custAttributes.redefine()</span>.</p>\n\
<p>If there are errors when the callback runs, the error message is printed to the listener and the function is removed as a callback (it is no longer called for subsequent custom attribute definitions).</p>\n\
<p>You can register multiple functions as callbacks.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;custAttributes.unRegisterDefLoadCallback &lt;function&gt;\n\
</pre></div><p>Removes the specified <span class=\'code\'>function</span>. Returns true if the callback is found and removed, false if it is not found. <strong>Available in 3ds Max 2021 and higher.</strong></p>\n\
<div class=\'codeBlock\'><pre>custAttributes.unRegisterAllDefLoadCallbacks()\n\
</pre></div><p>Removes all callbacks registered by <span class=\'code\'>registerDefLoadCallback()</span>. <strong>Available in 3ds Max 2021 and higher.</strong></p>\n\
<div class=\'codeBlock\'><pre>custAttributes.showregisteredDefLoadCallbacks [to:stream] [asArray:&lt;boolean&gt;]\n\
</pre></div><p>Shows all callbacks registered by <span class=\'code\'>registerDefLoadCallback()</span>. If <strong>to:<stream></stream></strong> is specified, output is sent to the specified stream. If <strong>asArray:true</strong> is specified, information is returned as an array. Each array element will be a 2 element array, where the first element is the function name, and the second element is the script file where the function was defined, if any. <strong>Available in 3ds Max 2021 and higher.</strong> ### For Example</p>\n\
<p>Consider the &quot;weaponData&quot; custom attribute example. If we wanted to change the &quot;default&quot; parameter, and add a version parameter, we could register the following callback:</p>\n\
<div class=\'codeBlock\'><pre>fn modifyCADef def =\n\
(\n\
if (findstring def &quot;weaponData&quot;) != undefined do \n\
    (\n\
        def = substituteString def &quot;default:10&quot; &quot;default:20&quot;\n\
        def = substituteString def &quot;attributes weaponData\\n&quot; &quot;attributes weaponData version:1\\n&quot;\n\
    )\n\
    def\n\
)\n\
custAttributes.registerDefLoadCallback modifyCADef\n\
custAttributes.showregisteredDefLoadCallbacks()\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";