var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Scripted Custom Attributes</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Scripted Custom Attributes</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"scripted-custom-attributes\"></a></div>\n\
<p><span class=\'code\'>Custom Attributes</span> let you create and assign additional parameters to any object, modifier, or material in your scene. This is useful for game and other project-specific data.</p>\n\
<p>MAXScript provides a way to define and add these custom attributes to objects in a scene, and also a way to define UI rollups for accessing these attributes.</p>\n\
<p><strong>Custom Attributes Topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Custom-Attributes/Adding-Custom-Attributes.html\' title=\'\'>Adding Custom Attributes</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Custom-Attributes/Global-and-Private-Custom.html\' title=\'\'>Global and Private Custom Attributes Definitions</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Custom-Attributes/Custom-Attribute-Management.html\' title=\'\'>Custom Attribute Management Functions</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Custom-Attributes/Custom-Attributes-Definition.html\' title=\'\'>Custom Attributes Definition Values</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Custom-Attributes/Access-to-Custom-Attributes.html\' title=\'\'>Access to Custom Attributes Virtual Array</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Custom-Attributes/Custom-Attributes-in-Materials.html\' title=\'\'>Custom Attributes in Materials and Texture Maps</a></p>\n\
<div class=\'section\'><a id=\"attribute-definitions\"></a><h3 id=\"attribute-definitions\">Attribute Definitions</h3></div>\n\
<p>Attributes can be added to an object using an &quot; <span class=\'code\'>attribute definition</span> &quot;. This is a syntactic construct in MAXScript that is similar to a <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/Scripted-Plug-ins-1.html\' title=\'\'>scripted plug-in definition</a>, but rather than adding a new plug-in class, a definition is built to add custom attributes and rollout UI to any number of objects at any time through a special function.</p>\n\
<p>Note: You <span class=\'code\'>cannot</span> use Custom Attributes per face-data. The face-data channels store objects of a user defined type and MAXScript cannot create objects of types other than those known by MAXScript.</p>\n\
<p><strong>The syntax has the following form:</strong></p>\n\
<div class=\'codeBlock\'><pre>attributes &lt;name&gt; [version:n] [silentErrors:t/f] [initialRollupState:0xnnnnn] [remap:#(&lt;old_param_names_array&gt;, &lt;new_param_names_array&gt;)]\n\
(\n\
&lt;locals&gt;\n\
&lt;globals&gt;\n\
&lt;parameters&gt;\n\
&lt;rollouts&gt;\n\
&lt;handlers&gt;\n\
)\n\
\n\
</pre></div><p><strong>Remarks</strong></p>\n\
<p>The name is a descriptive name for the definition and can be either a <span class=\'code\'>&lt;name&gt;</span> or a <span class=\'code\'>&lt;string&gt;</span>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` gameDataCA = attributes &quot;Game Data&quot; ( ... ) or attributes gameData ( ... )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The attribute header keyword parameters and main clauses are basically identical to the same keyword parameters and clauses in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/Scripted-Plug-ins-1.html\' title=\'\'>Scripted Plug-ins</a>. The &#39;custom attributes&#39; are effectively the parameters defined in any parameter clauses in the body of the attributes definition. The UI for them is defined by the rollout clauses, which will be automatically displayed in the Command Panel and Material Editor when an object containing custom attributes is selected.</p>\n\
<p>The <span class=\'code\'>initialRollupState</span> argument is an integer whose 32 bits are used to initialize the rollouts&#39; rollup state in both the create and modify panel. However, the semantics are different for these two cases. Whenever the rollouts are created in the create tab, their state will be specified by this value. In the modify tab, the first time an object of this type is modified, the state will be that of this value, but after that it will remain what it was last set to. The bits of this value indicate the corresponding rollout is rolled up (closed). The zero bit corresponds to the first rollout, the first bit is the second rollout, and so on. The default value of 0x7fffffff is used, so the command panel can detect that this value is not being overridden, and leave the rollouts as is. For example, a value of 0x07 results in the first three rollouts being rolled up, and the remaining rollouts open (2<sup>2+2</sup>1+2^0 = 4+2+1 = 7).</p>\n\
<p>The following example defines three new attributes for weapon objects in a game level editor set up. The attributes, hitPoints, cost, and sound are defined as parameters and the UI for them in a rollout:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` weaponDataCA= attributes weaponData ( parameters main rollout:params ( hitPoints type:#float ui:hits default:10 cost type:#float ui:cost default:100 sound type:#string )</p>\n\
<p>rollout params &quot;Weapon Parameters&quot; ( spinner hits &quot;Hit Points&quot; type: #float spinner cost &quot;Cost&quot; type: #float dropdownlist sound_dd &quot;Sound&quot; items:# (&quot;boom&quot;,&quot;sparkle&quot;,&quot;zap&quot;,&quot;fizzle&quot;)</p>\n\
<p>on sound_dd selected i do sound = sound_dd.items [i] ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note:</p>\n\
<p>The auto-UI connection between the parameters and rollout items using the UI and keyword is the same as the support in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/Scripted-Plug-ins-1.html\' title=\'\'>Scripted Plug-ins</a>. You can treat attribute scripting as basically identical to scripting plug-ins in terms of parameter, rollout setup, and handler programming.</p>\n\
<p>Since <strong>3ds Max 5.1</strong>, scripted custom attributes can be applied to any MAXWrapper object such as, base objects, modifiers, materials, nodes, controllers, <a href=\'#!/url=./developer/MAXScript-Language-Reference/Reserved-Keywords-Symbols/3ds-Max-System-Globals.html\' title=\'\'>rootnodes</a>, render effects, and others.</p>\n\
<p>Custom attributes is currently supported only in the Material Editor and the Command Panel, so you can only see any rollouts associated with the custom attributes on base objects, modifiers, and materials.</p>\n\
<div class=\'section\'><a id=\"remapping-parameters-when-redefining-custom-attributes\"></a><h3 id=\"remapping-parameters-when-redefining-custom-attributes\">Remapping Parameters when Redefining Custom Attributes</h3></div>\n\
<p>The optional <span class=\'code\'>remap:</span> keyword allows parameter names in the definitions to be changed when updating existing definitions. It is also available in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/Scripted-Plug-ins-1.html\' title=\'\'>Scripted Plug-ins</a>.</p>\n\
<p>The keyword takes as an argument a two element array, where each element contains an array of string literal or name values. The size of the two arrays must be the same.</p>\n\
<p>The names in the first array are the existing parameter names and the names in the second array are the new parameter names. As parameter names are read in while migrating existing plugin instances, the parameter names are searched for in the first array. If the name is found, the data associated with that parameter is moved to the parameter name in the corresponding location in the second array. If a parameter name is not found in the first array, the parameter name is not remapped. If the parameter name in the second array does not match a parameter name in the new definition, the parameter data is not moved to the new definition.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` CAT_DEF = attributes Custom_Attributes Redefine:CAT_CurrentDef remap: # (# (&quot;Param1&quot;),# (&quot;Param9&quot;)) ( Parameters main rollout:params ( &#39;Param9&#39; Type:# float UI:&#39;Param9&#39; Default:0.0 &#39;Param2&#39; Type:# float UI:&#39;Param2&#39; Default:0.0 ) Rollout Params &quot;Custom Attributes&quot; ( spinner &#39;Param9&#39; &quot;Param9&quot; Width:160 Height:16 Align: # Center Type: # float Range:[0,100,0] spinner &#39;Param2&#39; &quot;Param2&quot; Width:160 Height:16 Align: # Center Type: # float Range:[0,100,0] ) ) CustAttributes.add CAT_TargetObject CAT_DEF #Unique BaseObject : false</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>This will move the data associated with Param1 to Param9 in existing instances.</p>\n\
<p><strong>Next Topic:</strong></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Custom-Attributes/MSCustAttribDef-Class.html\' title=\'\'>MSCustAttribDef Class</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";