var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Accessing the Viewport Vertex Alpha Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Accessing the Viewport Vertex Alpha Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"accessing-the-viewport-vertex-alpha-values\"></a></div>\n\
<p><strong>3ds Max</strong> supports 100 map channels that can be used for storing mapping coordinates.</p>\n\
<p>Historically,</p>\n\
<p><strong>3ds Max</strong> 1.0 supported only one texture channel which is currently Channel 1.</p>\n\
<p><strong>3ds Max</strong> 2.0 added support for a second channel which could be used either for texture coordinates or for storing vertex colors. Currently it is stored as Channel 0.</p>\n\
<p><strong>3ds Max</strong> 3.0 increased the number of channels to 100. The channels are numbered from 1 to 99 plus the already mentioned Vertex Colors Channel 0.</p>\n\
<p>All these Channels can be accessed by the Unwrap_UVW, by the Maps in the Material Editor etc. The channels support map vertices and faces connecting them. For details, you can see <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Understanding-Texture.html\' title=\'\'>Understanding Texture Coordinates</a>. For related methods, see <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Meshop-General-Mapping-Methods.html\' title=\'\'>General Meshop Mapping Methods</a></p>\n\
<p><strong>3ds Max</strong> 4.0 added support for Alpha in the Viewports. This new internal channel has been given the index -2.</p>\n\
<p>In addition, <strong>3ds Max</strong> 4.0 introduced 100 user data channels with indices from 1 to 100. These channels can be used to store arbitrary Point3 data per vertex, for example special data for game models that can be exported to game engines. They do not have face arrays, only vertex data arrays. For related methods, see <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Meshop-Vertex-Data-Methods.html\' title=\'\'>Meshop Vertex Data Methods</a></p>\n\
<p>Warning: Mapping channels and Vertex Data channels are not the same thing!</p>\n\
<p>While the User Data Channel 3 is dedicated to Alpha values, it is unrelated to the Viewport Vertex Alpha channel which is the internal map channel with index -2.</p>\n\
<p>In the following example we will create a sphere with 4 segments (only 6 vertices) and access its Viewport Alpha values. You can try and increase the number of sphere segments to get more vertices anytime.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` s = sphere segs:4 -- create a sphere convertToMesh s -- collapse to Editable Mesh s.showVertexColors = true -- enable Vertex Colors in Viewport s.vertexColorType = #alpha -- set Vertex Color type to Alpha</p>\n\
<p>```</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-26D57D79-C342-4716-9624-3B1144BCCCED-low.gif\' title=\'\'></div>\n\
<p>``` --Read the number of mesh vertices mesh_verts = s.numverts --Set the map vertices for the first and last mesh vertex to black --Note that this access will automatically enable channel -2 and --build its internal vertex and face arrays. meshop.setVertAlpha s -2 #(1, mesh_verts) 0.0</p>\n\
<p>```</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-5F73F8BA-7CC0-4783-AB21-71C8ADA0FE6E-low.gif\' title=\'\'></div>\n\
<p>``` --Read the number of map vertices in Channel -2 --Since the channel -2 is now enabled, you will get a valid result. --Evaluating this line BEFORE the previous one would lead to --an error message telling you Channel -2 is not enabled... map_verts = meshop.getNumMapVerts s -2 --Go through all map vertices except the first and last and change --their Alpha value to a non-greyscale color using direct access --to the Mapping Channel -2 for i = 2 to map_verts-1 do meshop.setMapVert s -2 i [i<em>0.1,i</em>0.05,1.0-i*0.1] --Update the mesh: update s</p>\n\
<p>```</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-BF63242B-CD06-45D9-B67F-9F75F8E9A277-low.gif\' title=\'\'></div>\n\
<p>``` --Go through all map vertices and print their values by --reading directly from Channel -2 for i = 1 to map_verts do format &quot;Map Vertex % = %\\n&quot; i (meshop.getMapVert s -2 i)</p>\n\
<p>```</p>\n\
<p><strong>RESULTS:</strong></p>\n\
<p>``` $Sphere:Sphere01 @ [0.000000,0.000000,0.000000] $Editable_Mesh:Sphere01 @ [0.000000,0.000000,0.000000] true #Alpha 6 OK 6 OK OK Map Vertex 1 = [0,0,0] Map Vertex 2 = [0.2,0.1,0.8] Map Vertex 3 = [0.3,0.15,0.7] Map Vertex 4 = [0.4,0.2,0.6] Map Vertex 5 = [0.5,0.25,0.5] Map Vertex 6 = [0,0,0] OK OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note: The array #(1, mesh_verts) specifies the Mesh Vertex Indices and not the Map Vertex indices! The <span class=\'code\'>meshop.setVertAlpha</span> will find all corresponding Map Vertices in the channel and affect them all without the need to look for them!</p>\n\
<p>On the other hand, the index supplied to <span class=\'code\'>meshop.setMapVert</span> is the Map Vertex index and not the Mesh Index as in the case of <span class=\'code\'>meshop.setVertAlpha</span> . If there are more Map Vertices corresponding to a single Mesh Vertex, you would have to find them all and read their values separately. In this simple case though, there are 6 Mesh Vertices and corresponding 6 Map Vertices, so the indices are the same.</p>\n\
<p><span class=\'code\'>meshop.getMapVert</span> reads the actually stored value from a specific Map Vertex which is always a Point3 value.</p>\n\
<p>As you see from the example, you can use <span class=\'code\'>meshop.setMapVert</span> to set the value of Map Vertices in the Alpha Channel -2 to a color which will be displayed as color in the viewport! The Alpha Channel -2 is just a regular mapping channel used in a similar way to the Vertex Color Channel 0.</p>\n\
<p><span class=\'code\'>meshop.setVertAlpha</span> lets the user set all Point3 components to single value at once for all Map Vertices related to the supplied array of Mesh Vertices. This ensures the Alpha channel contains a greyscale value and not an RGB value and shields the user from additional work to provide Point3 values and find out which Map Vertices to affect.</p>\n\
<p>The reason there is NO <span class=\'code\'>meshop.getVertAlpha</span> counterpart is that a single Mesh Vertex could have any number of corresponding Map Vertices, all with possibly different values, and all values having 3, possible different, components. It would be difficult to return meaningful values for a group of Mesh Vertices, each with multiple results and multiple Point3 components.</p>\n\
<p>Using <span class=\'code\'>meshop.getMapVert</span> , you will always get the exact Point3 value for the exact Map Vertex of interest, and will be able to use it the way you want.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";