var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Editable_Mesh : GeometryClass and TriMesh : Value</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Editable_Mesh : GeometryClass and TriMesh : Value</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"editable_mesh-geometryclass-and-trimesh-value\"></a></div>\n\
<p><strong>Editable_Mesh</strong> is the class of node objects that are the result of collapsing a modifier stack to an editable mesh object. Many of the mesh operations in MAXScript that modify meshes only work on Editable_Mesh scene nodes.</p>\n\
<p>The TriMesh class is a MAXScript value wrapper for the low-level <strong>3ds Max</strong> SDK Mesh class used extensively in mesh-based objects and modifiers in <strong>3ds Max</strong>. Meshes hold the actual vertex and face arrays, and so on, in a triangular mesh. For example, an Editable_Mesh object contains an instance of a Mesh. The prime purpose of the TriMesh class is to allow scripted primitive object plug-ins to access and build the Mesh object inside geometry objects. This class has a large range of mesh manipulation and construction functions, corresponding to the low-level mesh operations on Editable Mesh scene nodes.</p>\n\
<p>The properties and methods described in this topic are applicable to both Editable_Mesh objects and TriMesh values, and are signified by a value type of &lt; <span class=\'code\'>mesh</span> &gt;. The properties and methods applicable to just TriMesh values are signified by a value type of &lt; <span class=\'code\'>trimesh</span> &gt;.</p>\n\
<blockquote>\n\
<p>Warning: Meshes created by MAXScript are <span class=\'code\'>triMesh</span> values.</p>\n\
</blockquote>\n\
<p>Note:</p>\n\
<p><strong>Only</strong> the <span class=\'code\'>update()</span> function updates the mesh&#39;s internal caches and images in <strong>3ds Max</strong> viewports. This is because updates can be computationally expensive and you do not want them performed on every function call. However, you <strong>must</strong> make sure to call the <span class=\'code\'>update()</span> function after a series of changes and before the mesh is to be worked on in <strong>3ds Max</strong> or by other functions in MAXScript.</p>\n\
<p>Coordinates are given in the MAXScript working coordinate system.</p>\n\
<p>If the <span class=\'code\'>update()</span> function is called on an object that is selected and currently open in the Modify panel, it drops the current selection to avoid a potential crash in <strong>3ds Max</strong>, which at the moment, does not support scripted changes to an object open in the Modify panel.</p>\n\
<p>If you are creating or modifying a mesh, and have not yet run <span class=\'code\'>update()</span> on the mesh, <strong>3ds Max</strong> crashes if you minimize and then maximize the <strong>3ds Max</strong> window. This is because only a partial mesh is created, and the internal <strong>3ds Max</strong> mesh structure is left in an unstable state.</p>\n\
<p><strong>Constructors (Editable_Mesh)</strong></p>\n\
<div class=\'codeBlock\'><pre>editable_mesh... \n\
</pre></div><p>Creates an empty mesh.</p>\n\
<div class=\'codeBlock\'><pre>mesh [ length:&lt;integer&gt; ] [ width:&lt;integer&gt; ]  [ lengthsegs:&lt;integer&gt; ] [ widthsegs:&lt;integer&gt; ] \n\
</pre></div><p>Creates a flat rectangular mesh with the given size and number of segments. The default length and width are 50, the default number of segments is 5.</p>\n\
<div class=\'codeBlock\'><pre>mesh [ numverts:&lt;number&gt; ] [ numfaces:&lt;number&gt; ] \n\
</pre></div><p>Creates a mesh of the given geometry, but with no topology (no faces or edges). You have to individually place the vertices and create the faces from the vertices. The default number of vertices and faces are 36 and 50, respectively.</p>\n\
<div class=\'codeBlock\'><pre>mesh [ mesh:&lt;TriMesh&gt;] \n\
</pre></div><p>Creates a mesh using the specified TriMesh value as the mesh source.</p>\n\
<div class=\'codeBlock\'><pre>mesh vertices:&lt;array_of_point3s&gt; faces:&lt;array_of_point3s&gt; [ materialIDs:&lt;array_of_integers&gt; ] [ tverts:&lt;array_of_point3s&gt; ] \n\
</pre></div><p>Creates a mesh from an array of vertices and faces. Each Point3 value in the <span class=\'code\'>vertices</span> array specifies the position of the vertex in the current coordinate system. Each Point3 value in the <span class=\'code\'>faces</span> array specifies the three vertex indices that form the face. The <span class=\'code\'>materialIDs</span> array specifies the material ID to be assigned to each face.</p>\n\
<p>Each Point3 value in the <span class=\'code\'>tverts</span> array specifies the UVW coordinates of the texture vertices. See Texture Mapping in the methods section for more information on texture vertices.</p>\n\
<p>An example of mesh construction using this form of the constructor is:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` mesh vertices:#([0,0,0],[10,0,0],[0,10,0],[10,10,0])<br> faces:#([1,2,3],[2,4,3]) materialIDS:#(1,2)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note: The optional <span class=\'code\'>tverts</span> array feature is currently broken. The texture vertices are set correctly, but no texture faces are built internally. Until this gets fixed, you can work around by building the texture faces yourself:</p>\n\
<blockquote>\n\
<p><strong>WORKAROUND EXAMPLE:</strong></p>\n\
<p>``` mnode = mesh vertices:#([0,0,0],[10,0,0],[0,10,0],[10,10,0]) tverts:#([0,0,0],[10,0,0],[0,10,0],[10,10,0]) faces:#([1,2,3],[2,4,3]) mmesh = mnode.mesh buildTVFaces mmesh for i = 1 to mmesh.numfaces do(setTVFace mmesh i (getFace mmesh i))</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>collapseStack &lt;node&gt; -- mapped \n\
</pre></div><p>Collapses the object space modifiers out of a stack, leaving a resultant base object corresponding to the evaluation result on top of the node(s)&#39; stack. This means that the result is Editable_Meshonly when the result on top of the stack is Editable_Mesh. Some modifiers convert the object class implicitly, for example, a Box with MeshSmooth on top collapses to Editable_Poly because MeshSmooth implicitly converts the incoming geometry to polygons. Adding a MeshSelector a TurnToMesh modifier on top of the MeshSmooth modifier and then calling <span class=\'code\'>collapseStack()</span> results in an Editable_Mesh base object.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` b = box() --create a box --&gt; $Box:Box01 @ [0.000000,0.000000,0.000000] addModifier b (MeshSmooth()) --add meshSmooth modifier --&gt; OK classof b --check the class - it was turned into Polygons! --&gt; PolyMeshObject collapseStack b --collapse the stack of the box --&gt; OK classof b --the result is Editable_Poly --&gt; Editable_Poly addModifier b (Turn_To_Mesh()) --now add Turn To Mesh modifier --&gt; OK classof b --the class is now Editable_Mesh and not Editable_Poly! --&gt; Editable_mesh collapseStack b --collapse the stack --&gt; OK classof b --as expected, the result is an Editable_Mesh! --&gt; Editable_mesh</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>If there are no object space modifiers in the stack when this is called, no action is taken. So, if you want to force an object to be an editable mesh (for example, for the mesh operation listed below), you can apply a null modifier and then collapse the stack:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` b = box() --create a box --&gt; $Box:Box03 @ [0.000000,0.000000,0.000000] collapseStack b --try to collapse the stack --&gt; OK classof b --it is still a box - nothing to collapse! --&gt; Box addModifier b (meshSelect()) --add a MeshSelect modifier --&gt; OK collapseStack b --try to collapse the stack again --&gt; OK classof b --this time it worked! --&gt; Editable_mesh</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><span class=\'code\'>collapseStack()</span> does not collapse the effect of any world space modifiers (including bindings to SpaceWarps). The world space modifiers remain on the object&#39;s stack. To collapse an object with world space modifiers to a mesh use the <span class=\'code\'>snapshot()</span> method.</p>\n\
<div class=\'codeBlock\'><pre>snapshot &lt;node&gt; -- mapped\n\
</pre></div><p>This function provides functionality similar to the SnapShot tool in <strong>3ds Max</strong>. It generates a new node that contains a copy of the world-state mesh of the source &lt; <span class=\'code\'>node</span> &gt; at the time that the snapshot is made. Any existing modifiers are collapsed out of the new node and the mesh snapshot accounts for any currently applied space warps.</p>\n\
<div class=\'codeBlock\'><pre>convertToMesh &lt;node&gt; -- mapped\n\
</pre></div><p>Converts appropriate scene object types into Editable Meshes. Similar to <span class=\'code\'>collapseStack()</span> , it removes all object space modifiers that are present, but unlike <span class=\'code\'>collapseStack()</span> it <strong>always</strong> replaces the base object with an editable mesh version, even if there are no modifiers present.</p>\n\
<p>It can be applied to any object that an Edit Mesh modifier can work on such as, geometry and shapes, but not helpers, space warps, lights, and others.</p>\n\
<div class=\'codeBlock\'><pre>convertTo &lt;node&gt; [ TriMeshGeometry | Mesh ] -- mapped\n\
</pre></div><p>Converts appropriate scene object types into Editable Meshes. Operates in an identical manner to <span class=\'code\'>convertToMesh()</span> .</p>\n\
<p><strong>Constructors (TriMesh)</strong></p>\n\
<div class=\'codeBlock\'><pre>TriMesh() \n\
</pre></div><p>Creates an empty TriMesh. Use the methods listed below to build the mesh.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.mesh \n\
</pre></div><p>Extracts a copy of a node&#39;s world state if it is convertible to a mesh.</p>\n\
<div class=\'codeBlock\'><pre>&lt;editable_mesh_baseobject&gt;.mesh \n\
</pre></div><p>Extracts a copy of base object&#39;s mesh.</p>\n\
<div class=\'codeBlock\'><pre>&lt;trimesh&gt;.mesh \n\
</pre></div><p>Extracts a copy of another TriMesh&#39;s mesh.</p>\n\
<p>Note: <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Subclasses/GeometryClass-Node/GeometryClass-Common-Properties.html\' title=\'\'>GeometryClass boolean operations</a> also create editable_mesh objects.</p>\n\
<p><strong>Operators</strong></p>\n\
<p>The following operators perform boolean operations on meshes. These operations destructively modify the first operand mesh to contain the boolean result as do the same boolean &lt; <span class=\'code\'>node</span> &gt; operations.</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt; + &lt;mesh&gt; -- union\n\
&lt;mesh&gt; - &lt;mesh&gt; -- difference\n\
&lt;mesh&gt; * &lt;mesh&gt; -- intersection\n\
\n\
</pre></div><p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.numverts Integer \n\
</pre></div><p>Get or set the number of vertices. When setting the number of vertices using the <span class=\'code\'>numVerts</span> property or the <span class=\'code\'>setNumVerts</span> method, the new vertices are initialized to [0.,0.,0.].</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.numfaces Integer \n\
</pre></div><p>Get or set the number of faces.</p>\n\
<p>In versions prior to <strong>3ds Max 7</strong>, the user was responsible for re-initializing the mesh to make it valid before calling update. In <strong>3ds Max 7 and higher</strong>, the re-initializing is performed automatically when setting the <span class=\'code\'>.numfaces</span> value or calling the <span class=\'code\'>setNumFaces</span> function.</p>\n\
<p>Note:</p>\n\
<div class=\'codeBlock\'><pre>$.numfaces=300\n\
--is equivalent to\n\
setNumFaces $ 300 false\n\
--The false argument means to not keep the existing topology\n\
\n\
</pre></div><p><strong>For all new faces, the following occurs:</strong></p>\n\
<ul>\n\
<li><p>Smoothing group set to 1</p></li>\n\
<li><p>Vertices are set to [1,1,1] (1-based, crashes if # verts is 0 at update. It is expected at this point)</p></li>\n\
<li><p>Material ID is set to 1 (1-based)</p></li>\n\
<li><p>For each map channel in use:</p>\n\
<ul>\n\
<li><p>the map face verts are set to [1,1,1]</p></li>\n\
<li><p>if keep is false, the number of map verts is set to 1, and its verts are set to [1,1,1] (1-based)</p></li>\n\
</ul></li>\n\
</ul>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.numtverts Integer \n\
</pre></div><p>Get or set the number of texture vertices. When setting the number of texture vertices using the <span class=\'code\'>numTVerts</span> property or <span class=\'code\'>setNumTVerts</span> method, the new verts are initialized to [0.,0.,0.].</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.numcpvverts Integer \n\
</pre></div><p>Get or set the number of color-per-vertex vertices. When setting the number of CPV vertices using the <span class=\'code\'>numCPTVerts</span> property or <span class=\'code\'>setNumCPVVerts</span> method, the new verts are initialized to [0.,0.,0.].</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.mesh TriMesh \n\
</pre></div><p>Reading this property yields a copy of the mesh, taken after applying any modifiers, but before any space warps are applied. Assigning to this property sets the mesh to the TriMesh value given. You can use this property, along with <span class=\'code\'>copy()</span> and the <span class=\'code\'>&lt;node_or_baseobject&gt;.mesh</span> property to build a TriMesh from other objects&#39;meshes.</p>\n\
<p>Note: The following properties are <strong>not</strong> applicable to TriMeshes:</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.selectedVerts VertexArray \n\
</pre></div><p>Get the currently selected vertices of the Editable_Mesh object. See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/VertexSelection-Values.html\' title=\'\'>VertexSelection Values</a>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.verts VertexArray \n\
</pre></div><p>Get all of the vertices of the Editable_Mesh object. See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/VertexSelection-Values.html\' title=\'\'>VertexSelection Values</a>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.selectedFaces FaceArray \n\
</pre></div><p>Get the currently selected faces of the Editable_Mesh object. See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/FaceSelection-Values.html\' title=\'\'>FaceSelection Values</a>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.Faces FaceArray \n\
</pre></div><p>Get all of the faces of the Editable_Mesh object. See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/FaceSelection-Values.html\' title=\'\'>FaceSelection Values</a>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.selectedEdges EdgeArray \n\
</pre></div><p>Get the currently selected edges of the Editable_Mesh object. See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/EdgeSelection-Values.html\' title=\'\'>EdgeSelection Values</a>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.Edges EdgeArray \n\
</pre></div><p>Get all of the edges of the Editable_Mesh object. See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/EdgeSelection-Values.html\' title=\'\'>EdgeSelection Values</a>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.displacementMapping Boolean \n\
</pre></div><p>Get or set whether to perform displacement mapping for the Editable_Mesh object. There is no corresponding user interface element for this property.</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.subdivisionDisplacement Boolean \n\
</pre></div><p>Get or set whether to perform subdivision displacement for the Editable_Mesh object. This property corresponds to the Subdivision Displacement checkbox in the Surface Properties rollout.</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.splitMesh Boolean \n\
</pre></div><p>Get or set whether to split the mesh during subdivision displacement. This property corresponds to the Split Mesh checkbox in the Surface Properties rollout. Setting this property enables <span class=\'code\'>subdivisionDisplacement</span> if it is set to <span class=\'code\'>false</span> .</p>\n\
<p>You can both read and assign to the above properties with the exception of the properties that return a VertexSelection, FaceSelection, or EdgeSelection. If you assign numbers to them to add room for more vertices or faces, the mesh <strong>loses all current</strong> topology/geometry (vertices, faces, and edges), assuming you want to rebuild it from scratch. If you want to retain the current topology/geometry, use the <span class=\'code\'>setNumVerts()</span> , <span class=\'code\'>setNumTVerts()</span> , and <span class=\'code\'>setNumFaces()</span> methods that are described below.</p>\n\
<p>Up to N vertex coordinates are available as properties on Editable_Mesh objects, where N is the number of vertices in the mesh. A vertex is available as a property once a controller is assigned to the vertex. Controllers can be assigned to vertices using the <span class=\'code\'>animateVertex()</span> method described in <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Scripting-Vertex-and-Control/Scripting-Vertex-and-Control-1.html\' title=\'\'>Scripting Vertex and Control Point Animation</a> . For example, if a sphere object is collapsed to an Editable_Mesh, and some of its vertices are animated, the properties for the vertices are similar to:</p>\n\
<div class=\'codeBlock\'><pre>$Sphere01.vertex_209 Point3 value:[7.9,-40.0,0.0] -- animatable\n\
$Sphere01.vertex_210 Point3 value:[-7.8,-39.3,-7.9] -- animatable\n\
$Sphere01.vertex_211 Point3 value:[0.0,-40.0,-7.9] -- animatable\n\
\n\
</pre></div><div class=\'section\'><a id=\"methods\"></a><h3 id=\"methods\">Methods</h3></div>\n\
<p>The following methods operate on the base object in a node if no object space modifiers are present. If object space modifiers are present, the mesh <span class=\'code\'>get</span> operations access the world-state mesh, after the object space modifiers are applied. The mesh <span class=\'code\'>set</span> operations <strong>only</strong> work on base object Editable Meshes and signal an error if there are object space modifiers present, informing you that the mesh is not changeable when modifiers are present. You can convert objects to Editable Meshes with the <span class=\'code\'>collapseStack()</span> , <span class=\'code\'>snapshot()</span> , and <span class=\'code\'>convertToMesh()</span> methods. If there are no object space modifiers present, both <span class=\'code\'>get</span> and <span class=\'code\'>set</span> operations work on the base editable mesh object.</p>\n\
<p>Because the mesh <span class=\'code\'>get</span> operations require a mesh, the combination of base object and modifiers must yield a mesh at the top of the modifier stack. This excludes combinations such as, Patch base-objects and deformer modifiers like bend and twist because they pass a patch object and not a mesh up the stack. Applying an Edit Mesh modifier always forces the world-state object to be a mesh.</p>\n\
<p>If world space modifiers are present, the mesh <span class=\'code\'>get</span> operations access the world-state mesh after any object space modifiers are applied, but before the world space modifiers are applied. Currently, you cannot access the position of vertices as affected by world space modifiers. The mesh <span class=\'code\'>set</span> operations work only when world space modifiers are applied to the object. Setting a vertices position in such a case sets its position before the world space modifiers are applied. You can create a new mesh object using the <span class=\'code\'>snapshot()</span> method which accounts for the effects of world space modifiers.</p>\n\
<p>The <span class=\'code\'>update()</span> method makes any scripted changes to a base object mesh visible to <strong>3ds Max</strong> and you <strong>must</strong> call this function at some point after modifying a mesh so that <strong>3ds Max</strong> sees a valid mesh. Because this update can be a compute-intensive operation, it is made available as a separate function so you perform many changes on a mesh and then invoke the update just once to signal all the changes to <strong>3ds Max</strong>.</p>\n\
<p>All vertex and face indexes <strong>start at 1</strong>, following the other indexing conventions in MAXScript. All coordinates used are relative to the current working coordinate system.</p>\n\
<div class=\'section\'><a id=\"general-methods\"></a><h3 id=\"general-methods\">General Methods</h3></div>\n\
<div class=\'codeBlock\'><pre>update &lt;mesh&gt; [ geometry:&lt;boolean&gt; ] [ topology:&lt;boolean&gt; ] [ normals:&lt;boolean&gt; ] -- mapped\n\
</pre></div><p>The three optional keyword arguments provide control over the kind of update done to the mesh. If the <span class=\'code\'>geometry:</span> argument is <span class=\'code\'>true</span> , the geometry cache is rebuilt (normals and edge list) and the mesh&#39;s bounding box is invalidated. If the <span class=\'code\'>topology:</span> argument is <span class=\'code\'>true</span> , the edge and strip databases are rebuilt. If <span class=\'code\'>normals:</span> is <span class=\'code\'>true</span> , the face normals are computed. All flags default to <span class=\'code\'>true</span> so that a simple call to <span class=\'code\'>update()</span> causes a complete reconstruction of all the caches.</p>\n\
<div class=\'codeBlock\'><pre>attach &lt;mesh&gt; &lt;node&gt; \n\
</pre></div><p>Corresponds to the mesh attach function in the Editable Mesh Modify panel allowing you to construct a mesh by adding complete objects to it. Extracts the mesh from <span class=\'code\'>&lt;node&gt;</span> (first converting to a mesh, if needed), adds it to <span class=\'code\'>&lt;mesh&gt;</span> which must be an Editable Mesh object, and then deletes <span class=\'code\'>&lt;node&gt;</span> . The materials and material IDs in <span class=\'code\'>&lt;node&gt;</span> are merged into <span class=\'code\'>&lt;node&gt;</span> using the default settings for the attach operation in the Editable Mesh Modify panel. This method is not applicable to TriMeshes.</p>\n\
<div class=\'codeBlock\'><pre>meshop.attach{&lt;target_editable_mesh_node&gt; | &lt;target_mesh&gt;} \\ \n\
{&lt;source_node&gt; | &lt;source_mesh&gt;} \\ \n\
targetNode:&lt;node=unsupplied&gt; \\ \n\
sourceNode:&lt;node=unsupplied&gt; \\ \n\
attachMat:&lt;{#neither | #MatToID | #IDToMat}=#neither&gt;\\ \n\
condenseMat:&lt;boolean=true&gt; \\ \n\
deleteSourceNode:&lt;boolean=true&gt; \n\
</pre></div><p>Attaches the source mesh to the target mesh. If the target or source is specified as a mesh rather than a node, the mesh is attached using the local coordinate system of the mesh, and no material correction is performed. To get around this, if the target or source is a mesh, the corresponding <span class=\'code\'>targetNode</span> or <span class=\'code\'>sourceNode</span> named parameter is checked to see if a node is specified and, if so, the transform and material for that node is used. If the source or target is specified as a node, the corresponding <span class=\'code\'>targetNode</span> or <span class=\'code\'>sourceNode</span> named parameter is not checked. The <span class=\'code\'>attachMat</span> and <span class=\'code\'>condenseMat</span> options correspond to the attach options in the editable mesh.</p>\n\
<p><span class=\'code\'>condenseMat</span> is applicable only if <span class=\'code\'>attachMat:#IDToMat</span> is specified. If <span class=\'code\'>deleteSourceNode:false</span> is not specified, and the source was specified as a node, or as a mesh and a <span class=\'code\'>sourceNode</span> was specified, the source node is deleted after the attach.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` meshop.attach $.baseobject \\(sphere02 targetNode:\\) meshop.attach $box01 $box02 attachMat:#IDToMat<br> condenseMat:true deleteSourceNode:false</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>meshopgetUIParam. &lt;mesh&gt; &lt;param_name&gt; \n\
meshop.getUIParam &lt;node&gt; [ &lt;modifier_or_index&gt; ] &lt;param_name&gt; \n\
meshop.setUIParam &lt;mesh&gt; &lt;param_name&gt; { &lt;float&gt; | &lt;boolean&gt; } \n\
meshop.setUIParam &lt;node&gt; [ &lt;modifier_or_index&gt; ] &lt;param_name&gt; { &lt;number&gt; | &lt;boolean&gt; } \n\
</pre></div><p>Get/set a user-interface value. The optional <span class=\'code\'>&lt;modifier_or_index&gt;</span> identifies the Edit Mesh modifier on the given scene object to set the parameter value. These methods are UI-dependent, and require that the specified editable mesh or Edit Mesh modifier be currently displayed in the Modify panel. The valid <span class=\'code\'>param_name</span> values, their meaning, and parameter value type are:</p>\n\
<p><span class=\'code\'>#SelByVert</span> Selection - By Vertex (boolean)</p>\n\
<p><span class=\'code\'>#IgBack</span> Selection - Ignore Backfacing (boolean)</p>\n\
<p><span class=\'code\'>#IgnoreVis</span> Selection - Ignore Visibile Edges (boolean)</p>\n\
<p><span class=\'code\'>#PolyThresh</span> Selection - Planar Threshold (number)</p>\n\
<p><span class=\'code\'>#SoftSel</span> Soft Selection - Use Soft Selection (boolean)</p>\n\
<p><span class=\'code\'>#SSUseEDist</span> Soft Selection - Edge Distance (boolean)</p>\n\
<p><span class=\'code\'>#SSEDist</span> Soft Selection - Edge Distance (number) [note: if value has not changed, returns a value of 0]</p>\n\
<p><span class=\'code\'>#SSBack</span> Soft Selection - Ignore Backfacing (boolean) [note: this is the inverse of the UI element]</p>\n\
<p><span class=\'code\'>#Falloff</span> Soft Selection - Falloff (number)</p>\n\
<p><span class=\'code\'>#Pinch</span> Soft Selection - Pinch (number)</p>\n\
<p><span class=\'code\'>#Bubble</span> Soft Selection - Bubble (number)</p>\n\
<p><span class=\'code\'>#WeldDist</span> Weld - Distance (number)</p>\n\
<p><span class=\'code\'>#WeldBoxSize</span> Weld - Box Size in Pixels (number)</p>\n\
<p><span class=\'code\'>#ExtrudeType</span> Extrude/Chamfer (boolean) [note: true - Group; false - Local]</p>\n\
<p><span class=\'code\'>#ShowVNormals</span> Show Vertex Normals (boolean)</p>\n\
<p><span class=\'code\'>#ShowFNormals</span> Show Face Normals (boolean)</p>\n\
<p><span class=\'code\'>#NormalSize</span> Normal Scale (number)</p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;mesh_weld_overlapping_vertices &lt;TriMesh&gt;mesh\n\
</pre></div><p>Welds the overlapping vertices of a TriMesh. Available in <strong>in 3ds Max 2017 and higher</strong>.</p>\n\
<p><strong>For example:</strong></p>\n\
<div class=\'codeBlock\'><pre>s = sphere segs:128 --create a sphere with 128 segments\n\
--&gt; $Sphere:Sphere001 @ [0.000000,0.000000,0.000000]\n\
\n\
convertToMesh s --convert to Editable Mesh\n\
--&gt; $Editable_Mesh:Sphere001 @ [0.000000,0.000000,0.000000]\n\
\n\
s.numverts --check the number of vertices\n\
--&gt; 8066\n\
\n\
s1 = copy s --clone the sphere as a copy\n\
--&gt; $Editable_Mesh:Sphere002 @ [0.000000,0.000000,0.000000]\n\
\n\
attach s s1 --attach the copy to the original\n\
--&gt; OK\n\
\n\
s.numverts --check number of vertices again – it is doubled\n\
--&gt; 16132\n\
\n\
mesh_weld_overlapping_vertices s.mesh --weld the overlapping vertices\n\
--&gt; 0.888889\n\
\n\
s.numverts --check the number of vertices again...\n\
--&gt; 8066\n\
</pre></div><p><strong>Further Mesh-Related Topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Mesh-Vertex-Methods.html\' title=\'\'>Vertex Methods</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Meshop-Vertex-Methods.html\' title=\'\'>Vertex Methods (meshop struct)</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Meshop-Vertex-Data-Methods.html\' title=\'\'>Vertex Data Methods (meshop struct)</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Mesh-Edge-Methods.html\' title=\'\'>Edge Methods</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Meshop-Edge-Methods.html\' title=\'\'>Edge Methods (meshop struct)</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Mesh-Face-Methods.html\' title=\'\'>Face Methods</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Meshop-Face-Methods.html\' title=\'\'>Face Methods (meshop struct)</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Mesh-Methods.html\' title=\'\'>Mesh Methods (meshop struct)</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Meshop-General-Mapping-Methods.html\' title=\'\'>Mapping Methods - General (meshop struct)</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Mesh-Texture-Vertex-Methods.html\' title=\'\'>Texture Vertex Methods</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Mesh-Color-Per-Vertex-Methods.html\' title=\'\'>Color-Per-Vertex Methods</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Mesh-Subdivision-Displacement.html\' title=\'\'>Subdivision Displacement Surface Properties Methods</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Meshop-Editable_Mesh-UI-property.html\' title=\'\'>Editable Mesh UI Property Methods (meshop struct)</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Editable_Mesh-Modify-Panel.html\' title=\'\'>Editable Mesh Modify Panel Command Modes and Operations (meshOps struct)</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";