var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Mesh Texture Vertex Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Mesh Texture Vertex Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"mesh-texture-vertex-methods\"></a></div>\n\
<p>The following methods provide basic access to the legacy UVW channel.</p>\n\
<p>Note: When MAXScript was first introduced in <strong>3ds Max 2</strong>, there were only two mapping channels, with Channel 1 being the original texture channel of <strong>3ds Max 1</strong>. For generalized access to all 100 map channels, you should consider using the methods described in <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Meshop-General-Mapping-Methods.html\' title=\'\'>Meshop General Mapping Methods</a>.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>getNumTVerts &lt;mesh&gt;\n\
</pre></div><p>Returns number of texture vertices as an integer, equivalent to using <span class=\'code\'>&lt;mesh&gt;.numtverts</span></p>\n\
<div class=\'codeBlock\'><pre>setNumTVerts &lt;mesh&gt; &lt;number&gt; [ &lt;boolean&gt; ]\n\
</pre></div><p>Sets the number of texture vertices as specified. If the optional boolean argument is <span class=\'code\'>true</span> , the existing topology remains intact. If it is <span class=\'code\'>false</span> or not supplied, the topology is lost.</p>\n\
<p>When setting the number of texture vertices using the <span class=\'code\'>numTVerts</span> property or <span class=\'code\'>setNumTVerts</span> method, the new verts are initialized to [0.,0.,0.]</p>\n\
<div class=\'codeBlock\'><pre>getTVert &lt;mesh&gt; &lt;tvert_index_integer&gt;\n\
</pre></div><p>Returns the UVW coordinates of the indexed texture vertex</p>\n\
<div class=\'codeBlock\'><pre>setTVert &lt;mesh&gt; &lt;tvert_index_integer&gt; ( &lt;point3&gt; | &lt;x&gt; &lt;y&gt; &lt;z&gt; )\n\
</pre></div><p>Sets the UVW coordinates of the indexed texture vertex as a point3 value, or 3 floats - U,V,W</p>\n\
<div class=\'codeBlock\'><pre>getTVFace &lt;mesh&gt; &lt;face_index_integer&gt;\n\
\n\
setTVFace &lt;mesh&gt; &lt;face_index_integer&gt; &lt;vert_indices_point3&gt;\n\
\n\
setTVFace &lt;mesh&gt; &lt;face_index_integer&gt; &lt;tvert_index_integer&gt; &lt;tvert_index_integer&gt; &lt;tvert_index_integer&gt;\n\
\n\
</pre></div><p>The <span class=\'code\'>getTVFace()</span> and <span class=\'code\'>setTVFace()</span> functions mirror the <span class=\'code\'>getFace()</span> and <span class=\'code\'>setFace()</span> functions and are used to specify texture mapping topology in terms of texture vertices. You can set up and access texture vertices with the <span class=\'code\'>getTVert()</span> , <span class=\'code\'>setTVert()</span> , <span class=\'code\'>getNumTVerts()</span> , and <span class=\'code\'>setNumTVerts()</span> functions described above.</p>\n\
<div class=\'codeBlock\'><pre>buildTVFaces &lt;mesh&gt; [ &lt;boolean&gt; ]\n\
</pre></div><p>The <span class=\'code\'>buildTVFaces()</span> function only needs to be called on meshes you are adding texture vertices to yourself to create the internal texture face array. Meshes that <strong>3ds Max</strong> applies mapping coordinates to maintain the <span class=\'code\'>TVFace</span> array automatically. This is not done automatically when you add texture vertices to meshes yourself so you need to call <span class=\'code\'>buildTVFaces()</span> explicitly whenever you change the <span class=\'code\'>texture vertex</span> count, and before you construct the texture faces. If the optional boolean argument is <span class=\'code\'>true</span> , the existing texture mapping remains intact. If it is <span class=\'code\'>false</span> or not supplied, the existing texture mapping is lost (all texture faces are rebuilt, with all three vertices of the texture face using texture vertex 1).</p>\n\
<div class=\'codeBlock\'><pre>numMapsUsed &lt;mesh&gt;\n\
</pre></div><p>Returns the an upper limit on the number of texture map channels used by the given node. This is at least 1+(highest channel in use). This method is used so a script that does something to all map channels doesn&#39;t always have to do it to every channel up to 99 (the highest possible texture map channel), but rather only to this value. This method is not applicable to TriMeshes.</p>\n\
<p>Note:</p>\n\
<p>The mesh class contains a list of texture vertices which are completely independent of the regular vertices in the mesh. There is no correlation between the number of vertices in a mesh and the number of texture vertices. In addition to the texture vertices there are also texture faces. There needs to be one texture face for every regular face in the mesh.</p>\n\
<p>Each texture face has three indices into the texture vertex array. The coordinates of a texture vertex are UVW coordinates, and are accessed as Point3 values. The 3 components are U, V, and W, and each component value is in the range of 0 to 1. An example script for creating planar texture mapping on an object is shown in <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Working-with-Editable-Meshes-1.html\' title=\'\'>Working with Editable Meshes</a>.</p>\n\
<p>A detailed explanation of the way texture and color-per-vertex data is used can be found in the topic <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Understanding-Texture.html\' title=\'\'>Understanding Texture Coordinates and Vertex Colors</a></p>\n\
<p>The texture vertex methods do not support multiple mapping channels. Use the respective <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Meshop-General-Mapping-Methods.html\' title=\'\'>General Meshop Mapping Methods</a> instead.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";