var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Mesh Vertex Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Mesh Vertex Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"mesh-vertex-methods\"></a></div>\n\
<p>The following methods provide basic access the to Mesh vertices and vertex normals.</p>\n\
<p>{{toc}}</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'section\'><a id=\"mesh-vertexaccess\"></a><h2 id=\"mesh-vertexaccess\">Mesh VertexAccess:</h2></div>\n\
<div class=\'codeBlock\'><pre>getNumVerts &lt;mesh&gt;\n\
</pre></div><p>Returns number of vertices as an integer, equivalent to using <span class=\'code\'>&lt;mesh&gt;.numverts.</span></p>\n\
<div class=\'codeBlock\'><pre>setNumVerts &lt;mesh&gt; &lt;vert_index_integer&gt; [ &lt;boolean&gt; ]\n\
</pre></div><p>Set the number of vertices as specified. If the optional boolean argument is <span class=\'code\'>true</span> , the existing topology remains intact. If it is <span class=\'code\'>false</span> or left off, the topology is lost.</p>\n\
<p>When setting the number of vertices using the <span class=\'code\'>numVerts</span> property or the <span class=\'code\'>setNumVerts</span> method, the new vertices are initialized to [0.,0.,0.]</p>\n\
<div class=\'codeBlock\'><pre>getVert &lt;mesh&gt; &lt;vert_index_integer&gt;\n\
</pre></div><p>Returns the position (in the current working coordinate system) of the indexed vertex as a point3</p>\n\
<div class=\'codeBlock\'><pre>setVert &lt;mesh&gt; &lt;vert_index_integer&gt; ( &lt;point3&gt; | &lt;float&gt; &lt;float&gt; &lt;float&gt; )\n\
</pre></div><p>Sets the position coordinates of the indexed vertex as a point3 value, or 3 floats - X,Y,Z</p>\n\
<blockquote>\n\
<p>Warning: This low-level mesh method does NOT handle creation of vertex animation, even if the vertices have been prepared using <span class=\'code\'>animateVertex theMesh #all</span> and the method is called within an <span class=\'code\'>animate on</span> context! To operate on animated meshes, use the <span class=\'code\'>meshop.setVert()</span> method instead.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` obj = sphere() --create a Sphere convertToMesh obj --collapse to EditableMesh for v = 1 to getNumVerts obj do --loop through all vertices ( vert = getVert obj v --get the v-th vertex vert.z = 0.0 --change the Z coordinate to 0.0 setVert obj v vert --assign back to the v-thvertex ) update obj --update the mesh - the sphere should be flattened</p>\n\
<p>```</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-56447D3E-6486-4BD6-BA00-E4FDE47F2A78-low.gif\' title=\'\'></div>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>deleteVert &lt;mesh&gt; &lt;vert_index_integer&gt;\n\
</pre></div><p>Deletes the indexed vertex from the mesh and all faces that share the vertex. Renumbers vertices and faces to account for the deletions. Also adjusts face vertex indexes as necessary.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` p = plane() --create a Plane convertToMesh p --collapse toEditable_Mesh deleteVert p 13 --delete vertex 13 (the middle vertex) update p --update the mesh</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"meshvertex-normal\"></a><h2 id=\"meshvertex-normal\">MeshVertex Normal</h2></div>\n\
<div class=\'codeBlock\'><pre>getNormal &lt;mesh&gt; &lt;vert_index_integer&gt;\n\
</pre></div><p>Returns the normal at the indexed vertex&#39;s position as a point3. The normal is based on the faces that use the vertex and the smoothing groups assigned to those faces.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` obj = geosphere() --create a GeoSphere convertToMesh obj --collapse to Editable_Mesh --Count backwards from the last vertex to the first. --This is necessary because we intend to deletevertices --and this will renumber the remaining ones. Counting backwards --ensures the renumbering does not affect the loop: for v = obj.numVerts to 1 by -1 do ( --get the vertex normal and get the dot product with the +Z vector --If the result is less than the specifiedthreshold, --then delete the vertex the normal belongs to if dot (getNormal obj v) [0,0,1] &lt;= -0.25 do deleteVert obj v ) update obj --update the mesh</p>\n\
<p>```</p>\n\
<p><img src=\'developer/images/GUID-9F608830-AD1F-47DC-8659-BDDF9D3589A3-low.gif\' title=\'\'> <img src=\'developer/images/GUID-FFF48B7D-6F91-49AE-BE53-1FCD3F4457A1-low.gif\' title=\'\'></p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>setNormal &lt;mesh&gt; &lt;vert_index_integer&gt; &lt;point3&gt;\n\
</pre></div><p>Sets the indexed vertex&#39;s normal vector.</p>\n\
<p>Since <strong>3ds Max 2015</strong>, setting a vertex normal sets the normal as Explicit, so it will retain its value when the mesh gets updated. In versions prior to <strong>3ds Max 2015</strong>, setting the vertex normal using MAXScript had only a very short lasting effect because the data would be easily overwritten by the Smoothing Group-based implicit normal recalculation on viewport redraw or scene rendering.</p>\n\
<div class=\'section\'><a id=\"meshvertex-selection\"></a><h2 id=\"meshvertex-selection\">MeshVertex Selection:</h2></div>\n\
<div class=\'codeBlock\'><pre>getVertSelection &lt;node&gt; [ &lt;modifier_or_index&gt; ] [ name:&lt;name&gt; ]\n\
getVertSelection &lt;mesh&gt;\n\
\n\
</pre></div><p>Returns the current vertex selection set, or the specified named selection set if the optional <span class=\'code\'>name:</span> parameter is specified, as a BitArray. The optional <span class=\'code\'>&lt;modifier_or_index&gt;</span> identifies the Edit Mesh, Mesh Select, or Poly Select modifier on the given scene object from which the selection BitArray is obtained.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` getVertSelection $foo $foo.modifiers[3]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>If the optional <span class=\'code\'>&lt;modifier_or_index&gt;</span> argument is not supplied, the <span class=\'code\'>&lt;node&gt;</span> must be an Editable Mesh object and the selection is taken from <em>the top of the modifier stack</em>. If <span class=\'code\'>&lt;modifier_or_index&gt;</span> is supplied, it must be either a modifier on the node or a number. If it is a modifier, it must be either an Edit Mesh or a Mesh Select modifier. If it is a number, it is used as an index into the Edit Mesh/Select Modifiers on the <span class=\'code\'>&lt;node&gt;</span> starting from the top of the stack.</p>\n\
<p>Note:</p>\n\
<p>The index <strong>does not count</strong> any other types of modifier present! So, an index of 1 will always get the selection currently active at the top of the stack.</p>\n\
<p>The function returns a BitArray with bits set for the 1-based indices of the currently selected vertices, or the vertices specified by the named selection set, in the object by the given modifier.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` getVertSelection $foo $foo.modifiers[3]</p>\n\
<p>```</p>\n\
<p><strong>RETURNS</strong></p>\n\
<p>``` #{2..5,9,25..27}</p>\n\
<p>```</p>\n\
<p>This is a <strong>snapshot</strong> of the selection—the BitArray doesn&#39;t change automatically as you make different selections. Further, it reflects the current vertex selection whether or not the modifier is in vertex sub-object selection mode (this selection is remembered and re-established whenever you go back into vertex subobject mode). So, for example, if you select some vertices then click out of vertex subobject mode, the whole object rather than the selection is passed up the stack to the next modifier, but <span class=\'code\'>getVertSelection()</span> returns the selected vertices at the time the subobject mode was exited.</p>\n\
<p>You might use the <span class=\'code\'>modifiers</span> modifier array accessing scheme here if you&#39;ve got many edit mesh modifiers with non-unique names. You can also use a constructed string as an index into the <span class=\'code\'>modifiers</span> array,</p>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` $foo.modifiers[&quot;edit mesh&quot;+ i as string]</p>\n\
<p>```</p>\n\
<p>assuming the variable <span class=\'code\'>&#39;i&#39;</span> had some indexing value and the names were set up thusly. <span class=\'code\'>&#39;+&#39;</span> on strings concatenates.</p>\n\
<p>To access the selection from the EditableMesh base object when there are modifiers present on the stack, you should access the TriMesh value of the base object,</p>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` getVertSelection $foo.baseobject.mesh</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>setVertSelection &lt;node&gt; [&lt;modifier_or_index&gt;]( &lt;sel_bitarray&gt; | &lt;sel_array&gt; ) [name:&lt;name&gt;] [keep:&lt;boolean&gt;]\n\
setVertSelection &lt;mesh&gt; ( &lt;sel_bitarray&gt; | &lt;sel_array&gt; )[keep:&lt;boolean&gt;]\n\
</pre></div><p>Sets the vertex selections in an Editable Mesh base object, Mesh Select modifier, Edit Mesh Modifier, Poly Select Modifier, or TriMesh. This mirrors the selection getting method above.</p>\n\
<p>The <span class=\'code\'>&lt;modifier_or_index&gt;</span> argument is interpreted as for the get- form above, except that <strong>only</strong> the Mesh Select and Poly Select modifiers are supported for set operations.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` setVertSelection $foo #{1..4,100..102} setFaceSelection $foo (getFaceSelection $baz) keep:true</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>If the optional <span class=\'code\'>name:</span> argument is specified, the vertices in the specified named selection set in the Editable Mesh or Mesh Select modifier are selected. If the <span class=\'code\'>name:</span> argument is not specified, the selection index argument gives the indexes of the sub-object items to be selected as either a BitArray or an array of integers. If the optional <span class=\'code\'>keep:</span> keyword argument is <span class=\'code\'>false</span> or not supplied, any current selection will be replaced by the new one. If the <span class=\'code\'>keep:</span> keyword argument is <span class=\'code\'>true</span> , the new selection is <strong>added</strong> to the current selection. The <span class=\'code\'>name:</span> argument is not applicable to TriMeshes.</p>\n\
<p>Use the mesh <span class=\'code\'>update()</span> function after making a group of selection changes in order to make them visible to any modifiers on the object.</p>\n\
<div class=\'codeBlock\'><pre>averageSelVertCenter &lt;node&gt;\n\
</pre></div><p>Returns the average position (center) of the selected vertices in the given mesh as a Point3. If the object is not a mesh this method returns undefined. If no vertices are selected in the mesh, a value of [0,0,0] is returned. This method is not applicable to TriMeshes.</p>\n\
<div class=\'codeBlock\'><pre>averageSelVertNormal &lt;node&gt;\n\
</pre></div><p>Returns the normalized average of the normals of the selected vertices in the given mesh as a Point3. If the given node is not a mesh, it returns undefined. If no vertices are selected in the mesh, or the averaged normal is [0,0,0], a value of [1,0,0] is returned. This method is not applicable to TriMeshes.</p>\n\
<p>The vertex normals used in this method do not consider smoothing group data of the faces that use the vertex.</p>\n\
<p><strong>For more mesh-related methods, see:</strong></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Editable_Mesh-GeometryClass-and.html\' title=\'\'>Editable_Mesh : GeometryClass and TriMesh : Value</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";