var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Meshop Vertex Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Meshop Vertex Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"meshop-vertex-methods\"></a></div>\n\
<p>The following methods exposed by the <strong>meshOp Struct</strong> provide advanced access to the Mesh vertices.</p>\n\
<p>{{toc}}</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'section\'><a id=\"mesh-vertex-access\"></a><h2 id=\"mesh-vertex-access\">Mesh Vertex Access</h2></div>\n\
<div class=\'codeBlock\'><pre>meshop.getNumVerts &lt;Mesh mesh&gt;\n\
</pre></div><p>Returns the number of vertices in the mesh.</p>\n\
<div class=\'codeBlock\'><pre>meshop.setNumVerts &lt;Mesh mesh&gt; &lt;int&gt;\n\
</pre></div><p>Sets the number of vertices in the mesh. Any new vertices are created at [0,0,0] in the mesh&#39;s local coordinate system.</p>\n\
<div class=\'codeBlock\'><pre>meshop.getVert &lt;Mesh mesh&gt; &lt;int vertIndex&gt; node:&lt;node=unsupplied&gt;\n\
</pre></div><p>Returns the position of the specified vertex. If <span class=\'code\'>&lt;mesh&gt;</span> is a node, or if <span class=\'code\'>&lt;mesh&gt;</span> is an Editable Mesh or a Mesh value and <span class=\'code\'>node:</span> is specified, the position returned is in the current coordinate system context. If <span class=\'code\'>&lt;mesh&gt;</span> is an Editable Mesh or a Mesh value and <span class=\'code\'>node:</span> is not specified, the return value is in the mesh&#39;s local coordinate system.</p>\n\
<div class=\'codeBlock\'><pre>&lt;point3_array&gt; meshop.getVerts &lt;Mesh mesh&gt; &lt;vertlist&gt; node:&lt;node=unsupplied&gt;\n\
</pre></div><p>Available in <strong>3ds Max 2018.2 and higher</strong>: Returns an array of the positions of the specified vertices. If <span class=\'code\'>&lt;mesh&gt;</span> is a node, or if <span class=\'code\'>&lt;mesh&gt;</span> is an Editable Mesh or a Mesh value and <span class=\'code\'>node:</span> is specified, the positions returned are in the current coordinate system context. If <span class=\'code\'>&lt;mesh&gt;</span> is an Editable Mesh or a Mesh value and <span class=\'code\'>node:</span> is not specified, the return values are in the mesh&#39;s local coordinate system.</p>\n\
<div class=\'codeBlock\'><pre>meshop.setVert &lt;Mesh mesh&gt; &lt;vertlist&gt; {&lt;point3 pos&gt; | &lt;point3 pos_array&gt;} node:&lt;node=unsupplied&gt;\n\
</pre></div><p>Moves the specified vertices to the specified position. If <span class=\'code\'>&lt;mesh&gt;</span> is a node, or if <span class=\'code\'>&lt;mesh&gt;</span> is an Editable Mesh or a Mesh value and <span class=\'code\'>node:</span> is specified, the position is in the current coordinate system context. If <span class=\'code\'>&lt;mesh&gt;</span> is an Editable Mesh or a Mesh value and <span class=\'code\'>node:</span> is not specified, the position is in the mesh&#39;s local coordinate system.</p>\n\
<p>The positions can be optionally specified as array. In that case, the number of values in pos_array must match the number of vertices specified in vertlist.</p>\n\
<p>If executed in an animation on context or with the AutoKey button checked, animation keys will be created for the vertices of an Editable Mesh. This is not the case with the original <span class=\'code\'>setVert()</span> vertex method available since <strong>3ds Max 2</strong>.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<p>Note:</p>\n\
<p>It is very important to pass the <span class=\'code\'>&lt;vertlist&gt;</span> argument as a bitArray value and not as an array. Passing the argument as an array will cause a significant performance hit (orders of magnitude).</p>\n\
<p>This applies to all methods operating on sub-object lists.</p>\n\
<div class=\'codeBlock\'><pre>meshop.getVertexAngles &lt;Mesh mesh&gt; &lt;vertlist&gt;\n\
</pre></div><p>This method calculates for each vertex, the sum of the angles of this vertex&#39;s corner in each face it is on.</p>\n\
<p>So, for instance, a point lying in the middle of a grid will always have a vertex angle of 2*Pi (6.28319 radians, equal to 360 degrees), whereas a corner of a box will only have 3.0/2*Pi (4.71239 radians, equal to 270 degrees).</p>\n\
<p>Returns an array of size=(#vertices in <span class=\'code\'>mesh</span>). The array element for any vertices not specified in <span class=\'code\'>vertlist</span> will contain the value 0.</p>\n\
<div class=\'section\'><a id=\"vertex-color\"></a><h2 id=\"vertex-color\">Vertex Color</h2></div>\n\
<div class=\'codeBlock\'><pre>meshop.getVertsByColor &lt;Mesh mesh&gt; &lt;color color&gt; &lt;float red_thresh&gt; &lt;float green_thresh&gt; &lt;float blue_thresh&gt; channel:&lt;int=0&gt;\n\
</pre></div><p>Returns the vertices whose vertex color is within the color range as a <span class=\'code\'>&lt;bitarray&gt;</span>. The range values should be in the range of 0 to 255.</p>\n\
<div class=\'codeBlock\'><pre>meshop.getVertsByColor &lt;Mesh mesh&gt; &lt;point3 uvw&gt; &lt;Float u_thresh&gt; &lt;Float v_thresh&gt; &lt;Float w_thresh&gt; channel: &lt;int=0&gt;\n\
</pre></div><p>Returns the vertices whose vertex UVW is within the UVW range as a <span class=\'code\'>&lt;bitarray&gt;</span>. The range values should be in the range of 0 to 1.</p>\n\
<div class=\'codeBlock\'><pre>meshop.setVertColor &lt;Mesh mesh&gt; &lt;int mapChannel&gt; &lt;vertlist&gt; &lt;Color color&gt;\n\
</pre></div><p>Sets the vertex color for the specified vertices in the specified <span class=\'code\'>&lt;mapChannel&gt;</span>.</p>\n\
<div class=\'section\'><a id=\"new-vertices-using-break-chamfer-and-clone\"></a><h2 id=\"new-vertices-using-break-chamfer-and-clone\">New Vertices Using Break, Chamfer, and Clone</h2></div>\n\
<div class=\'codeBlock\'><pre>meshop.breakVerts &lt;Mesh mesh&gt; &lt;vertlist&gt;\n\
</pre></div><p>For each vertex in <span class=\'code\'>&lt;vertlist&gt;</span> , N-1 new vertices are created at the same location, where N is the number of faces using that vertex. Each of these faces will use one of these vertices.</p>\n\
<div class=\'codeBlock\'><pre>meshop.chamferVerts &lt;Mesh mesh&gt; &lt;vertlist&gt; &lt;float amount&gt;\n\
\n\
</pre></div><p>Chamfers the specified vertices by the specified amount.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` obj = plane() convertToMesh obj max modify mode select obj subObjectLevel = 1 meshop.chamferVerts obj #{13} 3.5</p>\n\
<p>```</p>\n\
<p><img src=\'developer/images/GUID-433C3FDB-164B-4125-8240-04B0146EAE96-low.gif\' title=\'\'> <img src=\'developer/images/GUID-A03E7380-3C1B-40D5-9992-EA4C9D64EB79-low.gif\' title=\'\'></p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>meshop.cloneVerts &lt;Mesh mesh&gt; &lt;vertlist&gt;\n\
</pre></div><p>Clones the specified vertices.</p>\n\
<div class=\'codeBlock\'><pre>meshop.detachVerts &lt;Mesh mesh&gt; &lt;vertlist&gt; delete:&lt;boolean=true&gt; asMesh:&lt;boolean=false&gt;\n\
</pre></div><p>Detaches the faces used by the specified vertices.</p>\n\
<p>If <span class=\'code\'>delete:</span> is <span class=\'code\'>true</span> , the faces are deleted after being detached.</p>\n\
<p>If <span class=\'code\'>delete:</span> is <span class=\'code\'>false</span> , the faces are not deleted.</p>\n\
<p>If <span class=\'code\'>asMesh:</span> is <span class=\'code\'>true</span> , the faces are detached and returned as a Mesh value.</p>\n\
<p>If <span class=\'code\'>asMesh:</span> is <span class=\'code\'>false</span> , the faces are detached as an element in the mesh and a value of <span class=\'code\'>OK</span> is returned.</p>\n\
<div class=\'section\'><a id=\"delete-vertices\"></a><h2 id=\"delete-vertices\">Delete Vertices</h2></div>\n\
<div class=\'codeBlock\'><pre>meshop.deleteIsoVerts &lt;Mesh mesh&gt;\n\
</pre></div><p>Deletes all vertices not used by a face.</p>\n\
<div class=\'codeBlock\'><pre>meshop.deleteVerts &lt;Mesh mesh&gt; &lt;vertlist&gt;\n\
</pre></div><p>Deletes the specified vertices.</p>\n\
<div class=\'section\'><a id=\"hidden-and-isolated-vertices\"></a><h2 id=\"hidden-and-isolated-vertices\">Hidden And Isolated Vertices</h2></div>\n\
<div class=\'codeBlock\'><pre>meshop.getHiddenVerts &lt;Mesh mesh&gt;\n\
</pre></div><p>Returns a bitarray of size=(#vertices inmesh) with bits set for all vertices that are hidden.</p>\n\
<div class=\'codeBlock\'><pre>meshop.setHiddenVerts &lt;Mesh mesh&gt; &lt;vertlist&gt;\n\
</pre></div><p>Sets the specified vertices as hidden, and non-specified vertices as visible.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` obj = plane() --create a plane convertToMesh obj --convert to Editable_Mesh --Hide half the vertices meshop.setHiddenVerts obj #{1..(obj.numverts/2)} update obj --update the mesh max modify mode --change to modify mode select obj --select the plane subObjectLevel = 1 --switch to vertex level to see the result</p>\n\
<p>```</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-D9D49D81-3C52-4B37-9340-D69A7773B8C4-low.gif\' title=\'\'></div>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>meshop.getIsoVerts &lt;Mesh mesh&gt;\n\
</pre></div><p>Returns a bitarray of size=(#vertices in <span class=\'code\'>mesh</span>) with bits set for all vertices that are not used by a face.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` obj = plane() --create a plane --&gt; $Plane:Plane001 @ [0.000000,0.000000,0.000000] convertToMesh obj --collapse to Editable_Mesh --&gt; $Editable_Mesh:Plane001 @ [0.000000,0.000000,0.000000] meshop.getIsoVerts obj --Get isolated vertices - none! --&gt; #{} --Delete the 8 faces in the middle of the plane, --leaving the middle isolated vertex undeleted meshop.deleteFaces obj #{11..14,19..22} delIsoVerts:false --&gt; OK update obj --update the mesh --&gt; OK meshop.getIsoVerts obj --check the isolated vertices - #13! --&gt; #{13}</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"min.-vertex-distance-from\"></a><h2 id=\"min.-vertex-distance-from\">Min. Vertex Distance From</h2></div>\n\
<div class=\'codeBlock\'><pre>meshop.minVertexDistanceFrom &lt;Mesh mesh&gt; &lt;int vertIndex&gt; &lt;vertlist&gt;\n\
</pre></div><p>Returns the minimal distance from <span class=\'code\'>&lt;vertIndex&gt;</span> to the vertices specified in <span class=\'code\'>&lt;vertlist&gt;</span>.</p>\n\
<div class=\'codeBlock\'><pre>meshop.minVertexDistancesFrom &lt;Mesh mesh&gt; &lt;vertlist&gt; &lt;int iterations&gt;\n\
</pre></div><p>This function computes distances from selected vertices (as indicated by <span class=\'code\'>&lt;vertlist&gt;</span>) to non-selected ones along edge paths. Returns an array of size=(#vertices in <span class=\'code\'>mesh</span>). Each element in this array is set to -1 if there is no selection. Otherwise, selected vertices have an array element value of 0; non-selected vertices that are <span class=\'code\'>&lt;iterations&gt;</span> or fewer edges away from a selected vertex are assigned the shortest edge-path distance to a selected vertex, and non-selected vertices that are more than <span class=\'code\'>&lt;iterations&gt;</span> edges away are set to -1. If <span class=\'code\'>&lt;iterations&gt;</span> is 0, the distances are computed from each vertex to the nearest selected vertex, regardless of topology. This is a very expensive algorithm, which takes almost 4 times as long for twice as many vertices. If <span class=\'code\'>&lt;iterations&gt;</span> is non-zero, it represents the number of edges one must &quot;travel&quot; in trying to find the nearest selected vertex; this means that it only takes twice as long for twice as many verts. This is like the Edge Distance parameter in EMesh&#39;s Soft Selection dialog.</p>\n\
<div class=\'section\'><a id=\"move-mesh-vertices\"></a><h2 id=\"move-mesh-vertices\">Move Mesh Vertices</h2></div>\n\
<div class=\'codeBlock\'><pre>meshop.moveVert &lt;Mesh mesh&gt; &lt;vertlist&gt; {&lt;point3 offset&gt; | &lt;point3 offset_array&gt;} node:&lt;node=unsupplied&gt; useSoftSel:&lt;boolean&gt;\n\
</pre></div><p>Moves the specified vertices by <span class=\'code\'>&lt;offset&gt;</span> .</p>\n\
<p>If <span class=\'code\'>&lt;mesh&gt;</span> is a node, or if <span class=\'code\'>&lt;mesh&gt;</span> is an Editable Mesh or a Mesh value and <span class=\'code\'>node:</span> is specified, the offset is in the current coordinate system context.</p>\n\
<p>If <span class=\'code\'>&lt;mesh&gt;</span> is an Editable Mesh or a Mesh value and <span class=\'code\'>node:</span> is not specified, the offset is in the mesh&#39;s local coordinate system.</p>\n\
<p>In <strong>3ds Max 2008 and higher</strong>, this method allows the position to be specified as array. In that case, the number of values in pos_array must match the number of verts specified in vertlist. This feature was previously available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<p>If <span class=\'code\'>useSoftSel:</span> is true, and the mesh&#39;s soft selection data channel is present, the specified offsets are multiplied by the vertex&#39;s soft selection value.</p>\n\
<p>Note:</p>\n\
<p>It is very important to pass the <span class=\'code\'>&lt;vertlist&gt;</span> argument as a bitArray value and not as an array. Passing the argument as an array will cause a significant performance hit (orders of magnitude).</p>\n\
<p>This applies to all methods operating on sub-object lists.</p>\n\
<div class=\'codeBlock\'><pre>meshop.moveVertsToPlane &lt;Mesh mesh&gt; &lt;vertlist&gt; &lt;point3 normal&gt; &lt;float offset&gt; node:&lt;node=unsupplied&gt;\n\
</pre></div><p>Moves the specified vertices into the specified plane. The target plane is defined as all points which when DotProd&#39;d with N, return the specified offset.</p>\n\
<p>All vertices are moved along the normal vector N.</p>\n\
<p>If <span class=\'code\'>&lt;mesh&gt;</span> is a node, or if <span class=\'code\'>&lt;mesh&gt;</span> is an Editable Mesh or a Mesh value and <span class=\'code\'>node:</span> is specified, the normal is in the current coordinate system context.</p>\n\
<p>If <span class=\'code\'>&lt;mesh&gt;</span> is an Editable Mesh or a Mesh value and <span class=\'code\'>node:</span> is not specified, the normal is in the mesh&#39;s local coordinate system.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` obj = sphere()--create a sphere convertToMesh obj--convert to Editable_mesh normal = getNormal obj 10--get the normal of vertex 10 --move all vertices of the mesh to the plane defined by the normal --vector with an offset of 0.0 (don&#39;t offset): meshop.moveVertsToPlane obj #{1..obj.numverts} normal 0.0 update obj--update the mesh</p>\n\
<p>```</p>\n\
<p><img src=\'developer/images/GUID-64EA4EE7-90F2-42BA-9EE9-DAFA3EFEC343-low.gif\' title=\'\'> <img src=\'developer/images/GUID-5FE145E5-78A1-46B7-A8AD-4118485B6B88-low.gif\' title=\'\'></p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>meshop.makeVertsPlanar &lt;Mesh mesh&gt; &lt;vertlist&gt;\n\
</pre></div><p>Moves the specified vertices, so that they are planar.</p>\n\
<div class=\'section\'><a id=\"weld-mesh-vertices\"></a><h2 id=\"weld-mesh-vertices\">Weld Mesh Vertices</h2></div>\n\
<div class=\'codeBlock\'><pre>meshop.weldVertsByThreshold &lt;Mesh mesh&gt; &lt;vertlist&gt; &lt;float threshold&gt;\n\
</pre></div><p>Welds the specified vertices that are within the threshold distance.</p>\n\
<div class=\'codeBlock\'><pre>meshop.weldVerts\n\
</pre></div><p>Renamed to <span class=\'code\'>meshOp.weldVertSet</span> .</p>\n\
<div class=\'codeBlock\'><pre>meshop.weldVertSet &lt;Mesh mesh&gt; &lt;vertlist&gt; weldpoint:&lt;point3=unsupplied&gt; node:&lt;node=unsupplied&gt;\n\
</pre></div><p>Welds the specified vertices.</p>\n\
<p>If <span class=\'code\'>weldpoint:</span> is specified, the resulting vertex is positioned at the supplied point.</p>\n\
<p>If <span class=\'code\'>weldpoint:</span> is not specified, the resulting vertex is positioned at the average location of the specified vertices.</p>\n\
<p>If <span class=\'code\'>&lt;mesh&gt;</span> is a node, or if <span class=\'code\'>&lt;mesh&gt;</span> is an Editable Mesh or a Mesh value and <span class=\'code\'>node:</span> is specified, the position is in the current coordinate system context.</p>\n\
<p>If <span class=\'code\'>&lt;mesh&gt;</span> is an Editable Mesh or a Mesh value and <span class=\'code\'>node:</span> is not specified, the position is in the mesh&#39;s local coordinate system.</p>\n\
<div class=\'section\'><a id=\"mesh-vertex-velocity\"></a><h2 id=\"mesh-vertex-velocity\">Mesh Vertex Velocity</h2></div>\n\
<div class=\'codeBlock\'><pre>meshop.getNumVelocity &lt;Mesh mesh&gt;\n\
</pre></div><p>Gets the number of vertices with velocity data in the velocity channel. This number should be equal to the number of vertices.</p>\n\
<div class=\'codeBlock\'><pre>&lt;point3_array&gt;meshop.getVelocity &lt;Mesh mesh&gt; &lt;vertlist&gt;\n\
</pre></div><p>Gets an array of velocities for the vertices specified by <span class=\'code\'>vertlist</span>.</p>\n\
<p><strong>For more mesh-related methods, see</strong></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Editable_Mesh-GeometryClass-and.html\' title=\'\'>Editable_Mesh : GeometryClass and TriMesh : Value</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";