var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Patch Objects</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Patch Objects</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"patch-objects\"></a></div>\n\
<p>Patches are the general editable versions of all the patch objects, in the same way that Editable Meshes relate to geometry objects. They are the objects that a patch is converted to when you apply an Edit Patch modifier and the result of collapsing a modifier stack on a patch base object. While MAXScript lets you construct patches, there are no properties or methods for accessing or modifying the sub-objects (vertices, edges, and patches) within the patch object.</p>\n\
<p><strong>Constructor</strong></p>\n\
<div class=\'codeBlock\'><pre>Quadpatch...\n\
Tripatch...\n\
\n\
</pre></div><p>To create a Patch scene object from scratch, you can call the Patch constructor function,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` Quadpatch pos:[10,10,10] name:&quot;foo&quot;</p>\n\
<p>```</p>\n\
<p>This creates an empty patch.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>convertTo &lt;node&gt; Editable_Patch -- mapped\n\
</pre></div><p>Converts the given scene node to a Patch object. If the object cannot be converted (typically, if it is not a geometry object), the function returns <span class=\'code\'>undefined</span> . Any modifiers present will be collapsed. The <span class=\'code\'>collapseStack()</span> function can also be used as well as the collapse button in the modifier stack dialog in <strong>3ds Max</strong>; both generate a Patch, but will only do so if there is at least one modifier present.</p>\n\
<p><strong>Properties</strong></p>\n\
<p>A control vertex and its tangents are available as properties once a controller has been assigned to the control vertex. The number of tangents for a control vertex is the number of edges associated with the control vertex. Controllers can not be assigned to the control vertices using MAXScript. If a TriPatch object is collapsed to Editable_Patch and some of its control vertices are animated, the properties for the control vertices and tangents will be similar to:</p>\n\
<div class=\'codeBlock\'><pre>$TriPatch01.Vertex_1 Point3value:[-21.5,-6.4,0] -- animatable\n\
$TriPatch01.Vertex_1_Vector_1 Point3value:[-21.5,-2.1,0] -- animatable\n\
$TriPatch01.Vertex_1_Vector_2 Point3value:[-7.1,-6.4,0 ]-- animatable\n\
$TriPatch01.Vertex_2 Point3value:[21.5,-6.4,0] -- animatable\n\
$TriPatch01.Vertex_2_Vector_1 Point3value:[7.1,-6.4,0] -- animatable\n\
$TriPatch01.Vertex_2_Vector_2 Point3value:[7.1,-2.1,0] -- animatable\n\
\n\
</pre></div><p>See also <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Identifying-and-Accessing/Class-and-Object-Inspector.html\' title=\'\'>Class and Object Inspector Functions</a> for details on accessing the patch vertices and tangents. The controller values assigned to the vertices and tangent handles is in the object space. See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/Using-Node-Transform-Properties.html\' title=\'\'>Using Node Transform Properties</a> for information on converting between world space to object space.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>getPatchSteps &lt;editable_patch_node&gt;\n\
</pre></div><p>Returns the number of steps the patch uses in the viewports, and reflects the View Steps spinner in the Modify panel.</p>\n\
<div class=\'codeBlock\'><pre>setPatchSteps &lt;editable_patch_node&gt; &lt;integer&gt;\n\
</pre></div><p>Sets the number of View Steps used by the editable patch object to the specified value.</p>\n\
<div class=\'section\'><a id=\"editable-patch-modify-panel-command-modes-and-operations\"></a><h2 id=\"editable-patch-modify-panel-command-modes-and-operations\">Editable Patch Modify Panel Command Modes and Operations</h2></div>\n\
<p>A suite of methods provide the ability for a script to invoke Editable Patch and Edit Mesh Modify panel modes and operations, corresponding to buttons available at various mesh sub-object levels. These methods reside in the <span class=\'code\'>patchOps</span> global structure. These methods effectively &quot;push the button&quot; in the Modify panel. To use these methods, the node must be selected and the Modify panel must be open. In the description of these methods, the first argument <span class=\'code\'>&lt;editable_patch_node_or_modifier&gt;</span> can be interpreted as either an Editable Patch node where the modifier stack level is at the base object, or an Edit Patch modifier where the modifier stack level is at the Edit Patch. In all cases, the following methods work at the current sub-object level, but only if that level is appropriate for the invoked operation.</p>\n\
<p>The follow methods invoke one of the &#39;user-interaction&#39; button operations in the Editable Patch Modify panel, acting on the currently selected sub-objects. These methods highlight the corresponding button in the Geometry rollout and start the operation, at which point the user interactively completes the operation. These methods return after starting the operation and before the user completes the operation, so ensure that your script does not interfere with the operation. Invoking any of these methods is the same as clicking on the associated button in the Modify panel. Calling a method when the operation is already in effect (either due to a user action or a MAXScript command) causes the operation to be terminated and the highlight is removed from the button.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.startAttach &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Attach&quot; command mode - valid in all Sub-Object levels, and when not in the Sub-Object mode.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.startBevel &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Bevel&quot; command mode - valid in the Patch Sub-Object level.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.startBind &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Bind&quot; command mode - valid in the Vertex Sub-Object level.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.startCreate &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Create&quot; command mode - valid in the Vertex, Patch, and Element Sub-Object levels.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.startExtrude &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Extrude&quot; command mode - valid in the Patch Sub-Object level.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.startFlipNormalMode &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Flip Normal&quot; command mode - valid in the Patch and Element Sub-Object levels.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.startWeldTarget &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Weld Target&quot; command mode - valid in the Vertex Sub-Object level.</p>\n\
<p><strong>The following methods invoke one of the &#39;instantaneous&#39; button operations in the Editable Patch Modify panel, acting on the currently selected sub-objects:</strong></p>\n\
<div class=\'codeBlock\'><pre>patchOps.addTri &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Adds a TriPatch to the selected edge - valid in the Edge Sub-Object level.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.addQuad &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Adds a QuadPatch to the selected edge - valid in the Edge Sub-Object level.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.break &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Creates a new vertex for each patch attached to the selected sub-objects - valid in the Vertex and Edge Sub-Object levels.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.clearAllSG &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Clears the smoothing groups on the currently selected patches - valid in the Face, Polygon, and Element Sub-Object levels.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.createShapeFromEdges &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Displays the Create Shape dialog allowing the user to specify an object name for the shape to create from the selected edges. Valid in the Edge Sub-Object level.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.delete &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Deletes the selected sub-objects - valid in all the Sub-Object levels.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.detach &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Displays the Detach dialog allowing the user to specify an object name. Valid in the Patch Sub-Object level.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.flipNormal &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Flips the normal of the selected patches - valid in the Patch and Element Sub-Object levels.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.hide &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Hides the selected sub-objects - valid in all the Sub-Object levels.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.selectByID &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Displays a Select By Material ID dialog and choose patches with the specified material ID. - valid in the Patch and Element Sub-Object levels.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.selectBySG &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Displays a Select By Smooth Groups dialog and choose patches with the specified smoothing groupd IDs - valid in the Patch and Element Sub-Object levels.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.selectOpenEdges &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Selects all edges with only one patch. Valid in the Edge Sub-Object level.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.subdivide &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Divides the selected sub-objects - valid in the Edge and Patch Sub-Object levels.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.unbind &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Unbinds the selected vertices - valid in the Vertex Sub-Object level.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.unifyNormal &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Unifies the normals of the selected patches - valid in the Patch and Element Sub-Object levels.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.unhideAll &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Unhides all hidden sub-objects -valid in all Sub-Object levels, and when not in Sub-Object mode.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.weld &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Welds the selected vertices - valid in the Vertex Sub-Object level.</p>\n\
<p><strong>The following methods are available in 3ds Max 6 and higher:</strong></p>\n\
<div class=\'codeBlock\'><pre>patchOps.growSelection &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Grows the selection - valid in all the Sub-Object levels except for Handle.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.shrinkSelection &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Shrinks the selection - valid in all the Sub-Object levels except for Handle.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.selectEdgeRing &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Selects a ring of edges - valid in the Edge Sub-Object level.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.selectEdgeLoop &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Selects a loop of edges - valid in the Edge Sub-Object level.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.patchSmooth &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Smooths the patch by avergaing the Handles.</p>\n\
<div class=\'codeBlock\'><pre>patchOps.toggleShadedFaces &lt;editable_patch_node_or_modifier&gt;\n\
</pre></div><p>Toggles the shaded faces.</p>\n\
<p>There is also a <span class=\'code\'>patch</span> structure containing a large number of functions for creating, modifying, and accessing patch objects.</p>\n\
<p>The following function is used to get the type of the patch.</p>\n\
<div class=\'codeBlock\'><pre>patch.getPatchType &lt; patch_object &gt;\n\
</pre></div><p>Returns <span class=\'code\'>#triPatch</span>, <span class=\'code\'>#quadPatch</span>, <span class=\'code\'>#undefPatch</span>, or <span class=\'code\'>&#39;undefined&#39;</span>. A value of <span class=\'code\'>#undefPatch</span> might be returned by third-party-defined patch object. A value of &#39;undefined&#39; will be returned if the internal patch type is not in the list of defined values.</p>\n\
<div class=\'section\'><a id=\"get-and-set-the-overall-geometry-of-the-patch\"></a><h3 id=\"get-and-set-the-overall-geometry-of-the-patch\">Get and set the overall geometry of the patch</h3></div>\n\
<p>Set <span class=\'code\'>keep:true</span> to the <span class=\'code\'>setNumXXX</span> functions for them to retain existing vertex/vector/patch/edge data. This value defaults to false, which cleans out the geometry.</p>\n\
<div class=\'codeBlock\'><pre>patch.getNumVerts &lt;obj&gt;\n\
</pre></div><p>Returns the number of vertices as integer value.</p>\n\
<div class=\'codeBlock\'><pre>patch.setNumVerts &lt;obj&gt; &lt;num&gt; [keep:&lt;boolean&gt;]\n\
</pre></div><p>Sets the number of vertices to the integer value.</p>\n\
<div class=\'codeBlock\'><pre>patch.getNumVecs &lt;obj&gt;\n\
</pre></div><p>Returns the number of vectors as integer value.</p>\n\
<div class=\'codeBlock\'><pre>patch.setNumVecs &lt;obj&gt; &lt;num&gt; [keep:&lt;boolean&gt;]\n\
</pre></div><p>Sets the number of vectors to the integer value.</p>\n\
<div class=\'codeBlock\'><pre>patch.getNumPatches &lt;obj&gt;\n\
</pre></div><p>Returns the number of patches as integer value.</p>\n\
<div class=\'codeBlock\'><pre>patch.setNumPatches &lt;obj&gt; &lt;num&gt; [keep:&lt;boolean&gt;]\n\
</pre></div><p>Sets the number of patches to the integer value.</p>\n\
<div class=\'codeBlock\'><pre>patch.getNumEdges &lt;obj&gt;\n\
</pre></div><p>Returns the number of edges as integer value.</p>\n\
<div class=\'codeBlock\'><pre>patch.setNumEdges &lt;obj&gt; &lt;num&gt; [keep:&lt;boolean&gt;]\n\
</pre></div><p>Sets the number of edges to the integer value.</p>\n\
<div class=\'section\'><a id=\"get-and-set-individual-vertex-and-vector-handle-locations\"></a><h3 id=\"get-and-set-individual-vertex-and-vector-handle-locations\">Get and set individual vertex and vector handle locations</h3></div>\n\
<p>The vertex and vector coordinates are interpreted in MAXScript&#39;s current working coordinate context. Consistent with the rest of MAXScript, all vertex/patch/vector/edge indexes start numbering at 1.</p>\n\
<div class=\'codeBlock\'><pre>patch.getVert &lt;obj&gt; &lt;index&gt;\n\
</pre></div><p>Returns the indexed vertex as the Point3 value.</p>\n\
<div class=\'codeBlock\'><pre>patch.setVert &lt;obj&gt; &lt;index&gt; &lt;point3&gt;\n\
</pre></div><p>Sets the indexed vertex to the Point3 value</p>\n\
<div class=\'codeBlock\'><pre>patch.getVec &lt;obj&gt; &lt;index&gt;\n\
</pre></div><p>Returns the indexed vector as the Point3 value</p>\n\
<div class=\'codeBlock\'><pre>patch.setVec &lt;obj&gt; &lt;index&gt; &lt;point3&gt;\n\
</pre></div><p>Sets the indexed vector to the Point3 value</p>\n\
<div class=\'section\'><a id=\"creating-individual-patches-in-the-patch-mesh\"></a><h3 id=\"creating-individual-patches-in-the-patch-mesh\">Creating individual patches in the patch mesh</h3></div>\n\
<div class=\'codeBlock\'><pre>patch.makeQuadPatch &lt;obj&gt; &lt;index&gt; &lt;va&gt; &lt;vab&gt; &lt;vba&gt; &lt;vb&gt; &lt;vbc&gt; &lt;vcb&gt; &lt;vc&gt; &lt;vcd&gt; &lt;vdc&gt; &lt;vd&gt; &lt;vda&gt; &lt;vad&gt; &lt;i1&gt; &lt;i2&gt; &lt;i3&gt; &lt;i4&gt; &lt;sm&gt;\n\
</pre></div><p>Where:</p>\n\
<ul>\n\
<li><strong>index</strong> = The index of the patch to create (0&gt; = index &lt; numPatches).</li>\n\
<li><strong>va</strong> = The first vertex.</li>\n\
<li><strong>vab</strong> = Vector ab.</li>\n\
<li><strong>vba</strong> = Vector ba.</li>\n\
<li><strong>vb</strong> = The second vertex.</li>\n\
<li><strong>vbc</strong> = Vector bc.</li>\n\
<li><strong>vcb</strong> = Vector cb.</li>\n\
<li><strong>vc</strong> = The third vertex.</li>\n\
<li><strong>vcd</strong> = Vector cd.</li>\n\
<li><strong>vdc</strong> = Vector dc.</li>\n\
<li><strong>vd</strong> = The fourth vertex.</li>\n\
<li><strong>vda</strong> = Vector da.</li>\n\
<li><strong>vad</strong> = Vector ad.</li>\n\
<li><strong>i1</strong> = Interior 1.</li>\n\
<li><strong>i2</strong> = Interior 2.</li>\n\
<li><strong>i3</strong> = Interior 3.</li>\n\
<li><strong>i4</strong> = Interior 4.</li>\n\
<li><strong>sm</strong> = The smoothing group mask</li>\n\
</ul>\n\
<div class=\'codeBlock\'><pre>patch.makeTriPatch &lt;obj&gt; &lt;index&gt; &lt;va&gt; &lt;vab&gt; &lt;vba&gt; &lt;vb&gt; &lt;vbc&gt; &lt;vcb&gt; &lt;vc&gt; &lt;vca&gt; &lt;vac&gt; &lt;i1&gt; &lt;i2&gt; &lt;i3&gt; &lt;sm&gt;\n\
</pre></div><p>Where:</p>\n\
<ul>\n\
<li><strong>index</strong> = The index of the patch to create (0&gt; = index &lt; numPatches).</li>\n\
<li><strong>va</strong> = The first vertex.</li>\n\
<li><strong>vab</strong> = Vector ab.</li>\n\
<li><strong>vba</strong> = Vector ba.</li>\n\
<li><strong>vb</strong> = The second vertex.</li>\n\
<li><strong>vbc</strong> = Vector bc.</li>\n\
<li><strong>vcb</strong> = Vector cb.</li>\n\
<li><strong>vc</strong> = The third vertex.</li>\n\
<li><strong>vca</strong> = Vector ca.</li>\n\
<li><strong>vac</strong> = Vector ac.</li>\n\
<li><strong>i1</strong> = Interior 1.</li>\n\
<li><strong>i2</strong> = Interior 2.</li>\n\
<li><strong>i3</strong> = Interior 3.</li>\n\
<li><strong>sm</strong> = The smoothing group mask</li>\n\
</ul>\n\
<div class=\'section\'><a id=\"update-a-patch-object\"></a><h3 id=\"update-a-patch-object\">Update a Patch object:</h3></div>\n\
<div class=\'codeBlock\'><pre>patch.update &lt;obj&gt;\n\
</pre></div><p>Forces all geometry and topology caches to be rebuilt, change notifications to be sent, and a screen redraw request to be flagged.</p>\n\
<p>You must call this function after making any changes to a path object, before exiting the script. If you make the changes otherwise, an invalid patch might be passed to MAX, possibly causing a crash. The <span class=\'code\'>patch.update()</span> function is similar in function and purpose to the <span class=\'code\'>update()</span> function in mesh object scripting.</p>\n\
<div class=\'section\'><a id=\"accessing-the-topology-of-an-existing-patch-object\"></a><h3 id=\"accessing-the-topology-of-an-existing-patch-object\">Accessing the topology of an existing patch object:</h3></div>\n\
<p>They return either indexes or arrays of indexes of the sub-objects requested. For example, <span class=\'code\'>getVertVecs()</span> returns an array of the vectors coming out of the specified vertex.</p>\n\
<div class=\'codeBlock\'><pre>patch.getVertVecs &lt;obj&gt; &lt;index&gt; -&gt; integer_array\n\
patch.getVertPatches &lt;obj&gt; &lt;index&gt; -&gt; integer_array\n\
patch.getVertEdges &lt;obj&gt; &lt;index&gt; -&gt; integer_array\n\
patch.getVecVert &lt;obj&gt; &lt;index&gt; -&gt; integer\n\
patch.getVecPatches &lt;obj&gt; &lt;index&gt; -&gt; integer_array\n\
patch.getEdgeVert1 &lt;obj&gt; &lt;index&gt; -&gt; integer\n\
patch.getEdgeVert2 &lt;obj&gt; &lt;index&gt; -&gt; integer\n\
patch.getEdgeVec12 &lt;obj&gt; &lt;index&gt; -&gt; integer\n\
patch.getEdgeVec21 &lt;obj&gt; &lt;index&gt; -&gt; integer\n\
</pre></div><div class=\'section\'><a id=\"accessing-and-manipulating-the-texture-mapping-information\"></a><h3 id=\"accessing-and-manipulating-the-texture-mapping-information\">Accessing and manipulating the texture mapping information</h3></div>\n\
<div class=\'codeBlock\'><pre>patch.setNumMaps &lt;obj&gt; &lt;num&gt; [keep:&lt;boolean&gt;]\n\
patch.getNumMaps &lt;obj&gt; -&gt; integer\n\
patch.setMapSupport &lt;obj&gt; &lt;map_chan&gt; [init:&lt;boolean&gt;]\n\
patch.getMapSupport &lt;obj&gt; &lt;map_chan&gt; -&gt; boolean\n\
patch.maxMapChannels &lt;obj&gt;\n\
patch.setNumMapVerts &lt;obj&gt; &lt;map_chan&gt; &lt;num&gt; [keep:&lt;boolean&gt;]\n\
patch.getNumMapVerts &lt;obj&gt; &lt;map_index&gt;\n\
patch.setNumMapPatches &lt;obj&gt; &lt;map_chan&gt; &lt;num&gt; [keep:&lt;boolean&gt;]\n\
patch.getMapVert &lt;obj&gt; &lt;map_chan&gt; &lt;index&gt;\n\
patch.setMapVert &lt;obj&gt; &lt;map_chan&gt; &lt;index&gt; &lt;point3&gt;\n\
patch.getMapPatch &lt;obj&gt; &lt;map_chan&gt; &lt;index&gt;\n\
patch.setMapPatch &lt;obj&gt; &lt;map_chan&gt; &lt;index&gt; &lt;index_array&gt;\n\
</pre></div><div class=\'section\'><a id=\"getting-and-setting-the-material-id-of-the-whole-object-or-individual-patches\"></a><h3 id=\"getting-and-setting-the-material-id-of-the-whole-object-or-individual-patches\">Getting and setting the material ID of the whole object or individual patches</h3></div>\n\
<div class=\'codeBlock\'><pre>patch.getPatchMtlID &lt;obj&gt; &lt;index&gt; -&gt; integer\n\
patch.setPatchMtlID &lt;obj&gt; &lt;patch_index&gt; &lt;mtl_id&gt;\n\
</pre></div><p>Note: The material ID value returned by <span class=\'code\'>patch.getPatchMtlID</span> and set by <span class=\'code\'>patch.setPatchMtlID</span> are now 1-based. The material ID value was 0-based in <strong>3ds Max 4</strong>.</p>\n\
<div class=\'section\'><a id=\"accessing-and-controlling-viewport-and-renderer-tesselation-and-visibility\"></a><h3 id=\"accessing-and-controlling-viewport-and-renderer-tesselation-and-visibility\">Accessing and controlling viewport and renderer tesselation and visibility</h3></div>\n\
<div class=\'codeBlock\'><pre>patch.setMeshSteps &lt;obj&gt; &lt;steps&gt;\n\
patch.getMeshSteps &lt;obj&gt;\n\
patch.setMeshStepsRender &lt;obj&gt; &lt;steps&gt;\n\
patch.getMeshStepsRender &lt;obj&gt;\n\
patch.setShowInterior &lt;obj&gt; &lt;boolean&gt;\n\
patch.getShowInterior &lt;obj&gt;\n\
patch.setAdaptive &lt;obj&gt; &lt;boolean&gt;\n\
patch.getAdaptive &lt;obj&gt;\n\
</pre></div><div class=\'section\'><a id=\"accessing-topology-info-for-the-specified-sub-object\"></a><h3 id=\"accessing-topology-info-for-the-specified-sub-object\">Accessing topology info for the specified sub-object</h3></div>\n\
<div class=\'codeBlock\'><pre>patch.getEdges &lt;obj&gt; &lt;v1&gt; [&lt;v2&gt;] -&gt; integer_array\n\
patch.getPatches &lt;obj&gt; &lt;v1&gt; [&lt;v2&gt;] -&gt; integer_array\n\
patch.getVectors &lt;obj&gt; &lt;vert&gt; -&gt; integer_array\n\
</pre></div><div class=\'section\'><a id=\"transforming-all-vertices-and-vectors-in-the-patch-object-by-the-given-matrix\"></a><h3 id=\"transforming-all-vertices-and-vectors-in-the-patch-object-by-the-given-matrix\">Transforming all vertices and vectors in the patch object by the given matrix</h3></div>\n\
<div class=\'codeBlock\'><pre>patch.transform &lt;obj&gt; &lt;matrix3&gt;\n\
</pre></div><p>This transform happens in object local space.</p>\n\
<div class=\'section\'><a id=\"performing-various-high-level-operations-on-a-patch-object\"></a><h3 id=\"performing-various-high-level-operations-on-a-patch-object\">Performing various high-level operations on a patch object</h3></div>\n\
<div class=\'codeBlock\'><pre>patch.weldVerts &lt;obj&gt; &lt;threshold&gt; &lt;weldIdentical_bool&gt; &lt;startVert&gt;\n\
patch.weld2Verts &lt;obj&gt; &lt;v1&gt; &lt;v2&gt;\n\
patch.weldEdges &lt;obj&gt;\n\
patch.deletePatchParts &lt;obj&gt; &lt;del_vert_bitarray&gt; &lt;del_patches_bitarray&gt;\n\
patch.clonePatchParts &lt;obj&gt; &lt;patch_bit_array&gt;\n\
patch.subdivideEdges &lt;obj&gt; &lt;propogate&gt;\n\
patch.subdividePatches &lt;obj&gt; &lt;propogate&gt;\n\
patch.addTriPatch &lt;obj&gt;\n\
patch.addQuadPatch &lt;obj&gt;\n\
</pre></div><div class=\'section\'><a id=\"getting-and-manipulating-surface-normal-information\"></a><h3 id=\"getting-and-manipulating-surface-normal-information\">Getting and manipulating surface normal information</h3></div>\n\
<div class=\'codeBlock\'><pre>patch.patchNormal &lt;obj&gt; &lt;patch&gt;\n\
patch.edgeNormal &lt;obj&gt; &lt;edge&gt;\n\
patch.updatePatchNormals &lt;obj&gt;\n\
patch.flipPatchNormal &lt;obj&gt; &lt;patch&gt;\n\
patch.unifyNormals &lt;obj&gt;\n\
patch.autoSmooth &lt;obj&gt; &lt;angle&gt; &lt;useSel_bool&gt; &lt;preventIndirectSmoothing_bool&gt;\n\
</pre></div><p>Normal vectors are given in MAXScript&#39;s current working coordinate context.</p>\n\
<div class=\'section\'><a id=\"accessing-and-changing-the-vertex-and-interior-vertex-types\"></a><h3 id=\"accessing-and-changing-the-vertex-and-interior-vertex-types\">Accessing and changing the vertex and interior vertex types</h3></div>\n\
<div class=\'codeBlock\'><pre>patch.changeVertType &lt;obj&gt; &lt;vert&gt; #corner|#coplanar patch.getVertType &lt;obj&gt; &lt;vert&gt; -&gt; #corner or #coplanar\n\
patch.changePatchInteriorType &lt;obj&gt; &lt;patch&gt; #automatic|#manual patch.getPatchInteriorType &lt;obj&gt; &lt;patch&gt; -&gt; #automatic or #manual\n\
</pre></div><div class=\'section\'><a id=\"accessingthe-current-mesh-tesselation-for-thepatch-object\"></a><h3 id=\"accessingthe-current-mesh-tesselation-for-thepatch-object\">Accessingthe current mesh tesselation for thepatch object</h3></div>\n\
<div class=\'codeBlock\'><pre>patch.getMesh &lt;obj&gt; -&gt; mesh value\n\
</pre></div><div class=\'section\'><a id=\"interpolating-individual-patch-surfaces\"></a><h3 id=\"interpolating-individual-patch-surfaces\">Interpolating individual patch surfaces</h3></div>\n\
<div class=\'codeBlock\'><pre>patch.interpTriPatch &lt;obj&gt; &lt;patch&gt; &lt;u&gt; &lt;v&gt; &lt;w&gt; -&gt; point3\n\
patch.interpQuadPatch &lt;obj&gt; &lt;patch&gt; &lt;u&gt; &lt;v&gt; -&gt; point3\n\
</pre></div><p>A tri-patch interpolation takes u,v,w <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/Node-Common-Methods/Node-Utility-Methods.html\' title=\'\'>barycentric coordinates</a>. A quad-patch takes u and c parameters. In both cases, the point returns is given in the current MAXScript working coordinate context.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";