var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>patches</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>patches</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"patches\"></a></div>\n\
<p>A patch function package containing a large number of functions for creating, modifying, and accessing patch objects has been introduced in <strong>3ds Max 4</strong>. The sub-object selection system in MAXScript has also been extended to cover patch objects.</p>\n\
<ul>\n\
<li><p>The Editable Patch object in MAX was called &#39;Patch&#39; in MAXScript. It has been renamed to &#39;Editable_Patch&#39; to be consistent with Editable_Mesh and Editable_Poly, and to allow the new patch function package to be named &#39;patch&#39;.</p></li>\n\
<li><p>The MAXScript sub-object selection system has been extended to work with Editable Patch objects. This means that all the MAXScript VertexSelection, FaceSelection, and EdgeSelection properties and operations now work with patch objects. The &#39;face&#39; sub-object selections in this system correspond to the &#39;patch&#39; sub-object level when applied to patches.</p></li>\n\
<li><p>The Patch functions. All the functions in this package take either a scene node containing an Editable Patch object or an Editable Patch base object as the first argument. QuadPatch and TriPatch objects need to be converted to Editable Patches for the Patch functions to be applicable. For example, when using the <span class=\'code\'>convertTo</span> $foo Editable_Patch.</p></li>\n\
</ul>\n\
<p>To create a patch object from scratch, create an Editable_Patch scene object to create an empty patch object and use the geometry &amp; topology creation functions below to fill the patch out, then use the <span class=\'code\'>patch.update</span> () function to complete the construction.</p>\n\
<p>Note: Any set of changes to a patch object using the following functions do not take effect fully until the <span class=\'code\'>patch.update</span> () function is called on it. This makes construction substantially more efficient, but can leave a patch in an unstable state if the script that contains the changing code finishes before calling patch <span class=\'code\'>.update</span> on it, which might result in a MAX crash.</p>\n\
<p><strong>Functions:</strong></p>\n\
<p>The following functions are used to get and set the overall geometry of the patch. Supply <span class=\'code\'>keep:true</span> to the setNumXXX functions for them to retain existing vertex/vector/patch/edge data, defaults to false, which cleans out the geometry.</p>\n\
<p><strong>The functions are largely direct calls to the methods of the same name on the MAX SDK class PatchMesh. See the SDK Help file Advanced Topic &quot;Working with Patches&quot;, and the documentation for the main Patch system classes for more detailed information</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt; patch.getNumVerts &lt;obj&gt;\n\
patch.setNumVerts &lt;obj&gt; &lt;num&gt; [keep:&lt;boolean&gt;] \n\
\n\
&lt;integer&gt; patch.getNumVecs &lt;obj&gt;\n\
patch.setNumVecs &lt;obj&gt; &lt;num&gt; [keep:&lt;boolean&gt;] \n\
\n\
&lt;integer&gt; patch.getNumPatches &lt;obj&gt;\n\
patch.setNumPatches &lt;obj&gt; &lt;num&gt; [keep:&lt;boolean&gt;] \n\
\n\
&lt;integer&gt; patch.getNumEdges &lt;obj&gt;\n\
patch.setNumEdges &lt;obj&gt; &lt;num&gt; [keep:&lt;boolean&gt;] \n\
</pre></div><p>The following functions get and set individual vertex and vector handle locations. The vertex and vector coordinates are interpreted in MAXScript&#39;s current working coordinate context.</p>\n\
<p>Note:</p>\n\
<p>Consistent with the rest of MAXScript, all vertex/patch/vector/edge indexes start numbering at 1.</p>\n\
<div class=\'codeBlock\'><pre>&lt;point3&gt; patch.getVert &lt;obj&gt; &lt;index&gt;\n\
patch.setVert &lt;obj&gt; &lt;index&gt; &lt;point3&gt;\n\
\n\
&lt;point3&gt; patch.getVec &lt;obj&gt; &lt;index&gt;\n\
patch.setVec &lt;obj&gt; &lt;index&gt; &lt;point3&gt;\n\
</pre></div><p>The following two functions are the main mechanism for creating individual patches in the patch mesh:</p>\n\
<div class=\'codeBlock\'><pre>patch.makeQuadPatch &lt;obj&gt; &lt;index&gt; &lt;va&gt; &lt;vab&gt; &lt;vba&gt; &lt;vb&gt; &lt;vbc&gt; &lt;vcb&gt; &lt;vc&gt; &lt;vcd&gt; &lt;vdc&gt; &lt;vd&gt; &lt;vda&gt; &lt;vad&gt; &lt;i1&gt; &lt;i2&gt; &lt;i3&gt; &lt;i4&gt; &lt;sm&gt;\n\
</pre></div><p>Where:</p>\n\
<ul>\n\
<li><span class=\'code\'>index</span> = The index of the patch to create (0&gt; = index &lt; numPatches).</li>\n\
<li><span class=\'code\'>va</span> = The first vertex.</li>\n\
<li><span class=\'code\'>vab</span> = Vector ab.</li>\n\
<li><span class=\'code\'>vba</span> = Vector ba.</li>\n\
<li><span class=\'code\'>vb</span> = The second vertex.</li>\n\
<li><span class=\'code\'>vbc</span> = Vector bc.</li>\n\
<li><span class=\'code\'>vcb</span> = Vector cb.</li>\n\
<li><span class=\'code\'>vc</span> = The third vertex.</li>\n\
<li><span class=\'code\'>vcd</span> = Vector cd.</li>\n\
<li><span class=\'code\'>vdc</span> = Vector dc.</li>\n\
<li><span class=\'code\'>vd</span> = The fourth vertex.</li>\n\
<li><span class=\'code\'>vda</span> = Vector da.</li>\n\
<li><span class=\'code\'>vad</span> = Vector ad.</li>\n\
<li><span class=\'code\'>i1</span> = Interior 1.</li>\n\
<li><span class=\'code\'>i2</span> = Interior 2.</li>\n\
<li><span class=\'code\'>i3</span> = Interior 3.</li>\n\
<li><span class=\'code\'>i4</span> = Interior 4.</li>\n\
<li><span class=\'code\'>sm</span> = The smoothing group mask</li>\n\
</ul>\n\
<div class=\'codeBlock\'><pre>patch.makeTriPatch &lt;obj&gt; &lt;index&gt; &lt;va&gt; &lt;vab&gt; &lt;vba&gt; &lt;vb&gt; &lt;vbc&gt; &lt;vcb&gt; &lt;vc&gt; &lt;vca&gt; &lt;vac&gt; &lt;i1&gt; &lt;i2&gt; &lt;i3&gt; &lt;sm&gt;\n\
</pre></div><p>Where:</p>\n\
<ul>\n\
<li><span class=\'code\'>va</span> = The first vertex.</li>\n\
<li><span class=\'code\'>vab</span> = Vector ab.</li>\n\
<li><span class=\'code\'>vba</span> = Vector ba.</li>\n\
<li><span class=\'code\'>vb</span> = The second vertex.</li>\n\
<li><span class=\'code\'>vbc</span> = Vector bc.</li>\n\
<li><span class=\'code\'>vcb</span> = Vector cb.</li>\n\
<li><span class=\'code\'>vc</span> = The third vertex.</li>\n\
<li><span class=\'code\'>vca</span> = Vector ca.</li>\n\
<li><span class=\'code\'>vac</span> = Vector ac.</li>\n\
<li><span class=\'code\'>i1</span> = Interior 1.</li>\n\
<li><span class=\'code\'>i2</span> = Interior 2.</li>\n\
<li><span class=\'code\'>i3</span> = Interior 3.</li>\n\
<li><span class=\'code\'>sm</span> = The smoothing group mask</li>\n\
</ul>\n\
<p>The following function forces all the geometry and topology caches to be rebuilt, change notifications to be sent, and a screen redraw request to be flagged.</p>\n\
<p>You must call this function after making any changes to a path object before exiting the script. Otherwise, an invalid patch might be passed to MAX, which can cause a crash. The <span class=\'code\'>patch.update</span> () function is similar to the update() function in mesh object scripting.</p>\n\
<div class=\'codeBlock\'><pre>patch.update &lt;obj&gt;\n\
</pre></div><p>The following functions give access to the topology of an existing patch object. They return either indexes or arrays of indexes of the sub-objects requested.</p>\n\
<p><span class=\'code\'>getVertVecs()</span> returns an array of the vectors coming out of the specified vertex.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer_array&gt; patch.getVertVecs &lt;obj&gt; &lt;index&gt;\n\
&lt;integer_array&gt; patch.getVertPatches &lt;obj&gt; &lt;index&gt;\n\
&lt;integer_array&gt; patch.getVertEdges &lt;obj&gt; &lt;index&gt;\n\
&lt;integer&gt; patch.getVecVert &lt;obj&gt; &lt;index&gt;\n\
&lt;integer_array&gt; patch.getVecPatches &lt;obj&gt; &lt;index&gt;\n\
&lt;integer&gt; patch.getEdgeVert1 &lt;obj&gt; &lt;index&gt;\n\
&lt;integer&gt;  patch.getEdgeVert2 &lt;obj&gt; &lt;index&gt;\n\
&lt;integer&gt; patch.getEdgeVec12 &lt;obj&gt; &lt;index&gt;\n\
&lt;integer&gt; patch.getEdgeVec21 &lt;obj&gt; &lt;index&gt;\n\
</pre></div><p>The following functions access and manipulate the texture mapping information in the patch object:</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt; patch.getNumMaps &lt;obj&gt;\n\
patch.setNumMaps &lt;obj&gt; &lt;num&gt; [keep:&lt;boolean&gt;]\n\
\n\
&lt;boolean&gt; patch.getMapSupport &lt;obj&gt; &lt;map_chan&gt;\n\
patch.setMapSupport &lt;obj&gt; &lt;map_chan&gt; [init:&lt;boolean&gt;]\n\
\n\
&lt;integer&gt; patch.getNumMapVerts &lt;obj&gt; &lt;map_index&gt;\n\
patch.setNumMapVerts &lt;obj&gt; &lt;map_chan&gt; &lt;num&gt; [keep:&lt;boolean&gt;]\n\
\n\
&lt;point3&gt; patch.getMapVert &lt;obj&gt; &lt;map_chan&gt; &lt;index&gt;\n\
patch.setMapVert &lt;obj&gt; &lt;map_chan&gt; &lt;index&gt; &lt;point3&gt;\n\
\n\
&lt;index_array&gt; patch.getMapPatch &lt;obj&gt; &lt;map_chan&gt; &lt;index&gt;\n\
patch.setMapPatch &lt;obj&gt; &lt;map_chan&gt; &lt;index&gt; &lt;index_array&gt;\n\
\n\
patch.maxMapChannels &lt;obj&gt;\n\
patch.setNumMapPatches &lt;obj&gt; &lt;map_chan&gt; &lt;num&gt; [keep:&lt;boolean&gt;]\n\
</pre></div><p>The following functions get and set the material ID for the patch object as a whole or for individual patches:</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt; patch.getMtlID &lt;obj&gt;\n\
patch.setMtlID &lt;obj&gt; &lt;mtl_id&gt;\n\
\n\
&lt;integer&gt;patch.getPatchMtlID &lt;obj&gt; &lt;index&gt;\n\
patch.setPatchMtlID &lt;obj&gt; &lt;patch_index&gt; &lt;mtl_id&gt;\n\
</pre></div><p>The following functions access and control the viewport and renderer tessellation and visibility:</p>\n\
<div class=\'codeBlock\'><pre>patch.setMeshSteps &lt;obj&gt; &lt;steps&gt;\n\
patch.getMeshSteps &lt;obj&gt;\n\
\n\
patch.setMeshStepsRender &lt;obj&gt; &lt;steps&gt;\n\
patch.getMeshStepsRender &lt;obj&gt;\n\
\n\
patch.setShowInterior &lt;obj&gt; &lt;boolean&gt;\n\
patch.getShowInterior &lt;obj&gt;\n\
\n\
patch.setAdaptive &lt;obj&gt; &lt;boolean&gt;\n\
patch.getAdaptive &lt;obj&gt;\n\
</pre></div><p>The following functions access the topology information for the specified sub-object:</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer_array&gt;  patch.getEdges &lt;obj&gt; &lt;v1&gt; [&lt;v2&gt;]\n\
&lt;integer_array&gt; patch.getPatches &lt;obj&gt; &lt;v1&gt; [&lt;v2&gt;]\n\
&lt;integer_array&gt; patch.getVectors &lt;obj&gt; &lt;vert&gt;\n\
</pre></div><p>The following function transforms all the vertices and vectors in the patch object by the given matrix. This transform happens in the object local space.</p>\n\
<div class=\'codeBlock\'><pre>patch.transform &lt;obj&gt; &lt;matrix3&gt;\n\
</pre></div><p>The following functions perform various high-level operations on a patch object:</p>\n\
<div class=\'codeBlock\'><pre>patch.weldVerts &lt;obj&gt; &lt;threshold&gt; &lt;weldIdentical_bool&gt; &lt;startVert&gt;\n\
patch.weld2Verts &lt;obj&gt; &lt;v1&gt; &lt;v2&gt;\n\
patch.weldEdges &lt;obj&gt;\n\
patch.deletePatchParts &lt;obj&gt; &lt;del_vert_bitarray&gt; &lt;del_patches_bitarray&gt;\n\
patch.clonePatchParts &lt;obj&gt; &lt;patch_bit_array&gt;\n\
patch.subdivideEdges &lt;obj&gt; &lt;propagate&gt;\n\
patch.subdividePatches &lt;obj&gt; &lt;propagate&gt;\n\
patch.addTriPatch &lt;obj&gt;\n\
patch.addQuadPatch &lt;obj&gt;\n\
</pre></div><p>The following functions get and manipulate surface normal information. Again, normal vectors are given in MAXScript&#39;s current working coordinate context.</p>\n\
<div class=\'codeBlock\'><pre>patch.patchNormal &lt;obj&gt; &lt;patch&gt;\n\
patch.edgeNormal &lt;obj&gt; &lt;edge&gt;\n\
patch.updatePatchNormals &lt;obj&gt;\n\
patch.flipPatchNormal &lt;obj&gt; &lt;patch&gt;\n\
patch.unifyNormals &lt;obj&gt;\n\
patch.autoSmooth &lt;obj&gt; &lt;angle&gt; &lt;useSel_bool&gt; &lt;preventIndirectSmoothing_bool&gt;\n\
</pre></div><p>The following functions access and change the vertex and interior vertex types:</p>\n\
<div class=\'codeBlock\'><pre>patch.changeVertType &lt;obj&gt; &lt;vert&gt; #corner|#coplanar patch.getVertType &lt;obj&gt; &lt;vert&gt; -&gt;#corneror#coplanar\n\
\n\
patch.changePatchInteriorType &lt;obj&gt; &lt;patch&gt; #automatic|#manual patch.getPatchInteriorType &lt;obj&gt; &lt;patch&gt; -&gt;#automaticor#manual\n\
</pre></div><p>The following function returns the current mesh tessellation for the patch object:</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh value&gt;patch.getMesh &lt;obj&gt;\n\
</pre></div><p>The following functions are used to interpolate individual patch surfaces. A tri-patch interpolation takes u,v,w barycentric coordinates. A quad-patch takes u and c parameters. In both cases, the point returns is given in the current MAXScript working coordinate context.</p>\n\
<div class=\'codeBlock\'><pre>&lt;point3&gt;patch.interpTriPatch &lt;obj&gt; &lt;patch&gt; &lt;u&gt; &lt;v&gt; &lt;w&gt;\n\
&lt;point3&gt;patch.interpQuadPatch &lt;obj&gt; &lt;patch&gt; &lt;u&gt; &lt;v&gt;\n\
</pre></div><div class=\'section\'><a id=\"subobject-selection\"></a><h3 id=\"subobject-selection\">SubObject Selection</h3></div>\n\
<p>The following methods require a selection to operate on. Using them with out selection will not give results.</p>\n\
<p><strong>subDivideEdges:</strong></p>\n\
<div class=\'codeBlock\'><pre>Quadpatch lengthsegs:1 widthsegs:1 length:100 width:100 isSelected:on\n\
convertTo $ Editable_Patch\n\
$.selectededges = #{1}\n\
patch.subdivideEdges $ false\n\
patch.update $\n\
\n\
</pre></div><p><strong>subdividePatches:</strong></p>\n\
<div class=\'codeBlock\'><pre>Quadpatch lengthsegs:1 widthsegs:1 length:100 width:100 isSelected:on\n\
convertTo $ Editable_Patch\n\
$.selectedfaces = #{1}\n\
patch.subdividePatches $ false\n\
patch.update $\n\
\n\
</pre></div><p><strong>addTriPatch/addQuadPatch:</strong></p>\n\
<div class=\'codeBlock\'><pre>Quadpatch lengthsegs:1 widthsegs:1 length:100 width:100 isSelected:on\n\
convertTo $ Editable_Patch\n\
$.selectededges = #{1}\n\
patch.addTriPatch $\n\
patch.update $\n\
$.selectededges = #{3}\n\
patch.addQuadPatch $\n\
patch.update $\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";