var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>SplineShape : Shape</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>SplineShape : Shape</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"splineshape-shape\"></a></div>\n\
<div class=\'codeBlock\'><pre>splineShape - superclass: Shape; super-superclass:Node - classID: #(10, 0)\n\
</pre></div><p>{{toc}}</p>\n\
<p>SplineShapes are the general editable versions of all the shape objects, in the same way that Editable Meshes relate to geometry objects. They are the objects that a shape is converted to when you apply an Edit Spline modifier and the result of collapsing a modifier stack on a shape base object. MAXScript lets you construct SplineShapes from scratch, add individual curves (splines) and controls points (knots), or modify an existing shape by converting it to a SplineShape using the methods listed below.</p>\n\
<p><strong>Constructors:</strong></p>\n\
<div class=\'codeBlock\'><pre>splineShape...\n\
bezierShape... \n\
convertToSplineShape &lt;shape&gt;\n\
</pre></div><p><strong>For practical examples of creating and modifying spline shapes, see also</strong></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Practical-Questions/Working-with-Scene-Nodes/How-do-I-create-a-line-between.html\' title=\'\'>MAXScript FAQ:How do I create a line between two points?</a></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Flatten-a-SplineShape.html\' title=\'\'>How To ... Flatten a SplineShape</a></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Draw-a-Freehand-Spline.html\' title=\'\'>How To ... Draw a Freehand Spline</a></p>\n\
<p>Note:</p>\n\
<p>You must convert existing shapes to SplineShapes (Editable Splines) to operate on them with the methods listed in this topic. Use the <span class=\'code\'>convertToSplineShape()</span> function to do this.</p>\n\
<p><strong>Only</strong> the <span class=\'code\'>updateShape()</span> function updates the shape&#39;s internal caches and images in <strong>3ds Max</strong> viewports. This is because updates can be computationally expensive and you do not want them performed on every function call. However, you <strong>must</strong> make sure you do call the <span class=\'code\'>updateShape()</span> function after a series of changes and before the shape is to be worked on in <strong>3ds Max</strong> or by other functions in MAXScript.</p>\n\
<p>The in and out vectors for Bezier control points are given as vector handle coordinates, not as true vectors as the names suggests.</p>\n\
<p>Coordinates are given in the MAXScript working coordinate system. This is important to note if you are familiar with the corresponding SDK spline functions that always work in object-local coordinates.</p>\n\
<p>If the <span class=\'code\'>updateShape()</span> function is called on an object that is selected and currently open in the Modify panel, it will drop the current selection to avoid a potential crash in <strong>3ds Max</strong>, which at the moment does not support scripted changes to an object open in the Modify panel.</p>\n\
<p>If you are creating or modifying a spline object and have not yet run <span class=\'code\'>updateShape()</span> on the spline, <strong>3ds Max</strong> will crash if you minimize and then maximize the <strong>3ds Max</strong> window. This is because the spline is only partially created and the internal <strong>3ds Max</strong> spline structure is left in an unstable state.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'section\'><a id=\"rendering-rollout\"></a><h2 id=\"rendering-rollout\">Rendering Rollout</h2></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-CB97B6DE-4980-4E4F-B017-E57E3CE1E874-low.gif\' title=\'\'></div>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_renderable BooleanClass default: false -- boolean; renderable\n\
</pre></div><p>Toggles the &quot;Enable in Renderer&quot; checkbox on and off.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_displayRenderMesh BooleanClass default: false -- boolean; displayRenderMesh\n\
</pre></div><p>Toggles the &quot;Enable In Viewport&quot; checkbox on and off. When set to true, the mesh will be displayed in the viewports.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_useViewportSettings BooleanClass default: false -- boolean; useViewportSettings\n\
</pre></div><p>Toggles the &quot;Use Viewport Settings&quot; checkbox on and off.</p>\n\
<p>When set to true, the mesh displayed in the viewport will use the Viewport settings.</p>\n\
<p>When false, the Renderer settings will be used for the viewport mesh.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_mapcoords BooleanClass default: false -- boolean; mapcoords\n\
</pre></div><p>Toggles mapping coordinates generation on and off.</p>\n\
<p>The U coordinate wraps once around the thickness of the spline; the V coordinate is mapped once along the length of the spline.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.realWorldMapSize BooleanClass default: false -- boolean\n\
</pre></div><p>Toggles the real-world map size option on and off.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_displayRenderSettings BooleanClass default: true -- boolean; displayRenderSettings\n\
</pre></div><p>Toggles the state of the Viewport/Renderer radio buttons.</p>\n\
<p>When set to true, the Renderer settings will be displayed in the rollout.</p>\n\
<p>When false, the Viewport settings will be shown instead.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_rectangular BooleanClass default: false -- boolean\n\
</pre></div><p>When set to true, enables the Rectangular cross-section mode to be used in the renderer.</p>\n\
<p>When false (default), enables the Radial cross-section mode.</p>\n\
<p>Corresponds to the Radial/Rectangular radio buttons in the UI in the Renderer mode.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_viewport_rectangular BooleanClass default: false -- boolean\n\
</pre></div><p>When set to true, enables the Rectangular cross-section mode to be used in the viewports.</p>\n\
<p>When false (default), enables the Radial cross-section mode.</p>\n\
<p>Corresponds to the Radial/Rectangular radio buttons in the UI in the Viewport mode.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'section\'><a id=\"renderer---radial-cross-section\"></a><h3 id=\"renderer---radial-cross-section\">Renderer - Radial Cross-Section</h3></div>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_thickness Float default: 1.0 -- animatable; thickness\n\
</pre></div><p>Gets/Sets the diameter of the Radial renderable spline mesh.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_sides Integer default: 12 -- animatable; sides\n\
</pre></div><p>Gets/Sets the number of sides for the spline mesh in the renderer.</p>\n\
<p>For example, a value of four will give you a square cross section.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_angle Float default: 0.0 -- animatable; angle\n\
</pre></div><p>Gets/Sets the rotational position of the Radial cross-section in the renderer.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'section\'><a id=\"renderer---rectangular-cross-section\"></a><h3 id=\"renderer---rectangular-cross-section\">Renderer - Rectangular Cross-Section</h3></div>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_length Float default: 6.0 -- animatable\n\
</pre></div><p>Gets/Sets the length of the Rectangular renderable spline mesh.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_width Float default: 2.0 -- animatable\n\
</pre></div><p>Gets/Sets the width of the Rectangular renderable spline mesh.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_angle2 Float default: 0.0 -- animatable\n\
</pre></div><p>Gets/Sets rotational position of the Radial cross-section in the renderer.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_aspect_locked BooleanClass default: false -- boolean\n\
</pre></div><p>Controls the state of the Aspect Lock checkbutton.</p>\n\
<p>When set to true, changing the Width will affect the Height and vice-versa, preserving the aspect at the time the lock was engaged.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'section\'><a id=\"viewport---radial-cross-section\"></a><h3 id=\"viewport---radial-cross-section\">Viewport - Radial Cross-Section</h3></div>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_viewport_thickness Float default: 1.0 -- float; viewport_thickness\n\
</pre></div><p>Gets/Sets the diameter of the Radial renderable spline mesh in the viewport.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_viewport_sides Integer default: 12 -- integer; viewport_sides\n\
</pre></div><p>Gets/Sets the number of sides for the Radial spline mesh in the viewports.</p>\n\
<p>For example, a value of four will give you a square cross section.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_viewport_angle Float default: 0.0 -- float; viewport_angle\n\
</pre></div><p>Gets/Sets the rotational position of the cross-section in the viewports.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'section\'><a id=\"viewport---rectangular-cross-section\"></a><h3 id=\"viewport---rectangular-cross-section\">Viewport - Rectangular Cross-Section</h3></div>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_viewport_length Float default: 6.0 -- float\n\
</pre></div><p>Gets/Sets the length of the Rectangular spline mesh in the viewports.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_viewport_width Float default: 2.0 -- float\n\
</pre></div><p>Gets/Sets the width of the Rectangular spline mesh in the viewports.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_viewport_angle2 Float default: 0.0 -- float\n\
</pre></div><p>Gets/Sets the rotational position of the Rectangular cross-section in the viewports.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_viewport_aspect_locked BooleanClass default: false -- boolean\n\
</pre></div><p>Controls the state of the Aspect Lock checkbutton.</p>\n\
<p>When set to true, changing the Width will affect the Height and vice-versa, preserving the aspect at the time the lock was engaged.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'section\'><a id=\"auto-smooth\"></a><h3 id=\"auto-smooth\">Auto Smooth</h3></div>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_auto_smooth BooleanClass default: true -- boolean\n\
</pre></div><p>Controls the state of the Auto Smooth checkbox.</p>\n\
<p>When set to true, auto smoothing will be enabled.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SplineShape&gt;.render_threshold Float default: 40.0 -- animatable;\n\
</pre></div><p>Gets/sets the Auto Smooth Threshold value. Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<p>Up to 3*N vertex and tangent coordinates are available as properties, where N is the number of vertices in the SplineShape.</p>\n\
<p>A vertex and its tangents are available as properties once a controller is assigned to the vertex.</p>\n\
<p>Controllers can be assigned to vertices using the <span class=\'code\'>animateVertex()</span> method described in <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Scripting-Vertex-and-Control/Scripting-Vertex-and-Control-1.html\' title=\'\'>Scripting Vertex and Control Point Animation</a>.</p>\n\
<p>For example, if a circle object is collapsed to a SplineShape and some of its vertices are animated, the properties for the vertices and tangents will be similar to:</p>\n\
<div class=\'codeBlock\'><pre>$Circle01.Spline_1___InVec_1 Point3 value: [-75,33,0] -- animatable\n\
$Circle01.Spline_1___Vertex_1 Point3 value: [-75,33,0] -- animatable\n\
$Circle01.Spline_1___OutVec_1 Point3 value: [-50,0,0] -- animatable\n\
$Circle01.Spline_1___InVec_2 Point3 value: [-20,-33,0] -- animatable\n\
$Circle01.Spline_1___Vertex_2 Point3 value: [7,-66,0] -- animatable\n\
$Circle01.Spline_1___OutVec_2 Point3 value: [32,-95,0] -- animatable\n\
\n\
</pre></div><div class=\'section\'><a id=\"interpolation-rollout\"></a><h2 id=\"interpolation-rollout\">Interpolation Rollout</h2></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-D53843D4-E650-472F-8DBD-2CC40925E59F-low.gif\' title=\'\'></div>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;splineshape&gt;.steps Integer default: 6 -- integer\n\
</pre></div><p>Controls the Interpolation Steps in the Interpolation rollout.</p>\n\
<div class=\'codeBlock\'><pre>&lt;splineshape&gt;.optimize Boolean default: true -- boolean\n\
</pre></div><p>Controls the state of the Optimize checkbox in the Interpolation rollout.</p>\n\
<div class=\'codeBlock\'><pre>&lt;splineshape&gt;.adaptive Boolean default: false -- boolean\n\
</pre></div><p>Controls the state of the Adaptive checkbox in the Interpolation rollout.</p>\n\
<div class=\'section\'><a id=\"selection-rollout\"></a><h2 id=\"selection-rollout\">Selection Rollout</h2></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-E06D9679-B32F-4756-A304-4DF64B981977-low.gif\' title=\'\'></div>\n\
<p><strong>No Related Properties or Method exposed to MAXScript</strong>.</p>\n\
<div class=\'section\'><a id=\"soft-selection-rollout\"></a><h2 id=\"soft-selection-rollout\">Soft Selection Rollout</h2></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-07FAF928-03B6-4852-938C-350122B2EDDB-low.gif\' title=\'\'></div>\n\
<p><strong>No Related Properties or Method exposed to MAXScript</strong>.</p>\n\
<div class=\'section\'><a id=\"geometry-rollout\"></a><h2 id=\"geometry-rollout\">Geometry Rollout</h2></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-E63C4424-384E-4A57-A1F5-DD085F8159DD-low.gif\' title=\'\'></div>\n\
<div class=\'section\'><a id=\"create-break-attach\"></a><h3 id=\"create-break-attach\">Create, Break, Attach</h3></div>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>splineOps.startCreateLine &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Create Line&quot; command mode. It is valid in all Sub-Object levels and when not in the Sub-Object mode.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.startBreak &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Break&quot; command mode. It is valid in Vertex and Segment Sub-Object levels.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.startAttach &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Attach&quot; command mode. It is valid in all Sub-Object levels and when not in the Sub-Object mode.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.attachMultiple &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Displays the Attach Multiple dialog allowing the user to select multiple shapes to attach. Valid in all Sub-Object levels and when not in the Sub-Object mode.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'section\'><a id=\"refine\"></a><h3 id=\"refine\">Refine</h3></div>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>splineOps.startRefine &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Refine&quot; command mode. It is valid in Vertex and Segment Sub-Object levels. This method does not turn off the Connect checkbox, so it is effectively the same as the <span class=\'code\'>startRefineConnect()</span> method.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.startRefineConnect &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Refine&quot; command mode. It is valid in Vertex and Segment Sub-Object levels. This method does not turn on the Connect checkbox, so it is effectively the same as the <span class=\'code\'>startRefine()</span> method.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'section\'><a id=\"weld-connect-insert-make-first-fuse-reverse-cycle\"></a><h3 id=\"weld-connect-insert-make-first-fuse-reverse-cycle\">Weld, Connect, Insert, Make First, Fuse, Reverse, Cycle</h3></div>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>splineOps.weld &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Welds the selected vertices. It is valid in the Vertex Sub-Object level.</p>\n\
<p>See also the related methods in <a href=\'SplineShape-Shape.html#weld\' title=\'\'>ShapeMethods-Weld</a>.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.startConnect &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Connect&quot; command mode. It is valid in the Vertex Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.startInsert &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Insert&quot; command mode. It is valid in all Sub-Object levels, and when not in the Sub-Object mode.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.makeFirst &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Makes the selected vertices the first vertex in the spline. It is valid in the Vertex Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.fuse &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Fuses the selected vertices. Valid in the Vertex Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.reverse &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Reverses the order of vertices in the selected splines. It is valid in the Spline Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.cycle &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Cycles through the vertices of the spline, selecting each vertex.</p>\n\
<p>At least one vertex must be selected before calling this method, or no vertex is selected.</p>\n\
<p>If more than one vertex is selected when this method is called, the first vertex of the first shape is selected.</p>\n\
<p>Valid in the Vertex Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'section\'><a id=\"crossinsert-fillet-chamfer-outline\"></a><h3 id=\"crossinsert-fillet-chamfer-outline\">CrossInsert, Fillet, Chamfer, Outline</h3></div>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>splineOps.startCrossInsert &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;CrossInsert&quot; command mode. It is valid in the Vertex Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.startFillet &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Fillet&quot; command mode. It is valid in the Vertex Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.startChamfer &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Chamfer&quot; command mode. It is valid in the Vertex Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.startOutline &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Outline&quot; command mode. It is valid in the Spline Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'section\'><a id=\"boolean\"></a><h3 id=\"boolean\">Boolean</h3></div>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>splineOps.startUnion &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Boolean Union&quot; command mode. It is valid in the Spline Sub-Object level.</p>\n\
<p>Only one closed spline must be selected to enter this command mode.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.startSubtract &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Boolean Subtract&quot; command mode. It is valid in the Spline Sub-Object level.</p>\n\
<p>Only one closed spline must be selected to enter this command mode.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.intersect &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Boolean Intersect&quot; command mode. It is valid in the Spline Sub-Object level.</p>\n\
<p>Only one closed spline must be selected to enter this command mode.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'section\'><a id=\"mirror\"></a><h3 id=\"mirror\">Mirror</h3></div>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>splineOps.mirrorHoriz &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Mirrors the selected splines horizontally. It is valid in the Spline Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.mirrorVert &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Mirrors the selected splines vertically. It is valid in the Spline Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.mirrorBoth &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Mirrors the selected splines horizontally and vertically. It is valid in the Spline Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'section\'><a id=\"trip-extend\"></a><h3 id=\"trip-extend\">Trip, Extend</h3></div>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>splineOps.startTrim &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Trim&quot; command mode. It is valid in the Spline Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.startExtend &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Extend&quot; command mode. It is valid in the Spline Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'section\'><a id=\"copy-paste-tangent\"></a><h3 id=\"copy-paste-tangent\">Copy, Paste Tangent</h3></div>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>splineOps.startCopyTangent &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Copy Tangent&quot; command mode. It is valid in the Vertex Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.startPasteTangent &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Paste Tangent&quot; command mode. It is valid in the Vertex Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'section\'><a id=\"hide-unhide\"></a><h3 id=\"hide-unhide\">Hide, Unhide</h3></div>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>splineOps.hide &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Hides the selected sub-objects. It is valid in all Sub-Object levels.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.unhideAll &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Unhides all hidden sub-objects. It is valid in all Sub-Object levels and when not in the Sub-Object mode.</p>\n\
<p>See also the related methods in <a href=\'SplineShape-Shape.html#hide-and-unhide\' title=\'\'>Shape Methods -Hide,Unhide</a>.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'section\'><a id=\"bind-unbind\"></a><h3 id=\"bind-unbind\">Bind, Unbind</h3></div>\n\
<div class=\'codeBlock\'><pre>splineOps.startBind &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Enters the &quot;Bind&quot; command mode. It is valid in the Vertex Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.unbind &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Unbinds the selected vertices. It is valid in the Vertex Sub-Object level.</p>\n\
<p>See also related methods in <a href=\'SplineShape-Shape.html#bind-and-unbind\' title=\'\'>ShapeMethods-Bind,Unbind</a>.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'section\'><a id=\"delete-close\"></a><h3 id=\"delete-close\">Delete, Close</h3></div>\n\
<div class=\'codeBlock\'><pre>splineOps.delete &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Deletes the selected sub-objects. It is valid in all Sub-Object levels.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.close &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Closes the selected splines. It is valid in the Spline Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'section\'><a id=\"divide-detach-explode\"></a><h3 id=\"divide-detach-explode\">Divide, Detach, Explode</h3></div>\n\
<div class=\'codeBlock\'><pre>splineOps.divide &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Divides the selected segments. It is valid in the Segment Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.detach &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Displays the Detach dialog allowing the user to specify an object name. It is valid in all Sub-Object levels.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'codeBlock\'><pre>splineOps.explode &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Explodes each segment in the selected splines into separate splines or objects. It is valid in the Spline Sub-Object level.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<div class=\'section\'><a id=\"surface-properties-rollout\"></a><h2 id=\"surface-properties-rollout\">Surface Properties Rollout</h2></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-0188C4B3-CCFA-433C-99D5-407A14AB67ED-low.gif\' title=\'\'></div>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>splineOps.selectByID &lt;editable_spline_or_line_node_or_modifier&gt;\n\
</pre></div><p>Presses the Select ID button.</p>\n\
<p>See also the related methods in <a href=\'SplineShape-Shape.html#material-id\' title=\'\'>ShapeMethods-MaterialID</a>.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/Editable-Spline-Modify-Panel.html\' title=\'\'>Editable Spline Modify Panel Command Modes and Operations</a> for the full list of UI-related methods.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'section\'><a id=\"shape-methods\"></a><h2 id=\"shape-methods\">Shape Methods</h2></div>\n\
<div class=\'codeBlock\'><pre>updateShape &lt;shape&gt;\n\
</pre></div><p>Updates the shape&#39;s internal caches and viewport display to account for all the changes made by other functions in this kit. This update <strong>must</strong> be done before <strong>3ds Max</strong> or any other code tries to work with a modified shape object.</p>\n\
<p>The <span class=\'code\'>updateShape()</span> function makes any scripted changes to a base object spline shape propagate into the bottom of any modifier stack that is present.</p>\n\
<p>Note that there is no check to warn you that modifications such as, topology changes might invalidate modifiers already in the stack.</p>\n\
<p>This is equivalent to opening and modifying the base object in a Modify panel ignoring its warnings about invalidating the object.</p>\n\
<div class=\'codeBlock\'><pre>resetShape &lt;shape&gt;\n\
</pre></div><p>Clears all the spline curves out of a shape.</p>\n\
<div class=\'codeBlock\'><pre>numSplines &lt;shape&gt;\n\
</pre></div><p>Returns the number of spline curves in the shape as an integer.</p>\n\
<p>Equivalent to <span class=\'code\'>&lt;shape&gt;.numSplines</span> .</p>\n\
<div class=\'codeBlock\'><pre>setFirstSpline &lt;shape&gt; &lt;spline_index_integer&gt;\n\
</pre></div><p>Rolls the order of the splines in a shape around so that the numbered spline is the first spline in the shape.</p>\n\
<p>This is useful when working with multi-spline shapes in the Lofter and some other modifiers such as, Surface Tools which are sensitive to spline order.</p>\n\
<div class=\'section\'><a id=\"weld\"></a><h3 id=\"weld\">Weld</h3></div>\n\
<div class=\'codeBlock\'><pre>addAndWeld &lt;to_shape&gt; &lt;from_shape&gt; &lt;weldthreshold_float&gt;\n\
</pre></div><p>Add the splines from one spline shape to the specified bezier shape.</p>\n\
<p>The weld threshold will weld the endpoints of the new splines onto endpoints of existing ones if they are within the specified distance.</p>\n\
<div class=\'section\'><a id=\"bind-and-unbind\"></a><h3 id=\"bind-and-unbind\">Bind and Unbind</h3></div>\n\
<div class=\'codeBlock\'><pre>bindKnot &lt;shape&gt; &lt;isEnd_boolean&gt; &lt;splineId_integer&gt; &lt;segIndex_integer&gt; &lt;splineSegId_integer&gt;\n\
</pre></div><p>Binds the first or end knot of a spline to the midpoint of the specified segment.</p>\n\
<p>A bind acts as a constraint, it constrains the first point or the end point of a spline to the mid point of a segment.</p>\n\
<p>If <span class=\'code\'>&lt;isEnd_boolean&gt;</span> is <span class=\'code\'>true</span> , the end knot of the spline is bound, otherwise the first knot is bound.</p>\n\
<p><span class=\'code\'>&lt;splineId_integer&gt;</span> specifies the index of the spline the first/end knot to bind belongs to, <span class=\'code\'>&lt;segIndex_integer&gt;</span> specifies the index of the segment to bind to, and <span class=\'code\'>&lt;splineSegId_integer&gt;</span> specifies the index of the spline the bind to segment belongs to.</p>\n\
<div class=\'codeBlock\'><pre>unBindKnot &lt;shape&gt; &lt;spline_index_integer&gt; &lt;isEnd_boolean&gt;\n\
</pre></div><p>Unbinds the specified end/first knot of the given spline.</p>\n\
<div class=\'codeBlock\'><pre>updateBindList &lt;shape&gt;\n\
</pre></div><p>Called when the topology changes to update the bind list. For example, when knots are deleted from the bound spline or the spline bound to.</p>\n\
<div class=\'section\'><a id=\"hide-and-unhide\"></a><h3 id=\"hide-and-unhide\">Hide and Unhide</h3></div>\n\
<div class=\'codeBlock\'><pre>hideselectedsplines &lt;shape&gt;\n\
</pre></div><p>Hides the selected splines in the shape.</p>\n\
<div class=\'codeBlock\'><pre>hideselectedsegments &lt;shape&gt;\n\
</pre></div><p>Hides the selected segments in the shape.</p>\n\
<div class=\'codeBlock\'><pre>hideselectedverts &lt;shape&gt;\n\
</pre></div><p>Hides the segments attached to the selected knots in the shape.</p>\n\
<div class=\'codeBlock\'><pre>unhidesegments &lt;shape&gt;\n\
</pre></div><p>Unhides all segments in the shape.</p>\n\
<div class=\'section\'><a id=\"material-id\"></a><h3 id=\"material-id\">Material ID</h3></div>\n\
<div class=\'codeBlock\'><pre>materialID &lt;shape&gt; &lt;spline_index_integer&gt; &lt;segment_index_integer&gt;\n\
</pre></div><p>Returns the material id for the given segment of the given shape object.</p>\n\
<div class=\'section\'><a id=\"vertex-animation\"></a><h3 id=\"vertex-animation\">Vertex Animation</h3></div>\n\
<div class=\'codeBlock\'><pre>animateVertex &lt;shape&gt; &lt;vertex_spec&gt;\n\
</pre></div><p>Applies controllers to the specified vertices and tangents of the splineshape, where <span class=\'code\'>&lt;vertex_spec&gt;</span> is one of these:</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer_index&gt;\n\
&lt;integer_index_array&gt;\n\
#all \n\
</pre></div><p>By assigning controllers to the vertices and tangents, the vertices and tangents are added to the Driver subAnim and appear as animatables in the Track View, allowing further scripting of the vertices and tangents.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` animateVertex $Circle01 #all</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The vertices to be animated are specified by index number or with the keyword <strong>#all</strong> to animate all vertices.</p>\n\
<p>See also <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Identifying-and-Accessing/Class-and-Object-Inspector.html\' title=\'\'>Class and Object Inspector Functions</a> and <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Scripting-Vertex-and-Control/Scripting-Vertex-and-Control-1.html\' title=\'\'>Scripting Vertex and Control Point Animation</a> for details on accessing the splineshape vertices and tangents. The controller values assigned to the vertices and tangent handles is in object space. See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/Using-Node-Transform-Properties.html\' title=\'\'>Using Node Transform Properties</a> for information on converting between world space to object space.</p>\n\
<p><strong>For examples of creating and modifying spline shapes, see also</strong></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Practical-Questions/Working-with-Scene-Nodes/How-do-I-create-a-line-between.html\' title=\'\'>MAXScript FAQ: How do I create a line between two points?</a></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Flatten-a-SplineShape.html\' title=\'\'>How To ... Flatten a SplineShape</a></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Draw-a-Freehand-Spline.html\' title=\'\'>How To ... Draw a Freehand Spline</a></p>\n\
<div class=\'section\'><a id=\"spline-methods\"></a><h2 id=\"spline-methods\">Spline Methods</h2></div>\n\
<div class=\'codeBlock\'><pre>addNewSpline &lt;shape&gt;\n\
</pre></div><p>Adds a new spline curve to the spline shape and returns an integer reflecting the spline index of the newly added spline curve.</p>\n\
<p>Individual spline curves are given index numbers starting at one.</p>\n\
<p>The <span class=\'code\'>addNewSpline()</span> function adds new spline curves to the end of the list of curves in a shape.</p>\n\
<div class=\'codeBlock\'><pre>getSplineSelection &lt;shape&gt;\n\
</pre></div><p>Returns the indices of the selected splines in the shape as an array of integers.</p>\n\
<div class=\'codeBlock\'><pre>setSplineSelection &lt;shape&gt; &lt;spline_index_array&gt; [keep:&lt;boolean&gt; ]\n\
</pre></div><p>Selects the splines specified by <span class=\'code\'>&lt;spline_index_array&gt;</span> in the specified shape.</p>\n\
<p><span class=\'code\'>&lt;spline_index_array&gt;</span> is an array of integers specifying the spline indices.</p>\n\
<p>Splines already selected are de-selected unless <span class=\'code\'>keep:true</span> is specified.</p>\n\
<div class=\'codeBlock\'><pre>deleteSpline &lt;shape&gt; &lt;spline_index_integer&gt;\n\
</pre></div><p>Deletes the indexed spline curve from the shape.</p>\n\
<p>The remaining curves are renumbered to account for the deletion.</p>\n\
<div class=\'codeBlock\'><pre>numSegments &lt;shape&gt; &lt;spline_index_integer&gt;\n\
</pre></div><p>Returns the number of line segments in the indexed spline as an integer.</p>\n\
<p>This is the same as the number of knots for closed splines and one less for open splines.</p>\n\
<div class=\'codeBlock\'><pre>numKnots &lt;shape&gt; [ &lt;spline_index_integer&gt; ]\n\
</pre></div><p>Returns the number of knots (also known as vertices or control points) in the indexed spline as an integer.</p>\n\
<p>If the spline index is not specified, returns the number of knots in the entire shape.</p>\n\
<div class=\'codeBlock\'><pre>isClosed &lt;shape&gt; &lt;spline_index_integer&gt;\n\
</pre></div><p>Returns true if the indexed spline is closed, false if it is open.</p>\n\
<div class=\'codeBlock\'><pre>close &lt;shape&gt; &lt;spline_index_integer&gt;\n\
</pre></div><p>Closes the indexed spline.</p>\n\
<div class=\'codeBlock\'><pre>open &lt;shape&gt; &lt;spline_index_integer&gt;\n\
</pre></div><p>Opens the indexed spline between its last and first knots.</p>\n\
<div class=\'codeBlock\'><pre>reverse &lt;shape&gt; &lt;spline_index_integer&gt;\n\
</pre></div><p>Reverses the order of the knots in the indexed spline.</p>\n\
<div class=\'codeBlock\'><pre>setFirstKnot &lt;shape&gt; &lt;spline_index_integer&gt; &lt;knot_index_integer&gt;\n\
</pre></div><p>Rolls the order of the knots in the indexed spline around so that the specified knot becomes the first knot in the spline.</p>\n\
<div class=\'codeBlock\'><pre>weldSpline &lt;splineShape node&gt; &lt;tolerance&gt;\n\
</pre></div><p>Welds the selected knots in the specified splineShape that are within the specified tolerance.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>.</p>\n\
<p>Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a> .</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` ( local sp = splineShape() addnewSpline sp addKnot sp 1 #corner #line [20,10,0] addKnot sp 1 #corner #line [-20,11,0] addKnot sp 1 #corner #line [-20,-11,0] addKnot sp 1 #corner #line [20,-10,0] close sp 1 updateShape sp select sp subobjectlevel = 1 setKnotSelection sp 1 #(1,4) keep:false -- Select the right most knots weldSpline sp 21.0 local knotCount = numknots sp if (knotCount != 3) do throw (&quot;Spline should have 3 knots, found &quot;+ (knotCount as string)) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>getSegLengths &lt;splineShape&gt; &lt;spline_index&gt; [cum:&lt;boolean&gt;] \\\n\
[byVertex:&lt;boolean&gt;] [numArcSteps:&lt;integer&gt;]\n\
</pre></div><p>Returns an array of segment lengths or vertex distances by spline fraction and length, and total spline length.</p>\n\
<p>Double precision calculations are very accurate.</p>\n\
<p>If <span class=\'code\'>cum:true</span>, the results are cumulative, otherwise they are relative.</p>\n\
<p>If <span class=\'code\'>byVertex:true</span>, the results are per vertex, otherwise per segment.</p>\n\
<p><strong>Defaults</strong>: <span class=\'code\'>cum:false</span> <span class=\'code\'>byVertex:false</span> <span class=\'code\'>numArcSteps:100</span></p>\n\
<div class=\'codeBlock\'><pre>subdivideSegment &lt;splineShape&gt; &lt;spline_index&gt; &lt;seg_index&gt; &lt;divisions&gt;\n\
</pre></div><p>Divides the segment into the specified number of divisions.</p>\n\
<p>Double precision calculations are very accurate.</p>\n\
<div class=\'codeBlock\'><pre>interpCurve3D &lt;splineShape&gt; &lt;spline_index&gt; &lt;param_float&gt; [pathParam:&lt;boolean&gt;]\n\
</pre></div><p>Returns a <span class=\'code\'>&lt;point3&gt;</span> coordinate on the indexed curve.</p>\n\
<p>If <span class=\'code\'>pathParam:false</span>, <span class=\'code\'>param_float</span> is the fraction of the spline length, otherwise it is a segment-based (path) fraction.</p>\n\
<p>Default is <span class=\'code\'>pathParam:false</span>.</p>\n\
<div class=\'codeBlock\'><pre>tangentCurve3D &lt;splineShape&gt; &lt;spline_index&gt; &lt;param_float&gt; [pathParam:&lt;boolean&gt;]\n\
</pre></div><p>Returns a <span class=\'code\'>&lt;point3&gt;</span> tangent on the indexed curve.</p>\n\
<p>If <span class=\'code\'>pathParam:false</span>, <span class=\'code\'>param_float</span> is the fraction of the spline length, otherwise it is a segment-based (path) fraction.</p>\n\
<p>Default is <span class=\'code\'>pathParam:false</span>.</p>\n\
<div class=\'codeBlock\'><pre>findPathSegAndParam &lt;shape&gt; &lt;curve_num&gt; &lt;param&gt;\n\
</pre></div><p>Returns a point2 value containing the segment and segment fraction for the specified <strong>vertex-interpolated</strong> spline parameter.</p>\n\
<p>The first and second arguments specify the shape and the spline within the shape to interpolate, the third argument is the parameter to interpolate.</p>\n\
<p>For example, passing a parameter of 0.5 with a 10 segments spline will always return a point2 value containing either [6,0.0] (or very close to 0) or [5,1.0] because the middle of a 10 segments spline using vertex interpolation is always the vertex between the 5 th and the 6 th segment.</p>\n\
<p>See the notes below for information about interpolation methods.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>findLengthSegAndParam &lt;shape&gt; &lt;curve_num&gt; &lt;param&gt;\n\
</pre></div><p>Returns a point2 value containing the segment and segment fraction for the specified <strong>length-interpolated</strong> spline parameter.</p>\n\
<p>The first and second arguments specify the shape and the spline within the shape to interpolate, and the third argument is the parameter to interpolate.</p>\n\
<p>In contrast to <span class=\'code\'>findPathSegAndParam()</span> , this method takes the actual length of the segments into account, normalizing the complete length between 0.0 and 1.0 and then interpolating along the length, so a parameter of 0.5 with a 10 segments spline will always return the segment and parameter within the segment that lies in the exact middle of the spline&#39;s length, varying based on the actual segment lengths/vertex distribution within the spline.</p>\n\
<p>See the notes below.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<blockquote>\n\
<p><strong>VERTEX AND LENGTH INTERPOLATION METHODS:</strong></p>\n\
<p>There are two methods to interpolate a position along the spline: <strong>vertex interpolation</strong> and <strong>length interpolation</strong>.</p>\n\
<p>When using <strong>vertex interpolation (path interpolation)</strong>, the spline is seen as a number of segments where each segment between two vertices is a normalized space from 0.0 to 1.0. The distance between the two vertices of a segment is ignored during the interpolation, which means that if the lengths of the segments are different, interpolating linearly along the spline will result in varying speed.</p>\n\
<p>You can visualize this on a <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Constraints/Path_Constraint-superclass.html\' title=\'\'>Path Constraint</a> with Constant Velocity unchecked where the object is moving faster between two vertices when the segment between them is longer (see the image below).</p>\n\
<p>When using <strong>length interpolation</strong>, the whole spline length is normalized, so a parameter of 0.5 will be exactly in the middle of the spline regardless of the segments&#39; lengths. The speed of a point interpolated along the spline using a parameter that changes linearly between 0.0 and 1.0 will remain constant along the whole spline even if the vertex placement is irregular.</p>\n\
<p>This can be demonstrated when checking the Constant Velocity checkbox in the Path Constraint that enables the length interpolation:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-42F3E6D9-1E1A-4FB4-A63E-FD8AE46C0CE8-low.gif\' title=\'\'></div>\n\
<p>In this image, the top object is a SplineShape with varying segment length and ten segments.</p>\n\
<p>The middle object is a copy of the same shape used as a path by a Point Helper. The <strong>Constant Velocity</strong> checkbox was <strong>unchecked</strong> in the Path Constraint causing it to use <strong>vertex interpolation</strong>. For 100 frames, it divided the shape in ten segments and placed ten samples on each segment resulting in varying speed dependent on the length of the segment.</p>\n\
<p>The bottom object is a copy of the same shape used as a path by another Point Helper, but this time <strong>Constant Velocity</strong> is <strong>turned on</strong> causing it to use <strong>length interpolation</strong>. You can see clearly that the samples are evenly spaces along the full length of the shape disregarding the distances between the vertices defining the segments.</p>\n\
<p>The time slider was set of frame 50. The <strong>length interpolation</strong> at the bottom places the point helper exactly at the <strong>middle</strong> of the path shape, while the <strong>vertex interpolation</strong> places it exactly <strong>on the vertex</strong> between the 5 th and the 6 th segment.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` ( local sp = splineShape() addnewSpline sp for i = 0 to 10 do ( addknot sp 1 #smooth #curve [i<em>10, i</em>i, i*10] ) updateShape sp for i = 0.0 to 1.0 by 0.05 do ( local pt1= findPathSegAndParam sp 1 i local pt2= findLengthSegAndParam sp 1 i format &quot;% : % \\t %\\n&quot;i pt2 pt1 ) )</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` 0.0 : [1,0] [1,0] 0.05 : [1,0.633532] [1,0.5] 0.1 : [2,0.261918] [1,1] 0.15 : [2,0.883245] [2,0.5] 0.2 : [3,0.486351] [2,1] 0.25 : [4,0.0810387] [3,0.5] 0.3 : [4,0.650404] [3,1] 0.35 : [5,0.206902] [4,0.5] 0.4 : [5,0.74293] [5,2.98023e-007] 0.45 : [6,0.261026] [5,0.5] 0.5 : [6,0.762596] [6,5.96046e-007] 0.55 : [7,0.246405] [6,0.500001] 0.6 : [7,0.714253] [7,5.96046e-007] 0.65 : [8,0.16969] [7,0.500001] 0.7 : [8,0.605653] [8,5.96046e-007] 0.75 : [9,0.0387986] [8,0.500001] 0.8 : [9,0.445251] [9,5.96046e-007] 0.85 : [9,0.851703] [9,0.500001] 0.9 : [10,0.241028] [10,5.96046e-007] 0.95 : [10,0.620515] [10,0.500001] 1.0 : [10,1] [10,0.999999] OK</p>\n\
<p>```</p>\n\
<p>The vertex interpolation at the right side hits more or less precisely the start or end vertex and the center of each of the 10 segments because we are stepping with 1/20 th per iteration, while the length interpolation takes into account the actual length of all segments and moves smoothly along the spline.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>interpBezier3D &lt;splineShape&gt; &lt;spline_index&gt; &lt;segment_index&gt; &lt;param_float&gt; pathParam:&lt;boolean&gt;\n\
</pre></div><p>Returns a point3 coordinate for the segment and segment fraction on the indexed curve.</p>\n\
<p>If <span class=\'code\'>pathParam:false</span>, <span class=\'code\'>param_float</span> is the fraction of the segment length, otherwise it is a segment-based (path) fraction.</p>\n\
<p>Default is <span class=\'code\'>pathParam:false</span> .</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>.</p>\n\
<p>Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>tangentBezier3D &lt;splineShape&gt; &lt;spline_index&gt; &lt;segment_index&gt; &lt;param_float&gt; pathParam:&lt;boolean&gt;\n\
</pre></div><p>Returns a point3 tangent for the segment and segment fraction on the indexed curve.</p>\n\
<p>If <span class=\'code\'>pathParam:false</span>, <span class=\'code\'>param_float</span> is the fraction of the segment length, otherwise it is a segment-based (path) fraction.</p>\n\
<p>Default is <span class=\'code\'>pathParam:false</span>.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>.</p>\n\
<p>Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` ( local sp = splineShape() addnewSpline sp for i = 1 to 100 by 10 do ( addknot sp 1 #smooth #curve [i, (i*i / 100.0), i] ) updateShape sp sp.wirecolor = color 255 0 0 local count = numknots sp - 1 for i = 1 to count do ( local pathp = true local pt = interpBezier3D sp 1 i 0.50 pathParam:pathp local tn = tangentBezier3D sp 1 i 0.50 pathParam:pathp local sr = splineShape() addnewSpline sr addknot sr 1 #corner #line pt addknot sr 1 #corner #line (pt + (tn * 30)) updateShape sr sr.wirecolor =blue ) )</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-04F2A396-599D-4365-9E92-E781C7445280-low.gif\' title=\'\'></div>\n\
</blockquote>\n\
<p><strong>For examples of creating and modifying spline shapes, see also</strong></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Practical-Questions/Working-with-Scene-Nodes/How-do-I-create-a-line-between.html\' title=\'\'>MAXScript FAQ:How do I create a line between two points?</a></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Flatten-a-SplineShape.html\' title=\'\'>How To ... Flatten a SplineShape</a></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Draw-a-Freehand-Spline.html\' title=\'\'>How To ... Draw a Freehand Spline</a></p>\n\
<div class=\'section\'><a id=\"segment-methods\"></a><h2 id=\"segment-methods\">Segment Methods</h2></div>\n\
<div class=\'codeBlock\'><pre>getSegmentType &lt;shape&gt; &lt;spline_index_integer&gt; &lt;seg_index_integer&gt;\n\
</pre></div><p>Gets the segment type of the indexed segment in the indexed spline.</p>\n\
<div class=\'codeBlock\'><pre>setSegmentType &lt;shape&gt; &lt;spline_index_integer&gt; &lt;seg_index_integer&gt; (#curve | #line)\n\
</pre></div><p>Sets the segment type of the indexed segment in the indexed spline.</p>\n\
<div class=\'codeBlock\'><pre>refineSegment &lt;shape&gt; &lt;spline_index_integer&gt; &lt;seg_index_integer&gt; &lt;seg_interp_param_float&gt;\n\
</pre></div><p>Adds a new knot to the indexed segment of the indexed curve at a place along the indexed segment corresponding to the given segment interpolation parameter.</p>\n\
<p>This value is a float in the range of <strong>0.0</strong> to <strong>1.0</strong> specifying a proportion along the segment.</p>\n\
<p>The new knot coordinates, and in-vector and out-vector are automatically computed to maintain the segment&#39;s existing curvature.</p>\n\
<p>This is the primitive used by the <span class=\'code\'>refine()</span> function in the Edit Spline modifier.</p>\n\
<p>You can use the MAXScript spline path interpolation functions to derive segment parameters given that a curve&#39;s <strong>path interpolation</strong> parameter is divided evenly among the segments in a curve.</p>\n\
<p>Given a path interpolation parameter <strong>u</strong> in a spline of <strong>m</strong> segments, the target segment is:</p>\n\
<div class=\'codeBlock\'><pre>n = (m*u) as integer + 1\n\
</pre></div><p>The segment parameter is:</p>\n\
<div class=\'codeBlock\'><pre>f = (u-(n-1)/m)*m\n\
</pre></div><p>This can be refactored to the following which will reduce roundoff error in the calculation:</p>\n\
<div class=\'codeBlock\'><pre>f = u*m-n+1\n\
</pre></div><p>The <span class=\'code\'>refineSegment()</span> function returns the index of the newly inserted knot.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` s = splineShape() --create a spline shape addNewSpline s --add a spline to it addKnot s 1 #corner #line [0,0,0] --add a knot at origin addKnot s 1 #smooth #curve [100,0,0] --add a knot <span class=\"cite\" data-citation-ids=\"100\">@100</span> units along X addKnot s 1 #corner #line [200,100,0] --add a third knot updateShape s --update the shape s.vertexTicks = true --enable vertex ticks</p>\n\
<p>```</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-36714871-84D7-4D51-83F0-2B5F13886D79-low.gif\' title=\'\'></div>\n\
<p>``` --We have two segments and three knots now. refineSegment s 1 1 0.3 --divide the first segment at 30/70% ratio updateShape s --update the shape to see the result --Since our first segment was 100 units long, the vertex is exactly --at 30 units from the origin, just as expected:</p>\n\
<p>```</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-87BCC80C-889E-4761-B7DA-128FD67A799A-low.gif\' title=\'\'></div>\n\
<p>``` --now we have 3 segments - the original second segment is not third refineSegment s 1 3 0.5 -- let&#39;s divide it in two equal parts updateShape s --update the shape to see the result --Because the segment is curved, the knot is not at equal distances --to the two other knots along a straight line, but the --distances ALONG THE CURVED SEGMENT are equal:</p>\n\
<p>```</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-FB446AB7-B061-4F5D-B2D8-7EE1467ADA3D-low.gif\' title=\'\'></div>\n\
<p>``` refineSegment s 1 4 0.8 --divide the new last segment at 80/20% ratio updateShape s --and update the shape to see the result:</p>\n\
<p>```</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-5B1D984F-6C21-4B24-975C-49C1415F8BA5-low.gif\' title=\'\'></div>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>getSegSelection &lt;shape&gt; &lt;spline_index_integer&gt;\n\
</pre></div><p>Returns the indices of the selected segments in the specified shape spline as an array of integers.</p>\n\
<div class=\'codeBlock\'><pre>setSegSelection &lt;shape&gt; &lt;spline_index_integer&gt; \\\n\
&lt;segment_index_array&gt; \\\n\
[keep: &lt;boolean&gt; ]\n\
</pre></div><p>Selects the segments specified by <span class=\'code\'>&lt;segment_index_array&gt;</span> in the specified shape spline.</p>\n\
<p><span class=\'code\'>&lt;segment_index_array&gt;</span> is an array of integers specifying the segment indices.</p>\n\
<p>Segments already selected are de-selected unless <span class=\'code\'>keep</span>:true` is specified.</p>\n\
<div class=\'codeBlock\'><pre>setMaterialID &lt;splineShape&gt; &lt;spline_index&gt; &lt;seg_index&gt; &lt;matID&gt;\n\
</pre></div><p>Sets the material ID of the specified spline segment.</p>\n\
<div class=\'codeBlock\'><pre>getMaterialID &lt;splineShape&gt; &lt;spline_index&gt; &lt;seg_index&gt;\n\
</pre></div><p>Gets the material ID of the specified spline segment.</p>\n\
<p><strong>For examples of creating and modifying spline shapes, see also:</strong></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Practical-Questions/Working-with-Scene-Nodes/How-do-I-create-a-line-between.html\' title=\'\'>MAXScript FAQ:How do I create a line between two points?</a></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Flatten-a-SplineShape.html\' title=\'\'>How To ... Flatten a SplineShape</a></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Draw-a-Freehand-Spline.html\' title=\'\'>How To ... Draw a Freehand Spline</a></p>\n\
<div class=\'section\'><a id=\"knot-methods\"></a><h2 id=\"knot-methods\">Knot Methods</h2></div>\n\
<div class=\'codeBlock\'><pre>addKnot &lt;shape&gt; &lt;spline_index_integer&gt; \\\n\
(#smooth | #corner | #bezier | #bezierCorner) \\\n\
(#curve | #line) &lt;position_point3&gt; \\\n\
[invec_point3 outvec_point3] \\\n\
[where_integer]\n\
</pre></div><p>Adds a new knot (control point) to the indexed spline and returns an integer reflecting the index of the newly added knot.</p>\n\
<p>The 3 rd argument specifies the type of the knot, the 4 th specifies the type of the segment leaving the knot.</p>\n\
<p>The 5 th specifies the coordinates for the new point (given in the current working coordinate system).</p>\n\
<p>If the knot type is <span class=\'code\'>#bezier</span> or <span class=\'code\'>#bezierCorner</span> , you must give the in-vector and out-vector handle coordinates as the 6 th and 7 th arguments. In the same way as splines are indexed in a shape, knots are indexed in a spline.</p>\n\
<p>The optional last argument lets you specify where in the knot order the new knot is to be inserted, defaulting to the end of the spline if you leave this argument off.</p>\n\
<div class=\'codeBlock\'><pre>deleteKnot &lt;shape&gt; &lt;spline_index_integer&gt; &lt;knot_index_integer&gt;\n\
</pre></div><p>Deletes the indexed knot in the indexed spline.</p>\n\
<p>The remaining knots are renumbered to account for the deletion.</p>\n\
<div class=\'codeBlock\'><pre>getKnotType &lt;shape&gt; &lt;spline_index_integer&gt; &lt;knot_index_integer&gt;\n\
</pre></div><p>Returns the knot type of the indexed knot in the indexed spline.</p>\n\
<p>The value is one of the names <span class=\'code\'>#smooth</span> , <span class=\'code\'>#corner</span> , <span class=\'code\'>#bezier</span> , or <span class=\'code\'>#bezierCorner</span> .</p>\n\
<div class=\'codeBlock\'><pre>setKnotType &lt;shape&gt; &lt;spline_index_integer&gt; &lt;knot_index_integer&gt; (#smooth | #corner | #bezier | #bezierCorner)\n\
</pre></div><p>Sets the knot type of the indexed knot in the indexed spline.</p>\n\
<p>This is equivalent to the right-mouse-button change you can make to spline control-points using the Edit Spline modifier in <strong>3ds Max</strong>.</p>\n\
<div class=\'codeBlock\'><pre>getKnotPoint &lt;shape&gt; &lt;spline_index_integer&gt; &lt;knot_index_integer&gt;\n\
</pre></div><p>Retrieves the coordinates of the indexed knot as a point3 in the current working coordinate system.</p>\n\
<div class=\'codeBlock\'><pre>setKnotPoint &lt;shape&gt; &lt;spline_index_integer&gt; &lt;knot_index_integer&gt; &lt;point3&gt;\n\
</pre></div><p>Sets the coordinates of the indexed knot in the indexed spline.</p>\n\
<p>Coordinates are given in the current working coordinate system.</p>\n\
<div class=\'codeBlock\'><pre>getInVec &lt;shape&gt; &lt;spline_index_integer&gt; &lt;knot_index_integer&gt;\n\
</pre></div><p>Retrieves the coordinates of the in-vector handle for the indexed knot as a point3 in the current working coordinate system.</p>\n\
<div class=\'codeBlock\'><pre>setInVec &lt;shape&gt; &lt;spline_index_integer&gt; &lt;knot_index_integer&gt; &lt;point3&gt;\n\
</pre></div><p>Sets the coordinates of the in-vector handle of the indexed knot.</p>\n\
<p>Coordinates are given in the current working coordinate system.</p>\n\
<div class=\'codeBlock\'><pre>getOutVec &lt;shape&gt; &lt;spline_index_integer&gt; &lt;knot_index_integer&gt;\n\
</pre></div><p>Retrieves the coordinates of the out-vector handle for the indexed knot as a point3 in the current working coordinate system.</p>\n\
<div class=\'codeBlock\'><pre>setOutVec &lt;shape&gt; &lt;spline_index_integer&gt; &lt;knot_index_integer&gt; &lt;point3&gt;\n\
</pre></div><p>Sets the coordinates of the out-vector handle of the indexed knot.</p>\n\
<p>Coordinates are given in the current working coordinate system.</p>\n\
<div class=\'codeBlock\'><pre>getKnotSelection &lt;shape&gt; &lt;spline_index_integer&gt;\n\
</pre></div><p>Returns the indices of the selected knots in the specified shape spline as an array of integers.</p>\n\
<div class=\'codeBlock\'><pre>setKnotSelection &lt;shape&gt; &lt;spline_index_integer&gt; &lt;knot_index_array&gt; [keep: &lt;boolean&gt; ]\n\
</pre></div><p>Selects the knots specified by <span class=\'code\'>&lt;knot_index_array&gt;</span> in the specified shape spline. <span class=\'code\'>&lt;knot_index_array&gt;</span> is an array of integers specifying the knot indices.</p>\n\
<p>Knots already selected are de-selected unless <span class=\'code\'>keep:true</span> is specified.</p>\n\
<p><strong>For examples of creating and modifying spline shapes, see also:</strong></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Practical-Questions/Working-with-Scene-Nodes/How-do-I-create-a-line-between.html\' title=\'\'>MAXScript FAQ:How do I create a line between two points?</a></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Flatten-a-SplineShape.html\' title=\'\'>How To ... Flatten a SplineShape</a></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Draw-a-Freehand-Spline.html\' title=\'\'>How To ... Draw a Freehand Spline</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";