var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Class and Object Inspector Functions</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Class and Object Inspector Functions</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"class-and-object-inspector-functions\"></a></div>\n\
<p>MAXScript provides a number of built-in functions for displaying information about the classes that are accessible in your particular <strong>3ds Max</strong> installation. These functions are useful as an online reference for the core <strong>3ds Max</strong> classes and provide the only way of determining what properties in <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Identifying-and-Accessing/Third-Party-Plug-In-Classes.html\' title=\'\'>third-party plug-in classes</a> are accessible.</p>\n\
<p>{toc}</p>\n\
<div class=\'section\'><a id=\"pattern-strings\"></a><h2 id=\"pattern-strings\">Pattern Strings</h2></div>\n\
<p>The <span class=\'code\'>apropos()</span>, <span class=\'code\'>showClass()</span> and <span class=\'code\'>showProperties()</span> methods take pattern strings as input. Pattern strings can contain:</p>\n\
<ul>\n\
<li>regular characters to be matched exactly</li>\n\
<li><span class=\'code\'>*</span> matching any sequence of characters (zero or more)</li>\n\
<li><span class=\'code\'>?</span> matching any single character</li>\n\
<li><span class=\'code\'>[SET]</span> matching any character in the set</li>\n\
<li><span class=\'code\'>[!SET]</span> or <span class=\'code\'>[^SET]</span> matching any character NOT in the set.</li>\n\
</ul>\n\
<p>A set is composed of characters, or a range of characters separated by a hyphen, such as &quot;0-9&quot; or &quot;A-D&quot;. Sets are case-sensitive, and uppercase letters are &quot;less than&quot; lowercase, so &quot;a-Z&quot; is not valid, while &quot;A-z&quot; is.</p>\n\
<p>Special characters can be escaped (treated as a literal character) by prepending with a backslash <span class=\'code\'>\\</span>. The special characters are: <span class=\'code\'>[]*?!^-\\</span></p>\n\
<div class=\'section\'><a id=\"apropos\"></a><h2 id=\"apropos\">apropos</h2></div>\n\
<p>The <span class=\'code\'>apropos()</span> function is used to search for and print out information about global variables by name pattern and class of contents.</p>\n\
<p>This function has the form:</p>\n\
<div class=\'codeBlock\'><pre>apropos &lt;pattern_string&gt; [ implicitWild:true ] [ to:&lt;stream&gt; ]\n\
</pre></div><p>The <span class=\'code\'>&lt;pattern_string&gt;</span> argument is a string containing a wild-card pattern for matching against global variables.</p>\n\
<p>The pattern form is:</p>\n\
<div class=\'codeBlock\'><pre>&lt;variable_name_pattern_string[:class_name_pattern_string]&gt;\n\
</pre></div><p>that is, a global variable name pattern optionally followed by a &#39;:&#39; and a class name pattern.</p>\n\
<p>If the optional class name pattern is given, it restricts the printout to globals containing values of the specified classes.</p>\n\
<p>The <span class=\'code\'>apropos()</span> function assumes a wild-card &#39;*&#39; at the start and end of each pattern, implying a &#39;contains&#39; pattern match, unless <span class=\'code\'>implicitWild:false</span> is specified, in which case no &#39;*&#39; are assumed. See <a href=\'Class-and-Object-Inspector.html#pattern-strings\' title=\'\'>Pattern Strings</a> above for more information.</p>\n\
<p>The output consists of the global variable name, a tag in () indicating if the variable is a system or const (unchangeable) variable and the class of the value currently in it, followed by a printed representation of that value.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES</strong></p>\n\
<p>``` apropos &quot;light&quot; -- any variables with &#39;light&#39; in the variable name apropos &quot;:float&quot; -- any variables containing float values apropos &quot;&quot; to:f -- dump all variables to the stream f apropos &quot;controller:super&quot; -- the list of controller superclasses apropos &quot;foo:control&quot; -- any variables whose name contains &#39;foo&#39; -- and that contain controller classes apropos &quot;[x-z]*&quot; implicitWild:false -- any classes or functions that start with x, y, or z</p>\n\
<p>```</p>\n\
<p>Here&#39;s a fragment of the first example&#39;s output:</p>\n\
<p>``` lights (const ObjectSet): $lights lightLevel (system Float): 1.0 Sunlight (const MAXClass): Sunlight Directionallight (const MAXClass): Directionallight lightLevelController (system Control): Controller:Bezier_Float light (const MAXSuperClass): light NewLight (const Primitive): NewLight() lightTintColor (system Color): (color 255 255 255) Volume_Light (const MAXClass): Volume_Light lightTintColorController (system Control): Controller:Bezier_Color gw.getMaxLights (Primitive): getMaxLights() gw.setLight (Primitive): setLight()</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>To make scripting easier to teach and use everyday, a ScriptTool function for <strong>Help</strong> has been added. It is an alias for <strong>apropos</strong>.</p>\n\
<p>Typing <strong>Help &quot;Box&quot;</strong> will show all the commands using the name BOX.</p>\n\
<div class=\'section\'><a id=\"showclass\"></a><h2 id=\"showclass\">showClass</h2></div>\n\
<p>The <span class=\'code\'>showClass()</span> function prints information about a specified <strong>3ds Max</strong> class or classes. It has the following form:</p>\n\
<div class=\'codeBlock\'><pre>showClass &lt;pattern_string&gt; [ to:&lt;stream&gt; ]\n\
</pre></div><p>where <span class=\'code\'>&lt;pattern_string&gt;</span> is a string containing a wild-card pattern to match against <strong>3ds Max</strong> class names, superclass names and property names, and the optional <span class=\'code\'>to:&lt;stream&gt;</span> keyword argument specifies a <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/Stream-Values-1.html\' title=\'\'>Stream Value</a> to output the display to.</p>\n\
<p>The pattern string has this form:</p>\n\
<div class=\'codeBlock\'><pre>&quot;&lt;class_name&gt;[:&lt;superclass_name&gt;][.&lt;property_name&gt;]&quot;\n\
</pre></div><p>See <a href=\'Class-and-Object-Inspector.html#pattern-strings\' title=\'\'>Pattern Strings</a> above for more information about special characters allowed in pattern strings.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES</strong></p>\n\
<p>``` showClass &quot;path<em>&quot; -- all 3ds Max classes starting &#39;path&#39; showClass &quot;noise.</em>&quot; -- all the accessible properties on the -- Noise texture map showClass &quot;<em>:mod</em>&quot; -- all the modifier classes showClass &quot;<em>.</em>rad<em>&quot; -- all the classes with a property name -- containing &#39;rad&#39; showClass &quot;</em>.<em>&quot; to:f -- everything, out to a file showClass &quot;</em>:<em>controller</em>&quot; -- all the classes that have -- &quot;controller&quot; in their superclass -- name showClass &quot;[X-Z]*&quot; -- all classes that start with X, Y, or Z</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In the output from the last example, the controllers include <strong>3ds Max</strong>&#39;s core controllers and any 3rd-party plug-in controllers. In some cases, embedded controllers for some complex plug-ins might be visible in the <span class=\'code\'>showClass()</span> listing (such as for Character Studio Bipeds). You must <strong>not</strong> attempt to create and use these controllers individually, this might result in system exceptions.</p>\n\
<p>If you leave out the superclass pattern (the <span class=\'code\'>&#39;:&#39;</span> part), it matches <strong>all</strong> superclasses. If you leave out the property pattern (the <span class=\'code\'>&#39;.&#39;</span> part), you only get class names printed.</p>\n\
<p>Note: This function <strong>only</strong> displays matching MAXWrapper classes (nodes, modifiers, materials, and others), not the foundation classes in MAXScript (float, integer, array, point3, and others).</p>\n\
<p>The following shows examples of the <span class=\'code\'>showClass()</span> output:</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` showclass &quot;box<em>&quot; -- show all classes whose name starts with &quot;box&quot; showclass &quot;box.</em>&quot; -- show all properties for class box</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` Box : GeometryClass {10,0} -- start of output from line 1 BoxGizmo : helper {3bc31904,67d74ec9} OK -- result returned from line 1 Box : GeometryClass {10,0} -- start of output from line 2 .height : float .length : float .lengthsegs : integer .width : float .widthsegs : integer .mapCoords : boolean .heightsegs : integer OK -- result returned from line 2</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"getobjectname\"></a><h2 id=\"getobjectname\">getObjectName</h2></div>\n\
<p>The getObjectName function returns the class name of an object, as it would appear in the history browser or modifier stack. If the passed object is not an object or modifier, this function returns undefined. The function has the following syntax:</p>\n\
<div class=\'codeBlock\'><pre>getObjectName &lt;object&gt; [localizedName:&lt;bool&gt;] \n\
</pre></div><p><img src=\'developer/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Identifying-and-Accessing/What-s-New-in-MAXScript-in-3ds.html\' title=\'\'>NEW</a> <strong>in 3ds Max 2022:</strong> When the <span class=\'code\'>localizedName</span> keyword parameter is <span class=\'code\'>true</span> (the default), the localized name as it appears in the UI is returned. Otherwise the non-localized name is returned.</p>\n\
<p>For example:</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` myBox = Box name:&quot;myBox&quot; myBend = Bend() myCompass = Compass() getObjectName myBox --&gt; &quot;Box&quot; getObjectName myBend --&gt; &quot;Bend&quot; getObjectName myCompass --&gt; &quot;Compass&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"showproperties\"></a><h2 id=\"showproperties\">showProperties</h2></div>\n\
<p>The <span class=\'code\'>showProperties()</span> function is used to display the properties for a specific object that is an instance of one of the MAXWrapper classes. It can be used in place of <span class=\'code\'>showClass()</span> in situations where you have an actual object in hand. Unlike <span class=\'code\'>showClass()</span> , it can display the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Identifying-and-Accessing/Dynamic-Properties.html\' title=\'\'>dynamic properties</a> that might appear in individual objects as you work on them in the scene such as, the sub-controllers in a list controller or the animated control points in an FFD modifier.</p>\n\
<p>The <span class=\'code\'>showProperties()</span> function has the following form:</p>\n\
<div class=\'codeBlock\'><pre>showProperties &lt;maxwrapper_object&gt; [ &lt;property_pattern&gt; ] [ to :&lt;stream&gt; ]\n\
</pre></div><p>where <span class=\'code\'>&lt;maxwrapper_object&gt;</span> is the <strong>3ds Max</strong> entity to be inspected, the optional <span class=\'code\'>&lt;property_pattern&gt;</span> is a wild-card pattern that names the properties to be inspected, and the optional <span class=\'code\'>to:&lt;stream&gt;</span> keyword argument specifies a <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/Stream-Values-1.html\' title=\'\'>Stream Value</a> to output the display to.</p>\n\
<p>The <span class=\'code\'>&lt;property_pattern&gt;</span> is a pattern string. See <a href=\'Class-and-Object-Inspector.html#pattern-strings\' title=\'\'>Pattern Strings</a> above for more information about special characters in pattern strings.</p>\n\
<p>If the property name pattern is not supplied, <strong>all</strong> properties are listed.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` showProperties $foo.bend -- show properties of the Bend modifier on object foo ffdmod = $baz.&#39;FFD_box__4x4x4&#39; -- point to the FFD modifier on object baz showProperties ffdmod &quot;disp<em>&quot; to:log -- show properties starting with &quot;disp&quot; in the FFD modifier showProperties $foo.pos.controller -- sub controllers in a position list controller showProperties $foo &quot;[t-z]</em>&quot; -- show properties starting with t to z on object foo</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note:</p>\n\
<p>When the <strong>3ds Max</strong> entity specified is a node (for example, $box01), this function <strong>only</strong> displays the properties of the base object. It does not show the properties of the transform controllers, modifiers, or materials applied to the object. To display the properties for one of these objects, it must be specified as the <strong>3ds Max</strong> entity as shown in the above examples.</p>\n\
<p><strong>showProperties</strong> includes properties defined by FPS interfaces in <strong>3ds Max 8 and higher</strong>.</p>\n\
<p>The following shows examples of the <strong>showProperties</strong> output:</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` b = box() -- create a box ffd_mod = ffdBox() -- create a ffdBox modifier addmodifier b ffd_mod -- apply ffdBox modifier to the box showproperties b -- show all properties for the box showproperties ffd_mod -- show all properties for the ffdBox modifier</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` $Box:Box07 @ [0.0000,0.0000,0.0000] -- result from line 1 FFD_box__4x4x4:FFD(box) 4x4x4 -- result from line 2 OK -- result from line 3 .height : float -- start of output from line 4 .length : float .lengthsegs : integer .width : float .widthsegs : integer .mapCoords : boolean .heightsegs : integer OK -- result from line 4 .dispLattice (Lattice) : boolean -- start of output from line 5 .dispSource (Source Volume) : boolean .deformType (<unknown>) : integer .falloff : float .tension : float .continuity : float .inPoints (Inside Points) : boolean .outPoints (Outside Points) : boolean .offset : float .lattice_transform : transform OK -- result from line 5<p>\n\
<p>```</p>\n\
</unknown></blockquote>\n\
<p>To make scripting easier to teach and use everyday, a ScriptTool function for &quot;Show&quot; has been added.</p>\n\
<p><strong>Show</strong> is the short way of typing <strong>ShowProperties</strong></p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` Show $ --will show you the properties of the selected object</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"getpropnames\"></a><h2 id=\"getpropnames\">getPropNames</h2></div>\n\
<p>The <span class=\'code\'>getPropNames()</span> function is similar to <span class=\'code\'>showProperties()</span> , except it returns the property names for a specific object as an array. Unlike <span class=\'code\'>showProperties()</span> , you can specify whether to return only the names of <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Identifying-and-Accessing/Dynamic-Properties.html\' title=\'\'>dynamic properties</a> of the object.</p>\n\
<p>The <span class=\'code\'>getPropNames</span> function has the form:</p>\n\
<div class=\'codeBlock\'><pre>getPropNames &lt;maxwrapper_obj&gt; [ #dynamicOnly]\n\
</pre></div><p>The <span class=\'code\'>getPropNames()</span> function returns an array of the property names accessible on the object.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>if a FFD(Box) modifier with animated control points is applied to a sphere,</p>\n\
<p>``` getPropNames $sphere01.&#39;FFD(box) 4x4x4&#39;</p>\n\
<p>```</p>\n\
<p>could yield:</p>\n\
<p>``` #(#dispLattice, #dispSource, #deformType, #falloff, #tension, #continuity, #inPoints, #outPoints, #offset, #Lattice_Transform, #Control_Point_49, #Control_Point_50, #Control_Point_51, #Control_Point_52, #Control_Point_53)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note:</p>\n\
<p>When the <strong>3ds Max</strong> entity specified is a node (for example, $box01), this function <strong>only</strong> returns the properties of the base object. It does not return the properties of the transform controllers, modifiers, or materials applied to the object. To return the properties for one of these objects, it must be specified as the <strong>3ds Max</strong> entity as shown in the above examples.</p>\n\
<p><strong>getPropNames</strong> includes properties defined by FPS interfaces in <strong>3ds Max 8 and higher</strong>.</p>\n\
<p>If you call <span class=\'code\'>getPropNames()</span> on MAXWrapper classes such as, Box, Line, or Bend, it will return the properties common to all instances of that class. If you call <span class=\'code\'>getPropNames()</span> on a <strong>3ds Max</strong> entity, it will return the properties currently defined for that entity. If you add the optional keyword <span class=\'code\'>#dynamicOnly</span> to the <span class=\'code\'>getPropNames()</span> call for an entity, it returns the dynamic properties unique to that instance.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>if a FFD(Box) modifier with animated control points is applied to a sphere,</p>\n\
<p>``` getPropNames $sphere01.&#39;FFD(box) 4x4x4&#39; #dynamicOnly</p>\n\
<p>```</p>\n\
<p>could yield:</p>\n\
<p>``` #(#Lattice_Transform, #Control_Point_49, #Control_Point_50, #Control_Point_51, #Control_Point_52, #Control_Point_53)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note: The property names for the lattice transform and control points which was returned by the previous example is not returned when <span class=\'code\'>#dynamicOnly</span> is specified. These properties are unique to the specific FFD modifier.</p>\n\
<p>As a special case, you can also call <span class=\'code\'>getPropNames()</span> on the superclass &#39;Node&#39; to get the list of properties common to all scene nodes such as, <span class=\'code\'>.position</span> , <span class=\'code\'>.name</span> , or <span class=\'code\'>.wireColor</span> .</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` getPropNames node</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"getpropnames-and-interfaces\"></a><h2 id=\"getpropnames-and-interfaces\">getPropNames and Interfaces</h2></div>\n\
<p>The <span class=\'code\'>getPropNames</span> method has been extended to work with the various interface values. The method will return the names of properties exposed by the interface.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` getpropnames s.inode #(#boneEnable, #posTaskWeight, #rotTaskWeight, #boneAutoAlign, #boneFreezeLength, #boneScaleType, #stretchTM, #boneAxis, #boneAxisFlip, #primaryVisibility, #secondaryVisibility, #applyAtmospherics, #vertexColorType, #showVertexColors, #shadeVertexColors, #handle, #posInParent, #rotInParent, #scaleInParent, #scaleOrientInParent)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"getproperty-and-setproperty\"></a><h2 id=\"getproperty-and-setproperty\">getProperty and setProperty</h2></div>\n\
<p>The <span class=\'code\'>getProperty()</span> and <span class=\'code\'>setProperty()</span> functions allow you to access and set properties using computed property names.</p>\n\
<p>The forms for each of these functions are:</p>\n\
<div class=\'codeBlock\'><pre>getProperty &lt;obj&gt; &lt;property_name&gt; [removeUIScaling:&lt;boolean&gt;]\n\
setProperty &lt;obj&gt; &lt;property_name&gt; &lt;value&gt; [applyUIScalling:&lt;boolean&gt;]\n\
</pre></div><p>The property name can be either a name, for example, <span class=\'code\'>#length</span> , or a string, for example, <span class=\'code\'>&quot;length&quot;</span> . You can construct property names with string operations.</p>\n\
<p>The <span class=\'code\'>removeUIScaling</span>/<span class=\'code\'>applyUIScaling</span> parameters default to true. If false, the value will be affected by the scale factor on High DPI displays, for those properties related to screen values (for example, #pos for UI controls). Available in <strong>in 3ds Max 2017 and higher</strong>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` getProperty foo #x -- equiv. to foo.x setProperty $foo &quot;radius&quot; 23 -- equiv. to $foo.radius = 23 getProperty $foo.ffd_2x2x2 (&quot;control_point_&quot; + n as string)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The <span class=\'code\'>getPropNames()</span> function can be used in conjunction with the <span class=\'code\'>getProperty()</span> function to implement object &#39;dumping’ tools that can iterate over all the properties of an arbitrary object and output them as required.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` for p in getPropNames $foo do format &quot;% = %\\n&quot; p (getProperty $foo p)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Similar functions for accessing and setting the values of property-assigned controllers are:</p>\n\
<div class=\'codeBlock\'><pre>getPropertyController &lt;value&gt; &lt;string_or_name&gt;\n\
setPropertyController &lt;value&gt; &lt;string_or_name&gt; &lt;controller&gt;\n\
</pre></div><p>Get and set the controller assigned to the named property of the value. If no controller has been assigned to the property, a value of undefined is returned.</p>\n\
<div class=\'section\'><a id=\"hasproperty\"></a><h2 id=\"hasproperty\">hasProperty</h2></div>\n\
<p>The <span class=\'code\'>hasProperty()</span> function allows you to test whether an object has a specified property name. Unlike <span class=\'code\'>isProperty(),</span> the property name string supports wildcard patterns.</p>\n\
<div class=\'codeBlock\'><pre>hasProperty &lt;obj&gt; &lt;prop_name_or_pattern_string&gt;\n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the object has the given property or has properties matching the string pattern.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` hasProperty $Box01 &quot;height&quot; --test for height in a Box --&gt; true hasProperty $Box01 &quot;radius&quot; --test for radius in a Box --&gt; false hasProperty $Sphere01 &quot;radius&quot; --test for radius in a Sphere --&gt; true hasProperty $Sphere01 &quot;rad*&quot; --test for any property name --&gt; true --starting with &quot;rad&quot; in a Sphere</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"isproperty\"></a><h2 id=\"isproperty\">isProperty</h2></div>\n\
<p>The <span class=\'code\'>isProperty()</span> function allows you to test whether an object has a specified property.</p>\n\
<div class=\'codeBlock\'><pre>isProperty &lt;MAXWrapper_object&gt; &lt;property_name_or_string&gt;\n\
</pre></div><p><span class=\'code\'>isProperty()</span> returns <span class=\'code\'>true</span> if the specified property is a property of the MAXWrapper object, <span class=\'code\'>false</span> otherwise. The property name can be either a name, for example, <span class=\'code\'>#length</span> , or a string, for example, <span class=\'code\'>&quot;length&quot;</span> . You can construct property names with string operations.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` b=box() s=sphere() isProperty $Box001 #height --test for height in a Box --&gt; true isProperty $Box001 #radius --test for radius in a Box --&gt; false isProperty $Sphere001 #radius --test for radius in a Sphere --&gt; true</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"the-difference-between-hasproperty-and-isproperty\"></a><h2 id=\"the-difference-between-hasproperty-and-isproperty\">The difference between hasProperty and isProperty</h2></div>\n\
<p><strong>hasProperty</strong> and <strong>isProperty</strong> do entirely different things.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` hasProperty $Box01 &quot;name&quot; --&gt; false isProperty $Box01 &quot;name&quot; --&gt; true</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>hasProperty</strong> uses the same code as <span class=\'code\'>showPropeties()</span> , but instead of returning a list of the properties found, it returns true on the first property name that matches the specified pattern. <strong>showProperties</strong> is looking at just the box base object and its MAXClass definition. It does not look at any higher level properties (and in versions prior to <strong>3ds Max 8</strong> it does not look at any of the FPS interface exposed properties).</p>\n\
<p><strong>isProperty</strong> on the other hand actually tries to access the specified object with the specified name and to detect whether the access succeeded or failed.</p>\n\
<div class=\'section\'><a id=\"ispropertyanimatable\"></a><h2 id=\"ispropertyanimatable\">isPropertyAnimatable</h2></div>\n\
<div class=\'codeBlock\'><pre>isPropertyAnimatable &lt;obj&gt; &lt;string_or_name&gt;\n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the property is found and is animatable. Returns <span class=\'code\'>false</span> if the property is not found or is not animatable.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` s = Sphere() --create a sphere --&gt; $Sphere:Sphere01 @ [0.000000,0.000000,0.000000] isPropertyAnimatable s #radius --check if radius is animatable --&gt; true isPropertyAnimatable s #mapCoords --check if UV coords are --&gt; false</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>ANOTHER EXAMPLE:</strong></p>\n\
<p>``` s = Sphere() --create a sphere --Print a list of all properties of the sphere and whether --they are animatable or not: for i in getPropNames s do format &quot;% Property: % - Animatable: %\\n&quot;s.name i (isPropertyAnimatable s i)</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` $Sphere:Sphere003 @ [0.000000,0.000000,0.000000] Sphere003 Property: #smooth - Animatable: true Sphere003 Property: #radius - Animatable: true Sphere003 Property: #segs - Animatable: true Sphere003 Property: #mapcoords - Animatable: false Sphere003 Property: #slice - Animatable: false Sphere003 Property: #hemisphere - Animatable: true Sphere003 Property: #sliceFrom - Animatable: true Sphere003 Property: #sliceTo - Animatable: true Sphere003 Property: #chop - Animatable: false Sphere003 Property: #recenter - Animatable: false Sphere003 Property: #realWorldMapSize - Animatable: false OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"subanims-and-paramblocks\"></a><h2 id=\"subanims-and-paramblocks\">SubAnims and ParamBlocks</h2></div>\n\
<p><strong>3ds Max</strong> stores all of properties for objects in structures called <em>subAnims</em>. In some cases, a subAnim will contain nested subAnims. An example of this can be seen with the Standard material. If you apply a Standard material to a <strong>3ds Max</strong> object, and then expand the object&#39;s tracks in Track View to display the material, you will see three Track View nodes - Parameters, Maps, and Shader. Each of these nodes is a subAnim defined in the Standard material’s class. Expanding the tracks for these three nodes, you will see various properties listed. These properties are defined in each of the nested subAnims in a structure called a <em>ParamBlock</em>.</p>\n\
<p>MAXScript automatically finds animatable properties in all ParamBlocks associated with an object. To access these properties, you use the same nesting as shown in Track View when referencing those properties in MAXScript.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>you would access the Ambient Color property in a Standard material in MAXScript as:</p>\n\
<p>``` $box01.material.shader.diffuse_color</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>For more information about accessing animatable properties in MAXScript, see also <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Identifying-and-Accessing/Indexed-Access-to-Animatable.html\' title=\'\'>Indexed Access to Animatable Properties in 3ds Max Objects</a>.</p>\n\
<p>The properties accessible on various kinds of values are documented for each class. Many of the foundation classes in MAXScript (such as, point3, color, and so on) support a special kind of <strong>nested-property assignment</strong> which allows sub-properties on object properties such as, the <span class=\'code\'>.x</span> , <span class=\'code\'>.y</span> , and <span class=\'code\'>.z</span> coordinates in a node&#39;s <span class=\'code\'>.position</span> property to be individually and directly set. See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXWrapper-Value/Nested-Object-Properties.html\' title=\'\'>Nested Object Properties</a> for details.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";