var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Indexed Access to Animatable Properties in 3ds Max Objects</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Indexed Access to Animatable Properties in 3ds Max Objects</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"indexed-access-to-animatable-properties-in-3ds-max-objects\"></a></div>\n\
<p>As an alternative to using named property accesses, you can access in an object any animatable property that is visible as a track in Track View by indexing the <strong>3ds Max</strong> object value as though it were an array.</p>\n\
<p>This simplifies such tasks as iterating over all the animatable properties in an object and accessing sub-controllers that don&#39;t have unique names, such as within list controllers.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;maxwrapper_object&gt;.numSubs : Integer, read-only     \n\
</pre></div><p>Yields the number of accessible sub-animatables, or tracks, in an object. This is the number of immediate <strong>children subAnims</strong>, and may include as yet invisible tracks in the track view, such as visibility tracks on a node or yet-to-be animated vertices in an FFD. This property operates on any MAXWrapper subclass.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>getSubAnimName &lt;maxwrapper_object&gt; &lt;index&gt; [asString:&lt;bool&gt;] [localizedName:&lt;bool&gt;] \n\
</pre></div><p>Returns the name of the indexed subAnimin the supplied MAXWrapper.</p>\n\
<p>If the optional <span class=\'code\'>asString</span> keyword is supplied and set to <span class=\'code\'>true</span> , the name is returned as a string. If <span class=\'code\'>false</span> or not specified, a Name Value is returned.</p>\n\
<p><img src=\'developer/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Identifying-and-Accessing/What-s-New-in-MAXScript-in-3ds.html\' title=\'\'>NEW</a> <strong>in 3ds Max 2022:</strong> When the <span class=\'code\'>localizedName</span> keyword parameter is <span class=\'code\'>true</span> (the default), the name as it appears in the UI is returned. Otherwise the non-localized name is returned.</p>\n\
<div class=\'codeBlock\'><pre>getSubAnimNames &lt;maxwrapper_object&gt; [localizedNames:&lt;bool&gt;] \n\
</pre></div><p>Returns an array of names in subAnim index order.</p>\n\
<p><img src=\'developer/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Identifying-and-Accessing/What-s-New-in-MAXScript-in-3ds.html\' title=\'\'>NEW</a> <strong>in 3ds Max 2022:</strong> When the <span class=\'code\'>localizedNames</span> keyword parameter is <span class=\'code\'>true</span> (the default), the names as they appear in the UI is returned. Otherwise the non-localized names are returned.</p>\n\
<div class=\'codeBlock\'><pre>getSubAnim &lt;maxwrapper_object&gt; &lt;index&gt; \n\
</pre></div><p>Returns the indexed subAnim. See the index operator below.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;maxwrapper_object&gt;[&lt;index_number&gt;|&lt;subanim_name&gt;] \n\
</pre></div><p>Returns the subAnim with the specified index or name. You can apply the index operator, <span class=\'code\'>[&lt;index_number&gt;]</span> , to any MAXWrapper object (nodes, modifiers, controllers, materials, etc.) to access a numbered subAnim.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` for i in 1 to $foo.numSubs do print $foo[i] -- iterate them $bar.position.controller[3] -- third subAnim in a position list controller ffd_mod[i].value -- position of i&#39;th FFD control point</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note:</p>\n\
<p>You cannot set subAnims with the index operator, this is a read-only access.</p>\n\
<p>In place of an index, you can also use a subanim name. It can be any expression that yields a string or name value. So, whereas in releases prior <strong>3ds Max 4</strong>, getting at the position subAnim in a node require you to remember index 3 for the transform subanim and 1 for its position subanim, in other words</p>\n\
<blockquote>\n\
<p>``` $foo[3][1] -- position within transform within node</p>\n\
<p>```</p>\n\
<p>you can use instead:</p>\n\
<p><span class=\'code\'>$foo[#transform][#position]</span></p>\n\
</blockquote>\n\
<p>The names you can use are those seen in the track view or retrieved with the functions <span class=\'code\'>getSubAnimName()</span> or <span class=\'code\'>getSubAnimNames().</span></p>\n\
<div class=\'section\'><a id=\"subanim-class\"></a><h2 id=\"subanim-class\">SubAnim Class</h2></div>\n\
<p>MAXScript defines a <span class=\'code\'>SubAnim</span> class, instances of which provide a general representation for sub-animatables. Whenever you use the index operator on a <strong>3ds Max</strong> object, it returns a SubAnim instance.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` $box01[3] -&gt; SubAnim:Transform</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The third subAnim in a node is typically the transform track.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;subAnim&gt;.name : String, read-only \n\
</pre></div><p>Returns the name of the track subAnim as shown in TrackView.</p>\n\
<div class=\'codeBlock\'><pre>&lt;subAnim&gt;.parent : Node, read-only \n\
</pre></div><p>Returns the true owner of the subAnim.</p>\n\
<p>Note:</p>\n\
<p>The true object owning the subAnim can be different than what was originally specified when creating the subAnim, and MAXScript automatically hides certain types of subAnims, automatically promoting the subAnims within them.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` s=sphere() sa = s.baseobject[1] --&gt; SubAnim:Radius sa.parent --&gt; ReferenceTarget:ParamBlock sa.index --&gt; 1 --The actual owner of the Radius subAnim is the sphere&#39;s parameter block.</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;subAnim&gt;.index : Integer, read-only \n\
</pre></div><p>Returns the index of the subAnim.</p>\n\
<div class=\'codeBlock\'><pre>&lt;subAnim&gt;.value : Value \n\
</pre></div><p>The current value of the track subAnim, equivalent to <span class=\'code\'>&lt;controller&gt;.value</span> . Returns <span class=\'code\'>undefined</span> if no appropriate value exists or the track has not yet been assigned a controller. The <span class=\'code\'>.value</span> property yields the value at the current MAXScript time. You can assign to this value to set the track&#39;s value at that time.</p>\n\
<div class=\'codeBlock\'><pre>&lt;subAnim&gt;.controller : Controller \n\
</pre></div><p>The controller for the track SubAnim. Returns <span class=\'code\'>undefined</span> if a controller has not yet been assigned or if the SubAnim is not animatable. You can assign a new controller to a track by assigning to the <span class=\'code\'>.controller</span> property of its subAnim.</p>\n\
<div class=\'codeBlock\'><pre>&lt;subAnim&gt;.keys : KeyArray, read-only \n\
</pre></div><p>Yields the key array for that track or <span class=\'code\'>undefined</span> if not keyable or a controller has not yet been assigned. This property is read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;subAnim&gt;.isAnimated : Boolean, read-only \n\
</pre></div><p>Yields <span class=\'code\'>true</span> if there is an animated controller present. This property is read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;subAnim&gt;.object : MAXWrapper, read-only \n\
</pre></div><p>Yields the subAnim object, or <span class=\'code\'>undefined</span> if not assigned. This property is read-only. The <span class=\'code\'>.object</span> property may return any kind of MAXWrapper object, depending on what the parent object decides to put there. For example, <span class=\'code\'>&lt;node&gt;[1].object</span> is the visibility controller or <span class=\'code\'>undefined</span> if not yet assigned, <span class=\'code\'>&lt;node&gt;[2].object</span> contains the bindings of any space warps bound to the node, or <span class=\'code\'>undefined</span> if none have been bound, <span class=\'code\'>&lt;node&gt;[3].object</span> is the transform controller, <span class=\'code\'>&lt;node&gt;[4].object</span> is the node&#39;s object, either the modified object if there are modifiers present or the base object if not, <span class=\'code\'>&lt;node&gt;[5].object</span> is the material assigned to the node or <span class=\'code\'>undefined</span> if no material has been assigned, and <span class=\'code\'>&lt;node&gt;[6].object</span> is the Image Motion Blur Multiplier controller or <span class=\'code\'>undefined</span> if not yet assigned.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` b = box() b[4].object -- returns a reference to the Box base object</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;subAnim&gt;.numSubs : Integer, read-only \n\
</pre></div><p>The number of immediate subAnim children.</p>\n\
<p>If you attempt to access subAnim properties, such as <span class=\'code\'>.value</span> , <span class=\'code\'>.numSubs</span> , <span class=\'code\'>.category</span> , etc., on certain subAnims that had yet to be assigned controllers, such as scene node visibility tracks, these properties return null values such as 0, or <span class=\'code\'>undefined</span> , as appropriate.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>getSubAnim &lt;subAnim&gt; &lt;index&gt; \n\
</pre></div><p>Returns the indexed subAnim. See the index operator below.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;subAnim&gt;[&lt;index_number&gt;] \n\
</pre></div><p>Returns the indexed subAnim. You can work down through nested subAnims (nested tracks) by indexing into subAnims themselves.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` $box01[3][2]</p>\n\
<p>```</p>\n\
<p>yields the rotation track subAnim since <node>[3] is always the transform track and the second track in it is always the rotation track. Indexing a SubAnim always yields another SubAnim. For those familiar with SubAnims in the <strong>3ds Max</strong> SDK, it should be noted that MAXScript SubAnims descend automatically through &#39;hidden&#39; subAnim levels, reflecting the structure seen in Track View.<p>\n\
</node></blockquote>\n\
<p>Note:</p>\n\
<p>You can get at the base object&#39;s Track View parameters by indexing into the base object:</p>\n\
<div class=\'codeBlock\'><pre>b=box()\n\
getSubAnimNames b[4] -- returns #(#length, #width, #height, ...)\n\
b[4][2].value -- returns current width value\n\
i = 3\n\
b[4][i].controller = float_list() -- assign height controller\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";