var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>getClassInstances</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>getClassInstances</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"getclassinstances\"></a></div>\n\
<p>The <strong>getClassInstances</strong> function available in <strong>3ds Max 7 and higher</strong> returns an array of all instances of a specified class that exist in a scene.</p>\n\
<p>It was previously available through the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard</a> DLX 3rd party MAXScript extension.</p>\n\
<p>Until <strong>3ds Max 2011</strong>, the function was looking for the class instances by enumerating the animatable tree. There are many cases where the subAnims of an object are a subset of the references held by an object, so instances present in the scene were being missed.</p>\n\
<p>Starting with <strong>3ds Max 2011</strong>, <span class=\'code\'>getClassInstances()</span> can search for class instances in a variety of ways depending on its arguments, including the two new ones: <span class=\'code\'>processAllAnimatables:</span> and <span class=\'code\'>processChildren:</span> .</p>\n\
<p>The syntax is:</p>\n\
<div class=\'codeBlock\'><pre>getClassInstances &lt;MAXClass&gt; processAllAnimatables:&lt;boolean&gt; target:&lt;MAXObject&gt; asTrackViewPick:&lt;boolean&gt; processChildren:&lt;boolean&gt;\n\
</pre></div><p><span class=\'code\'>&lt;MAXClass&gt;</span> specifies the class whose instances are being searched for.</p>\n\
<div class=\'section\'><a id=\"processallanimatables\"></a><h3 id=\"processallanimatables\">processAllAnimatables:</h3></div>\n\
<p>If <span class=\'code\'>processAllAnimatables:true</span> is specified in <strong>3ds Max 2011 or higher</strong>, all existing objects, even those not present in the scene, are tested to see if they are instances of the specified class. These objects include, for example, objects held only by MAXscript values.</p>\n\
<p>When <span class=\'code\'>processAllAnimatables:true</span> is specified, no other keyword parameters are applicable and are ignored.</p>\n\
<p>The default value for this parameter is <span class=\'code\'>false</span> .</p>\n\
<div class=\'section\'><a id=\"target\"></a><h3 id=\"target\">target:</h3></div>\n\
<p>If <span class=\'code\'>target</span> : is specified, only the hierarchy for that target is searched.</p>\n\
<p>If <span class=\'code\'>target</span> : is not specified, the entire scene under the scene root is searched. The scene in this case refers not only to the node hierarchy, but also the Material Editor, Track View, and others.</p>\n\
<div class=\'section\'><a id=\"astrackviewpick\"></a><h3 id=\"astrackviewpick\">asTrackViewPick:</h3></div>\n\
<p>If <span class=\'code\'>asTrackViewPick:true</span> is specified, each use of a class instance is returned as a <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Track-View/GUID-B3D86BDD-E947-43F3-B57B-168A1420E3FA.html#trackviewpick---value\' title=\'\'>TrackViewPick value</a>.</p>\n\
<p>If asTrackViewPick:true is specified, the hierarchy that is searched is the Animatable tree under the target. There are lots of cases where the subAnims of an object are a subset of the references held by an object, so class instances present in the scene might be missed. The Animatable tree is the tree shown in TrackView.</p>\n\
<p>If <span class=\'code\'>asTrackViewPick:false</span> is specified or not supplied, each class instance is returned, and the hierarchy that is searched is the Reference tree under the target.</p>\n\
<p>The default value for this parameter is <span class=\'code\'>false</span> .</p>\n\
<div class=\'section\'><a id=\"processchildren\"></a><h3 id=\"processchildren\">processChildren:</h3></div>\n\
<p>If <span class=\'code\'>processChildren:true</span> is specified in <strong>3ds Max 2011 or higher</strong>, children scene nodes are also searched as part of the Animatable or Reference hierarchy.</p>\n\
<p>The default value for this parameter is <span class=\'code\'>false</span> unless no target is specified, the scene root node (rootNode) is specified, or the scene root (rootScene) is specified, in which case the default is <span class=\'code\'>true</span> .</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` --Create two spheres, and an instance of one of the spheres: resetMaxFile #noPrompt s1 = sphere() s2 = sphere pos:[100,0,0] s3 = instance s1 s3.pos = [-100,0,0]</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` OK $Sphere:Sphere01 @ [0.000000,0.000000,0.000000] $Sphere:Sphere02 @ [100.000000,0.000000,0.000000] $Sphere:Sphere03 @ [0.000000,0.000000,0.000000] [-100,0,0]</p>\n\
<p>```</p>\n\
<p><strong>EXECUTE:</strong></p>\n\
<p>``` tvps=getClassInstances sphere asTrackViewPick:true for tvp in tvps do ( print tvp.anim print tvp.client print tvp.subNum print tvp.name print tvp.client[tvp.subNum] )</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` #(TrackViewPick:&quot;Object (Sphere)&quot;, TrackViewPick:&quot;Object (Sphere)&quot;, TrackViewPick:&quot;Object (Sphere)&quot;) Sphere $Sphere:Sphere001 @ [0.000000,0.000000,0.000000] 4 &quot;Object (Sphere)&quot; SubAnim:Object__Sphere Sphere $Sphere:Sphere002 @ [100.000000,0.000000,0.000000] 4 &quot;Object (Sphere)&quot; SubAnim:Object__Sphere Sphere $Sphere:Sphere003 @ [-100.000000,0.000000,0.000000] 4 &quot;Object (Sphere)&quot; SubAnim:Object__Sphere OK</p>\n\
<p>```</p>\n\
<p><strong>NOW EXECUTE:</strong></p>\n\
<p>``` objs=getClassInstances sphere for obj in objs do print (refs.dependents obj) #nomap</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` #(Sphere, Sphere) #($Sphere:Sphere003 @ [-100.000000,0.000000,0.000000], \\(Sphere:Sphere001 @ [0.000000,0.000000,0.000000], ReferenceTarget:NodeRefMgr)  #(\\)Sphere:Sphere002 @ [100.000000,0.000000,0.000000]) OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>CONCLUSION:</strong></p>\n\
<p>As one of the spheres is instanced, three TrackViewPick values are returned, but only two class instances are returned.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>EXPLORING ARGUMENT COMBINATIONS:</strong></p>\n\
<p>``` t1 = bitmaptex filename:&quot;t1.bmp&quot; name:#Sphere_DiffuseMap t2 = bitmaptex filename:&quot;t2.bmp&quot; name:#Teapot_DiffuseMap t3 = bitmaptex filename:&quot;t3.bmp&quot; name:#Displace t4 = bitmaptex filename:&quot;t4.bmp&quot; name:#VolSelect t5 = bitmaptex filename:&quot;t5.bmp&quot; name:#HairDens t6 = bitmaptex filename:&quot;t6.bmp&quot; name:#NoWhere t7 = bitmaptex filename:&quot;t7.bmp&quot; name:#MEdit t8 = bitmaptex filename:&quot;t8.bmp&quot; name:#NodeCustAttrib t9 = bitmaptex filename:&quot;t9.bmp&quot; name:#ObjCustAttrib s = sphere material:(standard showInViewport:true) t = teapot material:(standard showInViewport:true) pos:[0,50,0] parent:s s.material.diffusemap = t1 s.material.specularmap = t1 t.material.diffusemap = mix mask:t2 addModifier s (displace map:t3 strength:10) addModifier t (volumeSelect texture:t4) addModifier s (HairMod()) s.modifiers[1].maps[1] = t5 s.modifiers[1].mapEnables[1] = true meditmaterials[1] = t7 g=geosphere() testCADef = attributes testCA ( parameters main ( map type:#texturemap ) ) CustAttributes.add g testCADef BaseObject:false CustAttributes.add g testCADef BaseObject:true g.testCA.map = t8 g.baseobject.testCA.map = t9</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` Sphere_DiffuseMap:Bitmap Teapot_DiffuseMap:Bitmap Displace:Bitmap VolSelect:Bitmap HairDens:Bitmap NoWhere:Bitmap medit:Bitmap NodeCustAttrib:Bitmap ObjCustAttrib:Bitmap $Sphere:Sphere001 @ [0.000000,0.000000,0.000000] $Teapot:Teapot001 @ [0.000000,50.000000,0.000000] Sphere_DiffuseMap:Bitmap Sphere_DiffuseMap:Bitmap Mix:Mix OK OK OK HairDens:Bitmap true medit:Bitmap $GeoSphere:GeoSphere001 @ [0.000000,0.000000,0.000000] <attributedef:testca> true true NodeCustAttrib:Bitmap ObjCustAttrib:Bitmap<p>\n\
<p>```</p>\n\
<p><strong>TEST 1:</strong></p>\n\
<p>``` for b in getClassInstances bitmaptex do format &quot;Name : %, Texture name : %, Affected Nodes : %\\n&quot; b.name b.filename (refs.dependentNodes b)</p>\n\
<p>```</p>\n\
<p><strong>TEST 1 OUTPUT</strong></p>\n\
<p>``` Name : medit, Texture --&gt; Name : t7.bmp , Affected Nodes : #() Name : Sphere_DiffuseMap, Texture --&gt; Name : t1.bmp, Affected Nodes : #(\\(Object:Sphere001 @ [0.000000,0.000000,0.000000])  Name : Teapot_DiffuseMap, Texture --&gt; Name : t2.bmp, Affected Nodes : #(\\)Editable_Mesh:Teapot001 @ [0.000000,50.000000,0.000000]) Name : VolSelect, Texture --&gt; Name : t4.bmp, Affected Nodes : #(\\(Editable_Mesh:Teapot001 @ [0.000000,50.000000,0.000000])  Name : Displace , Texture --&gt; Name : t3.bmp, Affected Nodes : #(\\)Object:Sphere001 @ [0.000000,0.000000,0.000000]) Name : HairDens, Texture --&gt; Name : t5.bmp, Affected Nodes : #(\\(Object:Sphere001 @ [0.000000,0.000000,0.000000])  Name : ObjCustAttrib, Texture name : t9.bmp, Affected Nodes : #()  Name : NodeCustAttrib, Texture name : t8.bmp, Affected Nodes : #(\\)GeoSphere:GeoSphere001 @ [0.000000,0.000000,0.000000])</p>\n\
<p>```</p>\n\
<p><strong>TEST 2</strong></p>\n\
<p>``` for b in getClassInstances bitmaptex target:rootnode do format &quot;Name : %, Texture name : %, Affected Nodes : %\\n&quot; b.name b.filename (refs.dependentNodes b)</p>\n\
<p>```</p>\n\
<p><strong>TEST 2 OUTPUT</strong></p>\n\
<p>``` Name : VolSelect, Texture --&gt; Name : t4.bmp, Affected Nodes : #(\\(Editable_Mesh:Teapot001 @ [0.000000,50.000000,0.000000])  Name : Teapot_DiffuseMap, Texture --&gt; Name : t2.bmp, Affected Nodes : #(\\)Editable_Mesh:Teapot001 @ [0.000000,50.000000,0.000000]) Name : Displace, Texture --&gt; Name : t3.bmp, Affected Nodes : #(\\(Object:Sphere001 @ [0.000000,0.000000,0.000000])  Name : HairDens, Texture --&gt; Name : t5.bmp, Affected Nodes : #(\\)Object:Sphere001 @ [0.000000,0.000000,0.000000]) Name : Sphere_DiffuseMap, Texture --&gt; Name : t1.bmp, Affected Nodes : #(\\(Object:Sphere001 @ [0.000000,0.000000,0.000000])  Name : ObjCustAttrib, Texture name : t9.bmp, Affected Nodes : #()  Name : NodeCustAttrib, Texture name : t8.bmp, Affected Nodes : #(\\)GeoSphere:GeoSphere001 @ [0.000000,0.000000,0.000000])</p>\n\
<p>```</p>\n\
<p><strong>TEST 3</strong></p>\n\
<p>``` for b in getClassInstances bitmaptex target:s do format &quot;Name : %, Texture name : %, Affected Nodes : %\\n&quot; b.name b.filename (refs.dependentNodes b)</p>\n\
<p>```</p>\n\
<p><strong>TEST 3 OUTPUT</strong></p>\n\
<p>``` Name : Displace, Texture --&gt; Name : t3.bmp, Affected Nodes : #(\\(Object:Sphere001 @ [0.000000,0.000000,0.000000])  Name : HairDens, Texture --&gt; Name : t5.bmp, Affected Nodes : #(\\)Object:Sphere001 @ [0.000000,0.000000,0.000000]) Name : Sphere_DiffuseMap, Texture --&gt; Name : t1.bmp, Affected Nodes : #($Object:Sphere001 @ [0.000000,0.000000,0.000000])</p>\n\
<p>```</p>\n\
<p><strong>TEST 4</strong></p>\n\
<p>``` for b in getClassInstances bitmaptex target:s processChildren:true do format &quot;Name : %, Texture name : %, Affected Nodes : %\\n&quot; b.name b.filename (refs.dependentNodes b)</p>\n\
<p>```</p>\n\
<p><strong>TEST 4 OUTPUT</strong></p>\n\
<p>``` Name : VolSelect, Texture --&gt; Name : t4.bmp, Affected Nodes : #(\\(Editable_Mesh:Teapot001 @ [0.000000,50.000000,0.000000])  Name : Teapot_DiffuseMap, Texture --&gt; Name : t2.bmp, Affected Nodes : #(\\)Editable_Mesh:Teapot001 @ [0.000000,50.000000,0.000000]) Name : Displace, Texture --&gt; Name : t3.bmp, Affected Nodes : #(\\(Object:Sphere001 @ [0.000000,0.000000,0.000000])  Name : HairDens, Texture --&gt; Name : t5.bmp, Affected Nodes : #(\\)Object:Sphere001 @ [0.000000,0.000000,0.000000]) Name : Sphere_DiffuseMap, Texture --&gt; Name : t1.bmp, Affected Nodes : #($Object:Sphere001 @ [0.000000,0.000000,0.000000])</p>\n\
<p>```</p>\n\
<p><strong>TEST 5</strong></p>\n\
<p>``` for b in getClassInstances bitmaptex target:g do format &quot;Name : %, Texture name : %, Affected Nodes : %\\n&quot; b.name b.filename (refs.dependentNodes b)</p>\n\
<p>```</p>\n\
<p><strong>TEST 5 OUTPUT</strong></p>\n\
<p>``` Name : ObjCustAttrib, Texture name : t9.bmp, Affected Nodes : #() Name : NodeCustAttrib, Texture name : t8.bmp, Affected Nodes : #($GeoSphere:GeoSphere001 @ [0.000000,0.000000,0.000000])</p>\n\
<p>```</p>\n\
<p><strong>TEST 6</strong></p>\n\
<p>``` for b in getClassInstances bitmaptex processAllAnimatables:true do format &quot;Name : %, Texture name : %, Affected Nodes : %\\n&quot; b.name b.filename (refs.dependentNodes b)</p>\n\
<p>```</p>\n\
<p><strong>TEST 6 OUTPUT</strong></p>\n\
<p>``` Name : Sphere_DiffuseMap, Texture --&gt; Name : t1.bmp, Affected Nodes : #(\\(Object:Sphere001 @ [0.000000,0.000000,0.000000])  Name : Teapot_DiffuseMap, Texture --&gt; Name : t2.bmp, Affected Nodes : #(\\)Editable_Mesh:Teapot001 @ [0.000000,50.000000,0.000000]) Name : Displace, Texture --&gt; Name : t3.bmp, Affected Nodes : #(\\(Object:Sphere001 @ [0.000000,0.000000,0.000000])  Name : VolSelect, Texture --&gt; Name : t4.bmp, Affected Nodes : #(\\)Editable_Mesh:Teapot001 @ [0.000000,50.000000,0.000000]) Name : HairDens, Texture --&gt; Name : t5.bmp, Affected Nodes : #(\\(Object:Sphere001 @ [0.000000,0.000000,0.000000])  Name : NoWhere, Texture --&gt; Name : t6.bmp, Affected Nodes : #()  Name : medit, Texture --&gt; Name : t7.bmp, Affected Nodes : #()  Name : ObjCustAttrib, Texture name : t9.bmp, Affected Nodes : #()  Name : NodeCustAttrib, Texture name : t8.bmp, Affected Nodes : #(\\)GeoSphere:GeoSphere001 @ [0.000000,0.000000,0.000000])</p>\n\
<p>```</p>\n\
<p><strong>TEST 7</strong></p>\n\
<p>``` for b in getClassInstances bitmaptex asTrackViewPick:true do format &quot;Name : %, Texture name : %, Client: %, subAnim: %, Affected Nodes : %&quot; b.anim.name b.anim.filename b.client b.subnum (refs.dependentNodes b.anim)</p>\n\
<p>```</p>\n\
<p><strong>TEST 7 OUTPUT</strong></p>\n\
<p>``` Name : Sphere_DiffuseMap, Texture name : t1.bmp, Client: ReferenceTarget:ReferenceTarget, subAnim: 4 , Affected Nodes : #(\\(Object:Sphere001 @ [0.000000,0.000000,0.000000])  Name : Sphere_DiffuseMap, Texture name : t1.bmp, Client: ReferenceTarget:ReferenceTarget, subAnim: 6 , Affected Nodes : #(\\)Object:Sphere001 @ [0.000000,0.000000,0.000000]) Name : Teapot_DiffuseMap, Texture name : t2.bmp, Client: Mix:Mix, subAnim: 4, Affected Nodes : #(\\(Editable_Mesh:Teapot001 @ [0.000000,50.000000,0.000000])  Name : medit, Texture name : t7.bmp, Client: #meditMaterials(), subAnim: 1, Affected Nodes : #()  Name : Displace, Texture name : t3.bmp, Client: Displace:Displace, subAnim: 3, Affected Nodes : #(\\)Object:Sphere001 @ [0.000000,0.000000,0.000000])</p>\n\
<p>```</p>\n\
<p><strong>TEST 8</strong></p>\n\
<p>``` for b in getClassInstances bitmaptex target:s asTrackViewPick:true do format &quot;Name : %, Texture name : %, Client: %, subAnim: %, Affected Nodes : %\\n&quot; b.anim.name b.anim.filename b.client b.subnum (refs.dependentNodes b.anim)</p>\n\
<p>```</p>\n\
<p><strong>TEST 8 OUTPUT</strong></p>\n\
<p>``` Name : Displace, Texture name : t3.bmp, Client: Displace:Displace, subAnim: 3 , Affected Nodes : #(\\(Object:Sphere001 @ [0.000000,0.000000,0.000000])  Name : Sphere_DiffuseMap, Texture name : t1.bmp, Client: ReferenceTarget:ReferenceTarget, subAnim: 4 , Affected Nodes : #(\\)Object:Sphere001 @ [0.000000,0.000000,0.000000]) Name : Sphere_DiffuseMap, Texture name : t1.bmp, Client: ReferenceTarget:ReferenceTarget, subAnim: 6 , Affected Nodes : #($Object:Sphere001 @ [0.000000,0.000000,0.000000])</p>\n\
<p>```</p>\n\
<p><strong>TEST 9</strong></p>\n\
<p>``` for b in getClassInstances bitmaptex target:s processChildren:true asTrackViewPick:true do format &quot;Name : %, Texture name : %, Client: %, subAnim: %, Affected Nodes : %\\n&quot; b.anim.name b.anim.filename b.client b.subnum (refs.dependentNodes b.anim)</p>\n\
<p>```</p>\n\
<p><strong>TEST 9 OUTPUT</strong></p>\n\
<p>``` Name : Displace, Texture name : t3.bmp, Client: Displace:Displace, subAnim: 3, Affected Nodes : #(\\(Object:Sphere001 @ [0.000000,0.000000,0.000000])  Name : Sphere_DiffuseMap, Texture name : t1.bmp, Client: ReferenceTarget:ReferenceTarget, subAnim: 4, Affected Nodes : #(\\)Object:Sphere001 @ [0.000000,0.000000,0.000000]) Name : Sphere_DiffuseMap, Texture name : t1.bmp, Client: ReferenceTarget:ReferenceTarget, subAnim: 6, Affected Nodes : #(\\(Object:Sphere001 @ [0.000000,0.000000,0.000000])  Name : Teapot_DiffuseMap, Texture name : t2.bmp, Client: Mix:Mix, subAnim: 4, Affected Nodes : #(\\)Editable_Mesh:Teapot001 @ [0.000000,50.000000,0.000000])</p>\n\
<p>```</p>\n\
</attributedef:testca></blockquote>\n\
<div class=\'section\'><a id=\"getclasscounts\"></a><h2 id=\"getclasscounts\">getClassCounts()</h2></div>\n\
<p>The <span class=\'code\'>getClassCounts()</span> function, available in <strong>3ds Max 2018 and higher</strong>, returns array of DataPair instances, where v1 is a maxclass and v2 is the number of instances of the corresponding class that exist in the scene. The syntax is:</p>\n\
<div class=\'codeBlock\'><pre>&lt;array of datapair(maxclass,count)&gt;getClassCounts()\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";