var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: AssetManager</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: AssetManager</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-assetmanager\"></a></div>\n\
<p>The <strong>AssetManagerCore Interface</strong> introduced in <strong>3ds Max 2010</strong> manages the saving of Asset data into the <strong>3ds Max</strong> scene file.</p>\n\
<p>In releases prior to <strong>3ds Max 2010</strong>, a plug-in that referenced an external file (an asset) holds the asset’s filename as a string or as a Path object, and stores the filename to the <strong>3ds Max</strong> scene file as a string or an IParameterBlock2 TYPE_FILENAME parameter. To allow <strong>3ds Max</strong> to identify the assets used by a plug-in, the plug-in implements an IAssetAccessor-derived class. The information provided from this class was primarily used by the Asset Tracker.</p>\n\
<p>Since <strong>3ds Max 2010</strong>, assets are handled as instances of class <strong>AssetUser</strong> . An instance of this class contains information on the asset filename, its type, and the <strong>3ds Max</strong> scene file that depends on it (this is used for resolving external references). Access to, and lifetime management of assets is handled by the <strong>Asset Manager</strong>.</p>\n\
<p>Loading and saving the Asset to the <strong>3ds Max</strong> scene file is now done through the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/Asset-Management/IObject-AssetUser.html\' title=\'\'>AssetUser</a> and the <strong>AssetManager</strong>.</p>\n\
<p>When saving a <strong>3ds Max</strong> scene, the asset data is saved by the Asset Manager to a <strong>separate stream</strong> in the <strong>3ds Max</strong> file. This gives the capability to external programs to access the asset data to identify the assets used by the scene and potentially modify the asset data without loading the scene file into <strong>3ds Max</strong>.</p>\n\
<p>The following methods expose the information handled by the AssetManager to MAXScript:</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'section\'><a id=\"get-asset\"></a><h2 id=\"get-asset\">Get Asset</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;IObject&gt;AssetManager.GetAsset &lt;filename&gt;fileName &lt;enum&gt;assetType autoAcquire:&lt;boolean&gt;         \n\
\n\
assetType enums: {#Other | #Bitmap | #XRef | #Photometric | #Animation | #VideoPost | #BatchRender | #ExternalLink | #RenderOutput | #PreRenderScript | #PostRenderScript | #Sound | #Container | #MaxCreationGraph}        \n\
autoAcquire default value: true        \n\
</pre></div><p>Returns the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/Asset-Management/IObject-AssetUser.html\' title=\'\'>AssetUser Object</a> of the asset with the specified file name and asset type.</p>\n\
<div class=\'codeBlock\'><pre>&lt;IObject&gt;AssetManager.GetAssetByIndex &lt;index&gt;index \n\
</pre></div><p>Returns the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/Asset-Management/IObject-AssetUser.html\' title=\'\'>AssetUser Object</a> of the asset with the given index.</p>\n\
<p>Use <span class=\'code\'>AssetManager.GetNumAssets()</span> to get the number of Assets.</p>\n\
<p>See <a href=\'Interface-AssetManager.html#examples-\' title=\'\'>example at the end of this topic</a> for details.</p>\n\
<div class=\'codeBlock\'><pre>&lt;IObject&gt;GetAssetById &lt;string&gt;assetid\n\
</pre></div><p>Returns the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/Asset-Management/IObject-AssetUser.html\' title=\'\'>AssetUser Object</a> of the asset with the given asset ID. Available in <strong>in 3ds Max 2017 and higher</strong>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` box material:(standard diffusemap:(bitmaptexture filename:&quot;fur.tga&quot;)) --&gt; $Box:Box002 @ [0.000000,0.000000,0.000000] assetid = (assetmanager.GetAssetByIndex 1).GetAssetId(); --&gt; &quot;{DBD187ED-0BA9-4D07-9B85-BA44F5170FD9}&quot; assetmanager.GetFileName assetid --&gt; &quot;fur.tga&quot;<br> a=assetmanager.GetAssetById assetid --&gt; <iobject:assetuser> a.GetFileName() --&gt; &quot;fur.tga&quot;<p>\n\
<p>```</p>\n\
</iobject:assetuser></blockquote>\n\
<div class=\'section\'><a id=\"get-asset-id-and-file-name\"></a><h2 id=\"get-asset-id-and-file-name\">Get Asset ID and File Name</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;AssetManager.GetAssetId &lt;filename&gt;fileName &lt;enum&gt;assetType \n\
\n\
assetType enums: {#Other | #Bitmap | #XRef | #Photometric | #Animation | #VideoPost | #BatchRender | #ExternalLink | #RenderOutput | #PreRenderScript | #PostRenderScript | #Sound | #Container | #MaxCreationGraph} \n\
</pre></div><p>Returns the asset ID of the specified file name of the given asset type.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` AssetManager.GetAssetID &quot;Simple_Stone_Mtl_Marble_bump.jpg&quot; #Bitmap &quot;{7477A3A4-0304-47AC-8427-6B490673231A}&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;AssetManager.GetFileName &lt;string&gt;assetid\n\
</pre></div><p>Returns the file name of the asset with the given AssetID.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` AUIO = AssetManager.GetAssetByIndex 1--get the AsserUser with index 1 --&gt;<iobject:assetuser><p>\n\
<p>AUIO.GetFileName()--get the file name --&gt;&quot;Untitled Scene&quot;</p>\n\
<p>--This is equivalent: AssetManager.GetFileName (AUIO.getAssetID())--get the name by AssetID --&gt;&quot;Untitled Scene&quot;</p>\n\
<p>```</p>\n\
</iobject:assetuser></blockquote>\n\
<div class=\'section\'><a id=\"add-and-release-reference\"></a><h2 id=\"add-and-release-reference\">Add and Release Reference</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;AssetManager.GetNumReference &lt;string&gt;assetid\n\
</pre></div><p>Returns the number of the References to the Asset with the given AssetID.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;AssetManager.AddReference &lt;string&gt;assetid\n\
</pre></div><p>Adds a Reference to the Asset with the given AssetID.</p>\n\
<p>Returns true on success, false on failure.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;AssetManager.ReleaseReference &lt;string&gt;assetid\n\
</pre></div><p>Releases the Reference of the Asset with the given AssetID.</p>\n\
<p>Returns true on success, false on failure.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` AUIO = AssetManager.GetAssetByIndex 1--get the AsserUser with index 1 --&gt;<iobject:assetuser><p>\n\
<p>AID =AUIO.getAssetID()--get the file name --&gt;&quot;{7477A3A4-0304-47AC-8427-6B490673231A}&quot;</p>\n\
<p>AssetManager.GetNumReference AID--get the reference numberby AssetID --&gt;4</p>\n\
<p>AssetManager.AddReference AID--add a referenceby AssetID --&gt;true</p>\n\
<p>AssetManager.GetNumReference AID--get thereference numberby AssetID --&gt;5</p>\n\
<p>AssetManager.ReleaseReference AID--release a referenceby AssetID --&gt;true</p>\n\
<p>AssetManager.GetNumReference AID--get thereference numberby AssetID --&gt;4</p>\n\
<p>```</p>\n\
</iobject:assetuser></blockquote>\n\
<div class=\'section\'><a id=\"get-number-of-assets-and-assetusers\"></a><h2 id=\"get-number-of-assets-and-assetusers\">Get Number of Assets and AssetUsers</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;integer64&gt;AssetManager.GetNumAssetUsersCreated() \n\
</pre></div><p>Returns the total number of AssetUser instances created during the current <strong>3ds Max</strong> session.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer64&gt;AssetManager.GetNumAssetUsers() \n\
</pre></div><p>Returns the number of AssetUser instances.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer64&gt;AssetManager.GetNumAssetsCreated() \n\
</pre></div><p>Returns the total number of Assets created during the current <strong>3ds Max</strong> session.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer64&gt;AssetManager.GetNumAssets() \n\
</pre></div><p>Returns the number of Assets.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` AssetManager.GetNumAssetUsersCreated() --&gt;19862L</p>\n\
<p>AssetManager.GetNumAssetUsers() --&gt;114L</p>\n\
<p>AssetManager.GetNumAssetsCreated() --&gt;1080L</p>\n\
<p>AssetManager.GetNumAssets() --&gt;18L</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;AssetManager.RemoveMissingAssets()\n\
</pre></div><p>Removes any missing assets.</p>\n\
<p>Returns True if missing assets were removed successfully.</p>\n\
<p>Returns False if no missing assets were removed.</p>\n\
<p>Available in <strong>3ds Max 2016 and higher</strong>.</p>\n\
<div class=\'section\'><a id=\"examples\"></a><h3 id=\"examples\">Examples:</h3></div>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>The following script outputs to the MAXScript Listener the ID, type, and file name of all Assets in the current scene:</p>\n\
<p>``` --Loop through all Asset indices: for i = 1 to AssetManager.GetNumAssets() do ( local AUIO = AssetManager.GetAssetByIndex i--get the AssetUser IObject local AID = AUIO.GetAssetId()--get the Asset&#39;s ID local AType = AUIO.getType()--get the Asset&#39;s Type local AFile = AUIO.getfilename()--get the Asset&#39;s File Name format&quot;ID:% Type:% File:%\\n&quot;AID AType AFile--format the info )</p>\n\
<p>```</p>\n\
<p><strong>POSSIBLE OUTPUT:</strong></p>\n\
<p>``` ID:{B6D86A17-85FF-42E2-99D4-BB2F1857C4FB} Type:#bitmap File:C:\\Documents and Settings\\username\\My Documents\\3dsMax\\sceneassets\\images\\PlaneToBake<em>diffuse.tga ID:{7477A3A4-0304-47AC-8427-6B490673231A} Type:#bitmap File:Simple_Stone_Mtl_Marble_bump.jpg ID:{8188ACCD-A014-4B24-A3DD-697269D8BFDB} Type:#bitmap File:Simple_Concrete_Mtl_BroomStraight_pattern.jpg ID:{B0B6A6FD-2B76-4EA0-8B34-D1F3F3596F91} Type:#bitmap File:x47645df4 ID:{CF096A5C-41C8-43FD-852F-8823B9A707C7} Type:#bitmap File:C:\\Documents and Settings\\username\\My Documents\\3dsmax\\renderoutput\\AssetMan</em>.tga ID:{D5A9608F-EE4E-4BDC-AAB6-93D3D34E5F65} Type:#bitmap File:Simple_Concrete_Mtl_BroomCurved_pattern.jpg ID:{30241317-2623-4628-9BF1-ED06449E3D06} Type:#bitmap File:Simple_Metal_Mtl_DiamondPlate_pattern.jpg ID:{742F4FE3-91FC-48E7-9F3B-37CE76D37046} Type:#bitmap File:C:\\Documents and Settings\\username\\My Documents\\3dsMax\\sceneassets\\images\\Sphere01_diffuse.tga ID:{8BEFCD25-F133-4D5E-8678-E710F8BFBFF8} Type:#bitmap File:Simple_Metal_Mtl_CheckerPlate_pattern.jpg ID:{21B0F246-C6D0-44D3-9ECE-87D7BF8AFF14} Type:#bitmap File:Simple_Metal_Mtl_Break_pattern.jpg ID:{B5BB9B91-DBB4-486B-835A-A107F9F4783F} Type:#bitmap File:C:\\Documents and Settings\\username\\My Documents\\3dsMax\\sceneassets\\images\\PlaneToBake<em>lighting.tga ID:{65CAE8F4-F0DF-4CC3-A05C-733CC0285CF4} Type:#bitmap File:C:\\Program Files\\Autodesk\\3ds Max 2010\\CachedThumbnails\\1000000000000003.bmp ID:{5FF857B0-D2E0-4DCC-B4F7-97248CBC6FC5} Type:#bitmap File:C:\\Documents and Settings\\username\\My Documents\\3dsMax\\sceneassets\\images\\Sphere01LightingMap.tga ID:{31FE4D48-12B5-422E-A5D2-3A2979D773CD} Type:#bitmap File:C:\\Documents and Settings\\username\\My Documents\\3dsMax\\sceneassets\\images\\Sphere01_lighting.tga ID:{6AC17983-685D-42A8-8269-DBEA5FECB0DB} Type:#bitmap File:C:\\Documents and Settings\\username\\My Documents\\3dsMax\\sceneassets\\images\\Plane01_lighting.tga ID:{9BEAD40C-2562-42CF-A95D-E13E0EBD526D} Type:#bitmap File:C:\\Program Files\\Autodesk\\3ds Max 2010\\CachedThumbnails\\1000000000000004.bmp ID:{2253E2F5-82FE-46B1-B012-BC5FA100D86A} Type:#bitmap File:C:\\Documents and Settings\\username\\My Documents\\3dsMax\\sceneassets\\images\\Sphere01DiffuseMap.tga ID:{42B8F3F4-0D38-49D9-A9D9-598288A4E674} Type:#renderoutput File:C:\\Documents and Settings\\username\\My Documents\\3dsmax\\renderoutput\\AssetMan</em>.tga ID:{AC8AF90A-44DB-42C9-AC9E-7C35A7EBFF1A} Type:#bitmap File:C:\\Documents and Settings\\username\\My Documents\\3dsMax\\sceneassets\\images\\Plane01_diffuse.tga ID:{A9742E5A-4AB4-471D-A440-DE47F5262EF9} Type:#bitmap File:Simple_Stone_Mtl_Granite_bump.jpg ID:{8EC0A624-D996-48D7-9AA8-775ACA1652B9} Type:#xref File:C:\\Documents and Settings\\username\\My Documents\\3dsmax\\scenes\\RENOIR\\AssetManagerTest.max ID:{B51DCC8A-57C6-4308-B5B8-00FE0A105A29} Type:#bitmap File:Simple_Stone_Mtl_StoneWall_bump.jpg ID:{16544B6C-5D81-4E96-9B4D-550BFD4111E3} Type:#bitmap File:Simple_Metal_Mtl_Brush_pattern.jpg</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>See also</strong></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/Asset-Management/Accessing-AssetManager-AssetUser.html\' title=\'\'>Accessing AssetManager, AssetUser and Asset Metadata in MAX Files</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/Asset-Management/IObject-AssetUser.html\' title=\'\'>IObject:AssetUser</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/3ds-Max-Scene-Files-Access/MAX-File-Asset-Metadata-Stream.html\' title=\'\'>MAX File Asset Metadata Stream Access</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/E-F-G-H/Interface-FileResolutionManager.html\' title=\'\'>Interface: FileResolutionManager</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";