var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: actionMan</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: actionMan</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-actionman\"></a></div>\n\
<p>The <strong>actionMan Interface</strong> provides MAXScript access to the <strong>ActionTables</strong> and <strong>ActionItems</strong> that represent the actions that can be assigned to Toolbars, Menus, QuadMenus and Keyboard Shortcuts using the Customize User Interface dialog. ActionItems include MacroScripts created using the Macro Recorder or written manually by a MAXScript user. This interface provides methods for executing actions and for managing Keyboard Shortcuts files as well as access to the ActionTables and through them the ActionItems MixinInterfaces, which are documented at the end of this topic.</p>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>actionMan.numActionTables : integer : Read\n\
</pre></div><p>Contains the number of Action Tables registered with the Action Manager. Read-only.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;actionMan.executeAction &lt;integer&gt;tableId &lt;string&gt;persistentId   \n\
</pre></div><p>Executes the action specified by the table ID and persistent ID.</p>\n\
<p>Returns True if successful, False otherwise.</p>\n\
<p>You can get an action&#39;s IDs by enabling the MacroRecorder and performing actions in the <strong>3ds Max</strong> User Interface. Actions that can be performed only using the actionMan interface will appear as <span class=\'code\'>actionMan.executeAction()</span> calls with the corresponding IDs.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<ul>\n\
<li><p>Enable MacroRecorder.</p></li>\n\
<li><p>Go to Main Menu &gt; Tools &gt; Selection Floater.</p></li>\n\
<li><p>The MacroRecorder will display the code:</p></li>\n\
</ul>\n\
<p>``` actionMan.executeAction 0 &quot;40266&quot; -- Selection: Selection Floater</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;actionMan.loadKeyboardFile &lt;filename&gt;file   \n\
</pre></div><p>Loads the keyboard shortcuts settings from the specified file.</p>\n\
<p>If the keyboard shortcut file is in a legacy format (.kbdx), the file is converted and saved under User Settings in the new .hsx format.</p>\n\
<p>Available in <strong>3ds Max 2020.1 Update and higher</strong>.</p>\n\
<p>For example:</p>\n\
<div class=\'codeBlock\'><pre>actionman.loadKeyboardFile &quot;D:/my_kbdx/my_kbdx_file.kbdx&quot;\n\
--&gt; true \n\
actionman.getKeyboardFile()\n\
&quot;C:/Users/UserName/Autodesk/3ds Max 2020/User Settings/my_kbdx_file.hsx&quot;\n\
</pre></div><p>Returns True if successful and False otherwise.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;actionMan.saveKeyboardFile &lt;filename&gt;file \n\
</pre></div><p>Saves the keyboard shortcuts settings to the specified filename.</p>\n\
<p>Returns True if successful and False otherwise.</p>\n\
<div class=\'codeBlock\'><pre>&lt;filename&gt;actionMan.getKeyboardFile() \n\
</pre></div><p>Returns the filename of the current keyboard shortcuts file.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` actionMan.getKeyboardFile() &quot;C:\\Program Files\\Autodesk\\3ds Max 2008\\UI\\MaxStartUI.kbd&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;Interface&gt;actionMan.getActionTable &lt;index&gt;index\n\
</pre></div><p>Returns the <span class=\'code\'>&lt;MixinInterface:ActionTable&gt;</span> of the indexed Action Table.</p>\n\
<p>The index must be in the range of 1 to <strong><span class=\'code\'>actionMan.numActionTables</span></strong> .</p>\n\
<div class=\'section\'><a id=\"actiontable-mixininterface\"></a><h2 id=\"actiontable-mixininterface\">ActionTable MixinInterface</h2></div>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;ActionTable&gt;.id : integer : Read\n\
</pre></div><p>Contains the ID of the ActionTable. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;ActionTable&gt;.name : string : Read\n\
</pre></div><p>Contains the Name of the ActionTable. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;ActionTable&gt;.contextID : integer : Read\n\
</pre></div><p>Contains the ContextID of the ActionTable. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;ActionTable&gt;.contextName : string : Read\n\
</pre></div><p>Contains the Context Name of the ActionTable. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;ActionTable&gt;.numActionItems : integer : Read\n\
</pre></div><p>Contains the number of ActionItems in the ActionTable. Read-only.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;Interface&gt;&lt;ActionTable&gt;.getActionItem &lt;index&gt;index\n\
</pre></div><p>Returns the <span class=\'code\'>&lt;MixinInterface:ActionItem&gt;</span> of the indexed Action Item.</p>\n\
<p>The index must be between 1 and <span class=\'code\'>&lt;ActionTable&gt;.numActionItems</span>.</p>\n\
<div class=\'section\'><a id=\"actionitem-mixininterface\"></a><h2 id=\"actionitem-mixininterface\">ActionItem MixinInterface</h2></div>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;ActionItem&gt;.id : integer : Read\n\
</pre></div><p>Contains the ID of the ActionItem.</p>\n\
<div class=\'codeBlock\'><pre>&lt;ActionItem&gt;.isVisible : boolean : Read\n\
</pre></div><p>Contains the Visible state of the ActionItem as determined by its isVisible event handler.</p>\n\
<div class=\'codeBlock\'><pre>&lt;ActionItem&gt;.isEnabled : boolean : Read\n\
</pre></div><p>Contains the Enabled state of the ActionItem as determined by its isEnabled event handler.</p>\n\
<div class=\'codeBlock\'><pre>&lt;ActionItem&gt;.isChecked : boolean : Read\n\
</pre></div><p>Contains the Checked state of the ActionItem as determined by its isChecked event handler.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;ActionItem&gt;.getDescription &lt;&amp;String&gt;text\n\
\n\
text is Out parameter\n\
</pre></div><p>Sets the by-reference argument to the ActionItem&#39;s Description.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;ActionItem&gt;.getCategory &lt;&amp;String&gt;text\n\
\n\
text is Out parameter\n\
</pre></div><p>Sets the by-reference argument to the ActionItem&#39;s Category.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;ActionItem&gt;.getButtonText &lt;&amp;String&gt;text\n\
\n\
text is Out parameter\n\
</pre></div><p>Sets the by-reference argument to the text that will be displayed on a button when the ActionItem is assigned to a Toolbar.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;ActionItem&gt;.getMenuText &lt;&amp;String&gt;text\n\
\n\
text is Out parameter\n\
</pre></div><p>Sets the by-reference argument to the text that will be displayed when the ActionItem is assigned to a Menu or QuadMenu.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;&lt;ActionItem&gt;.hasIcon()\n\
</pre></div><p>Returns True if the ActionItem has an icon associated with it, False if the ActionItem has no icon.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;&lt;ActionItem&gt;.getIconFileName &lt;&amp;String&gt;fileName\n\
\n\
fileName is Out parameter\n\
</pre></div><p>Sets the by-reference argument to the Icon file name, or to &quot;&quot; if no Icon file is associated with the ActionItem.</p>\n\
<p>Returns True on success, False if no Icon file is associated with the ActionItem.</p>\n\
<div class=\'codeBlock\'><pre>&lt;index&gt;&lt;ActionItem&gt;.getIconIndex()\n\
</pre></div><p>Returns the index of the Action Item&#39;s Icon within the Icon file, or 0 if there is no icon associated with it (<span class=\'code\'>&lt;ActionItem&gt;.hasIcon()</span> returns <span class=\'code\'>false</span> ).</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` for i = 1 to actionMan.numActionTables-1 do ( atbl = actionMan.getActionTable i format &quot;% ID:% Name:&#39;%&#39; ContextID:% ContextName:&#39;%&#39; NumActionItems:%\\n&quot; i atbl.id atbl.name atbl.contextID atbl.contextName atbl.numActionItems for j = 1 to atbl.numActionItems do ( aitm = atbl.getActionItem j aitm.getDescription &amp;desc aitm.getCategory &amp;cat aitm.getButtonText &amp;btn aitm.getMenuText &amp;mnu hasicon = aitm.hasIcon() if hasicon then ( aitm.getIconFileName &amp;iconfile iconfile = filenamefrompath iconfile iconindex = aitm.getIconIndex() format &quot;\\t% ID:% Desc:&#39;%&#39; Cat:&#39;%&#39; BtnTxt:&#39;%&#39; MnuTxt:&#39;%&#39; Icon:[%,%] \\n&quot; j aitm.id desc cat btn mnu iconfile iconindex ) else format &quot;\\t% ID:% Desc:&#39;%&#39; Cat:&#39;%&#39; BtnTxt:&#39;%&#39; MnuTxt:&#39;%&#39;\\n&quot; j aitm.id desc cat btn mnu ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>PARTIAL OUTPUT</strong></p>\n\
<p>``` ... 3 ID:-1159893849 Name:&#39;Render&#39; ContextID:0 ContextName:&#39;Main UI&#39; NumActionItems:1 1 ID:36864 Desc:&#39;Render Message Window Toggle&#39; Cat:&#39;Render&#39; BtnTxt:&#39;Render Message Window...&#39; MnuTxt:&#39;Render Message Window...&#39; 4 ID:1724956863 Name:&#39;Asset Tracking System&#39; ContextID:0 ContextName:&#39;Main UI&#39; NumActionItems:2 1 ID:0 Desc:&#39;Generate Proxies&#39; Cat:&#39;Asset Tracking System&#39; BtnTxt:&#39;Generate Proxies&#39; MnuTxt:&#39;Generate Stale Proxies&#39; 2 ID:1 Desc:&#39;Set Proxy Resolution...&#39; Cat:&#39;Asset Tracking System&#39; BtnTxt:&#39;Set Proxy Resolution...&#39; MnuTxt:&#39;Set Proxy Resolution...&#39; 5 ID:161818329 Name:&#39;FixAmbientActions&#39; ContextID:2 ContextName:&#39;Material Editor&#39; NumActionItems:2 1 ID:1 Desc:&#39;Fix Ambient All&#39; Cat:&#39;Utilities&#39; BtnTxt:&#39;Fix Ambient All&#39; MnuTxt:&#39;Fix Ambient All&#39; 2 ID:2 Desc:&#39;Fix Ambient Selected&#39; Cat:&#39;Utilities&#39; BtnTxt:&#39;Fix Ambient Selected&#39; MnuTxt:&#39;Fix Ambient Selected&#39; 6 ID:132537306 Name:&#39;MMCleanActions&#39; ContextID:2 ContextName:&#39;Material Editor&#39; NumActionItems:1 1 ID:1 Desc:&#39;Clean MultiMaterial&#39; Cat:&#39;Utilities&#39; BtnTxt:&#39;Clean MultiMaterial&#39; MnuTxt:&#39;Clean MultiMaterial...&#39; 7 ID:4745576 Name:&#39;InstanceDuplMapActions&#39; ContextID:2 ContextName:&#39;Material Editor&#39; NumActionItems:1 1 ID:1 Desc:&#39;Instance Duplicate Map&#39; Cat:&#39;Utilities&#39; BtnTxt:&#39;Instance Duplicate Map&#39; MnuTxt:&#39;Instance Duplicate Map...&#39; 8 ID:-1682387772 Name:&#39;Scene State Manager&#39; ContextID:0 ContextName:&#39;Main UI&#39; NumActionItems:3 1 ID:4096 Desc:&#39;Save Scene State&#39; Cat:&#39;Scene State&#39; BtnTxt:&#39;Save Scene State...&#39; MnuTxt:&#39;Save Scene State...&#39; 2 ID:4112 Desc:&#39;Scene State Manager Dialog Toggle&#39; Cat:&#39;Scene State&#39; BtnTxt:&#39;Manage Scene States...&#39; MnuTxt:&#39;Manage Scene States...&#39; 3 ID:8192 Desc:&#39;Restore Scene State&#39; Cat:&#39;Scene State&#39; BtnTxt:&#39;Restore Scene State&#39; MnuTxt:&#39;Restore Scene State&#39; 9 ID:-1172021248 Name:&#39;Containers&#39; ContextID:0 ContextName:&#39;Main UI&#39; NumActionItems:17 1 ID:0 Desc:&#39;Inherit Container&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Inherit Container&#39; MnuTxt:&#39;Inherit Container&#39; Icon:[Containers,6] 2 ID:1 Desc:&#39;Create Container from Selection&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Create Container from Selection&#39; MnuTxt:&#39;Create Container from Selection&#39; Icon:[Containers,4] 3 ID:2 Desc:&#39;Add Selected to Container&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Add Selected to Container&#39; MnuTxt:&#39;Add Selected to Container&#39; Icon:[Containers,2] 4 ID:3 Desc:&#39;Remove Selected from Container&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Remove Selected from Container&#39; MnuTxt:&#39;Remove Selected from Container&#39; Icon:[Containers,12] 5 ID:4 Desc:&#39;Unload Container&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Unload Container&#39; MnuTxt:&#39;Unload Container&#39; Icon:[Containers,14] 6 ID:5 Desc:&#39;Load Container&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Load Container&#39; MnuTxt:&#39;Load Container&#39; Icon:[Containers,7] 7 ID:6 Desc:&#39;Close Container&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Close Container&#39; MnuTxt:&#39;Close Container&#39; Icon:[Containers,3] 8 ID:7 Desc:&#39;Open Container&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Open Container&#39; MnuTxt:&#39;Open Container&#39; Icon:[Containers,9] 9 ID:8 Desc:&#39;Save Container&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Save Container&#39; MnuTxt:&#39;Save Container&#39; Icon:[Containers,13] 10 ID:9 Desc:&#39;Update Container&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Update Container&#39; MnuTxt:&#39;Update Container&#39; Icon:[Containers,1] 11 ID:10 Desc:&#39;Reload Container&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Reload Container&#39; MnuTxt:&#39;Reload Container&#39; Icon:[Containers,11] 12 ID:11 Desc:&#39;Make All Content Unique&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Make All Content Unique&#39; MnuTxt:&#39;Make All Content Unique&#39; Icon:[Containers,15] 13 ID:12 Desc:&#39;Merge Container Source&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Merge Container Source&#39; MnuTxt:&#39;Merge Container Source&#39; Icon:[Containers,8] 14 ID:13 Desc:&#39;Edit Container&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Edit Container&#39; MnuTxt:&#39;Edit Container&#39; Icon:[Containers,5] 15 ID:14 Desc:&#39;Override Object Properties&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Override Object Properties&#39; MnuTxt:&#39;Override Object Properties&#39; Icon:[Containers,10] 16 ID:15 Desc:&#39;Select Content&#39;s Container&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Select Content&#39;s Container&#39; MnuTxt:&#39;Select Content&#39;s Container&#39; Icon:[Containers,16] 17 ID:16 Desc:&#39;Override All Locks&#39; Cat:&#39;Containers&#39; BtnTxt:&#39;Override All Locks&#39; MnuTxt:&#39;Override All Locks&#39; Icon:[Containers,18] ...</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>All Action Items are macro recorded when executed. This includes main menu items, CUI buttons, keyboard shortcuts, and quad menu items.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";