var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: assemblyMgr</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: assemblyMgr</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-assemblymgr\"></a></div>\n\
<p>Represents the interface to the Assembly Manager. Used to put objects together to Assemblies, and test and manipulate the Assemblies.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;assemblyMgr.Assemble &lt;node array&gt;nodes [ name:&lt;string&gt; ][ classDesc:&lt;class&gt; ] [ select:&lt;boolean&gt; ]     \n\
\n\
name default value: undefined    \n\
classDesc default value: undefined   \n\
select default value: true   \n\
</pre></div><p>Create a new Assembly using the nodes in the <span class=\'code\'>&lt;node array&gt;</span>.</p>\n\
<p>A Create Assembly dialog will be displayed if either the name or the classDesc is not specified. The classDesc is passed a MAXClass, an instance of which will be used as the assembly head. This MAXClass must be for a helper object. You can create a scripted plug-in that extends helper to use as assembly head, exposing the properties you desire for the assembly head.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` object1 = Cylinder()--create a cylinder --&gt; $Cylinder:Cylinder001 @ [0.000000,0.000000,0.000000] object2 = Box()--create a box --&gt; $Box:Box001 @ [0.000000,0.000000,0.000000] object3 = OmniLight() --&gt; \\(Omni_Light:Omni001 @ [0.000000,0.000000,0.000000]  obj_array = #(object1, object2, object3)  --&gt; #(\\)Cylinder:Cylinder001 @ [0.000000,0.000000,0.000000], $Box:Box001 @ [0.000000,0.000000,0.000000], $Omni_Light:Omni001 @ [0.000000,0.000000,0.000000])</p>\n\
<p>--Create a new Assembly out of the objects, name it Test001 and use --a Dummy as the head. new_ass will contain the assembly head. new_ass = assemblyMgr.assemble obj_array name:&quot;Test001&quot; classDesc:Dummy --&gt; $Dummy:Test001 @ [0.000000,0.000000,-8.000000]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assemblyMgr.Disassemble &lt;node array&gt;nodes \n\
</pre></div><p>Disassembles the specified nodes. Returns <span class=\'code\'>true</span> on success.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` --Continuing with the assembly from the above example... obj_array --&gt; #($Cylinder:Cylinder001 @ [0.000000,0.000000,0.000000], $Box:Box001 @ [0.000000,0.000000,0.000000], $Omni_Light:Omni001 @ [0.000000,0.000000,0.000000]) --We cannot disassemble the original array because it does not --contain the head object! assemblyMgr.Disassemble obj_array --&gt; false --Let’s append the head to the array and try again... append obj_array \\(Test001  --&gt; #(\\)Cylinder:Cylinder001 @ [0.000000,0.000000,0.000000], $Box:Box001 @ [0.000000,0.000000,0.000000], $Omni_Light:Omni001 @ [0.000000,0.000000,0.000000], $Dummy:Test01 @ [0.000000,0.000000,-8.000000]) --Now that we supplied all objects of the assembly, --the Disassemble method worked. assemblyMgr.Disassemble obj_array --&gt; true</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assemblyMgr.Open &lt;node array&gt;nodes [clearSelection:&lt;boolean&gt;] \n\
\n\
clearSelection default value: true \n\
</pre></div><p>Opens the specified nodes. Returns <span class=\'code\'>true</span> on success. When <span class=\'code\'>clearSelection:</span> is supplied as <span class=\'code\'>false</span> , the selection will not be cleared.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assemblyMgr.Close &lt;node array&gt;nodes [select:&lt;boolean&gt;] \n\
\n\
select default value: true \n\
</pre></div><p>Closes the specified nodes. Returns <span class=\'code\'>true</span> on success.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assemblyMgr.Explode &lt;node array&gt;nodes \n\
</pre></div><p>Explodes the specified nodes. Returns <span class=\'code\'>true</span> on success.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assemblyMgr.Attach &lt;node array&gt;nodes [assembly:&lt;node&gt;] \n\
\n\
assembly default value: undefined \n\
</pre></div><p>Attaches the specified nodes to the assembly. Returns <span class=\'code\'>true</span> on success.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assemblyMgr.Detach &lt;node array&gt;nodes \n\
</pre></div><p>Detaches the specified nodes from the assembly. Returns <span class=\'code\'>true</span> on success.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assemblyMgr.CanAssemble &lt;node array&gt;nodes \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the <span class=\'code\'>&lt;node array&gt;</span> contains nodes that can be assembled.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assemblyMgr.CanDisassemble &lt;node array&gt;nodes \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the <span class=\'code\'>&lt;node array&gt;</span> contains nodes that can be disassembled.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assemblyMgr.CanExplode &lt;node array&gt;nodes \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the <span class=\'code\'>&lt;node array&gt;</span> contains nodes that can be exploded.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assemblyMgr.CanOpen &lt;node array&gt;nodes \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the <span class=\'code\'>&lt;node array&gt;</span> contains nodes that can be opened.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assemblyMgr.CanClose &lt;node array&gt;nodes \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the <span class=\'code\'>&lt;node array&gt;</span> contains nodes that can be closed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assemblyMgr.CanAttach &lt;node array&gt;nodes assembly:&lt;node&gt; \n\
\n\
assembly default value: undefined \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the nodes in <span class=\'code\'>&lt;node array&gt;</span> can be attached to the assembly.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assemblyMgr.CanDetach &lt;node array&gt;nodes \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the nodes in <span class=\'code\'>&lt;node array&gt;</span> can be detached.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;assemblyMgr.IsAssembly &lt;node array&gt;nodes \n\
</pre></div><p>Returns the Head Node of the Assembly comprised by the nodes specified by <span class=\'code\'>&lt;node array&gt;</span> , or <span class=\'code\'>undefined</span> if the nodes do not form an Assembly.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assemblyMgr.FilterAssembly &lt;node&gt;assemblyHead &lt;value&gt;filterSClassID &lt;&amp;node array&gt;filteredNodes \n\
\n\
filteredNodes is Out parameter \n\
</pre></div><p>Filters all nodes of the specified superclass that are contained in the assembly with the specified head and passes them out to the supplied filterNodes array. Returns <span class=\'code\'>true</span> on success.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES</strong></p>\n\
<p>``` --Assembly contains a Cylinder,a Box and a Dummy Helper as head: test_array = #($Box001, \\(Cylinder001)  --&gt; #(\\)Box:Box001 @ [0.000000,0.000000,0.000000], \\(Cylinder:Cylinder001 @ [0.000000,0.000000,0.000000])  --Check for assembly with the lights only  assemblyMgr.IsAssembly test_array  --&gt; undefined  --Now check with all assembly nodes including the Head  test_array = #(\\)Box001, $Cylinder001, $Omni001, \\(Test001)  --&gt; #(\\)Box:Box001 @ [0.000000,0.000000,0.000000], $Cylinder:Cylinder001 @ [0.000000,0.000000,0.000000], $Omni_Light:Omni001 @ [0.000000,0.000000,0.000000], $Dummy:Test001 @ [0.000000,0.000000,-8.000000]) a_head = assemblyMgr.IsAssembly test_array --&gt; $Dummy:Test001 @ [0.000000,0.000000,-8.000000] --a_head now contains the Head of the Assembly containing the above objects!</p>\n\
<p>--Find all light objects in assembly a_head AssemblyMgr.FilterAssembly a_head Light &amp;lightnodes --&gt; true -- lightnodes now contains all nodes corresponding to objects of superclass Light lightnodes --&gt; #($Omni_Light:Omni001 @ [0.000000,0.000000,0.000000]) --Find all camera objects in assembly a_head AssemblyMgr.FilterAssembly a_head Camera &amp;camnodes --&gt; true --There are no cameras in the assembly! camnodes --&gt; #()</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";