var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: CustomSceneStreamManager</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: CustomSceneStreamManager</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-customscenestreammanager\"></a></div>\n\
<p>The <span class=\'code\'>CustomSceneStreamManager</span> interface is used to query, add, modify and remove <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/Custom-File-Streams.html\' title=\'\'>CustomFileStreams</a> in the current 3ds Max scene file. Available in <strong>3ds Max 2019 and higher</strong>.</p>\n\
<div class=\'section\'><a id=\"flag-values\"></a><h2 id=\"flag-values\">Flag Values</h2></div>\n\
<p>Custom file streams have three flags that determine how they are handled by the <span class=\'code\'>CustomFileStreamManager</span>:</p>\n\
<div class=\'section\'><a id=\"persistence-flag\"></a><h4 id=\"persistence-flag\">Persistence Flag</h4></div>\n\
<p>When this flag is set, the CustomSceneStreamManager writes this stream to the scene file when the scene file is saved, and reads the stream into its cache when the scene file is loaded. This flag&#39;s value is persisted across a save/load operation. This allows a CustomFileStream to be automatically persisted across multiple load/save operations. See is/setStreamPersistent().</p>\n\
<div class=\'section\'><a id=\"save-flag\"></a><h4 id=\"save-flag\">Save Flag</h4></div>\n\
<p>This flag indicates whether the CustomFileStream is saved when the scene file is saved. Setting this flag allows you to add a non-persistent stream and have it saved on scene file save. This flag does not persist, and is cleared when the stream is read from the scene file.</p>\n\
<div class=\'section\'><a id=\"no-load-flag\"></a><h4 id=\"no-load-flag\">No Load Flag</h4></div>\n\
<p>This flag indicates whether the CustomFileStream is loaded by the CustomSceneStreamManager when the scene file is loaded. This flag allows you to create streams that are not loaded on file load, for example for data to be consumed by an external tool or workflow. See getNoLoadOnSceneLoad() and setNoLoadOnSceneLoad().</p>\n\
<p>Note: These flags are stored in a &quot;private&quot; 32 bit integer (private in the sense that all bits are reserved for future use by 3ds Max). The <span class=\'code\'>CustomSceneStreamManager</span> interface exposes methods to get this integer value, or to get and set the individual flags in the value. There is also a &quot;public&quot; 32 bit integer value that you can use for defining additional custom flags.</p>\n\
<p>Note: If the Save Flag is set, the Persistence Flag is not set, and the No Load Flag is not set, then the stream is persisted across a single save/load operation, since the Save Flag is cleared on load.</p>\n\
<div class=\'section\'><a id=\"notifications\"></a><h2 id=\"notifications\">Notifications</h2></div>\n\
<p>Because the <span class=\'code\'>CustomSceneStreamManager</span> code may be loaded and invoked at different times, depending on system configuration, the order in which it and other 3ds Max components will receive file operation notifications can be unpredictable. For this reason, you should use the interface&#39;s methods for registering callbacks if you need to operate on the <span class=\'code\'>CustomSceneStreamManager</span> itself, or on the scene file (such as copying and storing it).</p>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>.numEntries : integer : Read\n\
</pre></div><p>The number of entries in the <span class=\'code\'>CustomSceneStreamManager</span>&#39;s cache.</p>\n\
<div class=\'codeBlock\'><pre>.locked : boolean : Read|Write\n\
</pre></div><p>Whether the <span class=\'code\'>CustomSceneStreamManager</span> is locked. When locked, the <span class=\'code\'>CustomSceneStreamManager</span> does not react to any notifications from 3ds Max. This means that the manager does not automatically load or save data streams.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;getStreamName &lt;index&gt;index\n\
</pre></div><p>Returns the name of the stream for the specified cache entry index.</p>\n\
<div class=\'codeBlock\'><pre>&lt;index&gt;getStreamByName &lt;string&gt;name\n\
</pre></div><p>Returns the index of the named stream. Throws an exception if the named stream does not exist.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;doesStreamExist &lt;value&gt;which\n\
</pre></div><p>Returns true if the specified stream exists. The <span class=\'code\'>which</span> parameter can be either a stream name or a stream index.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;getStreamFlag &lt;value&gt;which\n\
    privateFlag:&lt;boolean&gt;\n\
    privateFlag default value: false\n\
\n\
&lt;void&gt;setStreamFlag &lt;value&gt;which\n\
    &lt;integer&gt;value privateFlag:&lt;boolean&gt;\n\
    privateFlag default value: false\n\
</pre></div><p>Gets or sets the specified stream&#39;s public or private flags value. The &quot;private&quot; integer contains the persistence, save, and cache flags in the first 3 bits. The remaining bits are reserved for future use. The &quot;public&quot; integer can contain any flags or other data you wish. The <span class=\'code\'>which</span> parameter can be either a stream name or a stream index. Throws an exception if the specified stream does not exist.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;isStreamDataAnArray &lt;value&gt;which\n\
</pre></div><p>Returns true if the specified stream&#39;s content is an array of strings. The <span class=\'code\'>which</span> parameter can be either a stream name or a stream index. Throws an exception if the specified stream does not exist.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;getStreamData &lt;value&gt;which\n\
</pre></div><p>Returns the specified stream&#39;s content as a string. If the content is an array of strings, the first string is returned. The <span class=\'code\'>which</span> parameter can be either a stream name or a stream index. Throws an exception if the specified stream does not exist.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string array&gt;getStreamDataAsArray\n\
    &lt;value&gt;which\n\
</pre></div><p>Returns the specified stream&#39;s content as an array of strings. If the content is a single string, it is returned in a 1 element array. The <span class=\'code\'>which</span> parameter can be either a stream name or a stream index. Throws an exception if the specified stream does not exist.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;setStreamData &lt;value&gt;which\n\
    &lt;string&gt;string\n\
</pre></div><p>Sets the specified stream&#39;s content as a string. The <span class=\'code\'>which</span> parameter can be either a stream name or a stream index. Throws an exception if the specified stream does not exist.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;setStreamDataAsArray &lt;value&gt;which &lt;string array&gt;string_array\n\
       setStreamDataAsArray - no automatic redraw after invoked\n\
</pre></div><p>Sets the specified stream&#39;s content as an array of strings. The <span class=\'code\'>which</span> parameter can be either a stream name or a stream index. Throws an exception if the specified stream does not exist. <strong>Note</strong>: if you store an empty array, <span class=\'code\'>isStreamDataAnArray()</span> returns false.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;isStreamPersistent &lt;value&gt;which\n\
\n\
&lt;void&gt;setStreamPersistent &lt;value&gt;which\n\
    &lt;boolean&gt;persistent\n\
</pre></div><p>Gets or sets the specified stream is flagged as persistent when written to the scene file. The <span class=\'code\'>which</span> parameter can be either a stream name or a stream index. Throws an exception if the specified stream does not exist.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;getSaveNonPersistentStream &lt;value&gt;which\n\
\n\
&lt;void&gt;setSaveNonPersistentStream &lt;value&gt;which &lt;boolean&gt;val\n\
</pre></div><p>Gets or sets whether the specified stream is flagged as to be written to the scene file even if not flagged as persistent file. The <span class=\'code\'>which</span> parameter can be either a stream name or a stream index. Throws an exception if the specified stream does not exist.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;getNoLoadOnSceneLoad &lt;value&gt;which\n\
\n\
&lt;void&gt;setNoLoadOnSceneLoad &lt;value&gt;which &lt;boolean&gt;val\n\
</pre></div><p>Gets or sets whether the specified stream is flagged as not to be loaded on scene file load when written to the scene file. The <span class=\'code\'>which</span> parameter can be either a stream name or a stream index. Throws an exception if the specified stream does not exist.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;deleteStream &lt;value&gt;which\n\
</pre></div><p>Deletes the specified stream. The <span class=\'code\'>which</span> parameter can be either a stream name or a stream index.</p>\n\
<div class=\'codeBlock\'><pre>&lt;index&gt; createStream &lt;string&gt;name\n\
persistent:&lt;boolean&gt; saveNonPersistentStream:&lt;boolean&gt;\n\
noLoadOnSceneLoad:&lt;boolean&gt;\n\
persistent default value: true\n\
saveNonPersistentStream default value: true\n\
noLoadOnSceneLoad default value: false\n\
</pre></div><p>Creates a cache entry with the specified name and flag values. The content of the entry will be an empty string. Throws an exception if a cache entry with the same name already exists.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;registerCallback &lt;value&gt;callback_fn\n\
&lt;value&gt;callback_id &lt;enum&gt;event\n\
event enums: {#postLoad|#preSave|#postSave}\n\
</pre></div><p>Registers a callback function that is called when the corresponding <span class=\'code\'>CustomSceneStreamManager</span> event occurs. The <span class=\'code\'>callback_id</span> must be a name value. The callback function must take 2 arguments: the first argument is the file name and the second argument is the event type as a name value (<span class=\'code\'>#postLoad</span>, <span class=\'code\'>#preSave</span>, or <span class=\'code\'>#postSave</span>). If an exception occurs while executing a callback function, that function is automatically unregistered.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;unregisterCallbacks callback_fn:&lt;value&gt;\n\
callback_id:&lt;value&gt; event:&lt;enum&gt;\n\
callback_fn default value: undefined\n\
callback_id default value: undefined\n\
event enums: {#postLoad|#preSave|#postSave}\n\
event default value: -1\n\
</pre></div><p>Unregisters any callback functions that match all the values specified via the keyword arguments.</p>\n\
<div class=\'codeBlock\'><pre>&lt;value&gt;getCallbacks callback_fn:&lt;value&gt;\n\
callback_id:&lt;value&gt; event:&lt;enum&gt;\n\
callback_fn default value: undefined\n\
callback_id default value: undefined\n\
event enums: {#postLoad|#preSave|#postSave}\n\
event default value: -1\n\
</pre></div><p>Returns an array of all callback functions that match all the values specified via the keyword arguments.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";