var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface : DefaultParamInterface</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface : DefaultParamInterface</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-defaultparaminterface\"></a></div>\n\
<p>The <span class=\'code\'>DefaultParamInterface</span> is used to define and persist user-defined defaults for parameters in 3ds Max. If set as persistent, default values are stored in a file located in users\\[username]\\Autodesk\\3ds Max [year]\\User Settings\\DefaultParameters.ini. This file can be copied to other installations and newer versions of 3ds Max to preserve the settings. <strong>Available in 3ds Max 2021.1 Update and higher.</strong> Note: For those items that have a preset system (such as the Chamfer modifier), setting default values with this interface has no effect, since the default presets always take precedence.</p>\n\
<p><strong>Methods</strong>:</p>\n\
<div class=\'codeBlock\'><pre>    &lt;boolean&gt;DefaultParamInterface.IsClassCompatible &lt;class&gt;class &lt;&amp;enum&gt;result\n\
       result enums: {#success|#incompatibleClass|#parameterNotFound|#invalidParameterValue|#classNotFound|#iniFileWriteFailure|\n\
                            #paramNotOverridden|#paramOverridden}\n\
       result is Out parameter\n\
</pre></div><p>Returns whether the specified class can have default values set for parameters. This function checks whether the class implements parameters using the C++ ClassDescriptor2 interface. The function will return either true or false, as well as either <span class=\'code\'>#success</span> or <span class=\'code\'>#incompatibleClass</span> in the <span class=\'code\'>result</span> parameter.</p>\n\
<p>Most geometry and modifiers are compatible, though there are some (such as Splines and older modifiers) that are not.</p>\n\
<p>For example:</p>\n\
<div class=\'codeBlock\'><pre>res = DefaultParamInterface.IsClassCompatible Teapot &amp;result\n\
format &quot;Teapot result: % %\\n&quot; res result\n\
res = DefaultParamInterface.IsClassCompatible Line &amp;result\n\
format &quot;Line result: % %\\n&quot; res result\n\
    &lt;value&gt;DefaultParamInterface.GetDefaultParamValue &lt;class&gt;class &lt;string&gt;parameterName &lt;&amp;enum&gt;result\n\
       result enums: {#success|#incompatibleClass|#parameterNotFound|#invalidParameterValue|#classNotFound|#iniFileWriteFailure|\n\
                                                                #paramNotOverridden|#paramOverridden}\n\
       result is Out parameter\n\
</pre></div><p>Gets the default value for the specified parameter <span class=\'code\'>parameterName</span> for the specified class.</p>\n\
<p>This method returns either the value (if found) or undefined if not, with the reason supplied in the <span class=\'code\'>result</span> out parameter.</p>\n\
<div class=\'codeBlock\'><pre>    &lt;enum&gt;DefaultParamInterface.SetDefaultParamValue &lt;class&gt;class &lt;string&gt;parameterName &lt;value&gt;defaultValue persistent:&lt;boolean&gt;\n\
       SetDefaultParamValue enums: {#success|#incompatibleClass|#parameterNotFound|#invalidParameterValue|#classNotFound|\n\
                                                                                                                        #iniFileWriteFailure|#paramNotOverridden|#paramOverridden\n\
       persistent default value: false\n\
</pre></div><p>Sets the default value <span class=\'code\'>defaultValue</span> for the specified parameter <span class=\'code\'>parameterName</span> on the specified <span class=\'code\'>class</span>.</p>\n\
<p>If <span class=\'code\'>persistent</span> is true, default values are stored in a file located in users\\[username]\\Autodesk\\3ds Max [year]\\User Settings\\DefaultParameters.ini, and persisted between 3ds Max sessions.</p>\n\
<p>For example:</p>\n\
<div class=\'codeBlock\'><pre>result = defaultParamInterface.setDefaultParamValue teapot &quot;segs&quot; 4 persistent:true\n\
--&gt; #success\n\
    &lt;enum&gt;DefaultParamInterface.ClearDefaultParamValue &lt;class&gt;class &lt;string&gt;parameterName\n\
       ClearDefaultParamValue enums: {#success|#incompatibleClass|#parameterNotFound|#invalidParameterValue|#classNotFound\n\
                                     |#iniFileWriteFailure|#paramNotOverridden|#paramOverridden\n\
</pre></div><p>Clears the default value setting for the specified parameter on the specified class from the ini file. Note that the user-defined default value will remain in place for the current 3ds Max session. To revert to the factory default value for the current session, use <span class=\'code\'>RestoreFactoryDefaultValue()</span> (below).</p>\n\
<div class=\'codeBlock\'><pre>    &lt;enum&gt;DefaultParamInterface.ClearAllDefaultParamValues &lt;class&gt;class\n\
       ClearAllDefaultParamValues enums: {#success|#incompatibleClass|#parameterNotFound|#invalidParameterValue|#classNotFound|\n\
                                          #iniFileWriteFailure|#paramNotOverridden|#paramOverridden\n\
</pre></div><p>Clears all default value settings for the specified class from the ini file. Note that the user-defined default values will remain in place for the current 3ds Max session. To revert to the factory default values for the current session, use <span class=\'code\'>RestoreFactoryDefaultValue()</span> (below).</p>\n\
<div class=\'codeBlock\'><pre>    &lt;enum&gt;DefaultParamInterface.IsDefaultParamValueOverridden &lt;class&gt;class &lt;string&gt;parameterName\n\
       IsDefaultParamValueOverridden enums: {#success|#incompatibleClass|#parameterNotFound|#invalidParameterValue|\n\
                                             #classNotFound|#iniFileWriteFailure|#paramNotOverridden|#paramOverridden\n\
</pre></div><p>Returns whether the specified parameter on the specified class is currently overridden.</p>\n\
<div class=\'codeBlock\'><pre>    &lt;enum&gt;DefaultParamInterface.RestoreFactoryDefaultValue &lt;class&gt;class &lt;string&gt;parameterName\n\
       RestoreFactoryDefaultValue enums: {#success|#incompatibleClass|#parameterNotFound|#invalidParameterValue|#classNotFound|\n\
                                          #iniFileWriteFailure|#paramNotOverridden|#paramOverridden\n\
</pre></div><p>Clears the default value setting for the specified parameter on the specified class from the ini file, and reverts to the factory default value for the current 3ds Max session.</p>\n\
<div class=\'section\'><a id=\"complete-example\"></a><h3 id=\"complete-example\">Complete Example</h3></div>\n\
<div class=\'codeBlock\'><pre>--Set Box Segments to 10\n\
result = DefaultParamInterface.SetDefaultParamValue box &quot;LengthSegs&quot; 10 persistent:true\n\
result = DefaultParamInterface.SetDefaultParamValue box &quot;WidthSegs&quot; 10 persistent:true\n\
result = DefaultParamInterface.SetDefaultParamValue box &quot;HeightSegs&quot; 10 persistent:true\n\
--Clear Box Segment Defaults\n\
result = DefaultParamInterface.ClearAllDefaultParamValues box\n\
result = DefaultParamInterface.ClearDefaultParamValue box &quot;Lengthsegs&quot;\n\
--Editable Poly defaults examples\n\
result = DefaultParamInterface.SetDefaultParamValue Editable_Poly &quot;edgeChamferSmooth&quot; off persistent:true\n\
result = DefaultParamInterface.SetDefaultParamValue Editable_Poly &quot;edgeChamferSegments&quot; 0 persistent:true\n\
result = DefaultParamInterface.SetDefaultParamValue Editable_Poly &quot;edgeChamferMiteringType&quot; 2 persistent:true\n\
result = DefaultParamInterface.SetDefaultParamValue Editable_Poly &quot;extrusionType&quot; 1 persistent:true\n\
result = DefaultParamInterface.SetDefaultParamValue Editable_Poly &quot;insetType&quot; 1 persistent:true\n\
result = DefaultParamInterface.SetDefaultParamValue Editable_Poly &quot;selectMode&quot; 1 persistent:true\n\
result = DefaultParamInterface.SetDefaultParamValue Editable_Poly &quot;weldThreshold&quot; .001 persistent:true\n\
--Edit Poly defaults examples\n\
result = DefaultParamInterface.SetDefaultParamValue Edit_Poly &quot;edgeChamferSmooth&quot; off persistent:true\n\
result = DefaultParamInterface.SetDefaultParamValue Edit_Poly &quot;edgeChamferSegments&quot; 0 persistent:true\n\
result = DefaultParamInterface.SetDefaultParamValue Edit_Poly &quot;extrudeFaceType&quot; 1 persistent:true\n\
result = DefaultParamInterface.SetDefaultParamValue Edit_Poly &quot;insetType&quot; 1 persistent:true\n\
result = DefaultParamInterface.SetDefaultParamValue Edit_Poly &quot;selectMode&quot; 1 persistent:true\n\
result = DefaultParamInterface.SetDefaultParamValue Noisemodifier &quot;strength&quot; [20.0, 20.0, 20.0] persistent:true\n\
result = DefaultParamInterface.SetDefaultParamValue Noisemodifier &quot;fractal&quot; on persistent:true\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";