var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: colorMan</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: colorMan</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-colorman\"></a></div>\n\
<p>The <strong>colorMan Core Interface</strong> exposes the <strong>Color Manager</strong> to MAXScript.</p>\n\
<p>Within <strong>3ds Max</strong>, using the <strong>Main Menu &gt; Customize &gt; Customize User Interface &gt; Colors</strong> tab, you can alter the colors used for various UI elements, change the saturation, value and transparency of elements, and load and save color schemes.</p>\n\
<p>Note: After making any color changes, you must call <span class=\'code\'>colorMan.repaintUI #repaintAll</span> to apply the changes and synchronize with the customize dialog.</p>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>colorMan.colorTheme \n\
colorTheme enums: {#dark|#light}\n\
</pre></div><p>Gets or sets the Color Theme as a name value. Available in <strong>in 3ds Max 2017 and higher</strong>.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;enum&gt; colorMan.getColorTheme()\n\
\n\
getColorTheme enums: {#dark|#light}\n\
</pre></div><p>Gets the current Color Theme as a name value. Available in <strong>in 3ds Max 2017 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt; colorMan.setColorTheme &lt;enum&gt;theme\n\
\n\
theme enums: {#dark|#light}\n\
</pre></div><p>Sets the current Color Theme. Available in <strong>in 3ds Max 2017 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;enum&gt;colorMan.getColorSchemeType() \n\
\n\
getColorSchemeType enums: {#customColor|#standardWindows|#windowsTheme}\n\
</pre></div><p>Returns the current color scheme type as a name value.</p>\n\
<p>Available in <strong>3ds Max 2010 and higher up to 3ds Max 2017</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;enum&gt;colorMan.setColorSchemeType &lt;enum&gt;type \n\
\n\
setColorSchemeType enums: {#customColor|#standardWindows|#windowsTheme}\n\
type enums: {#customColor|#standardWindows|#windowsTheme}\n\
</pre></div><p>Sets the color scheme type to the specified name and returns the actual color scheme type as result.</p>\n\
<p>Available in <strong>3ds Max 2010 and higher up to 3ds Max 2017</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;colorMan.useStandardWindowsColors() \n\
</pre></div><p><img src=\'developer/images/GUID-58798F8D-5DC2-454D-A1A2-9DF57E5A2077-low.gif\' title=\'\'>In versions <strong>prior to 3ds Max 2010</strong>, returned <span class=\'code\'>true</span> if the standard windows colors were used and false if custom colors were used.</p>\n\
<div class=\'codeBlock\'><pre>colorMan.setUseStandardWindowsColors &lt;boolean&gt;onOff   \n\
</pre></div><p><img src=\'developer/images/GUID-58798F8D-5DC2-454D-A1A2-9DF57E5A2077-low.gif\' title=\'\'>In versions <strong>prior to 3ds Max 2010</strong>, used to set whether standard windows colors were used or not.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;colorMan.registerColor &lt;string&gt;color &lt;string&gt;name &lt;string&gt;category &lt;point3&gt;defaultColor \n\
</pre></div><p>This registers a new color with the system, and adds a color to the color manager database that is then accessible from the color customization UI. It returns <span class=\'code\'>false</span> if the color is already registered; otherwise <span class=\'code\'>true</span> .</p>\n\
<p><span class=\'code\'>&lt;string&gt;color</span>: The ID of the color to register. Example: #myNewColor</p>\n\
<p><span class=\'code\'>&lt;string&gt;name</span>: The name for the color. Example: &quot;My Own Color&quot;</p>\n\
<p><span class=\'code\'>&lt;string&gt;category</span>: The category for the color. If the name passed matches one of the existing <strong>3ds Max</strong> categories the color will be placed in there, otherwise a new one will be created. Example: &quot;Fun Gaming Colors&quot;</p>\n\
<p><span class=\'code\'>&lt;point3&gt;defaultColor</span>: The default value for the color. This is the value that the color will be reset to when a <strong>3ds Max</strong> user presses &quot;Reset&quot; in the color customization dialog. Example: [1,0,0]</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p><span class=\'code\'>colorMan.registerColor #myNewColor &quot;My Own Color&quot; &quot;Ugly Colors&quot; [1,0,0]</span></p>\n\
<p>This registers a new color, with the name <span class=\'code\'>#myNewColor</span> , with a default value of red. The category in the customization UI will be &quot;Ugly Colors&quot; and the name will be &quot;My Own Color&quot;.</p>\n\
<p>In other scripts you can access this color using:</p>\n\
<p><span class=\'code\'>colorMan.getColor #myNewColor</span></p>\n\
</blockquote>\n\
<p>Note: <span class=\'code\'>colorMan.registerColor</span> should be called from a script in the <em>\\stdplugs\\stdscripts</em> folder. These scripts are run when <strong>3ds Max</strong> starts, so the color will be available in the customization UI immediately. If the user customizes this color, its value will be saved in the <em>MaxColors.clr</em> file.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;colorMan.loadColorFile &lt;filename&gt;file \n\
</pre></div><p>This method will load the specified color file from the current UI directory. Returns <span class=\'code\'>true</span> if the load was successful, otherwise <span class=\'code\'>false</span> .</p>\n\
<p><span class=\'code\'>&lt;string&gt;file</span>: The filename of the color file to load.</p>\n\
<p>Note: The path specified must be relative to the <em>\\UI</em> directory.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;colorMan.saveColorFile &lt;filename&gt;file \n\
</pre></div><p>This method will save the specified color file from the current UI directory. Returns <span class=\'code\'>true</span> if the save process was successful, otherwise <span class=\'code\'>false</span> .</p>\n\
<p><span class=\'code\'>&lt;string&gt;file</span>: The filename of the color file to save.</p>\n\
<p>Note: The path specified must be relative to the <em>\\UI</em> directory.</p>\n\
<div class=\'codeBlock\'><pre>&lt;filename&gt;colorMan.getColorFile() \n\
</pre></div><p>Returns the file name of the current color file.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;colorMan.setColor &lt;string&gt;color &lt;point3&gt;colorValue \n\
</pre></div><p>Sets the color value of the previously registered color whose ID is passed. Returns <span class=\'code\'>true</span> if the color was set and <span class=\'code\'>false</span> if the id passed could not be found.</p>\n\
<p><span class=\'code\'>&lt;string&gt;color</span>: Specifies which color to set.</p>\n\
<p><span class=\'code\'>&lt;point3&gt;colorValue</span>: The color value to set.</p>\n\
<p>Predefined colors include:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">Name</th>\n\
<th align=\"left\">Description</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#background</span></td>\n\
<td align=\"left\">The background for all controls and buttons</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#text</span></td>\n\
<td align=\"left\">The text for all controls and buttons</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#activeCommand</span></td>\n\
<td align=\"left\">The color command mode buttons turn when pressed</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#hilight</span></td>\n\
<td align=\"left\">The highlight color for 3d controls</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#shadow</span></td>\n\
<td align=\"left\">The shadow color for 3d controls</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#window</span></td>\n\
<td align=\"left\">The background color for edit boxes, list boxes and other windows</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#activeCaption</span></td>\n\
<td align=\"left\">The color of the active caption</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#toolTipBackground</span></td>\n\
<td align=\"left\">The background for viewport tool tips</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#toolTipText</span></td>\n\
<td align=\"left\">The text color for viewport tool tips</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#hilightText</span></td>\n\
<td align=\"left\">The highlight color in the stack view drop-down list</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#windowText</span></td>\n\
<td align=\"left\">The color used in edit boxes, list boxes and other windows</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#itemHilight</span></td>\n\
<td align=\"left\">The item highlight color</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#subObjectColor</span></td>\n\
<td align=\"left\">The color used to highlight sub-object levels in StackView</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#3dDarkShadow</span></td>\n\
<td align=\"left\">the dark shadow color on 3d controls</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#3dLight</span></td>\n\
<td align=\"left\">the light color on 3d controls</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#appWorkspace</span></td>\n\
<td align=\"left\">the application workspace color</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#trackbarBg</span></td>\n\
<td align=\"left\">trackbar background</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#trackbarBgSel</span></td>\n\
<td align=\"left\">trackbar background for selected keys</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#trackbarText</span></td>\n\
<td align=\"left\">trackbar text</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#trackbarTicks</span></td>\n\
<td align=\"left\">trackbar ticks</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#trackbarKeys</span></td>\n\
<td align=\"left\">trackbar keys</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#trackbarSelKeys</span></td>\n\
<td align=\"left\">track bar selected keys</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#trackbarCursor</span></td>\n\
<td align=\"left\">track bar cursor</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#pressedButton</span></td>\n\
<td align=\"left\">background color for pressed buttons, like the transform constraints</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#timeSliderBg</span></td>\n\
<td align=\"left\">The background for the time slider bar.</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#viewportBorder</span></td>\n\
<td align=\"left\">The viewport border color</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#activeViewportBorder</span></td>\n\
<td align=\"left\">The active viewport border color</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#rollupTitleFace</span></td>\n\
<td align=\"left\">Rollout title background</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#rollupTitleText</span></td>\n\
<td align=\"left\">rollout title text</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#rollupTitleHilight</span></td>\n\
<td align=\"left\">rollout title 3d highlight</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#rollupTitleShadow</span></td>\n\
<td align=\"left\">rollout title 3d shadow</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#selectionRubberBand</span></td>\n\
<td align=\"left\">the selection marquee color</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#stackViewSelection</span></td>\n\
<td align=\"left\">the color of a selected item in stack view</td>\n\
</tr>\n\
</table>\n\
<div class=\'codeBlock\'><pre>&lt;color&gt;colorMan.getColor &lt;string&gt;color \n\
</pre></div><p>Returns the color value of the color whose ID is passed, or black (RGB(0,0,0)) if the <span class=\'code\'>Color</span> passed was not found.</p>\n\
<p><span class=\'code\'>&lt;string&gt;color</span>: Specifies which color to get.</p>\n\
<div class=\'codeBlock\'><pre>&lt;name&gt;colorMan.getName &lt;string&gt;color \n\
</pre></div><p>Returns the name of the color whose ID is passed.</p>\n\
<p><span class=\'code\'>&lt;string&gt;color</span>: The ID of the color.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;colorMan.getCategory &lt;string&gt;color \n\
</pre></div><p>Returns the category string of the color whose ID is passed.</p>\n\
<p><span class=\'code\'>&lt;string&gt;color</span>: The ID of the color.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;colorMan.setIconFolder &lt;filename&gt;folder \n\
</pre></div><p><span class=\'code\'>&lt;filename&gt;folder</span> - The name of the folder relative to the UI directory. Absolute pathnames are not supported.</p>\n\
<p>This method sets the folder from which all icons for the UI are loaded, and immediately reloads the icons from that folder.</p>\n\
<p>Note:</p>\n\
<p>If a folder with no icon files is loaded, all icons in the UI become blank, and no warning is issued.</p>\n\
<div class=\'codeBlock\'><pre>&lt;filename&gt;colorMan.getIconFolder() \n\
</pre></div><p>Returns the absolute pathname of the current icon folder. Note that <span class=\'code\'>getIconFolder</span> returns an absolute path while <span class=\'code\'>setIconFolder</span> accepts only relative paths.</p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;colorMan.getIconColorScale &lt;enum&gt;type &lt;enum&gt;which \n\
\n\
type enums: {#disabledIcon|#enabledIcon} \n\
which enums: {#saturationScale|#valueScale|#alphaScale} \n\
</pre></div><p>Returns a floating point value (in the range 0.0 to 1.0) that is one of the scale factors applied to the specified icon type. These scale values used to do image processing on the icons at start-up time.</p>\n\
<p><span class=\'code\'>&lt;enum&gt;type</span>: One of the following values:</p>\n\
<p><span class=\'code\'>#disabledIcon:</span> The disabled icons.</p>\n\
<p><span class=\'code\'>#enabledIcon:</span> The enabled icons.</p>\n\
<p><span class=\'code\'>&lt;enum&gt;which</span> : The icon color scale. One of the following values:</p>\n\
<p><span class=\'code\'>#saturationScale:</span> The saturation scale.</p>\n\
<p><span class=\'code\'>#valueScale:</span> The value scale.</p>\n\
<p><span class=\'code\'>#alphaScale:</span> The alpha scale.</p>\n\
<div class=\'codeBlock\'><pre>colorMan.setIconColorScale &lt;enum&gt;type &lt;enum&gt;which &lt;float&gt;value \n\
\n\
type enums: {#disabledIcon|#enabledIcon} \n\
which enums: {#saturationScale|#valueScale|#alphaScale} \n\
</pre></div><p>Sets the specified scale factor for the icon type passed. The color manager maintains the values for the <strong>3ds Max</strong> icon image processing system. Developers can set values to scale the saturation, value and transparency for enabled and disabled icon images using this method.</p>\n\
<p><span class=\'code\'>&lt;enum&gt;type</span>: The icon type. Can be one of the following values:</p>\n\
<p><span class=\'code\'>#disabledIcon:</span> The disabled icons.</p>\n\
<p><span class=\'code\'>#enabledIcon:</span> The enabled icons.</p>\n\
<p><span class=\'code\'>&lt;enum&gt;which</span>: The icon color scale. Can be one of the following values:</p>\n\
<p><span class=\'code\'>#saturationScale:</span> The saturation scale.</p>\n\
<p><span class=\'code\'>#valueScale:</span> The value scale.</p>\n\
<p><span class=\'code\'>#alphaScale:</span> The alpha scale.</p>\n\
<p><span class=\'code\'>&lt;float&gt;value</span>: The value runs from 0.0 to 100.0.</p>\n\
<div class=\'codeBlock\'><pre>colorMan.getIconColorInvert &lt;enum&gt;type \n\
\n\
type enums: {#disabledIcon|#enabledIcon} \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the invert flag is set for the specified icon type and <span class=\'code\'>false</span> if not set.</p>\n\
<p><span class=\'code\'>&lt;enum&gt;type</span>: The icon type. Can be one of the following values:</p>\n\
<p><span class=\'code\'>#disabledIcon:</span> The disabled icons.</p>\n\
<p><span class=\'code\'>#enabledIcon:</span> The enabled icons.</p>\n\
<div class=\'codeBlock\'><pre>colorMan.setIconColorInvert &lt;enum&gt;type &lt;boolean&gt;value \n\
\n\
type enums: {#disabledIcon|#enabledIcon} \n\
</pre></div><p>Sets the invert flag for the specified icon type to <span class=\'code\'>on</span> or <span class=\'code\'>off</span> .</p>\n\
<p><span class=\'code\'>&lt;enum&gt;type</span>: The icon type. One of the following values:</p>\n\
<p><strong><span class=\'code\'>#disabledIcon:</span></strong> The disabled icons.</p>\n\
<p><strong><span class=\'code\'>#enabledIcon:</span></strong> The enabled icons.</p>\n\
<p><span class=\'code\'>&lt;boolean&gt;value</span>: Pass true for inverted; false for not inverted.</p>\n\
<div class=\'codeBlock\'><pre>&lt;filename&gt;colorMan.getFileName() \n\
</pre></div><p>Returns the file name of the currently loaded color file.</p>\n\
<p>Note: This filename specifies an absolute path, even though <span class=\'code\'>loadColorFile</span> and <span class=\'code\'>saveColorFile</span> use relative paths.</p>\n\
<div class=\'codeBlock\'><pre>&lt;color&gt;colorMan.getDefaultColor &lt;string&gt;color \n\
</pre></div><p>Returns the default color for the specified ID. The default color is the value passed as defaultValue in registerColor, regardless if a <span class=\'code\'>SetColor()</span> has been done subsequently. This is used by the UI when the user presses &quot;Reset&quot; to reset a color to its default value.</p>\n\
<p><span class=\'code\'>&lt;string&gt;color</span>: The ID of the color.</p>\n\
<div class=\'codeBlock\'><pre>colorMan.repaintUI &lt;enum&gt;type \n\
\n\
type enums: {#repaintAll|#repaintTrackBar|#repaintTimeBar} \n\
</pre></div><p>This method allows you to issue a repaint of the user interface. This is equivalent to the Apply Colors Now button in the Customize dialog.</p>\n\
<p><span class=\'code\'>&lt;repaintType&gt;type</span>: The type of repaint you wish to issue; <span class=\'code\'>#repaintAll</span> , <span class=\'code\'>#repaintTrackBar</span> , <span class=\'code\'>#repaintTimeBar</span> .</p>\n\
<p>Here is a macroScript that turns the time slider and trackbar backgrounds blue:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` macroScript BlueBar category: &quot;Color&quot; tooltip: &quot;Blue Bar&quot; ( on execute do ( colorMan.setColor #timeSliderBg [0, 0, .6] colorMan.repaintUI #repaintTimeBar colorMan.setColor #trackbarBg [0, 0, .6] colorMan.repaintUI #repaintTrackBar ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note: All of <strong>3ds Max</strong>&#39;s standard icon BMP files must exist in that folder. If any of the standard files are missing, icons will appear blank in <strong>3ds Max</strong>&#39;s UI. All the icons files needed live in the <em>UI\\Icons</em> folder, which is the default icon folder.</p>\n\
<div class=\'codeBlock\'><pre>colorman.reInitIcons() \n\
</pre></div><p>Reloads all CUI icons from the icon files. This can be used to refresh the UI after adding new or editing existing icon bitmap files.</p>\n\
<p>Available in <strong>3ds Max 9 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;resolveIconFolder &lt;filename&gt;filename &lt;&amp;string&gt;path\n\
       path is Out parameter\n\
</pre></div><p>This method resolves the filename using the user icon path, then the system icon path, and then &lt;3dsmax.exe&gt;\\ui\\icons.</p>\n\
<p>If the file is found, fully qualified filename is placed in <span class=\'code\'>fullfilename</span> and the method returns true.</p>\n\
<p>If not found, the method returns false.</p>\n\
<p>Available in <strong>3ds Max 9 and higher</strong>.</p>\n\
<p>See also Class IcolorManager, in the SDK Help file accompanying this product</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";