var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: FileResolutionManager</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: FileResolutionManager</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-fileresolutionmanager\"></a></div>\n\
<blockquote>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Interfaces-1.html\' title=\'\'>Interfaces</a>&gt; <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-1.html\' title=\'\'>Core Interfaces</a> &gt; FileResolutionManager</p>\n\
</blockquote>\n\
<p>The <strong>FileResolutionManager Core Interface</strong> exposes the new system introduced in <strong>3ds Max 2010</strong> which is used internally by plug-ins to resolve the paths of their file assets.</p>\n\
<p>In releases prior to <strong>3ds Max 2010</strong>, the resolution of asset files was performed either locally in the plug-in code, or through one of several methods provided by <strong>3ds Max</strong>.</p>\n\
<p>Since <strong>3ds Max 2010</strong>, all resolutions of asset files must be performed through the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/Asset-Management/IObject-AssetUser.html\' title=\'\'>AssetUser object</a> that uses the new <strong>Asset File Resolution Manager</strong>. The File Resolution Manager can also be used for resolutions of Assets. All other resolution methods have been removed, and plug-ins should not implement their rules for resolving paths to a file asset. File resolution is based on the asset file name, asset type, and the file path to a scene that depends on the asset.</p>\n\
<p>The File Resolution Manager also implements a path caching mechanism. A set of methods has been exposed to allow plug-ins and scripts to control the cache enabled/disabled state, cache duration and also to provide a way to bypass the cache when getting the resolved path.</p>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>FileResolutionManager.searchScenePath : boolean : Read|Write\n\
</pre></div><p>Available in <strong>3ds Max 2018.4 and higher</strong>: Specifies whether or not the File Resolution Manager should search the scene file path for assets. This is a performance option - when false, this avoids searching the scene file folder; relative paths are still searched relative to the scene file. If this is false, it also implies the scene path subpaths are excluded. The default is true.</p>\n\
<div class=\'codeBlock\'><pre>FileResolutionManager.searchScenePathSubPaths : boolean : Read|Write\n\
</pre></div><p>Available in <strong>3ds Max 2018.4 and higher</strong>: Specifies whether or not the File Resolution Manager should search the subpaths of the scene file path for assets. This is a performance option - when false, this avoids searching of all subpaths below the scene file. Relative paths are still searched relative to the scene file, but excluding further subpaths. The default is true.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;FileResolutionManager.getFullFilePath &lt;&amp;string&gt;filePath &lt;enum&gt;assetType byPassCache:&lt;boolean&gt;   \n\
\n\
filePath is In and Out parameter     \n\
assetType enums: {#Other | #Bitmap | #XRef | #Photometric | #Animation | #VideoPost | #BatchRender | #ExternalLink | #RenderOutput | #PreRenderScript | #PostRenderScript | #Sound | #Container | #MaxCreationGraph}     \n\
byPassCache default value: false\n\
</pre></div><p>Returns the full file path by modifying the first argument passed by-reference. The second argument determines the asset type the file belongs to.</p>\n\
<p>If <span class=\'code\'>byPassCache:</span> is passed as true, the cache will not be used. If it is passed as false or not specified, the cache will be used.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` theFilename = &quot;Simple_Stone_Mtl_Marble_bump.jpg&quot; --&gt; &quot;Simple_Stone_Mtl_Marble_bump.jpg&quot;</p>\n\
<p>FileResolutionManager.getFullFilePath &amp;theFilename #Bitmap --&gt; true</p>\n\
<p>theFilename --&gt; &quot;C:\\Program Files\\Autodesk\\3ds Max 2010\\Maps\\adskMtl\\Simple_Stone_Mtl_Marble_bump.jpg&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;FileResolutionManager.getFullFilePath_assetID &lt;string&gt;assetID &lt;&amp;string&gt;filePath byPassCache:&lt;boolean&gt; \n\
\n\
filePath is In and Out parameter \n\
byPassCache default value: false \n\
</pre></div><p>Returns the full file path by modifying the second argument passed by-reference. The first argument defines the assetID to search for.</p>\n\
<p>If <span class=\'code\'>byPassCache:</span> is passed as true, the cache will not be used. If it is passed as false or not specified, the cache will be used.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` theID = AssetManager.GetAssetID &quot;Simple_Stone_Mtl_Marble_bump.jpg&quot; #Bitmap --&gt; &quot;{7477A3A4-0304-47AC-8427-6B490673231A}&quot;</p>\n\
<p>FileResolutionManager.getFullFilePath_assetID theID &amp;filePath --&gt; true</p>\n\
<p>filePath --&gt; &quot;C:\\Program Files\\Autodesk\\3ds Max 2010\\Maps\\adskMtl\\Simple_Stone_Mtl_Marble_bump.jpg&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;FileResolutionManager.doGetUniversalFileName &lt;&amp;string&gt;aFullFilePath \n\
\n\
aFullFilePath is In and Out parameter \n\
</pre></div><p>Returns the universal file name by modifying the by-reference argument.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;FileResolutionManager.GetNumAssetTypes() \n\
</pre></div><p>Returns the number of asset types.</p>\n\
<p>Available in <strong>3ds Max 2011 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;FileResolutionManager.GetAssetTypeString &lt;enum&gt;assetType \n\
\n\
assetType enums: {#Other | #Bitmap | #XRef | #Photometric | #Animation | #VideoPost | #BatchRender | #ExternalLink | #RenderOutput | #PreRenderScript | #PostRenderScript | #Sound | #Container | #MaxCreationGraph} \n\
</pre></div><p>Returns the asset type string corresponding to the provided asset type name.</p>\n\
<p>Available in <strong>3ds Max 2011 and higher</strong>.</p>\n\
<div class=\'section\'><a id=\"cache\"></a><h2 id=\"cache\">Cache</h2></div>\n\
<p>File Resolution results are being cached, but the cached results expire after a specified maximum cache duration period.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;FileResolutionManager.EnableCaching() \n\
</pre></div><p>Turns the cache on.</p>\n\
<p>The cache is on by default.</p>\n\
<p>File resolutions will be cached and the cached results returns if the same file has to be resolved again sooner than the maximum cache duration (see below).</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;FileResolutionManager.DisableCaching() \n\
</pre></div><p>Turns the cache off.</p>\n\
<p>Files will always be resolved without using the cache at all.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;FileResolutionManager.IsCachingEnabled() \n\
</pre></div><p>Returns true if the cache is on, false if it is off.</p>\n\
<p>The cache is on by default.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;FileResolutionManager.GetMaximumCacheDuration() \n\
</pre></div><p>Returns the maximum cache duration in milliseconds. Default is 1000.</p>\n\
<p>If a resolution has been cached and a new resolution of the same file is requested later than the time of the previous resolution plus the maximum cache duration, the cache result will be ignored and a new resolution will be performed.</p>\n\
<p>If the time passed since the last resolution is less than the maximum cache duration, the cached result will be returned.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;FileResolutionManager.SetMaximumCacheDuration &lt;integer&gt;newMaxDuration \n\
</pre></div><p>Sets the maximum cache duration.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer64&gt;FileResolutionManager.GetNumCacheHit() \n\
</pre></div><p>Returns the number of cache hits.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";