var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: IBitmapPager</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: IBitmapPager</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-ibitmappager\"></a></div>\n\
<p>The <strong>IBitmapPager Core Interface</strong> introduced in <strong>3ds Max 2010</strong> exposes settings related to the Bitmap Pager which has been extended to support an Automatic Limit Mode.</p>\n\
<p>The Bitmap Pager UI has been completely removed from the Customize &gt; Preferences &gt; Render tab and is now controllable only through MAXScript.</p>\n\
<blockquote>\n\
<p>Warning: The Bitmap Pager <strong>reduces the memory footprint</strong> of the renderer in order to <strong>improve system stability</strong> by minimizing the chances for out-of-memory problems, especially when rendering to a very large output image size (4K and higher). However, the Pager operates by <strong>swapping memory to disk</strong>, and therefore comes at a <strong>cost to performance</strong>. <strong>If the memory footprint is not a concern</strong>, for example on 64 bit OS running a 64 bit build of 3ds Max with large amounts of memory, <strong>the pager may be disabled</strong> using the following MAXScript call to improve rendering performance:</p>\n\
<p><span class=\'code\'>IBitmapPager.enabled = false</span></p>\n\
<p>This value <strong>does not take effect</strong> until the scene is <strong>reloaded</strong>!The value can be modified superficially at any time. The value is written to the file upon file save. However, disk paging never becomes enabled or disabled except when a scene is loaded, so <strong>changes to the value do not take effect unless the scene is saved and then reloaded</strong>!|</p>\n\
</blockquote>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>IBitmapPager.enabled : boolean : Read|Write   \n\
</pre></div><p>When set to true the Bitmap Pager is enabled.</p>\n\
<p>When set to false, the Bitmap Pager is disabled.</p>\n\
<p>Defaults to true.</p>\n\
<p>See the above <strong>WARNING</strong> for more details!</p>\n\
<div class=\'codeBlock\'><pre>IBitmapPager.pageFilePath : filename : Read|Write \n\
</pre></div><p>Get/set the Page File Path. Defaults to the Page File path specified by the Customize&gt; Configure System Paths &gt; Page File entry, also returned by <span class=\'code\'>getDir #pagefile</span></p>\n\
<div class=\'codeBlock\'><pre>IBitmapPager.memoryPadding_percent : float : Read|Write|Validated by Range: 0.0 to 1.0 \n\
</pre></div><p>Get/Set the Memory Padding Percentage as a value in the range from 0.0 to 1.0. This is a percentage (divided by 100) of available memory. Default is 0.2 (20%).</p>\n\
<div class=\'codeBlock\'><pre>IBitmapPager.memoryLimit_percent : float : Read|Write|Validated by Range: 0.0 to 1.0 \n\
</pre></div><p>Get/Set the Memory Limit Percentage as a value in the range from 0.0 to 1.0. This is a percentage (divided by 100) of the Padded Memory. Default is 0.1.</p>\n\
<div class=\'codeBlock\'><pre>IBitmapPager.memoryLimitAutoMode : boolean : Read|Write \n\
</pre></div><p>When set to true, the memory Limit will be calculated automatically using a heuristic method described further on this page. Default is true.</p>\n\
<div class=\'codeBlock\'><pre>IBitmapPager.memoryLimit_megabytes : integer : Read \n\
</pre></div><p>Get the Memory Limit in Megabytes.</p>\n\
<div class=\'codeBlock\'><pre>IBitmapPager.memoryUsedForPager_megabytes : integer : Read \n\
</pre></div><p>Get the Pager Used Memory in Megabytes.</p>\n\
<div class=\'codeBlock\'><pre>IBitmapPager.memoryTotalForPager_megabytes : integer : Read \n\
</pre></div><p>Get the Pager Total Memory in Megabytes.</p>\n\
<div class=\'codeBlock\'><pre>IBitmapPager.memoryPadding_megabytes : integer : Read \n\
</pre></div><p>Get the Padding Memory in Megabytes.</p>\n\
<div class=\'codeBlock\'><pre>IBitmapPager.memoryAvailablePadded_megabytes : integer : Read \n\
</pre></div><p>Get the Available Padded Memory in Megabytes.</p>\n\
<div class=\'section\'><a id=\"auto-mode-heuristic---bitmap-pager\"></a><h2 id=\"auto-mode-heuristic---bitmap-pager\">Auto Mode Heuristic - Bitmap Pager:</h2></div>\n\
<ul>\n\
<li><p>The amount of usable available memory is computed first. This is the total amount that can be allocated by the pager, minus a padding amount. The padding is 20% by default.</p></li>\n\
<li><p>If the system is not rendering, then the limit is set to 50% of usable memory. For example, if 1GB of memory is free, 20% percent is subtracted to yield 800MB, and the pager uses 50%, or 400MB.</p></li>\n\
<li><p>If the system is rendering, the pager makes a compromise between its own memory limit, and memory set aside for the renderer. The pager&#39;s goal is to have enough memory for all its bitmaps, but not more. The renderer&#39;s goal is unknown - there is no method to gauge the renderer&#39;s memory needs, so this goal is assumed equal to all usable memory. These two goals are added together, obtaining a goal for the entire system. The pager takes an amount of memory equal to the ratio of its own goal to the total. For example, with 1GB of memory free (800MB considered usable), if the total size of all bitmaps is 400MB, then the pager and renderer goals are 400MB and 800MB respectively, for a system total of 1200MB. The ratio of 400MB to 1200MB is 1/3, so the pager&#39;s limit is set to 1/3 of the usable 800MB, or 266MB.</p></li>\n\
<li><p>Two adjustments are made.</p>\n\
<ul>\n\
<li><p>First adjustment: During render, if the pager&#39;s goal is less than 25% of usable memory, then the pager abandons self-restraint and sets the limit to equal its entire goal. For example, if all bitmaps fit within 18% of usable memory, the prior formula would indicate a limit of 15%, but the pager sets the limit to the full 18%.</p></li>\n\
<li><p>Second adjustment: During render, the pager never sets a limit less than 10%, or more than 50% of usable memory.</p></li>\n\
</ul></li>\n\
<li><p>Internally, the Auto Mode adjustment happens at the following events: NOTIFY_SYSTEM_STARTUP, NOTIFY_SYSTEM_POST_RESET, NOTIFY_FILE_POST_OPEN, NOTIFY_SYSTEM_POST_NEW, NOTIFY_PRE_RENDER, NOTIFY_POST_RENDER.</p></li>\n\
</ul>\n\
<div class=\'section\'><a id=\"maxscript-rendering-and-bitmap-pager-improvements\"></a><h2 id=\"maxscript-rendering-and-bitmap-pager-improvements\">MAXScript Rendering And Bitmap Pager Improvements</h2></div>\n\
<p>In releases prior to <strong>3ds Max 2011</strong>, if a MAXScript performed multiple <span class=\'code\'>render()</span> calls, the result of previous renders remained in memory and were not released automatically. The user had to invoke a manual garbage collection to release them. This wasted memory and, because of the Bitmap Pager, disk space.</p>\n\
<p>This issue has been fixed in <strong>3ds Max 2011</strong> by performing periodic garbage collections automatically after rendering.</p>\n\
<p>When rendering through MAXScript, the system now measures any increase in memory usage due to bitmaps. The system sums this value from one render to the next, performing garbage collection whenever the total exceeds a certain threshold. Currently the threshold is the MAXScript Heap Size, defined in the Customize-&gt;Preferences dialog, MaxScript tab. Thus a garbage collection is performed following multiple render() calls, where the number of calls required depends on the size of the rendering - larger renders trigger more frequent garbage collection.</p>\n\
<p>Garbage collection will free any memory and disk space allocated by previous render() calls, unless the result of those calls is stored in a variable. For example, calling myImage=render() means the rendered image is held by the variable myImage and will not be collected until a different value is assigned to myImage. For this reason, MAXScript users should be careful to avoid leaving large images assigned to variables, unless an image is needed later. To release an image assigned to a variable, set the variable to undefined, for example by calling myImage=undefined.</p>\n\
<p>It is still possible to run out of disk space. If the disk is full, the new handling does not necessarily perform a garbage collection, so renders may still fail. The new handling only reduces this possibility by placing a low bound on the amount of disk space wasted through MAXScript renders.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";