var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: InstanceMgr</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: InstanceMgr</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-instancemgr\"></a></div>\n\
<p>The <strong>Instance Manager Core Interface</strong> provides access to properties and methods related to Instanced Nodes. It provides means for collecting instances, managing material propagation to instances, making instanced modifiers, controllers and nodes unique etc.</p>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>InstanceMgr.autoMtlPropagation : boolean : Read|Write    \n\
</pre></div><p>When set to <span class=\'code\'>True</span> , Materials assigned to an object will propagate automatically to all its instances.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;InstanceMgr.GetInstances &lt;node&gt;source &lt;&amp;node array&gt;instances   \n\
\n\
instances is Out parameter \n\
</pre></div><p>Returns the number of instances of the specified source node and the list of all instances in the by-reference Out parameter.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` tp = Teapot() --create a teapot --&gt; $Teapot:Teapot01 @ [0.000000,0.000000,0.000000] tp1 = instance tp --instance the teapot --&gt; $Teapot:Teapot02 @ [0.000000,0.000000,0.000000] tp2 = instance tp --instance it again --&gt; $Teapot:Teapot03 @ [0.000000,0.000000,0.000000] tp3 = copy tp --copy the teapot --&gt; \\(Teapot:Teapot04 @ [0.000000,0.000000,0.000000]  InstanceMgr.GetInstances tp &amp;instances -- get the instances of the original  --&gt; 3  instances --show the returned array- all instances are there, the copy isn&#39;t  --&gt; #(\\)Teapot:Teapot03 @ [0.000000,0.000000,0.000000], $Teapot:Teapot02 @ [0.000000,0.000000,0.000000], \\(Teapot:Teapot01 @ [0.000000,0.000000,0.000000])  InstanceMgr.GetInstances tp3 &amp;instances --get the instances of the copy  --&gt; 1  instances -- show the returned array - the copy is the only object in it  --&gt; #(\\)Teapot:Teapot04 @ [0.000000,0.000000,0.000000])</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note: This function also considers objects to be instances when they share the same styles or categories as defined in AutoCAD Architecture, or the same families and types as defined in Autodesk Revit, when a scene is imported or linked from a DWG file. In this case, the function works like the <strong>Select Similar</strong> command. In this case, to select only 3ds Max instances, use:</p>\n\
<div class=\'codeBlock\'><pre>-- Note that this code works only if the selection set ($) is not empty\n\
InstanceMgr.GetInstances $ &amp;rptInstances \n\
trueInstances = for n in rptInstances where (areNodesInstances $ n) collect n\n\
&lt;integer&gt; InstanceMgr.SetMtlOnInstances &lt;node&gt;source &lt;material&gt;newMtl \n\
</pre></div><p>Propagates the supplied new material to all instances of the specified source node. Normally, instances can have independent materials. Using this method, all instances can be updated to use the same material. Returns the number of instances.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` tp = Teapot() --create a teapot --&gt; $Teapot:Teapot01 @ [0.000000,0.000000,0.000000] tp.material = standard diffuse:(color 255 0 0) --assign a red material --&gt; Standardmaterial:Standard tp1 = instance tp --create an instance --&gt; $Teapot:Teapot02 @ [0.000000,0.000000,0.000000] tp1.pos = [100,0,0] --move the instance --&gt; [100,0,0] tp1.material = standard diffuse:(color 0 255 0) --assign a green material --&gt; Standardmaterial:Standard tp2 = instance tp --create another instance --&gt; $Teapot:Teapot03 @ [0.000000,0.000000,0.000000] tp2.pos = [200,0,0] --move the instance --&gt; [200,0,0] tp2.material = standard diffuse:(color 0 0 255) --assign a blue material --&gt; Standardmaterial:Standard newMaterial = standard diffuse:(color 250 255 255) --create a white material --&gt; Standardmaterial:Standard</p>\n\
<p>InstanceMgr.SetMtlOnInstances tp newMaterial --assign to all instances 3 --3 object affected!</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;InstanceMgr.MakeObjectsUnique &lt;node array&gt;nodes &lt;enum&gt;multiNodeOption\n\
       multiNodeOption enums: {#prompt|#individual|#group}\n\
</pre></div><p>Makes the objects passed by-reference unique. Returns <span class=\'code\'>True</span> on success.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` tp = Teapot() --create a teapot --&gt; $Teapot:Teapot01 @ [0.000000,0.000000,0.000000] tp1 = instance tp --instance the trapot --&gt; $Teapot:Teapot02 @ [0.000000,0.000000,0.000000] tp2 = instance tp --instance it once again --&gt; $Teapot:Teapot03 @ [0.000000,0.000000,0.000000] InstanceMgr.GetInstances tp &amp;instances --get all instances --&gt; 3 --make the instances unique. Show a prompt to confirm the operation InstanceMgr.MakeObjectsUnique &amp;instances #prompt --&gt; true --Check that every object is an instance of itself only. InstanceMgr.GetInstances tp &amp;instances --&gt; 1 InstanceMgr.GetInstances tp1 &amp;instances --&gt; 1 InstanceMgr.GetInstances tp2 &amp;instances --&gt; 1</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;InstanceMgr.CanMakeObjectsUnique &lt;node array&gt;nodes\n\
</pre></div><p>Returns <span class=\'code\'>True</span> when the specified nodes can be made unique, <span class=\'code\'>False</span> otherwise.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` tp = Teapot() --create a teapot --&gt; $Teapot:Teapot01 @ [0.000000,0.000000,0.000000] tp1 = instance tp --instance the teapot --&gt; $Teapot:Teapot02 @ [0.000000,0.000000,0.000000] tp2 = copy tp --copy the teapot --&gt; $Teapot:Teapot03 @ [0.000000,0.000000,0.000000] --Check if the two instances can be made unique - they can InstanceMgr.CanMakeObjectsUnique #(tp,tp1) --&gt; True --Check the original and the copy - not instances, cannot be made unique InstanceMgr.CanMakeObjectsUnique #(tp,tp2) --&gt; False</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;InstanceMgr.MakeModifiersUnique &lt;node array&gt;nodes &lt;maxObject array&gt;modifiers &lt;enum&gt;multiNodeOption\n\
       multiNodeOption enums: {#prompt|#individual|#group}\n\
</pre></div><p>Makes the specified modifiers of the supplied nodes unique. Returns <span class=\'code\'>True</span> on success.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;InstanceMgr.CanMakeModifiersUnique &lt;node array&gt;nodes &lt;maxObject array&gt;modifiers\n\
</pre></div><p>Returns <span class=\'code\'>True</span> when the specified modifiers of the supplied nodes can be made unique, <span class=\'code\'>False</span> otherwise.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;InstanceMgr.MakeControllersUnique &lt;node array&gt;nodes &lt;maxObject array&gt;controllers &lt;enum&gt;multiNodeOption\n\
       multiNodeOption enums: {#prompt|#individual|#group}\n\
</pre></div><p>Makes the specified controllers of the supplied nodes unique. Returns <span class=\'code\'>True</span> on success.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;InstanceMgr.CanMakeControllersUnique &lt;node array&gt;nodes &lt;maxObject array&gt;controllers\n\
</pre></div><p>Returns <span class=\'code\'>True</span> when the specified controllers of the supplied nodes can be made unique, <span class=\'code\'>False</span> otherwise.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";