var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: LockedTracksMan</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: LockedTracksMan</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-lockedtracksman\"></a></div>\n\
<p>The <strong>LockedTracksMan Core Interface</strong> available in <strong>3ds Max 2010 and higher</strong> exposes properties and methods related to animation track locking.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-C7E1A4BD-EE82-4B3D-8752-1112A73D9C1C-low.gif\' title=\'\'></div>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>LockedTracksMan.unLockOverride : boolean : Read|Write    \n\
</pre></div><p>Get/Set the state of the Override All Locks option.</p>\n\
<p>When set to true, the locked state of locked tracks will be temporarily overridden and their values can be changed.</p>\n\
<p>When set to false, the values of locked tracks cannot be changed.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'section\'><a id=\"get-and-set-locks\"></a><h2 id=\"get-and-set-locks\">Get and Set Locks</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;LockedTracksMan.SetLocks &lt;boolean&gt;lock &lt;&amp;maxObject array&gt;anims &lt;&amp;maxObject array&gt;clients &lt;&amp;index array&gt;subNums &lt;boolean&gt;includeChildren    \n\
\n\
anims is In and Out parameter    \n\
clients is In and Out parameter      \n\
subNums is In and Out parameter   \n\
</pre></div><p>Sets the locks of the specified tracks to the Boolean value supplied as first argument.</p>\n\
<p><span class=\'code\'>anims</span> is the array of subAnims</p>\n\
<p><span class=\'code\'>clients</span> is the array of parent controllers of the subAnims.</p>\n\
<p><span class=\'code\'>subNums</span> is the array of indices of the subAnims within their clients&#39; children hierarchies.</p>\n\
<p>When <span class=\'code\'>includeChildren</span> is passed as true, children tracks will also be locked/unlocked.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` trackview.open &quot;Trackview&quot; -- open trackview --Initialize three arrays to pass to the setLocks() method theAnims = #() theClients = #() theSubNums = #() --Loop through all selected tracks in the current TrackView for i in 1 to trackviews.current.numSelTracks() do ( --grab the parent of the current selected track local theParent = trackviews.current.getParentOfSelected i --if the parent is valid, if theParent != undefined do ( append theClients theParent --collecttheparrent --grab the sub-number of the subAnim relatively to the parent local theSubnum = trackviews.current.getSelectedSubNum i --get the subAnim track with that index from the parent local theSubanim = getsubAnim theParent theSubnum append theAnims theSubanim -- collectthe subanim append theSubNums theSubnum -- collect the index )--end if parent not undefined )--end i loop --Finally, set the locks of all selected tracks lockedTracksMan.setLocks true theAnims theClients theSubNums false</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;LockedTracksMan.  ToggleLocks &lt;&amp;maxObject array&gt;anims &lt;&amp;maxObject array&gt;clients &lt;&amp;index array&gt;subNums &lt;boolean&gt;includeChildren \n\
\n\
anims is In and Out parameter \n\
clients is In and Out parameter \n\
subNums is In and Out parameter \n\
</pre></div><p>Toggles the locked state of the given subAnims.</p>\n\
<p><span class=\'code\'>anims</span> is an array of the SubAnims to toggle.</p>\n\
<p><span class=\'code\'>clients</span> is an array of the parents of the SubAnims.</p>\n\
<p><span class=\'code\'>subNums</span> is an array of the indices of the SubAnims within the children hierarchy of their parents.</p>\n\
<p>If <span class=\'code\'>includeChildren</span> is passed as true, children of the track will also be toggled.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;LockedTracksMan.GetLocked &lt;maxObject&gt;anim &lt;maxObject&gt;client &lt;index&gt;subNum &lt;boolean&gt;checkOverride \n\
</pre></div><p>Returns the locked state of the given track.</p>\n\
<p><span class=\'code\'>anim</span> is the subAnim</p>\n\
<p><span class=\'code\'>client</span> is the parent controller of the subAnim.</p>\n\
<p><span class=\'code\'>subNum</span> is the index of the subAnim within the client&#39;s children hierarchy</p>\n\
<p>If <span class=\'code\'>checkOverride</span> is passed as true, the state of the Lock Overrides will also be respected, returning locked tracks as unlocked if an Override is active.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` --Loop through all selected tracks in the current TrackView for i in 1 to trackviews.current.numSelTracks() do ( --grab the parent of the current selected track local theParent = trackviews.current.getParentOfSelected i --if the parent is valid, if theParent != undefined do ( --grab the sub-number of the subAnim relatively to the parent local theSubnum = trackviews.current.getSelectedSubNum i --get the subAnim track with that index from the parent local theSubanim = getsubAnim theParent theSubnum --Check if the track is locked, unlocked or locked but overridden --and format the information about the track and its locked state: if lockedTracksMan.getlocked theSubanim theParent theSubnum true then format &quot;LOCKED: % Parent:% Subnum:% \\n&quot; theSubanim theParent theSubnum else format &quot;Not Locked: % Parent:% Subnum:% \\n&quot; theSubanim theParent theSubnum )--end if parent not undefined )--end i loop</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;UnlockChildren &lt;&amp;maxObject array&gt;anims &lt;&amp;maxObject array&gt;clients &lt;&amp;index array&gt;subNums \n\
\n\
anims is In and Out parameter \n\
clients is In and Out parameter \n\
subNums is In and Out parameter \n\
</pre></div><p>Unlocks the children of the specified controllers.</p>\n\
<p>Available in <strong>3ds Max 2011 and higher</strong>.</p>\n\
<div class=\'section\'><a id=\"checking-locks\"></a><h2 id=\"checking-locks\">Checking Locks</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;LockedTracksMan.IsLockable &lt;maxObject&gt;anim &lt;maxObject&gt;client &lt;index&gt;subNum \n\
</pre></div><p>Returns true if the given subAnim can be locked, false if it cannot be locked.</p>\n\
<p><span class=\'code\'>anim</span> is the subAnim to check.</p>\n\
<p><span class=\'code\'>client</span> is the parent controller of the subAnim to check.</p>\n\
<p><span class=\'code\'>subNum</span> is the index of the subAnim within the client&#39;s children hierarchy</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;LockedTracksMan.FindLockedAnims &lt;boolean&gt;locked &lt;boolean&gt;checkOverride &lt;maxObject&gt;refTarget &lt;&amp;maxObject array&gt;anims &lt;&amp;maxObject array&gt;clients &lt;&amp;index array&gt;subNums \n\
\n\
anims is In and Out parameter \n\
clients is In and Out parameter \n\
subNums is In and Out parameter \n\
</pre></div><p>Returns the tracks with the given locked state.</p>\n\
<p><span class=\'code\'>locked</span> is the state to search for - either true or false.</p>\n\
<p><span class=\'code\'>checkOverride</span> defined whether to take into account any Overrides or not.</p>\n\
<p><span class=\'code\'>refTarget</span> is the root maxObject to scan for locked/unlocked tracks.</p>\n\
<p><span class=\'code\'>anims</span> is a by-reference array to populated with the SubAnims</p>\n\
<p><span class=\'code\'>clients</span> is a by-reference array to be populated with the parents of the SubAnims</p>\n\
<p><span class=\'code\'>subNums</span> is a by-reference array to be populated with the indices of the SubAnims within the children hierarchy of their parents.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` b=box() ( --Find all unlocked tracks of Box01 Anims = #() Clients = #() SubNums = #() --Collect the unlocked tracks without taking Overrides into account: LockedTracksMan.FindLockedAnims false false $Box01 &amp;Anims &amp;Clients &amp;SubNums</p>\n\
<p>for i = 1 to Anims.count do format &quot;% % %\\n&quot; Anims[i] Clients[i] SubNums[i] )</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` Controller:Position_Rotation_Scale undefined 1 Controller:Position_XYZ Controller:Position_Rotation_Scale 1 Controller:Bezier_Float Controller:Position_XYZ 1 Controller:Bezier_Float Controller:Position_XYZ 2 Controller:Bezier_Float Controller:Position_XYZ 3 Controller:Euler_XYZ Controller:Position_Rotation_Scale 2 Controller:Bezier_Float Controller:Euler_XYZ 1 Controller:Bezier_Float Controller:Euler_XYZ 2 Controller:Bezier_Float Controller:Euler_XYZ 3 Controller:Bezier_Scale Controller:Position_Rotation_Scale 3</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;LockedTracksMan.IsAnimOverrideUnlocked &lt;maxObject&gt;anim \n\
</pre></div><p>Returns true if the given subAnim track is unlocked via an Override, false otherwise. It will return true if an Override is active even if the subAnim is not locked.</p>\n\
<div class=\'section\'><a id=\"uber-override-stack\"></a><h2 id=\"uber-override-stack\">Uber-Override Stack</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;LockedTracksMan.PushUberUnLockOverride() \n\
</pre></div><p>Pushes an Override on the Uber-Unlock Override stack.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;LockedTracksMan.PopUberUnLockOverride() \n\
</pre></div><p>Pops an Override from the Uber-Unlock Override stack.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;LockedTracksMan.GetUberUnLockOverride() \n\
</pre></div><p>Returns true if the Uber-Unlock Overrides stack contains any Overrides, false if there are no Overrides on the stack.</p>\n\
<div class=\'section\'><a id=\"expose-ui\"></a><h2 id=\"expose-ui\">Expose UI</h2></div>\n\
<div class=\'codeBlock\'><pre> &lt;void&gt;SetExposedUI &lt;boolean&gt;expose &lt;&amp;maxObject array&gt;anims \n\
\n\
anims is In and Out parameter \n\
</pre></div><p>Sets the Exposed UI state of the anims supplied by the second argument to the Boolean value provided by the first argument.</p>\n\
<p>Available in <strong>3ds Max 2011 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;GetExposedUI &lt;maxObject&gt;anim \n\
</pre></div><p>Returns the Exposed UI state of the controller supplied as argument.</p>\n\
<p>Available in <strong>3ds Max 2011 and higher</strong>.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";