var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: MemStream</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: MemStream</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-memstream\"></a></div>\n\
<p>The <strong>MemStream Core</strong> Interface was first introduced in <strong>gMax</strong> 1.0 and is available in MAXScript since <strong>3ds Max 5</strong>.</p>\n\
<p>It provides fast stream parsing by loading the entire file into memory.</p>\n\
<p>The <span class=\'code\'>memStreamMgr</span> and <span class=\'code\'>memStream</span> interfaces provide a large set of methods for parsing the stream.</p>\n\
<div class=\'section\'><a id=\"memstreammgr---interface\"></a><h3 id=\"memstreammgr---interface\">memStreamMgr - Interface</h3></div>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;Interface&gt;MemStreamMgr.openFile &lt;filename&gt;fname favor_type:&lt;enum&gt; code_page:&lt;integer&gt;\n\
\n\
favor_type enums: {#FAVOR_ACP|#FAVOR_UTF8}\n\
favor_type default value: #FAVOR_ACP\n\
code_page default value: 0\n\
\n\
\n\
</pre></div><p>Returns a memStream interface where the content of the specified file is the input stream to be processed.</p>\n\
<p>If the file cannot be opened, a value of undefined is returned.</p>\n\
<p>The optional keyword arguments <span class=\'code\'>favor_type:</span> and <span class=\'code\'>code_page:</span> available in <strong>3ds Max 2013 and higher</strong> provide control over the stream Encoding.</p>\n\
<p>ACP stands for ANSI Code Page</p>\n\
<p>UTF8 stands for UCS Transformation Format - 8 bit, where UCS stands for Universal Character Set.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Interface&gt;MemStreamMgr.openString &lt;filename&gt;string      \n\
</pre></div><p>Returns a memStream interface where the content of the string is the input stream to be processed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;MemStreamMgr.close &lt;Interface&gt;memStream   \n\
</pre></div><p>Closes the input stream for the memStream, freeing the memory associated with this stream.</p>\n\
<div class=\'section\'><a id=\"memstream---interface\"></a><h3 id=\"memstream---interface\">memStream - Interface</h3></div>\n\
<p>The memStream Interface provides methods for parsing the input stream. This interface is returned from the <span class=\'code\'>memStreamMgr.openString()</span> and <span class=\'code\'>memStreamMgr.openFile()</span> methods.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;filename&gt;&lt;Interface:MemStream&gt;.getFileName() \n\
</pre></div><p>Returns the file name that the memStream was created from. Returns &quot;&quot; if the interface was created using memStreamMgr.openString().</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;Interface:MemStream&gt;.skipSpace() \n\
</pre></div><p>Skips leading whitespace characters (space, tab, and newlines) starting at the current stream cursor position. Following this call the stream cursor position will be at a non-whitespace character, or at the end of the stream.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;&lt;Interface:MemStream&gt;.readChar() \n\
</pre></div><p>Reads a single character from the stream, returning it as a string.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;&lt;Interface:MemStream&gt;.peekChar() \n\
</pre></div><p>Reads a single character from the stream, returning it as a string. Does not increment the stream cursor position.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;&lt;Interface:MemStream&gt;.readLine() \n\
</pre></div><p>Reads all characters from the current stream cursor position until a newline and returns it as a string.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;&lt;Interface:MemStream&gt;.readToken() \n\
</pre></div><p>Reads a token from the given stream and returns it as a string. A token is defined by a sequence of characters surrounded by whitespace or the stream start or end. Leading whitespace and one line &quot;//&quot; style comments are automatically skipped.</p>\n\
<p>The maximum allowed length of the returned string is 5120 characters. If a token larger than this length is read, the string returned contains the first 5120 characters of the token. The stream cursor position will be at the next character.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;&lt;Interface:MemStream&gt;.peekToken() \n\
</pre></div><p>Same as <span class=\'code\'>&lt;memStream&gt;.readToken()</span> except it does not increment the stream cursor position.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;Interface:MemStream&gt;.unReadToken() \n\
</pre></div><p>Resets the stream cursor position to right before the last readToken operation.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;&lt;Interface:MemStream&gt;.readBlock &lt;string&gt;open &lt;string&gt;close \n\
</pre></div><p>Reads a block of tokens from the &#39;open&#39; token until the &#39;close&#39; token, automatically skipping nested open/close token pairs, and returns the contents as a string. This string will contain the initial &#39;open&#39; token and the final &#39;close&#39; token. The initial &#39;open&#39; token must be the next token in the input stream. If it is not, a value of ’r;undefined’ will be returned.</p>\n\
<p>Following this call, the stream cursor position will be at the beginning of the next token, or at the end of the stream if there are no more tokens following the &#39;close&#39; token. The comparison of tokens against the &#39;open&#39; and &#39;close&#39; tokens is case-insensitive.</p>\n\
<p>Note:</p>\n\
<p>The open and close strings represent tokens, and not character strings.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` b2=memStreamMgr.openstring &quot;{aaaaa}&quot; b2.readblock &quot;{&quot; &quot;}&quot;</p>\n\
<p>```</p>\n\
<p>will return undefined, because the &#39;{&#39; and &#39;}&#39; are not surrounded by whitespace, and so are not found as tokens (the entire content of the memStream is a single token).</p>\n\
</blockquote>\n\
<p>If the &#39;open&#39; token is not the next token in the input stream, a value of &#39;undefined&#39; will be returned and the stream cursor position will be unchanged.</p>\n\
<p>If the &#39;open&#39; token is the next token in the input stream, but the &#39;close&#39; token is not found, returns a string starting at the open token and ending at the end of stream -1 character.</p>\n\
<p>The maximum allowed length of the block is 5120 characters. If a block is found, but is larger than this length, a value of &#39;undefined&#39; is returned. However, the stream cursor position will be at the end of the block.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;Interface:MemStream&gt;.skipBlock &lt;string&gt;open &lt;string&gt;close \n\
</pre></div><p>Same as readBlock except does not return the block of tokens (this is a little faster).</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;&lt;Interface:MemStream&gt;.pos() \n\
</pre></div><p>Returns the current stream cursor position.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;Interface:MemStream&gt;.seek &lt;integer&gt;offset &lt;enum&gt;origin \n\
\n\
origin enums: {#seek_set|#seek_cur|#seek_end} \n\
</pre></div><p>Moves the stream cursor position &#39;offset&#39; number of characters from the base specified.</p>\n\
<div class=\'codeBlock\'><pre>#seek_set-- start of file\n\
#seek_cur-- current file position\n\
#seek_end-- end of file (works with negative offset values)\n\
&lt;integer&gt;size() \n\
</pre></div><p>Returns the size of the input stream.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;eos() \n\
</pre></div><p>Returns true if the current stream cursor position is at or past the end of the input stream, false otherwise.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` ms = memStreamMgr.openString &quot;token! //comment!\\n { { nested bracket pair } } &quot; ms.readToken() ms.readBlock &quot;{&quot; &quot;}&quot; ms.eos() memStreamMgr.close ms</p>\n\
<p>```</p>\n\
<p><strong>RESULT</strong></p>\n\
<p>``` <mixininterface:memstream> &quot;token!&quot; &quot;{ { nested bracket pair } }&quot; true OK<p>\n\
<p>```</p>\n\
</mixininterface:memstream></blockquote>\n\
<p>Note:</p>\n\
<p>The <span class=\'code\'>read</span> or <span class=\'code\'>peek</span> methods currently do not protect against reading past the end of the input stream.</p>\n\
<p>The <span class=\'code\'>seek</span> method currently does not protect against setting position past end of the input stream.</p>\n\
<p>The <span class=\'code\'>readBlock</span> and <span class=\'code\'>skipBlock</span> methods performs case-insensitive comparisons on the open and close token strings.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";