var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: missingPathCache</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: missingPathCache</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-missingpathcache\"></a></div>\n\
<p>3ds Max scenes can contain references to assets in many locations, including local drives and network shares. When a scene is loaded or saved, 3ds Max checks whether asset paths exist, and maintains a cache of missing file paths. This optimizes file load and save times, since once a missing file path is added to the cache, subsequent asset paths that match this path do not need to be queried in the filesystem, an expensive operation.</p>\n\
<p>For example, in tests involving 150 scene assets split among local and network shares, with some missing assets and file operation times exceeding 30 seconds (the OS file caching time), file load time is reduced by about 70% and file save by almost 80%.</p>\n\
<p>Available <strong>in 3ds Max 2018.4 and higher</strong>.</p>\n\
<p>Note: Only missing paths are cached. If an asset is missing, but its parent directory is present, the path is not added to the cache.</p>\n\
<p>Note: By default, the case sensitivity setting (<span class=\'code\'>missingPathCache.cacheCaseSensitive</span>) is true for robustness. However, we recommend you set this to false for performance reasons, if your file servers are not case sensitive.</p>\n\
<p>The Missing Path Cache is exposed in MAXScript in the <span class=\'code\'>missingPathCache</span> interface.</p>\n\
<div class=\'section\'><a id=\"properties\"></a><h2 id=\"properties\">Properties:</h2></div>\n\
<div class=\'codeBlock\'><pre>missingPathCache.cacheEntryValidityTime : integer : Read|Write|Validated by Range: 0 to 2147483647\n\
</pre></div><p>When sweeping the cache for entries that need to be tested to see if the entry now exists and should be removed from the cache, an entry is not tested if its previous test time plus <span class=\'code\'>cacheEntryValidityTime</span> is less than the current time. The default is 5000 (5 seconds).</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.cacheEntryPurgeTime : integer : Read|Write|Validated by Range: 0 to 2147483647\n\
</pre></div><p>When sweeping the cache, any entries that haven&#39;t been used to specify a filepath as not present within the last <span class=\'code\'>cacheEntryPurgeTime</span> milliseconds will be removed from the cache. The default is 3600000 (1 hour).</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.cacheSweepInterval : integer : Read|Write|Validated by Range: 0 to 2147483647\n\
</pre></div><p>The time interval between cache sweeps. The default is 1000 (1 second).</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.cacheEnabled : boolean : Read|Write\n\
</pre></div><p>Whether the cache is used to during filepath existence testing. Turning this off does not clear the cache. Default is true.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.includeFileWatchInSweep : boolean : Read|Write\n\
</pre></div><p>Whether a cache entry that has a FileWatch associated with it should also be tested for existence during a cache sweep. This is present to handle any potential cases where it is found that a FileWatch does not properly fire when directory-related changes occur to the folder the FileWatch is applied to. This would most likely occur with obscure file servers. No such cases are known. The default is false.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.existsTimeBackgroundThreshold : float : Read|Write\n\
</pre></div><p>When a filepath is being tested for existence and it is not in the cache, the time it took to perform that test is measured. If this time is less than the <span class=\'code\'>existsTimeBackgroundThreshold</span>, the filepath is processed for adding to the cache in the main thread. If it takes more than this time, the filepath is processed for adding to the cache in a worker thread. Setting this value to 0 forces all such processing to a worker thread. This value is in tenths of a millisecond, with a default value of 2.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.cacheCaseSensitive : boolean : Read|Write\n\
</pre></div><p>Whether the testing of a filepath against the cache should be case sensitive. Normally this can be set to false, but for some file servers it may need to be true. For robustness, the default is true. It is recommended to set this to false if your file servers are not case sensitive.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.cacheLocalDrives : boolean : Read|Write\n\
</pre></div><p>Whether to cache missing folders on local drives. Since file existence testing on local drives is fast, normally this setting should be false. The default is false.</p>\n\
<p>Note that changing this setting does not affect existing cache entries.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.clearCacheOnFileReset : boolean : Read|Write\n\
</pre></div><p>Whether to clear the missing path cache when 3ds Max is reset. The default is false.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.clearCacheOnSceneLoad : boolean : Read|Write\n\
</pre></div><p>Whether to clear the missing path cache before a scene is loaded. The default is false.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.persistSettingsOnExit : boolean : Read|Write\n\
</pre></div><p>Whether to persist cache settings to 3dsmax.ini on 3ds Max exit. The default is true.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.useFileWatch : boolean : Read|Write\n\
</pre></div><p>Whether to use FileWatch handles when possible. The default is true.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.numCacheEntries : integer64 : Read\n\
</pre></div><p>Performance statistic: the number of cache entries.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.numCacheHits : integer64 : Read\n\
</pre></div><p>Performance statistic: the number of filepath existence tests satisfied by cache hit.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.numCacheTests : integer64 : Read\n\
</pre></div><p>Performance statistic: the number of filepath existence tests while the cache was enabled.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.numCacheSweeps : integer64 : Read\n\
</pre></div><p>Performance statistic: the number of cache sweeps that have occurred.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.numThreadsSpawned : integer64 : Read\n\
</pre></div><p>Performance statistic: the number of cache entry existence test threads that have been created during cache sweeps.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.numDoesExistTests : integer64 : Read\n\
</pre></div><p>Performance statistic: the number of <span class=\'code\'>DoesFileExist()</span> and <span class=\'code\'>DoesDirectoryExist()</span> calls that have occurred.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.cacheSweepCumTime : integer64 : Read\n\
</pre></div><p>Performance statistic - the amount of time spent sweeping the cache. Note that this is occurring in its own thread.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.cacheSweepMaxTime : integer64 : Read\n\
</pre></div><p>Performance statistic: the maximum amount of time it took to sweep the cache. Note that this is occurring in its own thread.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.numFileWatchedEntries : integer64 : Read\n\
</pre></div><p>Performance statistic: the max number of cache entries using FileWatch handles.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.numFileWatchedEntriesCum : integer64 : Read\n\
</pre></div><p>Performance statistic: the commutative number of cache entries using FileWatch handles.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.numFileWatchedEntriesMax : integer64 : Read\n\
</pre></div><p>Performance statistic: the max number of cache entries using FileWatch handles.</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.isFilePathInCacheCumTime : double : Read\n\
</pre></div><p>Performance statistic: the commutative amount of time spent testing to see if a filepath is in the cache</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.isFilePathInCacheMaxTime : double : Read\n\
</pre></div><p>Performance statistic: the maximum amount of time spent testing to see if a filepath is in the cache</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.doesExistCumTime : double : Read\n\
</pre></div><p>P erformance statistic: the cumulative amount of time spent testing to see if a filepath exists</p>\n\
<div class=\'codeBlock\'><pre>missingPathCache.doesExistMaxTime : double : Read\n\
</pre></div><p>Performance statistic: the maximum amount of time spent testing to see if a filepath exists</p>\n\
<div class=\'section\'><a id=\"methods\"></a><h2 id=\"methods\">Methods:</h2></div>\n\
<div class=\'codeBlock\'><pre>    &lt;boolean&gt;missingPathCache.IsFilePathInCache &lt;filename&gt;filePath\n\
</pre></div><p>Returns true if any part of the <span class=\'code\'>filePath</span> is present in the cache. Primarily used for testing.</p>\n\
<div class=\'codeBlock\'><pre>    &lt;boolean&gt;missingPathCache.DoesFileExist &lt;filename&gt;filePath allowDirectory:&lt;boolean&gt;\n\
       allowDirectory default value: true\n\
</pre></div><p>Returns true if the <span class=\'code\'>filePath</span> exists, either as a file or as a directory.</p>\n\
<p>If <span class=\'code\'>allowDirectory</span> is true, the method returns true if <span class=\'code\'>filePath</span> exists as a directory, if false the method will return false if filePath exists as a directory.</p>\n\
<div class=\'codeBlock\'><pre>    &lt;boolean&gt;missingPathCache.DoesDirectoryExist &lt;filename&gt;dirPath\n\
</pre></div><p>Returns true if the <span class=\'code\'>dirPath</span> exists as a directory.</p>\n\
<div class=\'codeBlock\'><pre>    &lt;void&gt;missingPathCache.SeedCacheWithFilePath &lt;filename&gt;filePath\n\
</pre></div><p>Performs a file existence test of <span class=\'code\'>filePath</span> in a worker thread. The purpose of this is to seed the cache with <span class=\'code\'>filePath</span> if the file doesn&#39;t exist when you don&#39;t currently need to know whether the file exists, but expect to want to know later. By seeding the cache, that later file existence test will likely run faster if the <span class=\'code\'>filePath</span> doesn&#39;t exist because its directory doesn&#39;t exist.</p>\n\
<div class=\'codeBlock\'><pre>    &lt;void&gt;missingPathCache.Reset()\n\
</pre></div><p>Removes all entries from the cache.</p>\n\
<div class=\'codeBlock\'><pre>    &lt;void&gt;missingPathCache.ResetStatistics()\n\
</pre></div><p>Resets all the performance statistic variables to 0.</p>\n\
<div class=\'codeBlock\'><pre>    &lt;string array&gt;missingPathCache.GetNotPresentPaths unusedTime:&lt;&amp;integer64 array&gt;\n\
       unusedTime default value: #()\n\
       unusedTime is Out parameter\n\
</pre></div><p>Returns an array of the cache entry missing folder names. If <span class=\'code\'>unusedTime</span> is specified, on return it will return an array of Integer64 values which are the time in milliseconds since the corresponded entry in the cache was used to specify a <span class=\'code\'>filepath</span> as not present.</p>\n\
<div class=\'codeBlock\'><pre>    &lt;boolean&gt;missingPathCache.RemoveEntry &lt;filename&gt;filePath\n\
</pre></div><p>Removes the specified <span class=\'code\'>filePath</span> cache entry if present. The specified <span class=\'code\'>filePath</span> must match the cache entry exactly. Returns true if an entry was removed, otherwise false.</p>\n\
<div class=\'codeBlock\'><pre>   &lt;void&gt;LoadINISettings()\n\
</pre></div><p>Loads cache settings from 3dsmax.ini.</p>\n\
<div class=\'codeBlock\'><pre>    &lt;void&gt;SaveINISettings()\n\
</pre></div><p>Saves cache settings to 3dsmax.ini.</p>\n\
<div class=\'section\'><a id=\"actions\"></a><h2 id=\"actions\">Actions:</h2></div>\n\
<p>None</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";