var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: NetRender</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: NetRender</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-netrender\"></a></div>\n\
<p>This Core Interface exposes the Network Rendering to MAXScript.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;Interface&gt;NetRender.GetManager()    \n\
</pre></div><p>In order to access network rendering through MAXScript, you need to create a manager instance.</p>\n\
<p>The syntax is the following:</p>\n\
<div class=\'codeBlock\'><pre>NetRender.GetManager() \n\
</pre></div><div class=\'section\'><a id=\"mixin-interface-netrender.getmanager\"></a><h2 id=\"mixin-interface-netrender.getmanager\">Mixin Interface: netRender.getManager()</h2></div>\n\
<div class=\'codeBlock\'><pre>Interface: NetManager \n\
</pre></div><p>The <span class=\'code\'>NetManager</span> <a href=\'#!/url=./developer/Frequently-Asked-Questions/MAXScript-Syntax-and-Terminology/What-is-a-Mixin-Interface-.html\' title=\'\'>Mixin Interface</a> returned by the <span class=\'code\'>NetRender.GetManager</span> method lets you access network rendering through MAXScript.</p>\n\
<p><strong>Properties</strong></p>\n\
<p>The following properties can be used to get information or set certain properties of the manager.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.connected \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if connected to the manager. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.netStatus \n\
</pre></div><p>Returns the status of the manager. Various information about the manager can be gathered through <span class=\'code\'>netstatus</span> , see netstatus topic. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.wantControl \n\
</pre></div><p>If you have QueueControl and other computers call QueryControl, this indicates whether you want to maintain control, or relinquish it; their call to QueryControl will return whatever you have set for WantControl.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.haveControl \n\
</pre></div><p><span class=\'code\'>True</span> , if you currently have QueueControl. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.numJobs \n\
</pre></div><p>Returns the number of jobs in the queue. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.numServers \n\
</pre></div><p>Returns the number of servers. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.numGroups \n\
</pre></div><p>Returns the number of groups. Read-only.</p>\n\
<div class=\'section\'><a id=\"working-with-the-manager\"></a><h2 id=\"working-with-the-manager\">Working with the Manager</h2></div>\n\
<p><strong>Methods</strong></p>\n\
<p>The following methods can be used to query and or control the manager.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.setCallback &lt;#progress | #message | #update | #managerdown | #queuecontrol | #querycontrol&gt; &lt;somefunction&gt; \n\
</pre></div><p>Used to listen to the manager for certain event types that occur during a network render. For each event type, you can call a single function that you define. Each of the six callback types is one type of an event, and you can install a callback for any of these events or none.</p>\n\
<p>You must define the function to take a different number of arguments depending on the event type.</p>\n\
<p>Requires two arguments. They can be:</p>\n\
<div class=\'codeBlock\'><pre>#progress myprogess \n\
</pre></div><p>Called anytime a download/upload is underway including anytime you fetch information about jobs or servers.</p>\n\
<p>Requires a function defined with two integer parameters: ’r;Total’ and ’r;Current’. Total is the total amount to transfer and Current is the amount transferred so far.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` fn myprogress total current = -- Note: two integer parameters format &quot;Progress: completed % out of %\\n&quot; current total m.setcallback #progress myprogress -- sets the #progress callback to use myprogress()</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>#message mymessage \n\
</pre></div><p>Called when the manager has a text message for the user. Requires a function defined with one string parameter which is the message text.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` fn myNetMessage msg = -- Note: one string parameter format &quot;Message: %\\n&quot; msg m.setcallback #message mymessage -- sets the #message callback to use mymessage()</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>#update myupdate \n\
</pre></div><p>Called when something has changed like a job started or finished. Lets you know when you need to make GetUpdate calls or other refreshing. Requires a function defined with no parameters.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` fn myUpdate = job.GetUpdate() --example of what you might do m.setcallback #update myupdate -- sets the #update callback to use myupdate()</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>#managerdown mymanagerdown \n\
</pre></div><p>Called when the manager shuts down. Requires a function defined with no parameters.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` fn myManagerDown = format &quot;Manager is dead\\n&quot; m.setcallback mymanagerdown --sets the #managerdown callback to use mymanagerdown()</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>#queuecontrol myqueuecontrol \n\
</pre></div><p>Called whenever queue control changes. Requires a function defined with no parameters.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` fn myQueueControl = format &quot;Queue control has changed\\n&quot; m.setcallback #QueueControl myQueueControl --install the &quot;QueueControl&quot; callback</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>#querycontrol myquerycontrol\n\
</pre></div><p>Called when you have Queue Control and another computer wants it either through the QueueManager or with the script function <span class=\'code\'>&lt;netManager&gt;.QueryControl()</span>. If you want to keep control, set the value <span class=\'code\'>&lt;netManager&gt;.WantControl</span> to true, otherwise set it to false. The function must take one argument, which is the name of the machine requesting control. See the function <span class=\'code\'>&lt;netManager&gt;.QueueControl()</span> for more information.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` fn myQueryControl clientName = ( --Note: one string parameter format &quot;The computer % wants queue control&quot; clientName m.wantControl = true -- use this to keep queue control m.wantControl = false -- use this to release queue control ) m.setcallback #QueryControl myQueryControl -- install the &quot;QueryControl&quot; callback</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.GetCallback &lt;#progress | #message | #update | #managerdown | #queuecontrol | #querycontrol&gt; \n\
</pre></div><p>Returns the name of the function used for that particular callback. Returns an empty array if no callback is assigned. Requires one argument, can be:</p>\n\
<p><span class=\'code\'>#progress :</span> Called anytime a download/upload is underway, including anytime you fetch information about jobs or servers</p>\n\
<p><span class=\'code\'>#message :</span> Called when the manager has a text message for the user</p>\n\
<p><span class=\'code\'>#update :</span> Called when something has changed like a job started or finished. Lets you know when you need to make GetUpdate calls or other refreshing.</p>\n\
<p><span class=\'code\'>#managerdown :</span> Called when the manager dies</p>\n\
<p><span class=\'code\'>#queuecontrol :</span> Called whenever queue control changes</p>\n\
<p><span class=\'code\'>#querycontrol :</span> Called when you have Queue Control and another computer wants it</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.connect #manual &lt;manager name&gt;|&lt;manager IP address&gt; [port:&lt;integer&gt;] platform:&lt;enum&gt; \n\
</pre></div><p>or</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.connect #automatic &lt;subnet mask&gt; [port:&lt;integer&gt;] platform:&lt;enum&gt; \n\
</pre></div><p><span class=\'code\'>platform</span> enums: { <span class=\'code\'>#32|#64|#default</span> }</p>\n\
<p><span class=\'code\'>platform</span> default value: <span class=\'code\'>#default</span></p>\n\
<p>Establishes a connection to the manager allowing access to job states, server states, editing job settings, and so on.</p>\n\
<p>The optional <span class=\'code\'>platform:</span> argument can be used to specify 32 bit or 64 bit platform. The default is based on the platform of the <strong>3ds Max</strong> copy the command is being executed from.</p>\n\
<p>You can either connect to a manager manually by specifying the manager name or ip address of the manager as a string, or automatically by specifying the subnet mask and optional port number.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` m.connect #manual &quot;manager&quot; -- connects to manager of name &quot;manager&quot;</p>\n\
<p>```</p>\n\
<p>or</p>\n\
<p>``` m.connect #manual &quot;192.168.0.1&quot; -- connects to manager of IP 192.168.0.1</p>\n\
<p>```</p>\n\
<p>or</p>\n\
<p>``` m.connect #automatic &quot;255.255.255.0&quot; port:1234 -- automatically connects to manager on subnet 255.255.255.0 at port 1234</p>\n\
<p>```</p>\n\
<p>in either case, you can specify the optional port number should the manager be using a non-default port number. Will return true if connection was successful.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.Disconnect() \n\
</pre></div><p>Disconnects the connection established with <span class=\'code\'>&lt;netManager&gt;.connect.</span></p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.Kill() \n\
</pre></div><p>Shuts down the manager. You must have queue control to do this.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.QueryControl &lt;#wait | #dontwait&gt; \n\
</pre></div><p>This requires either <span class=\'code\'>#wait</span> or <span class=\'code\'>#dontWait</span> . The function works as follows:</p>\n\
<p>Nobody has queue control: <span class=\'code\'>#dontWait</span> returns <span class=\'code\'>true</span> , <span class=\'code\'>#wait</span> returns <span class=\'code\'>true</span> .</p>\n\
<p>Someone has queue control: <span class=\'code\'>#dontwait</span> returns <span class=\'code\'>false</span> , <span class=\'code\'>#wait</span> prompts the current queue controller.</p>\n\
<p>In the last case, the queue controller gets the QueryControl callback and must indicate if they want control. If that user indicates they want to keep control, then the function returns <span class=\'code\'>false</span> . If they will give up control (or the 10 second timeout expires), it returns <span class=\'code\'>true</span> . Note that the QueueManager gives a prompt for the user to indicate what they want; in MAXScript, you just get the callback and have to use the <span class=\'code\'>wantControl</span> value.</p>\n\
<p>Note: Refer to the callback, &quot; <span class=\'code\'>#queuecontrol myqueuecontrol</span> &quot;, found above in <span class=\'code\'>&lt;netManager&gt;.setCallback</span> .</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.GetControl() \n\
</pre></div><p>Takes control of the queue. Returns <span class=\'code\'>true</span> if control was taken. From that moment on, jobs can be submitted, edited, reprioritized, and servers can be removed, until queue control is relinquished.</p>\n\
<p>Note: The current queue controller does not get its <span class=\'code\'>QueryControl</span> callback triggered. Instead, they just lose the queue control (unless they also have the queue locked lock). You must always precede a call to <span class=\'code\'>GetControl()</span> with a call to <span class=\'code\'>QueryControl(true)</span> to ensure that it is OK to do this.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.Lock &lt;true | false&gt; \n\
</pre></div><p>Locks out others from getting queue control and if they call <span class=\'code\'>QueryControl</span> , it will automatically return <span class=\'code\'>false</span> . For example, suppose you got control of the queue through MAXScript using <span class=\'code\'>getcontrol()</span> , someone else who has the queuemanager up in readonly mode can request queuecontrol. Setting lock to <span class=\'code\'>true</span> will disallow anyone else to take control until you disconnect from the manager, or until you reset the lock to false. Note that the QueueManager always calls QueryControl to check if it can grab the queue.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.SetUpdates &lt;true | false&gt; \n\
</pre></div><p>This function’s usage resembles the <span class=\'code\'>Lock()</span> function in that a boolean value is passed, and you must already have queue control. Setting updates to <span class=\'code\'>false</span> will freeze the manager so that it refuses any changes to the queue. It does not affect the callbacks. Fewer Update callbacks will be received as the job queue is not updating. Use this function when submitting large numbers of changes and when you want all the changes to take effect at the same time. This will occur when <span class=\'code\'>setUpdates()</span> is called with a <span class=\'code\'>true</span> value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.checkoutputvisibility &lt;path&gt; \n\
</pre></div><p>Takes one argument, a pathname defined as a string (&quot;c:\\\\temp&quot;). It verifies that the path exists and returns &quot;The system cannot find the path specified. (0x3)&quot; if the path does not exist.</p>\n\
<p>Note: The manager checks this output path relative to itself, not to your local machine. Thus, if you pass &quot;C:\\&quot; and you have not shared your C drive, it will return OK (because the manager checks its own C drive). You must use a network name when calling this function like &quot;\\\\\\mymachine\\\\share\\&quot;. Also, if the parameter does not end in \\, the functions assumes you&#39;re naming a file (not a directory) and checks whether this file could be created. Always include the \\ at the end if you are checking whether a directory is accessible.</p>\n\
<div class=\'section\'><a id=\"working-with-jobs\"></a><h2 id=\"working-with-jobs\">Working with Jobs</h2></div>\n\
<p>Various functions and properties can be used to access jobs. You can use the <span class=\'code\'>GetJobs()</span> function to retrieve an array of all jobs in the queue. The jobs can be filtered in various ways to return an array based on the filter.</p>\n\
<blockquote>\n\
<p>Warning: Do not call <span class=\'code\'>GetJobs()</span> or <span class=\'code\'>GetServers()</span> very often, because these are VERY heavyweight methods.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.getjobs [filter:#suspended | #complete | #waiting | #started | #error | #name | #handle | #index] [key:&lt;name&gt; | &lt;handle&gt; | &lt;index&gt;] \n\
</pre></div><p>The latter three filter types require a corresponding key argument. If used without a filter, returns an array of all jobs in queue. If no jobs are in the queue, an empty array will be returned.</p>\n\
<p>filter <span class=\'code\'>:#suspended:</span> Returns an array of all suspended jobs. Returns an empty array <span class=\'code\'>#()</span> if no jobs are suspended.</p>\n\
<p>filter <span class=\'code\'>:#complete:</span> Returns an array of all completed jobs. Returns an empty array <span class=\'code\'>#()</span> if no jobs are complete.</p>\n\
<p>filter <span class=\'code\'>:#waiting:</span> Returns an array of jobs that are waiting to be rendered or are being rendered. Will return an empty array <span class=\'code\'>#()</span> if no jobs are waiting.</p>\n\
<p>filter <span class=\'code\'>:#started:</span> Returns an array of jobs that are actually started and being rendered.</p>\n\
<p>filter <span class=\'code\'>:#complete:</span> Returns an array of all completed jobs. Returns an empty array <span class=\'code\'>#()</span> if no jobs are complete.</p>\n\
<p>filter <span class=\'code\'>:#error:</span> Returns an array of all jobs experiencing an error. Returns an empty array <span class=\'code\'>#()</span> if no jobs have errors.</p>\n\
<p>filter <span class=\'code\'>:#name:</span> Pass a name as the Key argument; Returns an array of all jobs with the given name. Returns an empty array <span class=\'code\'>#()</span> if no jobs have that name.</p>\n\
<p>filter <span class=\'code\'>:#handle:</span> Pass a handle as the Key argument; the job with that handle will be returned (as an array with one element). Returns an empty array <span class=\'code\'>#()</span> if the no job has that handle.</p>\n\
<p>filter <span class=\'code\'>:#index:</span> Pass an integer as the Key argument; the job at that index in the queue will be returned (as an array with one element). Returns an empty array <span class=\'code\'>#()</span> if the no job exists at that index.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` manager.GetControl() --get queue control manager.SetUpdates false --the queue is now frozen jobs = manager.GetJobs() manager.SetUpdates true --the queue is unfrozen</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note: The <span class=\'code\'>GetJobs()</span> function can return incorrect results if the Queue is changed while the job information is downloading. <span class=\'code\'>SetUpdates()</span> is used to guarantee that <span class=\'code\'>GetJobs()</span> operates without error.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.SetJobOrder &lt;array&gt; \n\
</pre></div><p>Changes the order of the jobs in the queue. The array must contain the same jobs that are contained in the array from <span class=\'code\'>.getjobs(),</span> although they can be in different order. You must also have queuecontrol, use <span class=\'code\'>.getcontrol()</span> function to take control before setting the job order.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.NewJobfile:&lt;filename&gt; \n\
</pre></div><p>Creates a new job instance. It requires a valid max file name (a max file that exists somewhere on the hard drive or the network). Returns a job definition if the file exists, undefined if the file cannot be found.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` job.newJob file:&quot;file.max&quot; --submitting a file job.newJob() --submitting the current scene</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note: Jobs cannot have maps included and render element data will not be available for submitted job, but render elements will process correctly. These problems are resent when submitting a job from a file, but not when submitting the current scene.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.GetUpdate() \n\
</pre></div><p>Updates the information about the selected job. Remember this involves a network interaction, so it is a heavyweight operation.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.SendUpdate() \n\
</pre></div><p>Updates the job in the queue with new job settings. Must have queuecontrol. Use <span class=\'code\'>&lt;netManager&gt;.getcontrol()</span> to get queue control. Remember this involves a network interaction, so it is a heavyweight operation.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.Submit() Servers:&lt;array&gt; \n\
</pre></div><p>Submits a new job to be rendered to the queue. Must have queuecontrol. Use <span class=\'code\'>&lt;netManager&gt;.getcontrol()</span> to get queue control. If no servers are provided, then all servers will be assigned to the job.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.Suspend() \n\
</pre></div><p>Suspends the selected job. Must have queuecontrol. Use <span class=\'code\'>&lt;netManager&gt;.getcontrol()</span> to get queue control.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.Resume() \n\
</pre></div><p>Will cause the job to resume where it left off when it was suspended. Must have queuecontrol. Use <span class=\'code\'>&lt;netManager&gt;.getcontrol()</span> to get queue control.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.Restart() \n\
</pre></div><p>Will restart the job from the beginning. Must have queuecontrol. Use <span class=\'code\'>&lt;netManager&gt;.getcontrol()</span> to get queue control.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.Delete() \n\
</pre></div><p>Will delete the job from the queue. Must have queuecontrol. Use <span class=\'code\'>&lt;netManager&gt;.getcontrol()</span> to get queue control.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.AssignServer &lt;server&gt; \n\
</pre></div><p>Assigns a selected server to the job. Must have queuecontrol. Use <span class=\'code\'>&lt;netManager&gt;.getcontrol()</span> to get queue control.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.SuspendServer &lt;server&gt; \n\
</pre></div><p>Removes a server from the selected job. Must have queuecontrol. Use <span class=\'code\'>&lt;netManager&gt;.getcontrol()</span> to get queue control.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.GetServerInfo &lt;integer&gt; \n\
</pre></div><p>Gets information about a particular server assigned to the job. Requires a server number, 1 based.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.nonconcurrentDriver \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the output cannot be rendered one frame at a time (like an .MOV file). Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.uninterruptibleDriver \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the render cannot be resumed after it is interrupted or suspended.</p>\n\
<p>For example, you cannot render half of an .AVI file, then finish it later. You need to render the whole thing without interruption. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.GetCameras() \n\
</pre></div><p>Returns an array of cameras in the scene. An empty array <span class=\'code\'>#()</span> is returned if no cameras are in the scene.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.GetLog() start:x numLines:y \n\
</pre></div><p>Returns the log for the job as text. The &#39;start&#39; and &#39;numLines&#39; parameters are optional. If you pass no parameters, you get the entire log. If you only pass start, you get every line starting from the given line. If you pass only numLines, then start is assumed to be 0.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.GetServerStatusText &lt;server&gt; \n\
</pre></div><p>Returns any messages from the chosen server assigned to the job. Will return an empty string if no messages from the server. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.numServers \n\
</pre></div><p>Returns the number of servers assigned to the job. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.state \n\
</pre></div><p>Returns the state of the job. This can be <span class=\'code\'>#complete, #suspended, #busy</span> or <span class=\'code\'>#waiting</span> . Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.serverPID \n\
</pre></div><p>This function gives low-level information that is intended for internal-use-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.handle \n\
</pre></div><p>Returns the job’s handle. Read-only.</p>\n\
<p>Many of the following values are read-write, but changes you make to these values will not register with the manager until you call <span class=\'code\'>&lt;job&gt;.SendUpdate().</span></p>\n\
<p>Note: <strong>SendUpdate</strong> requires queue control (obtained using <span class=\'code\'>&lt;NetManager&gt;getControl</span>).</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.name \n\
</pre></div><p>Returns the name of the job. The name can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.filesize \n\
</pre></div><p>Returns the job’s file size.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.filesizeExtracted \n\
</pre></div><p>Returns the job’s extracted file size. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.timeSubmitted \n\
</pre></div><p>Returns the time at which the job was submitted as a string.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.timeStarted \n\
</pre></div><p>Returns the time at which the job was started as a string. Returns undefined if the job has not started. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.timeFinished \n\
</pre></div><p>Returns the time at which the job was finished as a sting. Returns undefined if the job has not finished. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.notifications \n\
</pre></div><p>Returns true if notifications are on. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.notifyFailure \n\
</pre></div><p>Returns true if notified of failures. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.notifyProgress \n\
</pre></div><p>Returns true if notified of progress. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.notifyCompletion \n\
</pre></div><p>Returns true if notified of progress is on. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.notifyFrameInterval \n\
</pre></div><p>Returns an interval at which notifications occur. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.fromFrame \n\
</pre></div><p>Returns the rendering start frame. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.toFrame \n\
</pre></div><p>Returns the rendering end frame. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.nthFrame \n\
</pre></div><p>Returns the rendering frame interval. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.outputWidth \n\
</pre></div><p>Returns the width of the rendered frame. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.outputHeight \n\
</pre></div><p>Returns the height of the rendered frame. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.numFramesComplete \n\
</pre></div><p>The number of completed frames for the job. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.priority \n\
</pre></div><p>Returns the job priority.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.videoPost \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if there is a video post sequence. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.includeMaps \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the job was submitted with include maps on. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.skipRenderedFrames \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if skip rendered frames was set to on when job was submitted. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.useAllServers \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if use all servers was set to on when job was submitted. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.suspended \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the job is suspended. Read-only. To suspend the job use <span class=\'code\'>&lt;job&gt;.suspend().</span></p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.finished \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the job is finished. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.ignoreShare \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the job was submitted with ignore share on. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.skipOutputTest \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the job was submitted with skip output test on. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.nonSeqFrames \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the job was submitted to render non sequential frames. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.combustionJob \n\
</pre></div><p>Returns <span class=\'code\'>false</span> if the job is a max job. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.uncompressedFile \n\
</pre></div><p>Returns <span class=\'code\'>false</span> if the job file is compressed. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.gammaCorrection \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the job was submitted with gamma correction on. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.gammaValueIn \n\
</pre></div><p>Returns a float value of the incoming gamma value. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.gammaValueOut \n\
</pre></div><p>Returns a float value of the outgoing gamma value. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.renderPixelAspect \n\
</pre></div><p>Returns a float value of the render pixel aspect ratio. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.renderCamera \n\
</pre></div><p>Returns a string with the name of the camera view being rendered. Will return an empty string if the view being rendered is a non camera view (perspective, front, user, and others). Can be changed. Use <span class=\'code\'>&lt;job&gt;.getcameras()</span> function to get a list of valid cameras in the scene to change to.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.renderElements \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if a job was submitted with the render elements active. Note that this will return true even if there are no elements to be rendered. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.numSceneObjects \n\
</pre></div><p>Returns the number of objects in the scene as an integer. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.numSceneFaces \n\
</pre></div><p>Returns the number of faces in the scene as an integer. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.numSceneLights \n\
</pre></div><p>Returns the number of lights in the scene as an integer. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.sceneStartTime \n\
</pre></div><p>Returns the scene start time in frames, so if your scene is set to use MM:SS:Ticks, this will still return a value in frames.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.sceneEndTime \n\
</pre></div><p>Returns the scene end time in frames.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.videoColorCheck \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the job was submitted with videocolorcheck on. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.force2Sided \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the job was submitted with force 2 sided on. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.renderHiddenObjects \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the job was submitted with render hidden objects on. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.renderAtmosphericEffects \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the job was submitted with render atmospheric effects on. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.superBlack \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the job was submitted with superblack on. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.serialNumbering \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the nth serial numbering on this property is accessible through the preferences  rendering dialog.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.ditherPaletted \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if Dither Paletted was enabled when the job was submitted. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.ditherTrueColor \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if Dither True Color was enabled when the job was submitted. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.renderFields \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if Render Fields was enabled when the job was submitted. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.renderDisplacements \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if displacements was enabled when the job was submitted. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.renderEffects \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if render effects was enabled when the job was submitted. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.fieldOrder \n\
</pre></div><p>Returns either <span class=\'code\'>#odd</span> or <span class=\'code\'>#even</span> depending on what the field order was set to when job was submitted. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.numRenderElements \n\
</pre></div><p>Returns the number of render elements in the scene. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.userName \n\
</pre></div><p>Returns the name of the user that submitted the job as a string. Note that if a job is submitted through MAXScript using <span class=\'code\'>&lt;job&gt;.submit()</span> , and the max file was last saved by another user on a different computer, the username will be that of the other user. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.computerName \n\
</pre></div><p>Returns the name of the computer from which the job was submitted as a string. Note that if a job is submitted through MAXScript using <span class=\'code\'>&lt;job&gt;.submit()</span> , and the max file was last saved by another user on a different computer, the computer name will be that of the computer on which the max file was last saved. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.managerShare \n\
</pre></div><p>Returns the shared folder as a string where all jobs are stored on the manager.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.frames \n\
</pre></div><p>Returns a string of frames to render ( <span class=\'code\'>&quot;1,3,5-12&quot;</span> ). Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.frameOutputName \n\
</pre></div><p>Returns the name and path of the output file. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.frameOutputGamma \n\
</pre></div><p>Returns the output gamma of the rendered frames.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.frameOutputDevice \n\
</pre></div><p>Returns the device name if a device is specified at render time.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.numFrames \n\
</pre></div><div class=\'section\'><a id=\"accessing-render-element-information\"></a><h2 id=\"accessing-render-element-information\">Accessing Render Element Information</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.GetRenderElement &lt;index&gt; \n\
</pre></div><p>Returns information as a data structure about the nth element. The <span class=\'code\'>&lt;element&gt;</span> structure is defined below. Returns <span class=\'code\'>undefined</span> if no element is at the index number, for example, <span class=\'code\'>el = jobs\\[1\\].getrenderelement</span> 1 -- retrieves the 1st element in the 1st job in the queue. With this you can find out if the element is enabled, if filtering is enabled, if atmosphere is applied, if shadows are applied, the element name, and the element output filename. The following are the properties that are valid for an element.</p>\n\
<div class=\'codeBlock\'><pre>&lt;element&gt;.enabled \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the element is enabled. Can also set its state.</p>\n\
<div class=\'codeBlock\'><pre>&lt;element&gt;.filterEnabled \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if filtering is enabled. Can also set its state.</p>\n\
<div class=\'codeBlock\'><pre>&lt;element&gt;.atmosphereApplied \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if atmosphere is applied. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;element&gt;.shadowsApplied \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if shadows are applied. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;element&gt;.name \n\
</pre></div><p>Returns the elements name. Name can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;element&gt;.output \n\
</pre></div><p>Returns the element’s output file name. Output name and path can be changed. However, changing the filetype will change the extension of the image, but not the actual file type. For example, the current output returned is <span class=\'code\'>&quot;\\\\\\ej4sf\\\\frames\\\\foo_diffuse.tga&quot;</span> and changing the extension to .bmp will just result in the tga file having a .bmp extension instead of the .tga extension.</p>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.SetRenderElement &lt;index&gt; &lt;element&gt; \n\
</pre></div><p>Sets the selected render element to the new values assigned to the element. In order for the change to take effect in the job, you need to do a <span class=\'code\'>&lt;job&gt;.sendupdate()</span> to update the job itself in the queue.</p>\n\
<div class=\'section\'><a id=\"accessing-frame-information\"></a><h2 id=\"accessing-frame-information\">Accessing Frame Information</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;job&gt;.GetFrameInfo &lt;integer&gt; \n\
</pre></div><p>Returns information, as a data structure, about the nth frame. The index is 1 based. The <span class=\'code\'>&lt;frame&gt;</span> structure is defined below.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` fr = getframeinfo 4 -- Returns info about the 4th frame. Read-only.</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;frame&gt;.state \n\
</pre></div><p>Returns the state of the frame. The state can be <span class=\'code\'>#waiting</span> , <span class=\'code\'>#assigned</span> , or <span class=\'code\'>#complete</span> .</p>\n\
<div class=\'codeBlock\'><pre>&lt;frame&gt;.index \n\
</pre></div><p>Returns the actual frame number. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;frame&gt;.serverhandle \n\
</pre></div><p>Returns the serverhandle. Must return undefined when frame has not been rendered yet. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;frame&gt;.servername \n\
</pre></div><p>Returns the name of the server that is assigned to that frame. Must return undefined if the frame is not assigned yet. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;frame&gt;.elapsedtime \n\
</pre></div><p>Returns the time it took for the frame to render. Must return undefined if the frame is not assigned yet. Read-only.</p>\n\
<div class=\'section\'><a id=\"working-with-servers\"></a><h2 id=\"working-with-servers\">Working with Servers</h2></div>\n\
<p>Various functions and properties can be used to access rendering servers. You can use the <span class=\'code\'>getservers()</span> function to retrieve an array of all servers managed by the manager. The servers can be filtered in various ways to return an array based on the filter.</p>\n\
<blockquote>\n\
<p>Warning: Do not call <span class=\'code\'>GetJobs()</span> or <span class=\'code\'>GetServers()</span> very often, because these are VERY heavyweight methods!</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.GetServers [filter:#idle | #busy | #absent | #suspended | #error | #group | #job | #handle | #index] [key:&lt;string&gt; | &lt;integer&gt; | &lt;job&gt; ] \n\
</pre></div><p>If used without a filter, <span class=\'code\'>GetServers</span> () will return an array of all servers managed by the manager. If there are no servers, the function will return an empty array.</p>\n\
<p><span class=\'code\'>filter:#idle:</span> Returns an array of all idle servers</p>\n\
<p><span class=\'code\'>filter:#busy:</span> Returns an array of all servers that are busy rendering a job</p>\n\
<p><span class=\'code\'>filter:#absent:</span> Returns an array of all servers that are absent (that were connected to the manager at one point, but that are either down or the server service or serverapp is not running on it).</p>\n\
<p><span class=\'code\'>filter:#suspended:</span> Returns an array of all suspended servers</p>\n\
<p><span class=\'code\'>filter:#error:</span> Returns an array of all servers experiencing an error</p>\n\
<p><span class=\'code\'>filter:#group:</span> Returns an array of servers in a group. Requires that the key option is used, the key can be a group name as a string, or a group number as an integer (1 based). An empty array is returned if no groups are defined.</p>\n\
<p><span class=\'code\'>filter:#job:</span> Returns an array of servers that are assigned to the specified job. Requires that the key option be used. The key must be a job definition.</p>\n\
<p><span class=\'code\'>filter:#handle:</span> Returns the server with a given handle (as an array with one item). Requires that the key option be used. The key must be a server handle.</p>\n\
<p><span class=\'code\'>filter:#index:</span> Returns the server at a given index in the server list (as an array with one item). Requires that the key option be used. The key must be an integer (the index).</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` server = m.getservers()</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.GetUpdate() \n\
</pre></div><p>Gets an update on the state of the server. Returns Ok if successful.</p>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.SendUpdate() \n\
</pre></div><p>Updates the server with new settings. Must have queuecontrol.</p>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.Delete() \n\
</pre></div><p>Deletes the server from the manager. Must have queuecontrol.</p>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.ResetPerformance() \n\
</pre></div><p>Resets the performance metric to 0.0. Must have queuecontrol and must do <span class=\'code\'>&lt;server&gt;.sendupdate()</span> to update the server.</p>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.netStatus \n\
</pre></div><p>Netstatus</p>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.handle \n\
</pre></div><p>Returns the server’s handle. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.state \n\
</pre></div><p>Returns the state of the server. This can be #idle, #absent, or #busy.</p>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.name \n\
</pre></div><p>Returns the name of the server. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.totalFrames \n\
</pre></div><p>Returns the total number of frames rendered by the server. Read-only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.totalTime \n\
</pre></div><p>Returns the total time that the server has been up. The value returned is in hours.</p>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.performance \n\
</pre></div><p>Returns the performance index of the server. Read-only</p>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.AttendedPriority \n\
</pre></div><p>Returns the priority, as an integer, of the server when the user is logged in.</p>\n\
<p>0: high priority</p>\n\
<p>1: low priority</p>\n\
<p>2: idle.</p>\n\
<p>Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.UnattendedPriority \n\
</pre></div><p>Returns the priority level, as an integer, of the server when the system is logged out.</p>\n\
<p>0: high priority</p>\n\
<p>1: low priority</p>\n\
<p>2: idle.</p>\n\
<p>Note that this is only valid if running <span class=\'code\'>serversvc</span> and the user is not logged in on the system. If running <span class=\'code\'>serversvc</span> and a user is logged in on the system, then the <span class=\'code\'>attendedpriority</span> values are in effect. Can be changed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.schedule \n\
</pre></div><p>Returns an array of seven bitarrays. Each bitarray is a day, each bit is an hour, each bit within that bit array means that the server is available at that hour. A bit array of <span class=\'code\'>#{1, 3..5, 15..24}</span> means that the server is available from 12 midnight to 1am, from 3am to 5am, and from 3pm to midnight.</p>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.jobHandle \n\
</pre></div><p>Returns the handle of the job it is working on. Will return a value of 0 if no job is being worked on by that server.</p>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.jobFrameIndex \n\
</pre></div><p>Returns the frame index of the job that the server is working on.</p>\n\
<div class=\'codeBlock\'><pre>&lt;server&gt;.jobFrameTimeStarted \n\
</pre></div><p>Returns the time at which the frame being rendered was started.</p>\n\
<div class=\'section\'><a id=\"working-with-groups\"></a><h2 id=\"working-with-groups\">Working with Groups</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.SizeofGroup &lt;index&gt; \n\
</pre></div><p>Returns the number of servers in the nth group.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.GetGroupName&lt;index&gt; \n\
</pre></div><p>Returns the name of the nth group.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.CreateGroup &lt;array&gt; &lt;string&gt; \n\
</pre></div><p>Creates a named group of servers. It takes two arguments: an array of servers and a string to define the group name.</p>\n\
<div class=\'codeBlock\'><pre>&lt;netManager&gt;.DeleteGroup &lt;string&gt; \n\
</pre></div><p>Deletes a named group. Takes a string as an argument.</p>\n\
<div class=\'section\'><a id=\"netstatus\"></a><h2 id=\"netstatus\">Netstatus</h2></div>\n\
<p>Both manager and servers have a netstatus property. All properties are read-only.</p>\n\
<div class=\'codeBlock\'><pre>system = m.netstatus\n\
&lt;system&gt;.SpaceOnDisk &lt;index&gt; \n\
</pre></div><p>Returns the amount of space in megs on a specified disk. The index is 1 based. Disks 1 and 2 are the a: and b: drives.</p>\n\
<p>Note:</p>\n\
<p>Currently, this only returns correct results for one disk, your workdisk (given by <span class=\'code\'>.workdisk</span> ). You actually need to pass (workdisk+1).</p>\n\
<p>To maintain compatibility with UNIX/Linux, a NetStatus object will always report exactly 1 disk, which is the work disk. Thus, the <span class=\'code\'>NetStatus.SpaceOnDisk()</span> value will not actually be correct, though it is still possible to determine the amount of free space on the working disk (which is the information most users will usually want):</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.numDroppedPackets \n\
</pre></div><p>Returns the number of dropped packets.</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.numBad \n\
</pre></div><p>Returns the number of bad packets.</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.numTCPRequests \n\
</pre></div><p>Returns the number of TCP requests.</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.numUDPRequests \n\
</pre></div><p>Returns the number of UDP packets.</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.bootTime \n\
</pre></div><p>Returns the time at which the system was started.</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.memorySize \n\
</pre></div><p>Returns the amount of memory of the system.</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.numProcessors \n\
</pre></div><p>Returns the number of processors in the system.</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.username \n\
</pre></div><p>Returns the login name of the user logged in on the computer or the login name used by the service.</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.computerName \n\
</pre></div><p>Returns the name of the computer.</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.workdisk \n\
</pre></div><p>Returns the disk where max is setup.</p>\n\
<p>Note:</p>\n\
<p>Currently broken, always returns the same value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.Disks \n\
</pre></div><p>Returns a bitarray of which disks exist (1=A, 2=B, 3=C, and so on) .</p>\n\
<p>Note:</p>\n\
<p>Currently broken.</p>\n\
<p>To maintain compatibility with UNIX/Linux, a NetStatus object will always report exactly 1 disk, which is the work disk. Thus, the <span class=\'code\'>NetStatus.Disks()</span> value will not actually be correct, though it is still possible to determine the amount of free space on the working disk (which is the information most users will usually want).</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.mac \n\
</pre></div><p>Returns the MAC address of the system’s network card. If the computer is a network server, this is its handle.</p>\n\
<p><strong>The following properties are no longer supported in 3ds Max 5 and higher because of the introduction of the Backburner technolgy:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.platformID \n\
</pre></div><p>In <strong>3ds Max 4</strong>, it returns an integer. A value of 1 indicates win95 and a value of 2 indicates WinNT.</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.majorVersion \n\
</pre></div><p>In <strong>3ds Max 4</strong>, it returns an integer. When the platformID indicates a WinNT system, a value of 5 or higher here indicates Win2k.</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.minorVersion \n\
</pre></div><p>In <strong>3ds Max 4</strong>, it returns an integer. Win98 is indicated by a minor build greater than 0 for win95</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.buildNumber \n\
</pre></div><p>In <strong>3ds Max 4</strong>, it returns the build number, this only applies to winnt and win2k. Not supported under win95, win98, or win ME.</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.CSDVersion \n\
</pre></div><p>In <strong>3ds Max 4</strong>, it returns the service pack number of the OS as a string.</p>\n\
<div class=\'codeBlock\'><pre>&lt;system&gt;.tempDir \n\
</pre></div><p>In <strong>3ds Max 4</strong>, it returns the tempdir for the system.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES</strong></p>\n\
<p>``` -- ESTABLISHING A CONNECTION -- m = netrender.getmanager() --get a NetManager instance</p>\n\
<p>--start this session m.connect #manual &quot;nimbus&quot; -- OR m.connect #manual &quot;nimbus&quot; port:1234 --specifying a port number</p>\n\
<p>```</p>\n\
<p>``` -- QUEUE CONTROL -- --Get QueueControl using GetControl(); --there is no way to release control, but if wantControl==false --then control will be relinquished to the next client --that requests it if ( m.QueryControl #wait ) do --only take control if you have permission m.getcontrol() --takes queue control m.wantControl=true --if another client does QueryControl(), they will get a return value of false m.Lock true --this completely prevents others from getting queue control m.Lock false --others can now get control</p>\n\
<p>```</p>\n\
<p>``` -- SUBMITTING JOBS -- job = m.newjob file:&quot;c:\\share\\test.max&quot; job.suspended = true --jobs can be submitted as suspended job.state --should be unsubmitted job.includeMaps = true --turn on &quot;Include Maps&quot; srv_list = m.getservers() --get the server list to assign to the job</p>\n\
<p>job.submit servers:srv_list --specify which servers to use for the job -- job.submit() --this uses all servers for the job</p>\n\
<p>```</p>\n\
<p>``` -- GETTING JOBS &amp; SERVER OBJECTS -- m.SetUpdates false --lock the queue, to make sure nothing changes while you download info j = m.getjobs filter:#suspended --an array of NetJob objects; filters are optinal s = m.getservers filter:#idle --an array of NetServer objects; filters are optinal --see below for other filters... there are many m.SetUpdates true --be sure to unlock the queue!</p>\n\
<p>```</p>\n\
<p>``` -- WORKING WITH GROUPS -- m.creategroup s &quot;myGroup&quot; --takes an array of NetServers and a name</p>\n\
<p>num_groups = m.numGroups --total number of groups size_group1 = m.SizeofGroup 1 --number of servers in the first group g = m.getservers filter:#group key:1 --an array of the servers for group 1 g = m.getservers filter:#group key:&quot;myGroup&quot; --an array of the servers for group &quot;myGroup&quot; g_name = m.GetGroupName 1 --the name of the first group m.deletegroup g_name --delete a group</p>\n\
<p>```</p>\n\
<p>``` -- WORKING WITH JOBS -- job = j[1] --pull a job out of the list</p>\n\
<p>jHandle = job.handle --the job&#39;s ID p = job.priority --job&#39;s priority if job.nonSeqFrames == True then frames = job.frames --one of those &quot;1,3,5-12&quot; frame lists else frames = (job.fromFrame as string) + &quot;-&quot; + (job.toFrame as string) --now frames is &quot;0-100&quot; if 0 and 100 are the start/end frames cameraArray = job.GetCameras() --an array of the camera names l = job.GetLog --the entire log, as text l = job.GetLog start:4 numLines:2 --gets the 4th and 5th entries of the log<br> statText = job.GetServerStatusText s[1] --text about a server, regarding this job num_workers = job.numServers --number of servers on this job job.frameOutputName = &quot;d:\\blah.bmp&quot; --change the output name isDevice = job.frameOutputDevice --true if the output is to a device, false otherwise share = job.managerShare --the manager share for this job job.filesize --size of the MAZ file for the job job.filesizeextracted --extracted size of the MAZ file for the job<br> ```</p>\n\
<p>``` -- WORKING WITH SERVERS -- srv = s[1] --pull a server out of the list sHandle = srv.Handle --the server&#39;s ID sName = srv.name --the server&#39;s machine name speed = srv.performance --server&#39;s performance index srv.ResetPerformance() --reset the index timeUsed = srv.totalTime --total time spent rendering sjHandle = srv.jobHandle --the handle of the server&#39;s current job, 0 if none sjFrameIndex = srv.jobFrameIndex --the index of the frame the server is rendering</p>\n\
<p>```</p>\n\
<p>``` --PRACTICAL EXAMPLE; get info about the frame being rendered sjHandle = srv.jobHandle sjIndex = srv.jobFrameIndex sJobs = m.getJobs filter:job key:sjHandle --should be an array with one entry frameInfo = (sJobs[1].getFrameInfo sjIndex) --get info about the current frame frameTime = frameInfo.elapsedTime</p>\n\
<p>```</p>\n\
<p>``` -- UPDATES FROM MANAGER -- --Jobs and Servers support GetUpdate and SendUpdate functions, -- for synchronizing with the manager job.status --should be busy</p>\n\
<p>job.Suspend() job.status --still says busy (status value is stale) job.GetUpdate() --download the latest news job.status --now says suspended s[1].GetUpdate() --servers also have Get/SendUpdate</p>\n\
<p>```</p>\n\
<p>``` -- CALLBACKS -- -- These are used to listen for messages from the manager, -- They are functions you can define, that will get called when -- the manager has something to say</p>\n\
<p>-- There are 6 possible callbacks -- Note: you can name these functions anything you want, but they must have correct paramters</p>\n\
<p>--NETPROGRESS CALLBACK; Called anytime a download/upload is underway, -- including anytime you fetch information about jobs or servers fn myNetProgress total current = --Note: two integer parameters format &quot;Progress: completed % out of %\\n&quot; current total</p>\n\
<p>--NETMESSAGE CALLBACK; Called when the manager has a text message for the user fn myNetMessage msg = --Note: one string parameter format &quot;Message: %\\n&quot; msg</p>\n\
<p>--UPDATE CALLBACK; Called when something has changed, like a job started or finished</p>\n\
<p>-- Let&#39;s you know when you need to make GetUpdate calls, or other refreshing fn myUpdate = job.GetUpdate() --example of what you might do</p>\n\
<p>--MANAGERDOWN CALLBACK; Called when the manager dies fn myManagerDown = format &quot;Manager is dead\\n&quot;</p>\n\
<p>--QUEUECONTROL CALLBACK; Called whenever queue control changes fn myQueueControl = format &quot;Queue control has changed\\n&quot;</p>\n\
<p>--QUERYCONTROL CALLBACK; Called when you have Queue Control, and another computer wants it</p>\n\
<p>fn myQueryControl clientName = ( --Note: one string parameter format &quot;The computer % wants queue control&quot; clientName m.wantControl = true -- use this to keep queue control m.wantControl = false -- use this to release queue control )</p>\n\
<p>--INSTALLING THE CALLBACKS; after you define the functions, you must give them to the -- manager as follows --Note: only one callback of each type is allowed (e.g., you can&#39;t have two &quot;Update&quot; callbacks) m.setcallback #Progress myNetProgress --install the &quot;Progress&quot; callback</p>\n\
<p>m.setcallback #Message myNetMessage --install the &quot;Message&quot; callback m.setcallback #Update myUpdate --install the &quot;Update&quot; callback m.setcallback #ManagerDown myManagerDown --install the &quot;ManagerDown&quot; callback m.setcallback #QueueControl myQueueControl --install the &quot;QueueControl&quot; callback m.setcallback #QueryControl myQueryControl --install the &quot;QueryControl&quot; callback</p>\n\
<p>```</p>\n\
<p>``` -- NETSTATUS OBJECTS -- --Read-only information about a computer on the network</p>\n\
<p>stat = s[1].netStatus --get network info about server 1 stat.boottime --make a query stat.Disks -- d = stat.workDisk --which is the disk for net-rendering work? stat.SpaceOnDisk d --megabytes of free space on the workdisk stat.memorySize --computer&#39;s memory in bytes (note: 1 meg = 1048576 bytes) s[1].GetUpdate() --this refreshes the netStatus object</p>\n\
<p>stat = m.netStatus --manager also has a NetStatus --Note: Manager has no GetUpdate(), you must fetch the NetStatus again to see any changes</p>\n\
<p>--To print out the operating system on the machine... --Win95 has a platformID of 1; WinNT has a platformID of 2 --Win2K is indicated by a majorBuild of 5 or more for WinNT --Win98 is indicated by a minorBuild greater than 0 for Win95. -- Also, build number and the CSDVersion string are not supported by Win95/98 format &quot;Windows %.%, Build %, %\\n&quot;<br> stat.majorVersion stat.minorVersion stat.buildNumber stat.CSDVersion</p>\n\
<p>```</p>\n\
<p>``` -- JOBFRAME OBJECTS -- num_frames = job.numFrames()</p>\n\
<p>frame = job.getFrameInfo 1 --get info about the 1st frame elapsed_time = frame.ElapsedTime --amount of time frame has been rendering</p>\n\
<p>num_rendElems = job.numRenderElements() --number of render elements for render if num_rendElems&gt;0 do ( rendElem = job.GetRenderElement 1 --pass the index of the element rendElem.enabled = false --turn off the rend element job.SetRenderElement 1 rendElem --update the job with the new changes job.SendUpdate() --upload the changes )</p>\n\
<p>```</p>\n\
<p>``` -- JOBSERVER OBJECTS -- --Read-only information about a server, in relation to a particular job j_num_servers = j[1].numServers --how many servers does the job have? js = j[1].GetServerInfo 1 --info about the job&#39;s first server sh = js.serverHandle --what&#39;s the server&#39;s handle? sn = js.serverName --what&#39;s the server&#39;s name? isWorker = js.active --whether this server participates in this job js_state = js.state --is the server busy with the job? has an error? etc</p>\n\
<p>--Print out some stats format &quot;rendering frame %, completed %, total time % hours\\n&quot;<br> js.currentFrame js.numFramesComplete js.elapsedTime</p>\n\
<p>--ways to get more info about this server... jSrv = m.GetServers filter:#handle key:sh --get the actual server object statText = j[1].GetServerStatusText jSrv[1] --text info from the server about this job</p>\n\
<p>```</p>\n\
<p>``` -- RENDERELEMENT OBJECTS -- --Information about particular render elements for a job n = j[1].numRenderElements --how many render elements for this job?</p>\n\
<p>re = j[1].GetRenderElement 1 --get the first one re.enabled = false --disable it re.filterEnabled = false --disable filtering re.name = &quot;newName&quot; --change its name useShadows = re.shadowsApplied --are shadows applied? (read-only) useShadows = re.atmosphereApplied --are atmospherics applied (read-only) re.output = &quot;C:\\share\\rendElem1.bmp&quot; --change its output path &amp; name j[1].SetRenderElement 1 re --update the job with the new changes</p>\n\
<p>j[1].SendUpdate --upload the changes</p>\n\
<p>```</p>\n\
<p>``` -- WEEKLY SCHEDULES -- -- a servers&#39; weekly schedule is an array of seven BitArrays; -- Each bitArray is a day, each bit is an hour sched = s[1].schedule sched[1][11] = false --sunday 11am, the server will not work sched[1][12] = false -- same for sunday noon s[1].attendedPriority = 60 --set the priorities for the server&#39;s schedule s[1].unattendedPriority = 10 s[1].schedule = sched --set the new schedule s[1].schedule --printout to prove the change worked s[1].SendUpdate() --upload the changes to this server --Note: a Schedule is just a BitArray and has no GetUpdate, --you must fetch it again from the server to see any changes</p>\n\
<p>```</p>\n\
<p>``` -- MISCELANEOUS FUNCTIONS -- jobList = #( j[3], j[1], j[2] ) --make an array of some jobs m.SetJobOrder jobList --rearrange the jobs; e.g. j[3] is now the first in the queue mName = (m.netStatus).computerName --the machine name of the manager</p>\n\
<p>```</p>\n\
<p>``` -- JOB &amp; SERVER FILTERS -- jobServers = m.getservers filter:#Job key:j[1] groupServers = m.getservers filter:#group key:&quot;Clouds&quot;</p>\n\
<p>```</p>\n\
<p>``` -- ENDING THE SEESION -- m.wantControl=true --other clients can now get QueueControl</p>\n\
<p>m.disconnect() --end this session -- m.kill() --brings down the manager, (would need queue control)</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";