var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: PlacementTool</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: PlacementTool</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-placementtool\"></a></div>\n\
<p>The <strong>PlacementTool Core Interface</strong> exposes the Placement Tool&#39;s controls and functionality to MAXScript. Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>PlacementTool.ActiveMode : boolean : Read|Write\n\
</pre></div><p>Get/set the Enabled state of the Placement Tool.</p>\n\
<p>When set to False (default), the Placement Tool will be disabled.</p>\n\
<p>When set to True, selected objects can be placed interactively in the scene by performing ray intersection will all other scene geometry, or can be rotated in place depending on the <span class=\'code\'>PlacementTool.RotateMode</span> property state.</p>\n\
<div class=\'codeBlock\'><pre>PlacementTool.RotateMode : boolean : Read|Write\n\
</pre></div><p>Get/set the state of the Rotate mode.</p>\n\
<p>When set to False (default), moving the mouse in the viewport will perform ray intersection with the scene geometry and place the selection to the intersection point.</p>\n\
<p>When set to True, moving the mouse up and down will rotate the selected objects about their up axes.</p>\n\
<div class=\'codeBlock\'><pre>PlacementTool.UseBase : boolean : Read|Write\n\
</pre></div><p>Get/set the state of Use Base As Pivot option.</p>\n\
<p>When set to False (default), the object&#39;s pivot will be used to perform the alignment / rotation.</p>\n\
<p>When set to True, the base of the object will be used instead.</p>\n\
<div class=\'codeBlock\'><pre>PlacementTool.PillowMode : boolean : Read|Write\n\
</pre></div><p>Get/set the state of the Pillow Mode option.</p>\n\
<div class=\'codeBlock\'><pre>PlacementTool.AutoParent : boolean : Read|Write\n\
</pre></div><p>Get/set the state of the Auto-Parent option.</p>\n\
<p>When set to False (default), objects will be placed without changing parent-child relationship.</p>\n\
<p>When set to True, objects will be automatically parented to the object whose surface they were placed on.</p>\n\
<div class=\'codeBlock\'><pre>PlacementTool.UpAxis : enum : Read|Write \n\
    UpAxis enums: {#Positive_X | #Positive_Y | #Positive_Z | #Negative_X | #Negative_Y | #Negative_Z}\n\
</pre></div><p>Get/set the state of the Object Up Axis option.</p>\n\
<p>Default is <span class=\'code\'>#Positive_Z</span> .</p>\n\
<p>This option controls which axis of the placed object will be oriented along the surface&#39;s normal.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;PlacementTool.ShowOptionDialog()\n\
</pre></div><p>Opens the <strong>&quot;Placement Settings&quot;</strong> options dialog.</p>\n\
<p>Available in <strong>3ds Max 2016 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;IntegerPtr&gt;PlacementTool.GetCommandMode()\n\
</pre></div><p>Returns the command mode of the Placement Tool as a Pointer value.</p>\n\
<p>Available in <strong>3ds Max 2016 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;value&gt;PlacementTool.HitTestScene &lt;ray&gt;Ray\n\
</pre></div><p>Performs a hit test against the scene using the ray value passed as by-reference In parameter.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;PlacementTool.PlaceNode &lt;time&gt;Time &lt;node&gt;SelectedNode &lt;point3&gt;Position &lt;point3&gt;Normal &lt;node&gt;TargetNode &lt;boolean&gt;bRotateUpAxisToNormal\n\
</pre></div><p>Places the specified node on the surface of the specified target at the given time using the Position and Normal values acquired from the <span class=\'code\'>PlacementTool.HitTestScene()</span> method.</p>\n\
<p>The <span class=\'code\'>Time</span> argument specifies the time at which to evaluate the objects.</p>\n\
<p>The <span class=\'code\'>SelectedNode</span> argument provides the node to be placed.</p>\n\
<p>The <span class=\'code\'>&amp;Position</span> argument passes the position as a by-reference in parameter.</p>\n\
<p>The <span class=\'code\'>&amp;Normal</span> argument passes the Normal vector as a by-reference in parameter.</p>\n\
<p>The <span class=\'code\'>TargetNode</span> argument specifies the node whose surface to use for placement.</p>\n\
<p>The <span class=\'code\'>bRotateUpAxisToNormal</span> boolean argument specifies whether to orient the up axis (determined by <span class=\'code\'>PlacementTool.UpAxis</span> ) of the placed node to the surface normal at the intersection point.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` ( resetMaxFile #noprompt</p>\n\
<p>--Create some geometry to test against local p = plane width:210 length:210 widthsegs:200 lengthsegs:200 local s = sphere radius:50 segs:100 pos:[14,15,-25] local n = noiseModifier() addModifier p n n.strength = [0,0,50] n.scale = 50.0</p>\n\
<div class=\'codeBlock\'><pre>  local theObjects = #() --collect objects to be placed in this array\n\
  for y = -100 to 100 by 5 do\n\
  (\n\
      for x = -100 to 100 by 5 do\n\
      (\n\
          local c = cone pos:[x,y,100] radius1:3 height:5 wirecolor:blue --create a grid of cones above the surfaces\n\
          append theObjects c --collect the cones in the array\n\
      )\n\
  )\n\
  local st = timestamp() --get a time stamp\n\
  for o in theObjects do --loop though all cones\n\
  (\n\
      local result = PlacementTool.HitTestScene (Ray o.pos [0,0,-1]) --intersect a ray down the -Z\n\
      local minDist = 100000.0 --initialize a variable for the minimum distance\n\
      local newPos = o.pos --set the new position to the current position of the current cone\n\
      local newNormal = o.dir --set the new normal to the current direction of the current cone\n\
      local theTarget = undefined\n\
      for i in result do --loop through all results\n\
      (\n\
          local dist = (distance i[2].pos o.pos) --calculate the distance to the hit\n\
          if dist &lt; minDist do  --if it was closer, \n\
          (\n\
              minDist = dist --set the minimum distance to the current distance value\n\
              newPos = i[2].pos --record the position\n\
              newNormal = i[2].dir --and the normal\n\
              theTarget = i[1] --remember the object that was hit\n\
          )\n\
      )\n\
      if theTarget != undefined do --only place the object if a target was found\n\
          PlacementTool.PlaceNode currentTime o &amp;newPos &amp;newNormal theTarget true\n\
  )\n\
  format &quot;Placement of % objects took % ms.\\n&quot; theObjects.count (timestamp()-st) --print the time\n\
</pre></div><p>)</p>\n\
<p>```</p>\n\
<div class=\'codeBlock\'><pre> ![](../../../../../images/GUID-850899B0-9260-4A82-A231-62D29555F476-low.png)\n\
</pre></div></blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";