var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: pop</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: pop</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-pop\"></a></div>\n\
<p>The <strong>pop Core Interface</strong> exposes the properties and methods related to the set up and simulation of <strong>Populate</strong> systems.</p>\n\
<p>Available in <strong>3ds Max 2014 and higher</strong>.</p>\n\
<p>The Populate system distinguishes between <strong>Pedestrians</strong> - characters entering, walking along Flows and exiting the scene, and <strong>Idlers</strong> - characters standing or sitting around.</p>\n\
<p>Other than the Idlers, the Pedestrians can be reused - &quot;spawned&quot; in different places at different times. Each animation of a Pedestrian character, from the time it enters a portal to the time it exits a portal, is known as a “Spawn”.</p>\n\
<p>The Spawning implementation has changed since <strong>3ds Max 2015</strong>. In <strong>3ds Max 2014</strong>, all Pedestrians existed and were animated throughout the entire length of the animation. Although they might have had multiple Spawns, there was no time between Spawns - they only disappeared for a few frames to facilitate motion blur. All Pedestrians were always in the scene, and the same number of Pedestrians existed throughout the animation.</p>\n\
<p>Since <strong>3ds Max 2015</strong>, because the density of Flows can be animated and Portals can be opened and closed, the number of Pedestrians in the scene can vary drastically throughout the length of the animation. A simulation could start with zero density for all portals, and no Pedestrians in the scene, then the density could increase to add a lot of characters to the scene, and then decrease so that when they leave their flow they can’t spawn anywhere else.</p>\n\
<p>There are five operations that can be performed on selected Pedestrians: Regenerate, Swap Appearance, Switch Resolution, Delete, and Bake. When performed on a Pedestrian with multiple Spawns, some of these operations will affect only the current Spawn – the one which is active at the current frame, and others will affect all Spawns of the selected Pedestrian. The decision how to make the operations work was based on expected users needs, experimentation, and technical reasons. The following table shows how each operation works:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">Operation</th>\n\
<th align=\"left\">Effect</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">Regenerate</td>\n\
<td align=\"left\">Affects only the <strong>current</strong> Spawn</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">Swap Appearance</td>\n\
<td align=\"left\">Affects <strong>all</strong> Spawns</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">Switch Resolution</td>\n\
<td align=\"left\">Affects <strong>all</strong> Spawns</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">Delete</td>\n\
<td align=\"left\">Affects only the <strong>current</strong> Spawn</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">Bake</td>\n\
<td align=\"left\">Affects <strong>all</strong> Spawns</td>\n\
</tr>\n\
</table>\n\
<p>The scripted methods exposing operations which affect only the current Spawn take <span class=\'code\'>&lt;time&gt;</span> as an argument, in order to specify which Spawn should be affected.</p>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>pop.DisplayType : enum : Read|Write\n\
       DisplayType enums: {#StickFigure|#CrowdCustom|#CrowdSkin}\n\
</pre></div><p>Get/set the Display Type of the characters.</p>\n\
<p>Default is <span class=\'code\'>#CrowdSkin</span> .</p>\n\
<div class=\'codeBlock\'><pre>pop.TurnOpt : enum : Read|Write\n\
       TurnOpt enums: {#hybrid|#maxspeed|#maxdistribution|#mindistance|#none}\n\
</pre></div><p>Get/set the Turn Optimization mode.</p>\n\
<p>Default is <span class=\'code\'>#hybrid</span> .</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>pop.NumFrames : integer : Read|Write\n\
</pre></div><p>Get/set the number of frames to simulate.</p>\n\
<p>Default is 300.</p>\n\
<div class=\'codeBlock\'><pre>pop.RealWorldScale : float : Read|Write\n\
</pre></div><p>Get/set the World scale relatively to the current System Units settings.</p>\n\
<p>Default is 1.0.</p>\n\
<div class=\'codeBlock\'><pre>pop.SeatFemalePct : float : Read|Write\n\
</pre></div><p>Get/set the percentage of female seats.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>pop.SeatMaxTalkDist : float : Read|Write\n\
</pre></div><p>Get/set the maximum talking distance when seated.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>pop.SeatMaxTalkAngle : float : Read|Write\n\
</pre></div><p>Get/set the maximum talking angle when seated.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;pop.NumStandingIdlers()\n\
</pre></div><p>Returns the number of standing (not seated) idle characters in the simulation.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;pop.NumSeatedIdlers()\n\
</pre></div><p>Returns the number of seated idle characters in the simulation.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;pop.NumPedestrians()\n\
</pre></div><p>Returns the number of pedestrian (non-idle) characters in the simulation.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;pop.GetStandingIdler &lt;integer&gt;index\n\
</pre></div><p>Returns the node of the indexed standing idle character.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;pop.GetSeatedIdler &lt;integer&gt;index\n\
</pre></div><p>Returns the node of the indexed seated idle character.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;pop.GetPedestrian &lt;integer&gt;index\n\
</pre></div><p>Returns the node of the indexed pedestrian character.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;pop.AddIdleArea &lt;node&gt;IdleArea\n\
</pre></div><p>Adds the specified <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Subclasses/GeometryClass-Node/Geometry-Populate/IdleAreaObj-GeometryClass.html\' title=\'\'>IdleAreaObj object</a> to the flow simulation.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;pop.AddFlow &lt;node&gt;Flow\n\
</pre></div><p>Adds the specified <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Subclasses/GeometryClass-Node/Geometry-Populate/Flow-GeometryClass.html\' title=\'\'>Flow object</a> to the flow simulation.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;pop.AddSeat &lt;node&gt;Seat\n\
</pre></div><p>Adds the specified <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Subclasses/GeometryClass-Node/Geometry-Populate/Seat-GeometryClass.html\' title=\'\'>Seat object</a> to the flow simulation.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;pop.Simulate()\n\
</pre></div><p>Simulates the flow using the current settings.</p>\n\
<p>Equivalent to pressing the <strong>Simulate</strong> icon in the Populate &gt; Simulation panel of the UI.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;pop.ResimulateSelected() \n\
</pre></div><p>Resimulate the selected characters.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;pop.RegenerateSelected &lt;time&gt;time\n\
</pre></div><p>Regenerates the selected characters at the specified time.</p>\n\
<p>Equivalent to pressing the <strong>Regenerate Selected</strong> icon in the Populate &gt; Simulation panel of the UI.</p>\n\
<p>An argument specifying the time to regenerate at has been added to the existing method.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;pop.DisplayEnv &lt;boolean&gt;show\n\
</pre></div><p>When the argument is True, the Environment objects (Flows, IdleAreas) will be displayed.</p>\n\
<p>When the argument is False, the Environment objects will be hidden.</p>\n\
<p>Corresponds to the <strong>Show Environment</strong> toggle icon in the Populate &gt; Display panel of the UI.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;pop.DisplayPeople &lt;boolean&gt;show\n\
</pre></div><p>When the argument is True, the characters will be displayed.</p>\n\
<p>When the argument is False, the characters objects will be hidden.</p>\n\
<p>Corresponds to the <strong>Show People</strong> toggle icon in the Populate &gt; Display panel of the UI.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;pop.DisplayMarks &lt;boolean&gt;show\n\
</pre></div><p>When the argument is True, displays the marks.</p>\n\
<p>When the argument is False, hides the marks.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;pop.SetSelectedSeatsGender()\n\
</pre></div><p>Sets the Gender of the selected seats according to the <span class=\'code\'>pop.SeatFemalePct</span> seat gender percentage value.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;pop.ShowAppearanceUI()\n\
</pre></div><p>Opens the <strong>&quot;Crowd Style Customization&quot;</strong> dialog.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;pop.SwapSelPeopleAppearance()\n\
</pre></div><p>Swaps the appearance of the selected characters.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;pop.DeletePeople()\n\
</pre></div><p>Deletes the characters from the simulation.</p>\n\
<p>Equivalent to clicking the <strong>Delete People</strong> icon in the Populate &gt; Display panel of the UI.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;pop.DeleteSelPeople &lt;time&gt;time\n\
</pre></div><p>Deletes the selected characters from the simulation at the given time.</p>\n\
<p>Affects the current Spawn only. See the beginning of this page for more info about Spawning.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;pop.SwitchSelPeopleResolution()\n\
</pre></div><p>Switches the mesh and texture detail of the selected characters when Textured Skin is active.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;pop.SwitchSelPeoplePos &lt;time&gt;time\n\
</pre></div><p>Switches the positions of the selected characters at the given time.</p>\n\
<p>Affects the current Spawn only. See the beginning of this page for more info about Spawning.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;pop.BakeSelPeople()\n\
</pre></div><p>Bakes the selected characters to <strong>3ds Max</strong> Skin and Bones.</p>\n\
<p>The animation can be edited and any modifiers can be applied to the mesh. Characters can also be exported via FBX after they are baked.</p>\n\
<p>This functionality is <strong>only available through MAXScript</strong>.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;pop.SaveTextureMaps &lt;boolean&gt;save\n\
</pre></div><p>When the argument is True, saves the texture maps.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` theFlow = Flow() --Create a Flow object --&gt; $Flow:Flow001 @ [0.000000,0.000000,0.000000] theFlow.AddPoint [0,0,0] --Add some points --&gt; true theFlow.AddPoint [1000,0,0] --&gt; true theFlow.AddPoint [15000,500,0] --&gt; true theFlow.AddPoint [1000,1000,0] --&gt; true</p>\n\
<p>pop.AddFlow theFlow --Add the Flow to the Populate system --&gt; true pop.Simulate() --Perform the simulation --&gt; OK pop.DisplayEnv false --Hide the Flow environment, leaving only the people --&gt; OK pop.DisplayType = #StickFigure --Switch the character display to stick figures --&gt; #StickFigure</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";