var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: python</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: python</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-python\"></a></div>\n\
<p>The <strong>Python Core Interface</strong> exposes the Python engine&#39;s controls to MAXScript. Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<p>For examples of how to use this interface, see <a href=\'#!/url=./developer/Interaction-with-Other/Executing-Python-from-MAXScript.html\' title=\'\'>Executing Python from MAXScript</a></p>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;python&gt;.Import : value : Read|Write\n\
 \n\
</pre></div><p>This property points to the <span class=\'code\'>Import()</span> function used to import a native Python module for use in MAXScript.</p>\n\
<div class=\'codeBlock\'><pre>&lt;python&gt;.Reload : value : Read|Write\n\
</pre></div><p>This property points to the <span class=\'code\'>Reload()</span> function used to reload a native Python module. This can be useful if the module has become &quot;dirty&quot;, or some members have been re-defined.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;enum&gt;python.Init throwOnError:&lt;boolean&gt; \n\
    Init enums: {#success|#pathError|#argumentError|#initError|#scriptFileError|#executeError\n\
    Init - no automatic redraw after invoked\n\
    throwOnError default value: true\n\
</pre></div><p>Initializes the Python engine and returns <span class=\'code\'>#success</span> .</p>\n\
<p>If the initialization failed, returns an enum describing the cause of the failure - path error, initialization error, script file error or execution error.</p>\n\
<p>If the optional argument <span class=\'code\'>throwOnError:</span> is set to False, no error will be thrown if one is encountered.</p>\n\
<div class=\'codeBlock\'><pre>&lt;enum&gt;python.Execute &lt;string&gt;script fileName:&lt;filename&gt; throwOnError:&lt;boolean&gt; clearUndoBuffer:&lt;boolean&gt; \n\
\n\
    Execute enums: {#success|#pathError|#argumentError|#initError|#scriptFileError|#executeError\n\
    fileName default value: undefined \n\
    throwOnError default value: true \n\
    clearUndoBuffer default value: true\n\
</pre></div><p>Executes the Python script specified by the string in the first argument, or, if the optional <span class=\'code\'>fileName:</span> argument is provided, executes the specified Python script file.</p>\n\
<p>Returns <span class=\'code\'>#success</span> if the execution was successful, or one of the other enums describing the cause of the failure - path error, initialization error, script file error or execution error.</p>\n\
<p>If the optional argument <span class=\'code\'>throwOnError:</span> is set to False, no error will be thrown if one is encountered.</p>\n\
<p>If the optional argument <span class=\'code\'>clearUndoBuffer:</span> is set to False, the Undo Buffer will not be cleared before execution.</p>\n\
<div class=\'codeBlock\'><pre>&lt;enum&gt;python.ExecuteFile &lt;filename&gt;fileName throwOnError:&lt;boolean&gt; clearUndoBuffer:&lt;boolean&gt; \n\
\n\
    ExecuteFile enums: {#success | #pathError | #initError | #scriptFileError | #executeError} \n\
    throwOnError default value: true \n\
    clearUndoBuffer default value: true\n\
</pre></div><p>Executes the Python script file specified by the first argument.</p>\n\
<p>Returns <span class=\'code\'>#success</span> if the execution was successful, or one of the other enums describing the cause of the failure - path error, initialization error, script file error or execution error.</p>\n\
<p>If the optional argument <span class=\'code\'>throwOnError:</span> is set to False, no error will be thrown if one is encountered.</p>\n\
<p>If the optional argument <span class=\'code\'>clearUndoBuffer:</span> is set to False, the Undo Buffer will not be cleared before execution.</p>\n\
<div class=\'codeBlock\'><pre>&lt;value&gt;python.Import &lt;string&gt;moduleName throwOnError:&lt;boolean&gt;\n\
    throwOnError default value: true\n\
</pre></div><p>Imports the specified Python module for use in MAXScript.</p>\n\
<p>If the optional argument <span class=\'code\'>throwOnError:</span> is set to False, no error will be thrown if one is encountered.</p>\n\
<p>Available in <strong>3ds Max 2017 and higher</strong></p>\n\
<div class=\'section\'><a id=\"example\"></a><h3 id=\"example\">Example</h3></div>\n\
<div class=\'codeBlock\'><pre>-- import the Python built-in methods and constants\n\
bi = Python.Import &quot;__builtin__&quot;\n\
-- &lt;module &#39;__builtin__&#39; (built-in)&gt;\n\
bi.pow 2 3\n\
-- 8 \n\
-- use Python dictionary type\n\
d = bi.dict one:1 two:2 three:3 -- {u&#39;one&#39;: 1, u&#39;three&#39;: 3, u&#39;two&#39;: 2}\n\
-- {u&#39;one&#39;: 1, u&#39;three&#39;: 3, u&#39;two&#39;: 2} \n\
d[&quot;one&quot;]\n\
-- 1\n\
&lt;value&gt;python.Reload &lt;value&gt;module throwOnError:&lt;boolean&gt;\n\
    throwOnError default value: true\n\
</pre></div><p>Reloads the specified Python module. This can be useful if a module keyword gets re-defined.</p>\n\
<p>If the optional argument <span class=\'code\'>throwOnError:</span> is set to False, no error will be thrown if one is encountered.</p>\n\
<p>Available in <strong>3ds Max 2017 and higher</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;python.GetLastError() \n\
</pre></div><p>Returns the last error message as string.</p>\n\
<p>This is especially useful when executing with <span class=\'code\'>throwOnError:</span> set to False - if the return value is not <span class=\'code\'>#success</span> , you can use this method to display your own error message without throwing an error.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` ( result = python.Init throwOnError:false if result == #success do ( result = python.Execute &quot;print &quot;Hello World!&quot;&quot; throwOnError:false ) if result != #success then ( format &quot;Python Initialization Failed due to %\\n&quot; (result as string) format &quot;ERROR: %\\n&quot; (python.GetLastError()) ) else format &quot;The Python Execution Was A World-Wide Success!\\n&quot; OK )</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` Hello World! The Python Execution Was A World-Wide Success! OK</p>\n\
<p>```</p>\n\
<p><strong>CHANGE LINE 5 - MISTYPE PRINT AS PRUNT:</strong></p>\n\
<p>``` result = python.Execute &quot;prunt &quot;Hello World!&quot;&quot; throwOnError:false</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` Python Initialization Failed due to executeError ERROR: &lt;type &#39;exceptions.SyntaxError&#39;&gt; invalid syntax (, line 1) OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";