var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: SceneConverter</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: SceneConverter</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-sceneconverter\"></a></div>\n\
<p>This Core Interface exposes properties and methods for setting up the scene converter system and its rules. Available in <strong>in 3ds Max 2017 and higher</strong>.</p>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>SceneConverter.visible : boolean : Read|Write\n\
</pre></div><p>Get/set the visible state of the Scene Converter dialog.</p>\n\
<p>Setting the property to True will open the dialog, setting it to False will close it.</p>\n\
<p>Getting the property will indicate whether the dialog is open (True) or closed (False).</p>\n\
<p>See also the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/UtilityPlugin-Classes/Scene_Converter.html\' title=\'\'>Scene_Converter: GlobalUtilityPlugin</a> class and its Actions MixinInterface which exposes a <span class=\'code\'>.show()</span> method that can be used to open the dialog.</p>\n\
<div class=\'codeBlock\'><pre>SceneConverter.OpenWhenNeededOnFileOpen : boolean : Read|Write\n\
</pre></div><p>Get/set the state of the &quot;Open Scene Converter on file open when missing plugins&quot; checkbox.</p>\n\
<p>When set to False (default), the Scene Converter will not be opened automatically when loading a scene with missing plugins.</p>\n\
<p>When set to True, the Scene Converter will be opened automatically if missing plugins are detected.</p>\n\
<div class=\'codeBlock\'><pre>SceneConverter.BackupOriginalFiles : boolean : Read|Write\n\
</pre></div><p>Get/set whether to back up the original files before performing a conversion.</p>\n\
<p>When set to True, a backup copy with the suffix &quot;_backup&quot; will be created.</p>\n\
<div class=\'codeBlock\'><pre>SceneConverter.ConvertOnlySelectedObjects : boolean : Read|Write\n\
</pre></div><p>Get/set the state of the &quot;Apply only to selected objects&quot; checkbox.</p>\n\
<p>When set to False (default), the conversion will be applied to the whole scene.</p>\n\
<p>When set to True, the conversion will only be applied to the selected objects.</p>\n\
<div class=\'codeBlock\'><pre>SceneConverter.ApplyOnlySelectedRules : boolean : Read|Write\n\
</pre></div><p>Get/set whether to apply all rules (False) or only the selected rules (True). The selected rules are the rules selected in the Scene Converter dialog, which requires the user to use the UI.</p>\n\
<p>Default is False.</p>\n\
<div class=\'codeBlock\'><pre>SceneConverter.FilterConversionTypesFromScene : boolean : Read|Write\n\
</pre></div><p>Get/set the state of the &quot;Only display types in the current scene&quot; checkbox.</p>\n\
<p>When set to False (default), all object types that can be converted will be listed in the Source list of the dialog.</p>\n\
<p>When set to True, only the object types found in the current scene that can be converted will be listed in the Source list of the dialog.</p>\n\
<div class=\'codeBlock\'><pre>SceneConverter.ScriptFolder : string : Read|Write\n\
</pre></div><p>Get/set the Scene Converter Script Folder.</p>\n\
<p>Default is &quot;C:\\Users\\%USERNAME%\\AppData\\Local\\Autodesk\\3dsMax\\[Max Version]\\[Language]\\Scene Converter&quot;.</p>\n\
<p>This folder has two sub-folders:</p>\n\
<p>&quot;\\ConversionScripts&quot; containing the MAXScript files describing the conversion rules for individual object types,and</p>\n\
<p>&quot;\\ConversionPresets&quot; containing the MAXScript files describing the conversion presets for one renderer to another.</p>\n\
<div class=\'codeBlock\'><pre>SceneConverter.BatchMode : enum : Read|Write\n\
</pre></div><p>BatchMode enums: {#XRefs|#File|#Folder}</p>\n\
<p>Get/set the state of the &quot;Batch Conversions&quot; radio buttons under the &quot;Options&quot; tab of the dialog.</p>\n\
<p>Possible values are:</p>\n\
<ul>\n\
<li>0 - <span class=\'code\'>#XRefs</span> (default) – &quot;Convert Reference Files&quot; mode, will convert all external references of the scene.</li>\n\
<li>1 - <span class=\'code\'>#File</span> – &quot;Convert File&quot; mode, will convert the specified file.</li>\n\
<li>2 - <span class=\'code\'>#Folder</span> – &quot;Convert Folder&quot; mode, will convert the scene files in the specified folder.</li>\n\
</ul>\n\
<p>The integers 0, 1 and 2 can be used in place of the enums, but getting the property will always return the enum names.</p>\n\
<div class=\'codeBlock\'><pre>sceneconverter.AutoRemoveMissingLegacyAssets : boolean : Read|Write\n\
</pre></div><p>Available in <strong>3ds Max 2018.4 and higher</strong>: Gets or sets the state of the &quot;Automatically remove missing legacy assets on file open&quot; checkbox in the Scene Converter dialog. <strong>Note</strong>: Setting this to true will remove all missing legacy assets each time a file is opened or merged without the Scene Converter dialog appearing.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;SceneConverter.ConvertScene()\n\
</pre></div><p>Equivalent to pressing the &quot;Convert Scene&quot; button in the dialog.</p>\n\
<p>Performs the conversion of the current scene according to the set rules.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;SceneConverter.CancelConversion()\n\
</pre></div><p>Equivalent to pressing the &quot;Cancel&quot; button in the dialog.</p>\n\
<p>Cancels an ongoing scene conversion process.</p>\n\
<p>Applies to all possible conversion processes, including current scene, other MAX file, XRefs, or Batch conversion.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;SceneConverter.SaveSceneMaterialLibrary &lt;filename&gt;LibraryFullPathFilename\n\
</pre></div><p>Saves a .MAT Material Library with the scene materials.</p>\n\
<p>The argument is the full filename and path of the Material Library.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;SceneConverter.OverwriteFromMaterialLibrary &lt;filename&gt;LibraryFullPathFilename\n\
</pre></div><p>Replaces the scene materials and maps with material and maps with the same names from the specified .MAT Material Library.</p>\n\
<p>The argument is the full filename and path of the Material Library.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SceneConverter.ConvertAllReferencedFiles()\n\
</pre></div><p>Performs conversion of all XRef files without converting the current scene.</p>\n\
<p>Returns True on success, False on failure.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SceneConverter.ConvertMaxFile &lt;filename&gt;MaxFullpathFilename\n\
</pre></div><p>Performs conversion of the specified .MAX file.</p>\n\
<p>Returns True on success, False on failure.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SceneConverter.ConvertFolder &lt;string&gt;Folder\n\
</pre></div><p>Performs conversion of the .MAX files in the specified folder and its sub-folders.</p>\n\
<p>Returns True on success, False on failure.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SceneConverter.LoadConversionPreset &lt;filename&gt;presetFilename\n\
</pre></div><p>Loads the specified conversion preset.</p>\n\
<p>The argument is the fully qualified file name and path of the preset script file.</p>\n\
<p>Existing presets can be found by looking in the ConversionPresets subfolder of the SceneConverter.ScriptFolder folder and getting all .MS files using <span class=\'code\'>getFiles()</span>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` thePresets = getFiles (SceneConverter.ScriptFolder + @&quot;ConversionPresets*.ms&quot;) --get all preset files if thePresets.count &gt; 0 then SceneConverter.LoadConversionPreset thePresets[1] --load the first preset found, if any else format “--No Presets Found!\\n”</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;string array&gt;GetMissingLegacyAssetsName()\n\
      GetMissingLegacyAssetsName - no automatic redraw after invoked\n\
</pre></div><p>Available in <strong>3ds Max 2018.4 and higher</strong>: Returns a tab of strings, which is the list of missing assets.</p>\n\
<blockquote>\n\
<p>Note: This function will return missing assets for any plug-in, whether it is a legacy plug-in or not.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;RemoveMissingLegacyAssetsFromScene &lt;&amp;string array&gt;TabString_MissingLegacyAssetsNames\n\
       RemoveMissingLegacyAssetsFromScene - no automatic redraw after invoked\n\
       TabString_MissingLegacyAssetsNames is In and Out parameter\n\
</pre></div><p>Available in <strong>3ds Max 2018.4 and higher</strong>: Takes a tab of strings, which are the missing assets to remove from the scene. Passing an empty string array will remove all the missing assets in the scene.</p>\n\
<blockquote>\n\
<p>Note: This function will return missing assets for any plug-in, whether it is a legacy plug-in or not.</p>\n\
</blockquote>\n\
<p><strong>The following methods expose functionality that is meant for internal use only:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;SceneConverter.ClearInvalidClassIDs()\n\
</pre></div><p>For Internal use only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;SceneConverter.GetNumInvalidClassIDs &lt;enum&gt;classIDType\n\
</pre></div><p>For Internal use only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;int by value array&gt;SceneConverter.GetInvalidClassIDs &lt;enum&gt;classIDType &lt;integer&gt;index\n\
</pre></div><p>For Internal use only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SceneConverter.AddInvalidClassID &lt;enum&gt;classIDType &lt;Integer64 array&gt;classIDAs2IntegersInATab\n\
    classIDType enums: {#eLight|#eMaterial|#eMap|#eGeometry|#eCamera|#eExposureControl|#eRenderEffect|#eRenderElement|#eOther} \n\
     \n\
</pre></div><p>For Internal use only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SceneConverter.RemoveInvalidClassID &lt;enum&gt;classIDType &lt;integer&gt;index\n\
    classIDType enums: {#eLight|#eMaterial|#eMap|#eGeometry|#eCamera|#eExposureControl|#eRenderEffect|#eRenderElement|#eOther}\n\
</pre></div><p>For Internal use only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;SceneConverter.AddLoadedStandinRef &lt;maxObject&gt;standin &lt;string&gt;name &lt;integer&gt;isMentalRay\n\
</pre></div><p>For Internal use only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SceneConverter.AddConversionRule &lt;Integer64 array&gt;sourceClassID &lt;Integer64 array&gt;destinationClassID scriptID:&lt;string&gt; sourceAutodeskMaterialBaseType:&lt;string&gt; destinationAutodeskMaterialBaseType:&lt;string&gt;\n\
   scriptID default value: &quot;&quot; \n\
      sourceAutodeskMaterialBaseType default value: &quot;&quot; \n\
      destinationAutodeskMaterialBaseType default value: &quot;&quot;\n\
</pre></div><p>For Internal use only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SceneConverter.RemoveFromScene &lt;Integer64 array&gt;sourceClassID sourceAutodeskMaterialBaseType:&lt;string&gt;\n\
   sourceAutodeskMaterialBaseType default value: &quot;&quot;\n\
</pre></div><p>For Internal use only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SceneConverter.DoNotConvert &lt;Integer64 array&gt;sourceClassID sourceAutodeskMaterialBaseType:&lt;string&gt;\n\
   sourceAutodeskMaterialBaseType default value: &quot;&quot; \n\
     \n\
</pre></div><p>For Internal use only.</p>\n\
<p><strong>Actions:</strong></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";