var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: SceneEffectLoader</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: SceneEffectLoader</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-sceneeffectloader\"></a></div>\n\
<p>This Core Interface exposes <strong>the Scene Effect Loader Utility</strong> to MAXScript.</p>\n\
<p>Available in <strong>3ds Max 9 and higher</strong>.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SceneEffectLoader.LoadSceneEffect &lt;filename&gt;effectFile effectType:&lt;enum&gt; numberOfPasses:&lt;integer&gt;   \n\
\n\
effectType enums: { #Post | #Pre | #Env}     \n\
effectType default value: #Post      \n\
numberOfPasses default value: 0   \n\
</pre></div><p>Loads the specified effects file into the Scene Effect Loader.</p>\n\
<p>Loads the specified file and registers it with the Scene Effect system. The system maintains three lists: Post, Pre, and Env.</p>\n\
<p><span class=\'code\'>#Post</span> - The effect is applied at the end of the scene graph. For example, Sepia or edge detect.</p>\n\
<p><span class=\'code\'>#Pre</span> - Runs before any geometry is rendered. Useful for background effects. Only the first loaded pre-effect will be used.</p>\n\
<p><span class=\'code\'>#Env</span> - Environmental effects. These are run in a separate pass and generally create data for object based shaders or shaders later on in the scene graph. For example, shadows or depth info.</p>\n\
<p>To specify which list the effect belongs to, use the effectType: argument.</p>\n\
<p>The numberOfPasses: argumentis only used with Env type shaders. Environment shaders must specify how many passes it requires to the system, for example, to create a cubemap, the shader will need six passed.</p>\n\
<p>The lists are maintained in the order they are generated. This means that the effects are run in the same order. So, if you want to reorganize the list, simply remove all effects and apply them in the correct order.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;SceneEffectLoader.ResetEffects() \n\
</pre></div><p>Resets the Scene Effect Loader, removing all effects.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SceneEffectLoader.EnableSceneEffects &lt;boolean&gt;enable \n\
</pre></div><p>Enables or disables the Scene Effect Loader depending on the boolean argument. If there are no &quot;post&quot; effects present, the system will not be enabled. There needs to be at least one post effect for the system to be able to render.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SceneEffectLoader.IsSceneEffectsEnabled() \n\
</pre></div><p>Returns true if the Scene Effect Loader is enabled, false otherwise.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;SceneEffectLoader.GetNumberOfSceneEffects effectType:&lt;enum&gt; \n\
\n\
effectType enums: { #Post | #Pre | #Env } \n\
effectType default value: #Post \n\
</pre></div><p>Returns the number of scene effects currently loaded in the Scene Effect Loader. By default, returns only Post Effects unless the effect type is specified explicitly.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;SceneEffectLoader.RemoveSceneEffect &lt;index&gt;index effectType:&lt;enum&gt; \n\
\n\
effectType enums: { #Post | #Pre | #Env } \n\
effectType defaultvalue: #Post \n\
</pre></div><p>Removes the indexed scene effect from the Loader. By default, it affects the Post Effects list. A different effect type can be specified to affect the corresponding effects list.</p>\n\
<div class=\'codeBlock\'><pre>&lt;material&gt;SceneEffectLoader.GetSceneEffect &lt;index&gt;index effectType:&lt;enum&gt; \n\
\n\
effectType enums: { #Post | #Pre | #Env } \n\
effectType default value: #Post \n\
</pre></div><p>Returns a DirectX Shader material hosting the indexed effect from the specified effects list.</p>\n\
<p>For example, if the Post list contains the effect post_corona.fx, calling this method with index 1 will create a DirectX Shader with this fx file loaded, which can be assigned to any slot of the Material Editor for tweaking or manipulated using MAXScript.</p>\n\
<p>Note: You can run the following example only if the Viewport driver is legacy Direct3D.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` theFile = (GetDir #maxroot + &quot;maps\\fx\\scene\\post_corona.fx&quot;) --the FX file SceneEffectLoader.LoadSceneEffect theFile --add the file to the Post list. theShader = SceneEffectLoader.GetSceneEffect 1 --get the first Post effect theShader.GlowCol = blue --set the glow color to blue theShader.Bias = 8.0 --set the bias to 8 meditmaterials[1] = theShader --assign to MEdit slot 1 for manual tweaking SceneEffectLoader.EnableSceneEffects true --enable the scene effects</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";