var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: INodeShadingProperties</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: INodeShadingProperties</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-inodeshadingproperties\"></a></div>\n\
<p>The <strong>INodeShadingProperties Node Interface</strong> exposes the node-related viewport shading properties to MAXScript.</p>\n\
<p>Only nodes whose base object is of Light superclass will effectively use these properties, but the property can be set in any node.</p>\n\
<p>Available in <strong>3ds Max 2008</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>Interface: INodeShadingProperties \n\
</pre></div><p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>INodeShadingProperties.ViewportIllumination : boolean : Read|Write   \n\
</pre></div><p>When set to <span class=\'code\'>true</span> (default), enables Viewport Illumination for the node, assuming the base object is a Light and the Viewport Shading mode is set to Best (SM3.0) - see<a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/I-J-K/Interface-IViewportShadingMgr.html\' title=\'\'>Interface: IViewportShadingMgr</a> on how to enable the advanced shading modes. The Best mode depends on the graphics hardware supporting the SM3.0 shader model.</p>\n\
<p>On hardware that supports only SM2.0, the Good mode performs old-style vertex lighting only and does not support per-pixel lighting.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` IViewportShadingMgr.ShadingLimits= #Best --enable shadows $Spot01.on = true --make sure the light is on $Spot01.ViewportIllumination = true --display illumination</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-F15D72BA-EFE7-4859-9EE5-05FCE69E0CBA-low.gif\' title=\'\'></div>\n\
<p>When set to <span class=\'code\'>false</span> , Viewport Illumination is turned off for the node.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>`<span class=\'code\'>$Spot01.ViewportIllumination = false --</span> display illumination`</p>\n\
</blockquote>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-FE2D5F88-403F-4E2D-8FBB-D875096175BE-low.gif\' title=\'\'></div>\n\
<div class=\'codeBlock\'><pre>INodeShadingProperties.ViewportShadowCasting : boolean : Read|Write \n\
</pre></div><p>When set to <span class=\'code\'>true</span> , enables Viewport Shadow Casting for the node, provided the base object is a Light and Shadow Casting is turned on in the light&#39;s base object using <span class=\'code\'>&lt;light&gt;.baseobject.castShadows = true</span>. (Remember, <span class=\'code\'>.castShadows</span> is also a node property and requires explicit access in the baseobject to affect the shadow casting of the light).</p>\n\
<p>To see the shadows in the viewport, the Viewport Shading has to be set to Good (SM2.0) or Best (SM3.0) - see <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/I-J-K/Interface-IViewportShadingMgr.html\' title=\'\'>Interface: IViewportShadingMgr</a> on how to enable the advanced shading modes.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` IViewportShadingMgr.ShadingLimits = #Best --enable shadows $Spot01.baseobject.castshadows = true --enable shadows in Spot01 $Spot01.ViewportShadowCasting = true --display shadows ofSpot01</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-A95F4B80-0BE9-4CE2-871C-919A376E0556-low.gif\' title=\'\'></div>\n\
<p>When set to <span class=\'code\'>false</span> ,Viewport Shadow Casting is turned off for the node.</p>\n\
<p>Since <strong>3ds Max 2010</strong>, this property defaults to true, thus automatically enabling viewport shadow casting for any light that has its base object shadows turned on. In <strong>3ds Max 2008</strong> and <strong>2009</strong>, the property was set to false by default.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` $Spot01.ViewportShadowCasting = false</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-F15D72BA-EFE7-4859-9EE5-05FCE69E0CBA-low.gif\' title=\'\'></div>\n\
<div class=\'codeBlock\'><pre>INodeShadingProperties.LockedViewportIllumination : boolean : Read|Write \n\
</pre></div><p>When set to <span class=\'code\'>true</span> , locks the Viewport Illumination for the node</p>\n\
<p>When set to <span class=\'code\'>false</span> (default), Viewport Illumination is unlocked for this node.</p>\n\
<p>When the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/I-J-K/Interface-IViewportShadingMgr.html\' title=\'\'>Interface: IViewportShadingMgr</a> <span class=\'code\'>.AutoDisplaySelLights</span> property is set to <span class=\'code\'>true</span> , lights that are not selected will not illuminate the scene.</p>\n\
<p>By setting the <span class=\'code\'>.LockedViewportIllumination</span> property to <span class=\'code\'>true</span> , a light node can be locked to keep on illuminating the scene even after it has been deselected.</p>\n\
<p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/I-J-K/Interface-IViewportShadingMgr.html\' title=\'\'>Interface: IViewportShadingMgr</a> for methods to quickly lock and unlock multiple lights. The <strong>3ds Max QuadMenus</strong> provide menu items to call these methods on the selected lights:</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";