var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: IVFB</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: IVFB</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-ivfb\"></a></div>\n\
<p>The <strong>IVFB Interface</strong> is returned as notification parameter result by the two Rendered Frame Window and Image Viewer-related callbacks.</p>\n\
<p>It can be used to customize the appearance and register user-defined scripted rollouts in the top left, top right and bottom panels of the dialog.</p>\n\
<p>Available in <strong>3ds Max 2009 and higher</strong>.</p>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;IVFB&gt;.ShowOverlays : boolean : Read|Write   \n\
</pre></div><p>Get/set the display of the render region box in the Rendered Frame Window. Corresponds to the &quot;Toggle UI Overlays&quot; button in the Rendered Frame Window main toolbar.</p>\n\
<div class=\'codeBlock\'><pre>&lt;IVFB&gt;.ShowRollups : boolean : Read|Write   \n\
</pre></div><p>This property is true when the rollout panels are displayed in the Rendered Frame Window.</p>\n\
<p>If no rollout panels have been installed, this may still return true, because it&#39;s only a global toggle used to optionally hide the rollouts. Setting this property will show/hide the rollout panels, and the UI is immediately updated.</p>\n\
<div class=\'codeBlock\'><pre>&lt;IVFB&gt;.IsFramebuffer : boolean : Read \n\
</pre></div><p>This property contains true if the window is a Rendered Frame Window.</p>\n\
<p>It is false for Image Viewer windows (as from File&gt;View Image File).</p>\n\
<p>This allows a script to install render controls on only the Rendered Frame Window.</p>\n\
<div class=\'codeBlock\'><pre>&lt;IVFB&gt;.IsVisible: boolean : Read|Write \n\
</pre></div><p>Get/set the visible state of the Image Viewer.</p>\n\
<div class=\'codeBlock\'><pre>&lt;IVFB&gt;.IsInitialized : boolean : Read \n\
</pre></div><p>Contains true if the Image Viewer has been initialized already by calling the <span class=\'code\'>.InitLayout()</span> method documented further on this page.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;value&gt;&lt;IVFB&gt;.InitRolloutWindow &lt;enum&gt;which &lt;integer&gt;width &lt;integer&gt;height \n\
\n\
which enums: {#TopLeft | #TopRight | #Bottom} \n\
</pre></div><p>Returns a RolloutFloater value, allowing rollouts to be added to it.</p>\n\
<p>It represents a single panel, not the entire floating window.</p>\n\
<p>Note:</p>\n\
<p>MAXScript can now <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Other-Interfaces/Other-Interfaces-1/GUID-A72112A6-BDFB-47A6-88FB-8D49C4CBD049.html\' title=\'\'>create rollouts in borderless mode</a> by calling <span class=\'code\'>AddRollout</span> with the optional keyword argument <span class=\'code\'>border:</span> set to <span class=\'code\'>false</span> .</p>\n\
<p>Such rollouts do not have a title bar nor border around them and merge seamlessly with the rest of the panel.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;&lt;IVFB&gt;.GetRolloutWindowVisible &lt;enum&gt;which \n\
\n\
which enums: {#TopLeft | #TopRight | #Bottom} \n\
</pre></div><p>Returns the visibility of the specified rollout panel.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;IVFB&gt;.SetRolloutWindowVisible &lt;enum&gt;which &lt;boolean&gt;show \n\
\n\
which enums: {#TopLeft | #TopRight | #Bottom} \n\
</pre></div><p>Sets the visibility of the specified rollout panel.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;IVFB&gt;.SetMetric &lt;enum&gt;metricID &lt;integer&gt;value \n\
\n\
metric ID enums: {#HorzMarginLeft | #HorzMarginCenter | #HorzMarginRight | #VertMarginTop | #VertMarginCenter | #VertMarginBottom | #MinClientWidth | #MinClientHeight} \n\
</pre></div><p>Sets the spacing between the panels in the framebuffer.</p>\n\
<p>The first parameters can be one of the following:</p>\n\
<p><span class=\'code\'>#horzMarginLeft</span> - Space in pixels between the left edge of the window and the left rollout panel.</p>\n\
<p><span class=\'code\'>#horzMarginCenter</span> - Horizontal space in pixels between the two rollout panels.</p>\n\
<p><span class=\'code\'>#horzMarginRight</span> - Space in pixels between the right edge of the window and the right rollout panel.</p>\n\
<p><span class=\'code\'>#vertMarginTop</span> - Space in pixels between the top of the window and the top of the rollout panels.</p>\n\
<p><span class=\'code\'>#vertMarginCenter</span> - Vertical space in pixels between the rollout panels and the bitmap view.</p>\n\
<p><span class=\'code\'>#vertMarginBottom</span> - Vertical space in pixels between the bottom rollout panel and the bitmap view.</p>\n\
<p><span class=\'code\'>#minClientWidth</span> - Minimum sizable width of the window in pixels.</p>\n\
<p><span class=\'code\'>#minClientHeight</span> - Minimum sizable height of the window in pixels.</p>\n\
<p>Note:</p>\n\
<p>Despite the values of <span class=\'code\'>#minCleintWidth</span> and <span class=\'code\'>#minClientHeight</span> , the window can never be resized down to become smaller than the combined width of the top two rollouts.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;&lt;IVFB&gt;.GetMetric &lt;enum&gt;metricID \n\
\n\
metricID enums:{#HorzMarginLeft | #HorzMarginCenter | #HorzMarginRight | #VertMarginTop | #VertMarginCenter | #VertMarginBottom | #MinClientWidth | #MinClientHeight} \n\
</pre></div><p>Returns the spacing settings for the specified parameter of the current layout.</p>\n\
<p>See above for details.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;IVFB&gt;.InitLayout() \n\
</pre></div><p>Calling this method causes the current layout set up using the properties and methods above to be initialized.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";