var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Navigating CATRig Hierarchies using MAXScript</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Navigating CATRig Hierarchies using MAXScript</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"navigating-catrig-hierarchies-using-maxscript\"></a></div>\n\
<div class=\'section\'><a id=\"accessing-bones-in-the-catrig-skeleton\"></a><h2 id=\"accessing-bones-in-the-catrig-skeleton\">Accessing Bones in the CATRig Skeleton</h2></div>\n\
<p>Accessing bones by name in a skeleton tends to cause errors. For example, if an artist renames a bone, your scripts might stop working.</p>\n\
<p><strong>3ds Max CAT</strong> is designed to let you navigate hierarchies from a script without necessarily knowing the names of the bones in the rig. This means that you can write scripts that will work on any CATrig, regardless of the naming conventions used.</p>\n\
<p>The CATRig is <strong>structured like a tree</strong>.</p>\n\
<p>Each bone has child bones that you can navigate to and get their children.</p>\n\
<p>There are special controllers in CAT that hold parts of the tree together, but do not show up in the hierarchy you see in <strong>3ds Max</strong>. For example, there is a controller called &quot;Limb&quot; whose job is to maintain the limb (arm or leg). Each bone in the limb is generic and contains only information related to that specific bone. If you want information about the limb, you can access the limb controller.</p>\n\
<p>The <strong>basic tree structure</strong> looks like this:</p>\n\
<p>From a hub controller you can get to a limb controller and from a limb controller you can get to the collarbone controller.</p>\n\
<p>From a hub controller you can get to a tail controller and from a tail controller you can get to any of the tailbone controllers.</p>\n\
<p>From a hub controller you can get to a spine controller and from a spine controller you can get to any of the spine bone controllers, or to the hub controller at the tip of the spine.</p>\n\
<p>Hubs</p>\n\
<p>Hubs-&gt;Limbs</p>\n\
<p>Hubs-&gt;Limbs-&gt;Collarbone</p>\n\
<p>Hubs-&gt;Limbs-&gt;Limb Bones</p>\n\
<p>Hubs-&gt;Limbs-&gt;Limb Bones-&gt;Bone Segments</p>\n\
<p>Hubs-&gt;Limbs-&gt;Palm/Ankle</p>\n\
<p>Hubs-&gt;Limbs-&gt;Palm/Ankle-&gt;Digits</p>\n\
<p>Hubs-&gt;Limbs-&gt;Palm/Ankle-&gt;Digits-&gt;Digit Bones</p>\n\
<p>Hubs-&gt;Tails</p>\n\
<p>Hubs-&gt;Tails-&gt;Tail Bones</p>\n\
<p>Hubs-&gt;Spines</p>\n\
<p>Hubs-&gt;Spines-&gt;Spine Bones</p>\n\
<p>Hubs-&gt;Spines-&gt;Tip Hub</p>\n\
<div class=\'section\'><a id=\"using-bone-addresses\"></a><h2 id=\"using-bone-addresses\">Using Bone Addresses</h2></div>\n\
<p>The 3ds Max CAT scripting interface includes methods that let you access bones using bone &quot;addresses&quot;. Each bone in a CATRig contains a unique address.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` --Select a bone, for example left elbow: theAddress =$[3].address --the result will be something like: &quot;SceneRootNode.Hub.Spine[0].Hub.Limb[0].LimbBone[1].BoneSeg[0]&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Once you have an address, it is easy to get the same bone on a different rig.</p>\n\
<p>There is a method on the CATParent for retrieving a bone from the skeleton using an address.</p>\n\
<p>This method is called <span class=\'code\'>GetBoneUsingAddress:</span></p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` --Selectthe CATParent of a rig and call: $.GetBoneByAddresstheAddress --the result will be something like: $Object:MaramaLForeArm1 @ [18.374180,2.811419,91.353607]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"getting-all-the-bones-that-make-up-the-catrig\"></a><h2 id=\"getting-all-the-bones-that-make-up-the-catrig\">Getting all the Bones that make up the CATRig</h2></div>\n\
<p>The CATParent provides a property called CATRigNodes that contains a list of all the bones in a CATRig.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` --Select the CATParent of a CATRig andexecute: \\(.CATRigNodes  #(\\)Object:MaramaPelvis @ [0.643538,12.460782,56.982174], $IKTarget:MaramaLPlatform @ [-9.479717,45.484272,2.016279], $Object:MaramaLThigh @ [-5.399519,13.610688,52.234413], $Object:MaramaLCalf @ [-5.073243,42.623035,42.755692], $Object:MaramaLAnkle @ [-9.923340,42.132290,12.445667], $Object:MaramaLToe @ [-8.354513,46.355228,5.667924], $IKTarget:MaramaRPlatform @ [22.299629,-26.312172,2.125263], $Object:MaramaRThigh @ [7.615567,12.286880,53.555431], $Object:MaramaRCalf @ [18.307613,1.576054,27.048307], $Object:MaramaRAnkle @ [15.838839,-24.331221,10.763937], $Object:MaramaRToe @ [21.849598,-24.039907,5.285047], $Object:MaramaSpine1 @ [0.084267,13.617851,61.769054], $Object:MaramaSpine2 @ [0.155154,17.742903,70.302628], $Object:MaramaSpine3 @ [0.838520,20.302643,79.403381], $Object:MaramaRibcage @ [1.721320,22.587023,88.560089], $IKTarget:MaramaLIKTarget @ [-14.076582,23.387424,73.722427], $Object:MaramaLCollarbone @ [-0.265896,27.761074,90.442078], $Object:MaramaLUpperArm @ [-7.214790,19.994431,91.494965], $Object:MaramaLForeArm1 @ [-22.375963,8.502111,91.433647], $Object:MaramaLForeArm2 @ [-18.546179,13.426756,83.416336], ...)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>All the bones in the rig have been collected and put into an array for you. This makes it unnecessary to learn how to navigate CATRig hierarchies.</p>\n\
<div class=\'section\'><a id=\"getting-all-the-layer-controllers-in-a-catrig\"></a><h2 id=\"getting-all-the-layer-controllers-in-a-catrig\">Getting All the Layer Controllers in a CATRig</h2></div>\n\
<p>The <strong>CATParent</strong> also provides a property called <span class=\'code\'>CATRigLayerCtrls</span> that contains an array of all the layer controllers in a CATRig.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` -- Select the CATParent of a CATRig andexecute: $.CATRigLayerCtrls #(Controller:LayerWeights, Controller:LayerMatrix3, Controller:LayerFloat, Controller:LayerWeights, Controller:LayerFloat, Controller:LayerFloat, Controller:LayerFloat, Controller:LayerMatrix3, Controller:LayerMatrix3, Controller:LayerWeights, Controller:LayerMatrix3, Controller:LayerFloat, Controller:LayerMatrix3, Controller:LayerMatrix3, Controller:LayerWeights, Controller:LayerFloat, Controller:LayerFloat, Controller:LayerFloat, Controller:LayerMatrix3, Controller:LayerMatrix3, ...)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The Pose Mixer utility uses this function to find all the controllers that will be keyframed.</p>\n\
<div class=\'section\'><a id=\"navigating-bones\"></a><h2 id=\"navigating-bones\">Navigating Bones</h2></div>\n\
<p>Each bone in a CATRig is controlled by a controller.</p>\n\
<p>This controller exposes the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for-3ds-Max/CAT-Interfaces/Interface-17.html\' title=\'\'>CATNodeControl interface</a>.</p>\n\
<p>This means you can access information about that bone.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>If a hub bone is selected and you want to know how many limbs are attached to the hub, use the following line of script.</p>\n\
<p>``` $[3].address &quot;SceneRootNode.Hub.Spine[0].Hub.Limb[0].LimbBone[0].BoneSeg[2]&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>To get the layer controller for a CATBone, use the following line:</p>\n\
<p>``` $[3].layertrans.controller Controller:LayerMatrix3</p>\n\
<p>```</p>\n\
<p>Note that some bones do not have a layertrans controller such as, the bones in the procedural spine.</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"navigating-hubs\"></a><h2 id=\"navigating-hubs\">Navigating Hubs</h2></div>\n\
<p>Hubs are the &quot;joiners&quot; of the <strong>3ds Max CAT</strong> hierarchy.</p>\n\
<p>Hubs can have limbs (legs and arms), tails, spines, and extra bones attached to them.</p>\n\
<p>For any Hub, you can see how many limbs are attached and then you can access the limb and get the bones from that limb.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>If a hub bone is selected and you want to know how many limbs are attached to the hub, use the following line of script.</p>\n\
<p><span class=\'code\'>-- Select the CATParent of a CATRig andexecute:   $[3].limbs.count   2</span></p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"navigating-limbs\"></a><h2 id=\"navigating-limbs\">Navigating Limbs</h2></div>\n\
<p>Limbs are made up of the following types of controllers: <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for-3ds-Max/CAT-Controllers/CAT-Data-Controllers/CATLimbData2-ReferenceTarget.html\' title=\'\'>Limb</a>, <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for-3ds-Max/CAT-Controllers/CAT-Transform-Controllers/CATCollarBone-Matrix3Controller.html\' title=\'\'>Collarbone</a>, <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for-3ds-Max/CAT-Controllers/CAT-Data-Controllers/CATBoneDataMatrix3Controller.html\' title=\'\'>Bone</a>, <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for-3ds-Max/CAT-Controllers/CAT-Transform-Controllers/CATBoneSegTrans.html\' title=\'\'>BoneSeg</a>, <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for-3ds-Max/CAT-Controllers/CAT-Transform-Controllers/PalmTrans-Matrix3Controller.html\' title=\'\'>Palm</a>, <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for-3ds-Max/CAT-Controllers/CAT-Transform-Controllers/IKTargTrans-Matrix3Controller.html\' title=\'\'>IKTarget</a>, and Upvector.</p>\n\
<p>The Limb controller holds all the information about the whole limb, such as its name, and also keep a pointer to each bone in the limb, collarbone, ankle, and the IKTarget.</p>\n\
<p>From one limb bone you can access everything in a CATRig.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES</strong></p>\n\
<p>``` --To get the limb controller from a limb bone use the following: $[3].Limb Controller:CATLimbData2</p>\n\
<p>--If you have a Limb bone selected and you want to know how many --bones in the Limb use the following: $[3].Limb.bones.count 4</p>\n\
<p>--To get the second bone in the Limb use the following: $[3].Limb.bones[2] Controller:CATBoneData</p>\n\
<p>--If a limb bone is selected and you want to select all the bones --in the limb, you can use the following: select (for o in $[3].Limb.bonescollect o.node) OK ```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>If a limb bone is selected and you want to get the name of the first bone in the limb, you can use the following:</p>\n\
<p>``` $[3].limb.bones[1].node.name &quot;MarineLUpperarm1&quot;</p>\n\
<p>--Here is a quick overview of bone hierarchy access: $--&gt; accesses the selected bone $Object:MarineLUpperarm3 @ [32.745049,27.963869,14.721746] $[3]--&gt; accesses the selected bone&#39;s transform controller SubAnim:Transform $[3].limb--&gt; accesses the selected bone&#39;s tail controller Controller:CATLimbData2 $[3].limb.bones[1]--&gt; accesses the 1st bone in the limb controller Controller:CATBoneData $[3].limb.bones[1].node--&gt; accesses the node of the 1st bone. $Object:MarineLUpperarm1 @ [30.869087,27.893547,14.979661] $[3].limb.bones[1].node.name--&gt; accesses the name of the node of the 1st bone in the Limb. &quot;MarineLUpperarm1&quot; ```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"navigating-tails\"></a><h2 id=\"navigating-tails\">Navigating Tails</h2></div>\n\
<p>Tails are made up of two types of controllers: <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for-3ds-Max/CAT-Objects/TailData2-ReferenceTarget.html\' title=\'\'>TailData</a> and <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for-3ds-Max/CAT-Controllers/CAT-Transform-Controllers/TailTrans-Matrix3Controller.html\' title=\'\'>TailTrans</a>.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for-3ds-Max/CAT-Objects/TailData2-ReferenceTarget.html\' title=\'\'>TailData</a> holds all the information about the whole tail such as, its name and it also keep a pointer to each bone in the tail.</p>\n\
<p>From one tail bone you can access everything in a CATRig.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` --To get the TailData controller from a tail bone use the following: $[3].tail</p>\n\
<p>--If you have a Tail bone selected and you want to know how many bones --arein the tail, use the following: $[3].tail.bones.count</p>\n\
<p>--To get the second bone in the tail, use the following: $[3].tail.bones[2]</p>\n\
<p>--If you have one tail bone selected and you want to select all --the bones in the tail, you can use the following: select (for o in $[3].Limb.bones collect o.node) OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>If you have a tail bone selected and you want to get the name of the first bone in the tail, you can use the following:</p>\n\
<p>``` $[3].tail.bones[1].node.name</p>\n\
<p>--Here is a detailed overview of the hierarchy access: $--&gt; accesses the selected bone $[3]--&gt; accesses the selected bone&#39;s transform controller $[3].tail--&gt; accesses the selected bone&#39;s tail controller $[3].tail.bones[1]--&gt; accesses the 1st bone in the tail controller $[3].tail.bones[1].node--&gt; accesses the node of the 1st bone. $[3].tail.bones[1].node.name--&gt; accesses the name of the node of the 1st bone in the tail.</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";