var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Lock_Bond : Helper</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Lock_Bond : Helper</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"lock_bond-helper\"></a></div>\n\
<div class=\'codeBlock\'><pre>Lock_Bond- superclass: helper; super-superclass:node - 33:0 - classID:#(1395943682, 515064320) \n\
</pre></div><p><strong>Description:</strong></p>\n\
<p>The <strong>Lock_Bond</strong> operator attaches particles to objects, and can lock them to the object even as it animates. Particles can move over an object&#39;s surface, or the bond can be broken, causing particles to fly or break off from the object.</p>\n\
<p>The standard Position Object operator is also able to lock particles to an object, but because it chooses particle positions at random on the object&#39;s surface, particles can drift when the object is animated. The Position Object operator&#39;s main limitation is that it cannot be applied to particles that have already established their positions. Since the Position Object operator generates new particle positions regardless the old ones, there is the illusion that each particle shifts to a new location instantaneously. With <strong>Lock_Bond</strong>, you can force the particles to maintain their original positions with respect to an animated surface.</p>\n\
<p>In addition, <strong>Lock_Bond</strong> can also lock particle orientation. This means that particles with a definite orientation, such as darts or arrows, can maintain their orientation to the object even as it rotates. You can also limit particles&#39; rotation from their original orientations for fine control over wind and gravity effects.</p>\n\
<p>You can also dampen particle motion to simulate air, fluid, or friction as particles move across a surface or through the air.</p>\n\
<p><strong>Lock_Bond</strong> also serves as a test for particles breaking off from the object. See the parameter Break Off When Exceeds for information on the test performed.</p>\n\
<p>The <strong>Lock_Bond</strong> test was first added to <strong>3ds Max</strong> as part of the Creativity Extension to <strong>3ds Max 2009</strong> and became an integral part of <strong>3ds Max 2010</strong>.It was previously available in the Particle Flow Tools Box #1.</p>\n\
<p><strong>Constructor:</strong></p>\n\
<div class=\'codeBlock\'><pre>Lock_Bond... \n\
</pre></div><p><strong>Properties:</strong></p>\n\
<div class=\'section\'><a id=\"lock-on-objects\"></a><h2 id=\"lock-on-objects\">Lock On Objects</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Lock_On_Objects : node array \n\
</pre></div><p>Get/set the array of geometry objects to lock onto.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Lock_Type : radiobtnIndex \n\
</pre></div><p>Get/set the Lock Type radio button selection index.</p>\n\
<p>Possible values are:</p>\n\
<p>0 - <strong>Lock To Object</strong> (default)</p>\n\
<p>1 - <strong>Lock To Surface</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Animated_Surface : boolean \n\
</pre></div><p>Get/set the state of the Animated Surface option.</p>\n\
<p>Use this option when the object&#39;s surface changes shape or detail over time, such as with animated sub-objects or parameters, morphing, or a skin modifier. If the object is animated through transforms only (position, rotation, scale), leave this option turned off to reduce processing time.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Snap_To_Surface : boolean \n\
</pre></div><p>Get/set the state of the Snap To Surface option.</p>\n\
<p>This option differs from Lock to Surface, which locks particles to the surface but maintains the distance each particle had from the surface upon entering the event. Snap to Surface forces particles to lie on the object&#39;s surface.</p>\n\
<div class=\'section\'><a id=\"position-lockbond\"></a><h2 id=\"position-lockbond\">Position Lock/Bond</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Restrict_Position_To_Surface : boolean \n\
</pre></div><p>Forces particles to stay on the object&#39;s surface while they are moving. When the Force parameter is less than 100%, particles can move from their original positions based on Speed and Force operators within the event. In this case, turning on Restrict to Surface forces the particles to move only to other parts of the surface without leaving the surface itself.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Use_Position_Offset_Limit : boolean \n\
</pre></div><p>Get/set the state of the Offset checkbox. If this option is set to false, particles are not limited in their movement.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Position_Offset_Limit : worldUnits \n\
</pre></div><p>Get/set the Offset value which defines the maximum distance a particle can move from its lock point.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Use_Speed_Limit : boolean \n\
</pre></div><p>Get/set the state of the Speed Limit checkbox. If set to true and particles cannot keep up with lock points on an animated object, particles&#39; speed will be limited to the.Speed_Limit value even if Force is 100%. In other words, the Speed Limit, if turned on, overrides the Force %</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Speed_Limit : worldUnits \n\
</pre></div><p>Sets the maximum speed that a particle can travel, in units per frame.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Position_Force : percent \n\
</pre></div><p>Sets the amount of force holding the particle to its lock point. A 100% Force attempts to keep particles stuck to their lock points. When Force is set to values lower than 100%, particles can be moved off their lock points based on Speed and Force operators in the event. The lower the Force %, the more influence Speed and Force operators have on the particles.</p>\n\
<p>If Force is less than 100% and Restrict to Surface is turned on, particles will move along the object&#39;s surface. If Force is less than 100% and Restrict to Surface is off, particles will move off the surface but retain their relationships to lock points. In either case, particle movement will be based on Speed and Force operators, and will be restricted by Offset Limit and Speed Limit if these parameters are turned on.</p>\n\
<p>When Force is set to 100% and Restrict to Surface is turned on, particles are strictly locked to the object or surface, and do not move. If Force is 100% and Restrict to Surface is turned off, particles are locked to the object unless Break Off When Exceeds is enabled and the object is animated at a sufficient speed to break off particles.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Position_Dampening_Type : integer \n\
</pre></div><p>Get/set the selection index of the Dampening drop-down list which controls how particles are slowed down, simulating various resistence forces.</p>\n\
<p>Possible values are:</p>\n\
<p>0 - <strong>None</strong> - No dampening is applied, other than the default dampening on oscillating forces from Speed and Force operators.</p>\n\
<p>1 - <strong>Friction</strong> - Simulates a surface friction effect, which gradually slows particles until they stop moving.</p>\n\
<p>2 - <strong>Air/Fluid</strong> - Simulates the resistance of a medium such as air or water, which slows particles but never stops them completely.</p>\n\
<p>3 - <strong>Both</strong> - Combines both forces, Friction and Air/Water.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Dampening_Friction : worldUnits \n\
</pre></div><p>Get/set the Friction value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Dampening_Resistance (Birth_Texture_operator_Warning) : worldUnits \n\
</pre></div><p>Get/set the Resistance value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Speed_Unit : worldUnits \n\
</pre></div><p>Get/set the Speed Unit value.</p>\n\
<div class=\'section\'><a id=\"no-force-in-central-zone\"></a><h3 id=\"no-force-in-central-zone\">No Force In Central Zone</h3></div>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Use_No_Acceleration_Zone : boolean \n\
</pre></div><p>Get/set the state of the For Acceleration checkbox. When set to true, acceleration forces in each particle&#39;s centraz zone are turned off. This prevents the particle from slowing down to a stop.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Use_No_Dampening_Zone : boolean \n\
</pre></div><p>Get/set the state of the For Dampening checkbox.When set to true, dampening forces in each particle&#39;s centraz zone are turned off. This prevents particles from being slowed by friction and coming to a stop.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Zone_Radius : worldUnits \n\
</pre></div><p>Get/set the Radius value defining the radius of the central zone around a lock point.</p>\n\
<div class=\'section\'><a id=\"rotation-lockbond\"></a><h2 id=\"rotation-lockbond\">Rotation Lock/Bond</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Use_Rotation_Offset_Limit : boolean \n\
</pre></div><p>Get/set the state of the Offset Limit checkbox. When set to true, the Offset Limit will be used.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Rotation_Offset_Limit : angle \n\
</pre></div><p>Get/set the value of the Offset Limit property which controls the maximum number of degrees by which a particle can deviate from its lock point&#39;s rotation.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Use_Spin_Limit : boolean \n\
</pre></div><p>Get/set the state of the Spin Limit checkbox. When set to true, the Spin Limit will be used.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Spin_Limit : angle \n\
</pre></div><p>Get/set the value of the Spin Limit property which controls the maximum number of degrees per frame that a particle can rotate. If Spin Limit is turned on and particles cannot keep up with lock points that are rotating, particles will be limited to the Spin Limit even if Force is 100%. In other words, the Spin Limit, if turned on, overrides the Force %.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Rotation_Force : percent \n\
</pre></div><p>Get/set the value of the Force % property which controls the amount by which the particle&#39;s rotation is forced to match its lock point&#39;s rotation. When Force is 100%, particles maintain their original orientations, unless limited to rotate by Spin Limit settings. When Force is less than 100%, particles can be rotated with Force operators. The lower the Force value, the more a particle can be influenced by Force operators and inertial properties of a particle.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Rotation_Dampening : percent \n\
</pre></div><p>Get/set the value of the Dampening % property which controls the amount of resistance that holds a particle back from catching up with the lock point&#39;s rotation. A 0% creates no dampening, while 100% prevents the particle from rotating at all. If the Offset Limit is set, Dampening cannot cause the particle rotation to deviate from the lock point&#39;s rotation by more than the Offset Limit, even if Dampening is set to 100%. In other words, the Offset Limit overrides the Dampening value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Induced_By_Speed_Change : boolean \n\
</pre></div><p>Get/set the state of the Induced By Speed Change checkbox. When set to true, it causes particle rotation to occur due to surface&#39;s animation even when particles&#39; positions are locked to their lock points. This allows the simulation of the effect of a particle with a springy attachment to a surface. Since the center of gravity of a particle doesn&#39;t coincide with the lock point, any movement of the underlying surface initiates a rotational movement of a particle.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Inertial_Size : worldUnits \n\
</pre></div><p>Get/set the value of the Inertial Size value which controls the distance between the pivot point of a particle and the particle’s center of gravity. For example, a strand of grass&#39;s inertial size is a half length of the strand. Smaller values induce a stronger rotation. This option is used only when.Induced_By_Speed_Change is set to true.</p>\n\
<div class=\'section\'><a id=\"break-off\"></a><h2 id=\"break-off\">Break Off</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Use_Break_Off_Test : boolean \n\
</pre></div><p>Get/set the state of the Break Off When Exceeds option.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Break_Off_Type : radiobtnIndex \n\
</pre></div><p>Get/set the Break Off Type radio button selection.</p>\n\
<p>Possible values are:</p>\n\
<p>0 - <strong>Speed</strong> (default)</p>\n\
<p>1 - <strong>Accel</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Break_Off_Speed : worldUnits \n\
</pre></div><p>Get/set the Break Off Speed value. When the particle&#39;s speed exceeds this value and.Use_Break_Off_Test is set to true, the particle will break off from the surface and start moving again.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Break_Off_Acceleration : worldUnits \n\
</pre></div><p>Get/set the Break Off Acceleration value. When the particle&#39;s acceleration exceeds this value and.Use_Break_Off_Test is set to true, the particle will break off from the surface and start moving again.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Break_Off_Variation : percent \n\
</pre></div><p>Get/set the Break Off Variation value. It is used to introduce a random variation of the Break Off Speed and Acceleration values.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Break_If_Outwards_Only : boolean \n\
</pre></div><p>Get/set the state of the Break If Outwards Only option. When set to true, particles will break off only if moving along the surface normals. When set to true, particles will break off when the limits are exceeded regardless of the direction of motion.</p>\n\
<div class=\'section\'><a id=\"parameters-animation\"></a><h2 id=\"parameters-animation\">Parameters Animation</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Sync_Type(Sync_By_Type) : integer \n\
</pre></div><p>Get/set the selection index of the Sync By drop-down list.</p>\n\
<p>Possible values are:</p>\n\
<p>0 - <strong>Absolute Time</strong> (default)</p>\n\
<p>1 - <strong>Particle Age</strong></p>\n\
<p>2 - <strong>Event Duration</strong></p>\n\
<div class=\'section\'><a id=\"uniqueness\"></a><h2 id=\"uniqueness\">Uniqueness</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;Lock_Bond&gt;.Random_Seed : integer \n\
</pre></div><p>Get/set the Random Seed value.</p>\n\
<div class=\'section\'><a id=\"lock_bond-interfaces\"></a><h2 id=\"lock_bond-interfaces\">Lock_Bond Interfaces:</h2></div>\n\
<p><strong>The following Interfaces are exposed by the Lock_Bond Class:</strong></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for/Particle-Flow-Interfaces/Interfaces-2/Interface-action.html\' title=\'\'>Interface: action</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for/Particle-Flow-Interfaces/Interfaces-2/Interface-operator.html\' title=\'\'>Interface: operator</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for/Particle-Flow-Interfaces/Interfaces-2/Interface-PViewItem.html\' title=\'\'>Interface: PViewItem</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";