var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: MaterialHolder</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: MaterialHolder</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-materialholder\"></a></div>\n\
<p>The MaterialHolder Interface is exposed by the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for/Particle-Flow-Classes/Meta-Operators/Event-Helper.html\' title=\'\'>Event Helper class</a>.</p>\n\
<p>It provides access to the particles&#39; materials.</p>\n\
<p>Available in <strong>3ds Max 2014 and higher</strong>.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;&lt;PF_Event&gt;.isMaterialHolder()\n\
</pre></div><p>Returns True if a material is assigned to the Event via any of the Particle Flow Material operators.</p>\n\
<p>Returns False if no material is assigned (even if a Material operator exists, but no valid material is assigned to it).</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;&lt;PF_Event&gt;.inheritsMaterial()\n\
</pre></div><p>Returns True if the Event inherits a material from higher up in the flow, for example if the Material operator is assigned to the global PF_Source event, or if the Event has no material (neither in the Event nor in the global PF_Source event).</p>\n\
<p>Returns False if the Event does not inherit its material because the Material operator is in the Event itself.</p>\n\
<div class=\'codeBlock\'><pre>&lt;material&gt;&lt;PF_Event&gt;.getMaterial()\n\
</pre></div><p>Returns the material associated with the Event, either through a local Material operator, or inherited from a global Material operator.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;&lt;PF_Event&gt;.setMaterial &lt;material&gt;material\n\
</pre></div><p>Assigns a material to the Event. The material will only be used if the Event does not contain a Material operator.</p>\n\
<p>After assignment, the Particle Flow must be turned off and on again for the new material to take effect.</p>\n\
<p>The <span class=\'code\'>.getMaterial()</span> method will <strong>NOT</strong> return the material if assigned via <span class=\'code\'>.setMaterial()</span> , it will return undefined instead.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;&lt;PF_Event&gt;.getMaterialPriority()\n\
</pre></div><p>Returns the material priority.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;&lt;PF_Event&gt;.getStreamDepth()\n\
</pre></div><p>Returns the stream depth of the Event within the flow.</p>\n\
<p>For example, if the Event is directly connected to the PF_Source, the return value will be 1. If the Event is connected to the initial event, the return value will be 2 and so on.</p>\n\
<p>If an event is not connected, the return value will be 0.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;&lt;PF_Event&gt;.updateMaterial &lt;boolean&gt;doReport\n\
</pre></div><p>Updates the material and returns True if the material of the current event has been updated, False if it was already updated.</p>\n\
<p>If the argument is passed as True, a pop up message will report the state of the Event&#39;s material.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;&lt;PF_Event&gt;.updateMaterials &lt;boolean&gt;doReport\n\
</pre></div><p>Updates all materials in all Events in the flow the PF_Event is part of.</p>\n\
<p>If the argument is passed as True, a pop up message will report the state of the Event&#39;s material.</p>\n\
<p>Returns the number of Events whose materials have been updated, or 0 if all materials were already updated.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;&lt;PF_Event&gt;.updateMaterialsDownstream &lt;boolean&gt;doReport\n\
</pre></div><p>Updates all materials in all downstream Events of the flow the PF_Event is part of.</p>\n\
<p>If the argument is passed as True, a pop up message will report the state of the Event&#39;s material.</p>\n\
<p>Returns the number of Events whose materials have been updated, or 0 if all materials were already updated.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES AND RESULTS</strong></p>\n\
<p>``` pf = PF_Source() --Create a PF Source --&gt; $PF_Source:PF Source 001 @ [0.000000,0.000000,0.000000] ne = Event() --Create an Event --&gt; $Event:Event 001 @ [0.000000,0.000000,0.000000] particleFlow.beginEdit() --Disable automatic encapsulation --&gt; OK b = Birth() --Create a Birth operator --&gt; $Birth:Birth 001 @ [0.000000,0.000000,0.000000] rnd = RenderParticles() --Create a Render operator --&gt; $Render:Render 001 @ [0.000000,0.000000,0.000000] mtl = Material_Static() --Create a Material Static operator --&gt; $Material_Static:Material Static 001 @ [0.000000,0.000000,0.000000] shp = ShapeLibrary() --Create a Shape operator --&gt; $Shape:Shape 001 @ [0.000000,0.000000,0.000000] pos = Position_Icon() --Create a Position Icon operator --&gt; $Position_Icon:Position Icon 001 @ [0.000000,0.000000,0.000000] dis = DisplayParticles Type:6 Color:white--Create a white Display operator set to Geometry --&gt; $Display:Display 001 @ [0.000000,0.000000,0.000000] particleFlow.endEdit() --Enable automatic encapsulation --&gt; OK pf.appendAction rnd --Add the Render operator to the PF Source --&gt; true ne.appendAction b --Add the Birth operator to the Event --&gt; true ne.appendAction pos --Add the Position Icon operator to the Event --&gt; true pf.appendAction shp --Add the Shape Icon operator to the PF Source --&gt; true pf.appendAction dis --Add the Display operator to the PF Source --&gt; true pf.appendInitialActionList ne --Wire the Event to the PF Source as initial action list --&gt; true</p>\n\
<p>ne.isMaterialHolder() --Check to see if the Event is a material holder - it is not --&gt; false ne.appendAction mtl --Add the Material Static to the Event --&gt; true ne.isMaterialHolder() --Check again if the Event is a material holder - still not --&gt; false mtl.setmaterial (standard diffusecolor:red name:&quot;RedMat&quot;) --Assign a Red material --&gt; true ne.isMaterialHolder() --Check again if the Event is a material holder - now it is! --&gt; true ne.getMaterial() --Get the Event&#39;s material --&gt; RedMat:Standard ne.activate false --Turn off the Event... --&gt; OK ne.activate true -- ...and turn it on again to force an update --&gt; OK --RENDERING at this point will produce RED particles --based on the color of the Material in the Event.</p>\n\
<p>ne.inheritsMaterial() --See if the Event inherits its material - it does not. --&gt; false particleFlow.beginEdit() --Disable automatic encapsulation --&gt; OK mtl2 = Material_Static() --&gt; $Material_Static:Material Static 002 @ [0.000000,0.000000,0.000000] particleFlow.endEdit() --Enable automatic encapsulation --&gt; OK pf.appendAction mtl2 --Add the new Material Static to the PF Source --&gt; true ne.inheritsMaterial() --See if the Event inherits its material - it still does not. --&gt; false mtl2.setmaterial (standard diffusecolor:blue name:&quot;BlueMat&quot;) --Assign a Blue material --&gt; true ne.inheritsMaterial() --See if the Event inherits its material - it has its own. --&gt; false delete mtl --Delete the Material Static operator used by the Event --&gt; 1 ne.inheritsMaterial() --Now check to see if the Event inherits a material - it does! --&gt; true --RENDERING at this point will produce BLUE particles --based on the color of the inherited PF Source material.</p>\n\
<p>delete mtl2 --Delete the Material Static operator used by the PF Source --&gt; 1 ne.activate false --Turn off the Event... --&gt; OK ne.activate true -- ...and turn it on again --&gt; OK --RENDERING at this point will produce WHITE particles --based on the color of the Display operator.</p>\n\
<p>ne.setMaterial (standard diffusecolor:green name:&quot;GreenMat&quot;) --&gt; true ne.activate false --Turn off the Event... --&gt; OK ne.activate true -- ...and turn it on again --&gt; OK --RENDERING at this point will produce GREEN particles --The Green material is now assigned directly to the Event by MAXScript, --without the use of a Material operator!</p>\n\
<p>ne.getStreamDepth() --Check the stream depth at the Event - it incorrectly reports 0 --&gt; 0 ne.updateMaterials false --Force an update of all materials - it claims that they all were ok --&gt; 0 ne.getStreamDepth() --Check the stream depth at the Event again - now it is correct --&gt; 1</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>This Interface is available in:</strong></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for/Particle-Flow-Classes/Meta-Operators/Event-Helper.html\' title=\'\'>Event : Helper</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";