var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Interface: pfSystem</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Interface: pfSystem</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"interface-pfsystem\"></a></div>\n\
<p><strong>The pfSystem Interface is exposed by the Particle Flow Source Class</strong>.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;&lt;PF_Source&gt;.getMultiplier &lt;time&gt;time      \n\
</pre></div><p>Returns the Quality multiplier depending on the Render State. See methods <span class=\'code\'>setRenderState</span> and <span class=\'code\'>isRenderState</span> below for more details on Render State.</p>\n\
<p>A value of 1.0f means that the operator produces particles at 100% rate. A value of 0.5f means that the operator produces only half the particles that it is supposed to generate. For example, if a Birth operator is set to produce 1000 particles total, then when the multiplier is set to 0.5f, the operator will produce only 500 particles.</p>\n\
<p>Note: The <strong>time</strong> parameter is reserved <strong>for future use</strong>. Pass <strong>0f</strong> or any time value to call the method.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` --Create a new Particle Flow Source in the Viewport pfs = PF_Source() --&gt; $PF_Source:PF Source 001 @ [2.536594,-48.031052,0.000000] --Get the Multiplier while in Viewport state pfs.getMultiplier 0f --&gt; 0.5 --Change the Particle Source State to Render pfs.SetRenderState true --&gt; true --Get the Multiplier again - when in Render State, the Source --generates all particles! pfs.getMultiplier 0f --&gt; 1.0</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;&lt;PF_Source&gt;.getBornAllowance()   \n\
</pre></div><p>Returns the born allowance, which is currently the Upper Limit at time zero, same as <span class=\'code\'>&lt;PF_Source&gt;.Particle_Amount_Limit</span>.</p>\n\
<p>Note:</p>\n\
<p>Implemented for future use.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;&lt;PF_Source&gt;.hasEmitter() \n\
</pre></div><p>Returns <strong>true</strong> if the Particle System has emitter(s), <strong>false</strong> otherwise.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;&lt;PF_Source&gt;.getEmitterType &lt;time&gt;time \n\
</pre></div><p>Returns the Emitter Type at the specified time.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;PF_Source&gt;.getEmitterDimensions &lt;time&gt;time &lt;&amp;float array&gt;dimensions \n\
\n\
dimensions is In and Out parameter \n\
</pre></div><p>Returns the Emitter Dimensions at the specified time as an array of floats stored in the by-reference variable.</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;&lt;PF_Source&gt;.getEmitterGeometry &lt;time&gt;time \n\
</pre></div><p>Returns the Emitter geometry at the specified time as mesh.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;&lt;PF_Source&gt;.isEmitterGeometryAnimated() \n\
</pre></div><p>Returns <strong>true</strong> if the Emitter geometry is animated, <strong>false</strong> otherwise.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;&lt;PF_Source&gt;.setRenderState &lt;boolean&gt;renderState \n\
</pre></div><p>Sets the render State of the Particle System to the supplied boolean value. See explanation below.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;&lt;PF_Source&gt;.isRenderState() \n\
</pre></div><p>Returns <strong>true</strong> if the Particle System is in render state, <strong>false</strong> otherwise.</p>\n\
<blockquote>\n\
<p>Important:</p>\n\
<p>A <strong>Particle Flow</strong> particle system has two states: render and viewport. At any given moment it is exclusively in the one state or the other. The particle system might have different parameters during render and viewport (Multiplier value, emitter geometry, and others) therefore it is important to know what state it is in. It is possible to switch the state of a particle system using the <strong>setRenderState</strong> method. A <strong>Particle Flow</strong> particle system alternates its state automatically when the rendering starts and when the rendering ends.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;time&gt;&lt;PF_Source&gt;.getIntegrationStep() \n\
</pre></div><p>Returns the Integration Step as time value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;&lt;PF_Source&gt;.getUpdateType() \n\
</pre></div><p>Returns the Update Type as integer.</p>\n\
<p>0: <strong>Complete</strong></p>\n\
<p>1: <strong>Forward</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;&lt;PF_Source&gt;.numParticlesSelected() \n\
</pre></div><p>Returns the number of selected particles.</p>\n\
<div class=\'codeBlock\'><pre>&lt;index&gt;&lt;PF_Source&gt;.getSelectedParticleID &lt;index&gt;index \n\
</pre></div><p>Returns the particle ID of the indexed particle.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;&lt;PF_Source&gt;.isParticleSelected &lt;index&gt;index \n\
</pre></div><p>Returns <strong>true</strong> if the indexed particle is selected, <strong>false</strong> otherwise.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;&lt;PF_Source&gt;.numActionListsSelected() \n\
</pre></div><p>Returns the number of selected Action Lists.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;&lt;PF_Source&gt;.getSelectedActionList &lt;index&gt;index \n\
</pre></div><p>Returns the indexed Action List.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;&lt;PF_Source&gt;.isActionListSelected &lt;index&gt;index \n\
</pre></div><p>Returns <strong>true</strong> if the indexed Action List is selected, <strong>false</strong> otherwise.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES AND RESULTS:</strong></p>\n\
<p>``` --Create a new Particle Flow Source in the Viewport --from the Create tab, then get it by name from the scene pf = $&#39;PF Source 001&#39; --&gt; $PF_Source:PF Source 001 @ [0.000000,0.000000,0.000000] --Get the number of particles that the Source can give birth to pf.getBornAllowance() --&gt; 100000 --Check whether the Source has an emitter pf.hasEmitter() --&gt; true --Get the emitter type pf.getEmitterType 0 --&gt; 0 dim = #()--define an empty array --&gt; #() --get the Emitter dimensions, --pass the empty array variable by reference pf.getEmitterDimensions 0 &amp;dim --&gt; OK --look into the previously empty array - --the dimensions are in it Dim --&gt; #(20.0, 20.0) --Get the Emitter Geometry as TriMesh on frame 0 m = pf.getEmitterGeometry 0 --&gt; TriMesh m.numverts--check the number of vertices --&gt; 4 m.numfaces--check the number of faces --&gt; 2 --Check if the emitter geometry is animated pf.isEmitterGeometryAnimated() --&gt; false --Set and get the render state pf.setRenderState false --&gt; OK pf.isRenderState() --&gt; false pf.setRenderState true --&gt; OK pf.isRenderState() --&gt; true --Get the viewport integration step pf.getIntegrationStep() --&gt; 1f --Get the update type - 0 means Complete! pf.getUpdateType() --&gt; 0 --Get the number of selected particles pf.numParticlesSelected() --&gt; 0 --Check if particle 1 is selected pf.isParticleSelected 1 --&gt; false --Get the number of selected Action Lists in the UI pf.numActionListsSelected() --&gt; 0 --In the UI, select the first Action List and try again: pf.numActionListsSelected() --&gt; 1 --Get the node of the Action List you just selected: pf.getSelectedActionList 1 --&gt; $Event:Event 01 @ [0.000000,0.000000,0.000000]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>This Interface is available in:</strong></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for/Particle-Flow-Classes/Sources/PF_Source-GeometryClass.html\' title=\'\'>PF_Source : GeometryClass</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";