var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>particleFlow Global Interface</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>particleFlow Global Interface</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"particleflow-global-interface\"></a></div>\n\
<p><strong>Particle Flow</strong> provides the Core Interface <strong>particleFlow</strong>.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;particleFlow.beginEdit()   \n\
&lt;void&gt;particleFlow.endEdit()   \n\
</pre></div><p>Block the Event encapsulation of <strong>Particle Flow</strong> Actions created via MAXScript.</p>\n\
<p>When a <strong>Particle Flow</strong> Action (Operator or Test) is created, it is automatically encapsulated into a <strong>Particle Flow</strong> Event. This is done since all <strong>Particle Flow</strong> Actions should belong to an Event.</p>\n\
<p>Sometimes this behavior can be undesired and become an obstacle when creating Actions via MAXScript. To avoid this, the pair <strong>beginEdit</strong> / <strong>endEdit</strong> can be used.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;particleFlow.openParticleView() \n\
</pre></div><p>Opens the Particle View. Returns the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for/Particle-View-Access-and/Particle-View-Access/Particle_View-Helper.html\' title=\'\'>Particle View node</a>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` --Disable Automatic Event Encapsulation particleFlow.beginEdit() OK --Create a new Find_Target Action ft = Find_Target() --&gt; $Find_Target:Find Target 01 @ [0.000000,0.000000,0.000000] --Enable Automatic Event Encapsulation again particleFlow.endEdit() OK --Open Particle View and take a look: pview = particleFlow.openParticleView() --&gt; $Particle_View:Particle View 01 @ [0.000000,0.000000,0.000000] --As expected, Find_Target will not appear inside --an Event in Particle View</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>You can use the following short MacroScript to generate an ActionItem that can be placed on a Toolbar, Menu, QuadMenu or Keyboard Shortcut to quickly open Particle View even when there is no PF_Source in the scene.</p>\n\
<blockquote>\n\
<p><strong>SAMPLE SCRIPT:</strong></p>\n\
<p>``` macroScript PView_Open category:&quot;Particle View&quot; buttontext:&quot;Open PView&quot; tooltip:&quot;Open Particle View&quot; ( -- Open Particle View particleFlow.openParticleView() )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;particleFlow.scriptRunner() \n\
</pre></div><p>This method is used in <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for/Particle-Flow-Classes/Sources/PF_Source-GeometryClass.html\' title=\'\'>PF_Source</a><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for/Particle-Flow-Script-Examples/Update-Step-Scripts/Every-Step-Update-Example.html\' title=\'\'>Every Step Update</a> and <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for/Particle-Flow-Script-Examples/Update-Step-Scripts/Final-Step-Update-Example.html\' title=\'\'>Final Step Update</a> scripts to identify the actual PF_Source that is currently running the script.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` pf= particleFlow.ScriptRunner()</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;int&gt;particleFlow.getActionOrder() \n\
</pre></div><p>Get the Particle Flow Action Order.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;particleFlow.setActionOrder &lt;integer&gt;order \n\
</pre></div><p>Set the Particle Flow Action Order.</p>\n\
<p>Possible values are:</p>\n\
<p>0: <strong>Globals First</strong> - At each integration step, <strong>Particle Flow</strong> first applies actions in the global event, and then actions in the other (local) events. Typically, the result is that actions in the local events override comparable actions in the global event.</p>\n\
<p>1: <strong>Locals First</strong> - At each integration step, <strong>Particle Flow</strong> first applies actions in the local events, and then actions in the global event. Typically, the result is that actions in the global event override comparable actions in the local events</p>\n\
<p>Note: For predictable results, don&#39;t use similar actions in the global and local events. However, if comparable actions do exist in both the global event and other events, <strong>Particle Flow</strong> applies them to the system in the order specified here. Typically, the effect that&#39;s applied <em>last</em> is the one that&#39;s visible in the particle system. Default is <strong>1: Locals First</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;particleFlow.getUpdateType() \n\
</pre></div><p>Get the Particle Flow Update Type.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;particleFlow.setUpdateType &lt;integer&gt;type \n\
</pre></div><p>Set the Particle Flow Update Type.</p>\n\
<p>Possible values are:</p>\n\
<p>0 : <strong>Complete mode</strong> - the whole particle animation is recalculated starting at the first frame.</p>\n\
<p>1 : <strong>Forward mode</strong> - particles aren&#39;t updated right away. At playback time the particle history is not recalculated. Only new events that will happen with the particles have new settings.</p>\n\
<p>Note: The <strong>Update Type</strong> determines how <strong>Particle Flow</strong> updates the system when you change a parameter during playback. Because the state of the particle system at any given frame can depend on events in previous frames, using the Complete option can provide a more accurate depiction of the result of the change, at a cost in speed; it takes more time to recalculate the entire system starting at the first frame. Default is <strong>0: Complete</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;particleFlow.cleanUpParticleFlow &lt;boolean&gt;doReport \n\
</pre></div><p>Cleans up the Particle Flow by removing unused items.</p>\n\
<p>If the argument is passed as true, shows the result of the operation as a popup dialog. If false, performs the operation silently.</p>\n\
<p>Returns the number of &quot;dirty&quot; ParticleFlow items removed.</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;particleFlow.repairCacheSystem &lt;boolean&gt;doReport \n\
</pre></div><p>Repairs the Cache System.</p>\n\
<p>If the argument is passed as true, shows the result of the operation as a popup dialog. If false, performs the operation silently.</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;particleFlow.synchronizeLayers &lt;boolean&gt;doReport \n\
</pre></div><p>MovesParticle Flow items to the same layer as the Particle Flow Emitter object.</p>\n\
<p>When a Particle Flow Emitter object is moved to another layer via the Layer Manager, other related objects like all Particle Flow Operator Helpers and some internal objects are not moved to the same layer automatically. This can cause the flow to misbehave for example if a layer is turned off.</p>\n\
<p>This method performs the synchronization to ensure all objects are on the same layer.</p>\n\
<p>If the argument is passed as true, shows the result of the operation as a popup dialog. If false, performs the operation silently.</p>\n\
<p>Returns the number of synchronized layers.</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;particleFlow.resetParticleView() \n\
</pre></div><p>Resets the Particle View.</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;particleFlow.presetManager() \n\
</pre></div><p>Opens the Preset Manager dialog.</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;particleFlow.setNodeEditorDisplayFlags &lt;integer&gt;displayFlags\n\
</pre></div><p>Sets the Node Editor&#39;s display flags.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;particleFlow.forceRedrawParticleView &lt;node&gt;particleView\n\
</pre></div><p>Forces the redraw of the Particle View editor.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";