var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Scripted_Behavior : MAXObject</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Scripted_Behavior : MAXObject</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"scripted_behavior-maxobject\"></a></div>\n\
<div class=\'codeBlock\'><pre>Scripted_Behavior - superclass: ReferenceTarget; super-superclass:MAXWrapper - 4:0 - classID: #(716798510, 1784546452) \n\
</pre></div><p><strong>Introduction to the Crowd System</strong></p>\n\
<p>The crowd system works by assembling all of the force <a href=\'#!/url=./developer/Learning-MAXScript/Trigonometric-Functions.html\' title=\'\'>vectors</a> and speeds for a delegate from its active force behaviors. Then, based upon the delegate’s motion parameters, these force <a href=\'#!/url=./developer/Learning-MAXScript/Trigonometric-Functions.html\' title=\'\'>vectors</a> and speeds are averaged and integrated to create a velocity for the delegate. This velocity might then be modified if the delegate has an active constraint behavior or if it has an active default <strong>Avoidance</strong> behavior.</p>\n\
<p>After the velocity is set, if there is an active orientation behavior, it is used to set the orientation of the delegate, otherwise the orientation is calculated from the default delegate parameters. Finally, the velocity is integrated and a new position is calculated.</p>\n\
<p>The new position of the delegate is not set until all of the forces are calculated for all of the behaviors.</p>\n\
<p>For a <strong>biped crowd</strong>, bipeds work off of goals and not forces when determining which direction they can go in. So, to create a force behavior that will work with a Biped, a goal position must be specified. No forces need to be integrated into velocities because the movement of the Biped is not based upon calculating velocities, but rather by selecting clips found in the motion flow graph.</p>\n\
<p><strong>Constructor</strong></p>\n\
<div class=\'codeBlock\'><pre>Scripted_Behavior ... ScriptedBehavior ... \n\
</pre></div><p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;scripted_behavior&gt;.name String Default: &quot;Scripted&quot; \n\
&lt;Scripted_Behavior&gt;.scriptContextName String Default: &quot;apply&quot; Alias: Script_Context_Name \n\
</pre></div><p>The script functions declared in the Edit MaxScript window are declared in a hidden MaxScript context. This textbox specifies the name of the context. Giving a unique name here avoids conflicts among different scripted behaviors.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Scripted_Behavior&gt;.type Integer Default: 0 Alias: Behavior_Type \n\
</pre></div><p>One of the three behavior types: Force, Constraint, or Orientation.</p>\n\
<p><strong>Force:</strong> Behaviors of this type force the delegates to move in a particular direction, for example, Seek and Repel. Force behaviors work by returning a force <a href=\'#!/url=./developer/Learning-MAXScript/Vector-Arithmetic.html\' title=\'\'>vector</a> in the direction that the behavior wants the delegate to go in, and in some cases the speed it must be traveling at and the goal at which it is trying to reach.</p>\n\
<p><strong>Constraint:</strong> Behaviors of this type restrict the position and velocity of a delegate, for example, SurfaceFollow. Constraint behaviors set the velocity and sometimes might even change the delegate’s position to meet the constraint. You might only have one active constraint behavior per delegate per frame.</p>\n\
<p><strong>Orientation:</strong> Behaviors of this type affect only the orientation of the delegates, for example, Orientation. These behaviors do not work with forces, but instead return an orientation that the delegate must be at, represented by a quaternion. Any active orientation behavior will override the default orientation of the delegate. The velocity determines the default orientation. Like a constraint behavior, you might only have one active orientation behavior per delegate per frame.</p>\n\
<p>Note:</p>\n\
<p>Though there are no avoid behavior types, a force or constraint behavior might be used to create an avoidance behavior.</p>\n\
<p>We <strong>recommend</strong> to use the default <strong>Avoidance</strong> behavior because it is well integrated into the crowd solution pipeline.</p>\n\
<div class=\'codeBlock\'><pre>&lt;scripted_behavior&gt;.script: string \n\
</pre></div><div class=\'section\'><a id=\"edit-maxscript\"></a><h2 id=\"edit-maxscript\">Edit MaxScript</h2></div>\n\
<p>This button &quot;<strong>Edit MaxScript</strong>&quot;, in the Scripted Behavior Rollout opens a MAXScript editor window that can be used to enter a scripted behavior script. The editor window is similar to other MaxScript editor window, but is slightly customized for scripted behaviors.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-4B1DAAB1-7D5E-487A-B47E-FC2CC4974FA8-low.gif\' title=\'\'></div>\n\
<p>The following elements in the <strong>File Menu</strong> work differently:</p>\n\
<p><strong>New:</strong> disabled as only one editor per scripted behavior can be open at any time.</p>\n\
<p><strong>Open:</strong> opens a file in the existing editor window. <strong>Any existing text will be lost</strong>.</p>\n\
<p><strong>Evaluate:</strong> evaluates the script and saves it into the behavior&#39;s paramblock.</p>\n\
<p><strong>Close:</strong> saves into the behavior&#39;s paramblock and closes the editor if no errors are found.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-1C269E52-B932-422F-A441-846EF2A5B776-low.gif\' title=\'\'></div>\n\
<div class=\'section\'><a id=\"scripted-behavior-syntax\"></a><h2 id=\"scripted-behavior-syntax\">Scripted Behavior Syntax</h2></div>\n\
<p>The scripted behavior script is implemented by defining a set of <strong>event handlers</strong> that get called by the crowd system when solving the simulation. The event handlers are automatically enclosed into a hidden MAXScript context. The name of the context is taken from the dialog’s <strong>Script Context Name</strong> text box or its equivalent <strong>. scriptContextName</strong>.</p>\n\
<div class=\'section\'><a id=\"event-handlers-for-scripted-behaviors\"></a><h2 id=\"event-handlers-for-scripted-behaviors\">Event Handlers for Scripted Behaviors</h2></div>\n\
<div class=\'codeBlock\'><pre>on execute do &lt;expr&gt; \n\
</pre></div><p>Called whenever the script is evaluated. All initializing must be done here.</p>\n\
<div class=\'codeBlock\'><pre>on setupDelegates &lt;delegates&gt; &lt;behavior&gt;do&lt;expr&gt; \n\
</pre></div><p><span class=\'code\'>&lt;delegates&gt;</span> an array of all the delegates after they are ordered participating in the simulation. All delegates listed in the Behavior Assignments pane of the Behavior and Team Assignment dialog are found in this list.</p>\n\
<p><span class=\'code\'>&lt;behavior&gt;</span> is the current behavior</p>\n\
<p>Called before the simulation starts.</p>\n\
<p>Note: All of the delegates are passed in, regardless of whether they have this behavior assigned, so the behavior knows the max number of delegates that might be used and therefore sets up whatever data structures are required. Some behaviors need to keep track of parameters on a per delegate basis. This function allows the behavior to set up data structures to get that info. Also that is one of the reasons why the <strong>delegate.id</strong> is unique, so it can be used to hash or index these data structures. Due to cognitive controllers, you never really know exactly all of the delegates that will be active for a particular behavior.</p>\n\
<div class=\'codeBlock\'><pre>on display &lt;behavior&gt; &lt;time&gt;do&lt;expr&gt; \n\
</pre></div><p><span class=\'code\'>&lt;behavior&gt;</span> is the current behavior</p>\n\
<p><span class=\'code\'>&lt;time&gt;</span> is the current time of the simulation</p>\n\
<p>Called every time the crowd system is redrawn. You can use the low level drawing functions from the <strong>gw</strong> struct <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Viewports/Viewport-Drawing-Methods.html\' title=\'\'>Viewport Drawing Methods</a> to have a custom display for the behaviors.</p>\n\
<p>Note:</p>\n\
<p>This handler gets called a number of times, so the system will slow down if implemented.</p>\n\
<div class=\'codeBlock\'><pre>on behaviorStarted &lt;delegate&gt; &lt;behavior&gt; &lt;time&gt;do&lt;expr&gt; \n\
</pre></div><p><span class=\'code\'>&lt;delegate&gt;</span> is the delegate node the behavior is assigned to</p>\n\
<p><span class=\'code\'>&lt;behavior&gt;</span> is the current behavior</p>\n\
<p><span class=\'code\'>&lt;time&gt;</span>is the current time of the simulation</p>\n\
<p>Called whenever a behavior becomes active for a particular delegate. This can occur at the beginning of the simulation for an assigned behavior or when a cognitive controller activates the behavior.</p>\n\
<div class=\'codeBlock\'><pre>on initAtThisTime &lt;behavior&gt; &lt;time&gt; \n\
</pre></div><p>This function is called for each behavior at the beginning of the frame.</p>\n\
<div class=\'codeBlock\'><pre>on applyForce &lt;delegate&gt; &lt;behavior&gt; &lt;time&gt; &lt;numSubSamples&gt; &lt;displayHelpers&gt; &lt;weight&gt;do&lt;expr&gt; \n\
</pre></div><p>If the behavior type is <strong>Force</strong> or <strong>Orientation</strong>, this handler is called every frame to move the delegate.</p>\n\
<p><span class=\'code\'>&lt;delegate&gt;</span> is the delegate node the behavior is assigned to</p>\n\
<p><span class=\'code\'>&lt;behavior&gt;</span> is the current behavior</p>\n\
<p><span class=\'code\'>&lt;time&gt;</span> is the current time of the simulation</p>\n\
<p><span class=\'code\'>&lt;numSubSamples&gt;</span> is the number of sub samples required per frame.</p>\n\
<p>The <span class=\'code\'>&lt;displayHelpers&gt;</span> value is true/false depending on the <span class=\'code\'>&lt;Crowd&gt;.update</span> and <span class=\'code\'>&lt;Crowd&gt;.updateFrequency</span> as well as the current frame. If it is true, you must display any helper imagery you want using the display functions available from the delegates structure. For instance, most behaviors display their force if this is true, and pathfollow also displays its target. The <span class=\'code\'>delegates.lineDisplay</span>, <span class=\'code\'>.sphereDisplay</span>, <span class=\'code\'>.bboxDisplay</span>, and <span class=\'code\'>.textDisplay</span> are all functions which can be used to draw a graphic primitive for a particular delegate when the crowd simulation is being solved. See Viewport Drawing Methods for additional viewport drawing methods.</p>\n\
<p>Note:</p>\n\
<p>The graphic window functions gw.* described in <strong>Viewport Drawing Methods</strong> will not display correctly or at all while in Step Solve.</p>\n\
<p><span class=\'code\'>&lt;weight&gt;</span> is this behavior’s weight on the delegate</p>\n\
<p>The event handler must return an array of the following type:</p>\n\
<div class=\'codeBlock\'><pre>#(&lt;int_flags&gt;, &lt;point3_force&gt;, &lt;point3_goal&gt;, &lt;float_speed&gt;, &lt;Speed_Weight_at_the_Goal&gt;)\n\
</pre></div><p><span class=\'code\'>&lt;int_flags&gt;</span> sum of any of the following values:</p>\n\
<p>0 - the return value is not used by the crowd system</p>\n\
<p>1 - only force is affected</p>\n\
<p>2 - only goal is affected</p>\n\
<p>4 - only speed is affected</p>\n\
<p>For example, a value of 5, (1+4), indicates that the force and speed are affected.</p>\n\
<p><span class=\'code\'>&lt;point3_force&gt;</span> is the force vector. It must be unit normalized and then multiplied by the delegate’s average speed. Modify this value, greater or less, to make the force stronger or weaker.</p>\n\
<p><span class=\'code\'>&lt;point3_goal&gt;</span> is the goal position in world space.</p>\n\
<p><span class=\'code\'>&lt;float_speed&gt;</span> is the net speed of the delegate. This value must be normalized to the average speed of the delegate. A value of 1.0 means go at the average speed.</p>\n\
<p><span class=\'code\'>&lt;Speed_Weight_at_the_Goal&gt;</span> will represent the speed that the delegate must be at when it reaches its goal. This value must be normalized by the average speed of the delegate so that a value of 1.0 equals its average speed.</p>\n\
<p>Note: Any behavior that sets the <span class=\'code\'>&lt;int_flags&gt;</span> with a speed affected setting must ensure that a valid value is set for <span class=\'code\'>&lt;float_speed&gt;</span> and <span class=\'code\'>&lt;Speed_Weight_at_the_Goal&gt;</span>. Note that a goal does not need to be set for this to work. This is how the &#39;SpeedVary&#39; behavior works with Biped. It does not explicitly set a goal, but still modifies the <span class=\'code\'>&lt;Speed_Weight_at_the_Goal&gt;</span> value.</p>\n\
<div class=\'codeBlock\'><pre>on constraint &lt;delegate&gt; &lt;behavior&gt; &lt;time&gt; &lt;numSubSamples&gt; &lt;displayHelpers&gt; &lt;finalSet&gt; &lt;velocity&gt; &lt;speed&gt; &lt;pos&gt;do&lt;expr&gt; \n\
</pre></div><p>If the behavior type, <span class=\'code\'>&lt;Scripted_Behavior&gt;.type</span> is <strong>Constraint</strong>, this handler is called at least once every frame to constrain the delegate. The constraint behavior will override any other force behavior, the Avoidance Behavior, plus it will override any acceleration limits, speed limits, and others. So, it must be used with caution in a simulation.</p>\n\
<p>The constraint behavior constrains the position that the delegate is moving towards by changing the current position that the delegate is already at, it&#39;s current velocity and current speed. These values are combined to get the next position, <strong>Next_position = Current_Position +Normalized(vel) * Speed</strong>. Changing the current position does not actually change where it is at, it just changes the position that is used to calculate its new position. This design allows the constraint to make the objects velocity change abruptly and keep its speed, thus conserving the energy of the delegate.</p>\n\
<p><span class=\'code\'>&lt;delegate&gt;</span> is the delegate node the behavior is assigned to</p>\n\
<p><span class=\'code\'>&lt;behavior&gt;</span> is the current behavior</p>\n\
<p><span class=\'code\'>&lt;time&gt;</span> is the current time of the simulation</p>\n\
<p><span class=\'code\'>&lt;numSubSamples&gt;</span> is the number of sub samples required per frame</p>\n\
<p>The <span class=\'code\'>&lt;displayHelpers&gt;</span> value is true/false depending on the <span class=\'code\'>&lt;Crowd&gt;.update</span> and <span class=\'code\'>&lt;Crowd&gt;.updateFrequency</span> as well as the current frame. If it is true, you must display any helper imagery you want using the display functions available from the delegate. For instance, most behaviors display their force if this is true, and pathfollow also displays its target. The delegates.lineDisplay, .sphereDisplay, .bboxDisplay, and .textDisplay are all functions that can be used to draw a graphic primitive for a particular delegate when the crowd simulation is being solved. See Viewport Drawing Methods for additional viewport drawing methods.</p>\n\
<p><span class=\'code\'>&lt;finalSet&gt;</span> - whether or not this is the final time this behavior will be called during the current frame.</p>\n\
<p>Note: To handle constraints working correctly within the avoidance system the constraint behavior might be called more than once per frame. When the passed in parameter <strong>finalSet</strong> is <strong>true</strong>, it will be the last time the constraint function is called for that frame.</p>\n\
<p>Currently, the constraint behavior&#39;s &quot;<strong>on constraint</strong>&quot; event handler is called twice per frame. The first call occurs before an existing Avoid_Behavior with the passed in parameter <strong>finalSet</strong> having a value of <strong>false</strong> . The second call occurs after the delegate’s limits and Avoid_Behavior are applied with the passed in parameter <strong>finalSet</strong> having a value of <strong>true</strong>. This evaluation order is done so that the delegate’s limits and the Avoid_Behavior can affect the changes that the constraint performs. The second call is made to make sure that the constraint is still being met.</p>\n\
<p>One reason to check the state of <strong>finalSet</strong> is if internally something was cached and you did not want it to change. For example, the <strong>Surface_Follow</strong> constraint behavior keeps track of which triangle it is on and the barycentric coordinates of where it is at. The simulation will not change these values until finalSet is true.</p>\n\
<p><span class=\'code\'>&lt;velocity&gt;</span> is the current velocity of the delegate at this frame.</p>\n\
<p><span class=\'code\'>&lt;speed&gt;</span> is the current speed of the delegate at this frame.</p>\n\
<p><span class=\'code\'>&lt;pos&gt;</span> is the current position of the delegate at this frame.</p>\n\
<p>After the last delegate&#39;s &quot;<strong>on constraint</strong>&quot; has executed for the last frame of the simulation, &quot;on setupDelegates delegates behavior do&quot; will be called with an empty array &quot;#() ReferenceTarget:Scripted_Behavior&quot;. This is guaranteed and can be used by written constraint behaviors to clear out any internal caches.</p>\n\
<p>The event handler must return an array of the following type:</p>\n\
<div class=\'codeBlock\'><pre>#(&lt;int_flags&gt;, &lt;point3_velocity&gt;, &lt;point3_pos&gt;, &lt;point3_goal&gt;, &lt;float_speed&gt;)\n\
</pre></div><p><span class=\'code\'>&lt;int_flags&gt;</span> is the sum of any of the following values:</p>\n\
<p>0 - the return value is not used by the crowd system</p>\n\
<p>1 - the return value is used by the crowd system</p>\n\
<p><span class=\'code\'>&lt;point3_velocity&gt;</span> is the velocity.</p>\n\
<p><span class=\'code\'>&lt;point3_pos&gt;</span> is the modified current position that is used to calculate its new position. To meet a constraint this behavior is allowed to modify the current position of a delegate.</p>\n\
<p><span class=\'code\'>&lt;point3_goal&gt;</span> is the goal position in world space.</p>\n\
<p><span class=\'code\'>&lt;float_speed&gt;</span> is the net speed of the delegate. This value must be normalized to the average speed of the delegate.</p>\n\
<div class=\'codeBlock\'><pre>on orient &lt;delegate&gt; &lt;behavior&gt; &lt;time&gt; &lt;velocity&gt; do &lt;expr&gt; \n\
</pre></div><p>If the behavior type, <span class=\'code\'>&lt;Scripted_Behavior&gt;.type</span> is Orientation, this handler is called every frame. This handler is always called in conjunction with the applyForce handler.</p>\n\
<p><span class=\'code\'>&lt;delegate&gt;</span> is the delegate node the behavior is assigned to</p>\n\
<p><span class=\'code\'>&lt;behavior &gt;</span> is the current behavior</p>\n\
<p><span class=\'code\'>&lt;time&gt;</span> is the current time of the simulation</p>\n\
<p><span class=\'code\'>&lt;velocity&gt;</span> is the the current velocity of the delegate at this frame.</p>\n\
<p>The event handler must return an array of the following type:</p>\n\
<div class=\'codeBlock\'><pre> #(&lt;int_flags&gt;, quat_orientation)\n\
</pre></div><p><span class=\'code\'>&lt;int_flags&gt;</span> is the sum of any of the following values:</p>\n\
<p>0 - the return value is not used by the crowd system</p>\n\
<p>1 - the return value is used by the crowd system</p>\n\
<p><span class=\'code\'>&lt;quat_orientation&gt;</span> is the orientation of the delegate in quaternions.</p>\n\
<p>Note:</p>\n\
<p>The purpose of passing the crowd delegate and behavior to all of the event handlers is that you can call persisted global, saved with the scene, MAXScript functions that work for more than one crowd simulation.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>The following is a pair of scripted behaviors called &quot;FormationConstraint&quot; and &quot;FormationOrientation&quot;.</p>\n\
<p>The &quot;FormationOrientation&quot; will constrain the orientation to a fixed location. In this case, it is based on the current delegate&#39;s orientation found at its first rotation keyframe. The entire scripted orientation behavior can be implemented with one event handler:</p>\n\
<p>``` on orient delegate behavior time vel do ( #(1,delegate.rotation.keys[1].value as quat ) )</p>\n\
<p>```</p>\n\
<p>The &quot;FormationConstraint&quot; keeps a team of delegates in a given positional formation while maintaining the pace and direction of a designated leader named &quot;FormationLeader&quot;. This is similar to a drum major and a marching band or like football blockers running in front of a running back who might dart in any direction. This person dictates how and where the formation will move. This &quot;FormationLeader&quot; is not using the scripted behavior.</p>\n\
<p>This behavior will affect both the position and orientation of the delegate. The orientation is being calculated by the delegate’s velocity and the velocity is being set correctly.</p>\n\
<p>``` on execute do( print&quot; executed&quot;)</p>\n\
<p>on constraint delegate behavior time numsubsamples displayHelpers finalSet vel speed pos do ( leader_velocity = delegates.velocity $TheFormationLeader<br> Normalized_Leader_Velocity= normalize (delegates.velocity $TheFormationLeader)<br> magVel = speed<em>Normalized_Leader_Velocity<br> temp_dis = (pos+leader_velocity)- magVel<br> the_goal =temp_dis + magVel<br> if displayHelpers== true then<br> ( delegates.textDisplay delegate the_goal delegate.wirecolor delegate.name delegates.lineDisplay delegate pos (pos+leader_velocity) delegate.wirecolor true delegates.sphereDisplay delegate (pos+ (leader_velocity </em> $Crowd01.vectorScale)) 4 delegate.wirecolor<br> )<br> #(1, Normalized_Leader_Velocity, temp_dis, the_goal, speed) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";