var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>MAXWrapper Common Properties, Operators, and Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>MAXWrapper Common Properties, Operators, and Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"maxwrapper-common-properties-operators-and-methods\"></a></div>\n\
<p>The following properties and methods are applicable to any value that is derived from MAXWrapper.</p>\n\
<p><strong>Properties</strong></p>\n\
<p>The following MAXWrapper value and class properties give you access to the plug-in category such as, Standard Primitives, Extended Primitives, or Particle Systems:</p>\n\
<div class=\'codeBlock\'><pre>&lt;MAXWrapperobject&gt;.category Name, read-only \n\
&lt;maxclass&gt;.category Name, read-only \n\
&lt;maxsuperclass&gt;.categories Array, read-only      \n\
</pre></div><p>The <span class=\'code\'>category</span> property returns a Name value containing the category. You can use it on either a <strong>3ds Max</strong> object class such as, Line, Box, or Fog, or on an instance of any <strong>3ds Max</strong> object class. For scene nodes, the category usually corresponds to one of the names in the drop down list in the Create panel. These are the categories such as, <span class=\'code\'>#Standard_Primitives</span> , <span class=\'code\'>#Compound_Objects</span> , and <span class=\'code\'>#Particles_Only</span> .</p>\n\
<p>For modifiers, the category determines which group the modifier appears in the Configure Button Sets/Modifiers list. These are the categories such as, <span class=\'code\'>#MAX_STANDARD</span> , <span class=\'code\'>#MAX_EDIT</span> , and <span class=\'code\'>#MAX_SURFACE</span> .</p>\n\
<p>For textures, the category determines which group the texture appears in the Material/Map Browser. These are the categories such as, <span class=\'code\'>#2D</span> (2D maps), <span class=\'code\'>#3D</span> (3D maps), and <span class=\'code\'>#COMP</span> (Compositors).</p>\n\
<p>The <span class=\'code\'>categories</span> property can be used on any of the <strong>3ds Max</strong> object superclasses such as, Shape, GeometryClass, Helper, SpacewarpObject, TextureMap, or Modifier to get a list of the available categories for that superclass, returned as an array of Names.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` $line01.category --returns #Splines Gengon.category --returns #Extended_Primitives Shape.categories --returns #(#Shape, #Splines, #NURBS_Curves)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;maxsuperclass&gt;.classes Array, read-only   \n\
</pre></div><p>Returns an array of MAXClass values that belong to the MAXSuperClass. These MAXClass values can be used to create instances of the class.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` --create an instance of each light class: for aLight in light.classes do aLight()</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;MAXWrapperobject&gt;.classID \n\
&lt;maxclass&gt;.classID \n\
</pre></div><p>The <span class=\'code\'>classID</span> property retrieves the internal <strong>3ds Max</strong> Class ID of the MAXWrapper classes and objects.</p>\n\
<p>The value returned is an array containing two numbers, PartA and PartB of the <strong>3ds Max</strong> internal class ID.</p>\n\
<p>For a MAXWrapper object, the value returned is the Class ID of the class of which the object is an instance.</p>\n\
<p>The combination of the PartA and PartB numbers is guaranteed to be unique for each class.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` Box.classID --returns #(16, 0) b=box() b.classID --returns #(16, 0)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;MAXWrapperObject&gt;.superClassID \n\
&lt;maxclass&gt;.superClassID \n\
</pre></div><p>Retrieves the <strong>3ds Max</strong> superclass ID of the MAXWrapper classes and objects.</p>\n\
<div class=\'codeBlock\'><pre>&lt;maxclass&gt;.creatable Boolean, read-only\n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the class is flagged as being creatable.</p>\n\
<p>This property returning true does not guarantee that the class is really creatable.</p>\n\
<div class=\'codeBlock\'><pre>&lt;maxclass&gt;.ispb2based Boolean, read-only\n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the underlying class definition is a ClassDesc2, <span class=\'code\'>false</span> if a ClassDesc.</p>\n\
<p>ClassDesc2 classes use <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXWrapper-Value/GUID-461915FA-31A2-49CE-84AF-2544B782ACA3.html#parameters\' title=\'\'>ParamBlock2</a>, and ClassDesc classes use ParamBlock (pre-<strong>3ds Max3</strong>).</p>\n\
<div class=\'codeBlock\'><pre>&lt;maxclass&gt;.localizedName \n\
</pre></div><p>A read-only property which contains the localized name of the class.</p>\n\
<div class=\'codeBlock\'><pre>&lt;maxclass&gt;.nonLocalizedName \n\
</pre></div><p><img src=\'developer/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXWrapper-Value/What-s-New-in-MAXScript-in-3ds.html\' title=\'\'>NEW</a> <strong>in 3ds Max 2022:</strong> A read-only property which contains the non-localized name of the class.</p>\n\
<div class=\'codeBlock\'><pre>&lt;maxclass&gt;.dllName String, read-only \n\
</pre></div><p>A read-only property which contains the DLL file name implementing the class, if the class was defined by a plugin DLL; otherwise it will contain undefined.</p>\n\
<p>Available in <strong>3ds Max 2012 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;maxclass&gt;.dllIsLoaded Boolean, read-only\n\
</pre></div><p>A read-only boolean property which contains true when the DLL implementing the class has been already loaded or false when it has been deferred. If the class was not defined in a plugin DLL, this property will contain undefined.</p>\n\
<p>Available in <strong>3ds Max 2012 and higher</strong>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` for sc in superclasses do ( format &quot;%\\n&quot; sc for c in sc.classes do format &quot;\\t% : % : %\\n&quot; c c.dllName c.dllIsLoaded )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;maxclass&gt;.isMSPluginClass Boolean, read-only \n\
</pre></div><p>Indicates whether the maxclass is a scripted plug-in. Note that scripted custom attributes are a subcategory of scripted plug-in, and will also return true.</p>\n\
<p>Available in <strong>3ds Max 2018 and higher</strong>.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>copy &lt;MAXWrapper_object&gt; \n\
</pre></div><p>The <span class=\'code\'>copy()</span> function is implemented by <strong>all</strong> the <strong>3ds Max</strong> objects available in MAXScript such as, scene objects, controllers, modifiers, materials, and others. You can use this function to make a clone of the source object, for example, in situations where you want individual copies or you want to make a shared object unique.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` addModifier $foo $baz.bend</p>\n\
<p>```</p>\n\
<p>will cause <span class=\'code\'>foo</span> to share the bend modifier on <span class=\'code\'>baz</span> , whereas:</p>\n\
<p>``` addModifier $foo (copy $baz.bend)</p>\n\
<p>```</p>\n\
<p>will give <span class=\'code\'>foo</span> a separate clone of the bend modifier on <span class=\'code\'>baz</span> . Any changes to the bend modifier on <span class=\'code\'>foo</span> will not affect <span class=\'code\'>baz</span> and vice versa.</p>\n\
</blockquote>\n\
<p>In the next example, we set up several objects that share a single rotation controller.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` c = bezier_rotation() $foo.rotation.controller = c $baz.rotation.controller = c $bar.rotation.controller = c</p>\n\
<p>```</p>\n\
<p>To later make one of the controllers <strong>unique</strong>, you can do this:</p>\n\
<p>``` $baz.rotation.controller = copy $baz.rotation.controller</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>When the MAXWrapper object is not a scene node, the copy is only created in MAXScript memory. When the MAXWrapper object is a scene node, a new scene node is created which is visible and accessible by the user in the <strong>3ds Max</strong> viewports.</p>\n\
<div class=\'codeBlock\'><pre>exprForMAXObject &lt;MAXWrapper_object&gt; [explicitNames: &lt;boolean&gt;] \n\
</pre></div><p>Returns a string containing a MAXScript expression that will &#39;name&#39; the specified MAXWrapper object using property access and indexes as needed.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>If you have in variable <span class=\'code\'>m</span> a bend modifier on a scene object named &quot;foo&quot;, then:</p>\n\
<p>``` exprForMAXObject m</p>\n\
<p>```</p>\n\
<p>will yield the string:</p>\n\
<p>``` &quot;$foo.bend&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>When the <span class=\'code\'>explicitNames:</span> option is set to true, explicit node names are returned. When set to false, selection relative names are returned. If not specified, the current Macro Recorder settings under Customize &gt; Preferences &gt; MAXScript tab &gt; Code Generation are used.</p>\n\
<p>This method is an exposure of an internal method used by the MacroRecorder. When the <span class=\'code\'>explicitNames:</span> option is not specified, its output will vary depending on the Macro Recorder options.</p>\n\
<blockquote>\n\
<p><strong>MACRO RECORDER EXAMPLE:</strong></p>\n\
<p>``` b=box() --&gt;\\(Box:Box002 @ [0.000000,0.000000,0.000000]  c=b.pos.controller  --&gt;Controller:Bezier_Position  exprformaxobject c  --&gt;&quot;\\)Box002.pos.controller&quot; bm=bend() --&gt;Bend:Bend addmodifier b bm --&gt;OK exprformaxobject bm --&gt;&quot;$Box002.modifiers[#Bend]&quot;</p>\n\
<p>```</p>\n\
<p>Here, changing the Macro Recorder options from &quot;Explicit scene object names&quot; to &quot;Selection-relative scene object names&quot;, yields:</p>\n\
<p>``` exprformaxobject bm --&gt;&quot;$.modifiers[#Bend]&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note:</p>\n\
<p>In some cases, the Macro Recorder generated code does not work as expected. One such case is the ambientColorController - <span class=\'code\'>exprForMaxObject()</span> returns an invalid expression in this case:</p>\n\
<div class=\'codeBlock\'><pre>exprForMaxObject ambientColorController\n\
--&gt;&quot;Scene[#Environment].Ambient_Light.controller&quot;\n\
</pre></div><p>Possible workarounds to access the ambient color controller are:</p>\n\
<div class=\'codeBlock\'><pre>(getclassinstances scene)[1].Environment.Background_Color.controller \n\
\n\
(getclassinstances RenderEnvironment)[1].Background_Color.controller\n\
createInstance &lt;maxclass&gt; [ keyarg1:v] [ keyarg2:v] ... \n\
</pre></div><p>This method is used to directly create the &#39;base objects&#39; that you see in a Node (or any other object). The main use for this is to create temporary geometry base objects from which meshes will be extracted to help create the meshes for scripted geometry primitive plug-ins. The optional <span class=\'code\'>&lt;keyargs&gt;</span> are the same base-object keyword arguments as can be supplied for the class constructor. These are typically the parameters of the base object.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` b = createInstance Box length:10 height:40 width:20</p>\n\
<p>```</p>\n\
<p>creates an instance of a Box. This box will not appear in the <strong>3ds Max</strong> viewports, as it is not a node. It only contains the geometry associated with the Box object. You can get at the mesh representation of these instanced objects with the <span class=\'code\'>mesh</span> property, which yields a <span class=\'code\'>TriMesh</span> value.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>replaceInstances &lt;old_MAXWrapper&gt; &lt;new_MAXWrapper&gt; transferCAs: &lt;boolean&gt; \n\
</pre></div><p>Replaces all instances of the old MAXWrapper with the new MAXWrapper. Old and new MAXWrapper must have the same superclass.</p>\n\
<p>If <span class=\'code\'>transferCAs</span> is <span class=\'code\'>true</span> , any custom attributes on the old_MAXWrapper are transferred to the new_MAXWrapper if there is at least one occurrence of transferring the reference.</p>\n\
<p>References are not transferred for MAXWrapper values.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<blockquote>\n\
<p>Warning: Minimal error checking, use with extreme caution.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>isValidObj &lt;value&gt; \n\
</pre></div><p>Returns true if the value points to a MAX object (a MAXWrapper), and the MAX object has not been deleted.</p>\n\
<p>Note: In some cases, the MAX object might be deleted from the scene, but the object itself is not deleted. This method will return true in this case.</p>\n\
<div class=\'codeBlock\'><pre>isValidValue &lt;value&gt; \n\
</pre></div><p>Returns true if the argument is a valid value, false if the value has been deleted. Available in <strong>in 3ds Max 2017 and higher</strong>.</p>\n\
<p>This is identical to <strong>isDeleted()</strong> below, except it returns true when <strong>isDeleted()</strong> returns false, and false where it returns true.</p>\n\
<div class=\'codeBlock\'><pre>isDeleted &lt;MAXWrapper&gt;\n\
</pre></div><p>Returns true if the specified MAXWrapper has been deleted, false if not.</p>\n\
<p>This is identical to <strong>isValidValue()</strong> above, except it returns true where <strong>isValidValue()</strong> returns false, and false where it returns true.</p>\n\
<p>For most value types, <strong>isDeleted()</strong> always returns false. The value types that can return true are:</p>\n\
<ul>\n\
<li>FPS interface values</li>\n\
<li>Node values</li>\n\
<li>XRefScene values</li>\n\
<li>MAXWrapper values</li>\n\
<li>SelectionSet values</li>\n\
</ul>\n\
<div class=\'codeBlock\'><pre>getClassName &lt;MAXWrapper&gt; [localizedName:&lt;bool&gt;] \n\
</pre></div><p>Returns the class name of the MAXWrapper as a string value.</p>\n\
<p><img src=\'developer/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXWrapper-Value/What-s-New-in-MAXScript-in-3ds.html\' title=\'\'>NEW</a> <strong>in 3ds Max 2022:</strong> When the <span class=\'code\'>localizedName</span> keyword parameter is <span class=\'code\'>true</span> (the default), the localized name as it appears in the UI is returned. Otherwise the non-localized name is returned.</p>\n\
<div class=\'codeBlock\'><pre>getObjectName &lt;object&gt; [localizedName:&lt;bool&gt;] \n\
</pre></div><p>Returns the base name of the MAXWrapper&#39;s BaseObject, if it derives from one, as a string value. For example, this method returns &quot;bend&quot; for a bend modifier.</p>\n\
<p><img src=\'developer/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXWrapper-Value/What-s-New-in-MAXScript-in-3ds.html\' title=\'\'>NEW</a> <strong>in 3ds Max 2022:</strong> When the <span class=\'code\'>localizedName</span> keyword parameter is <span class=\'code\'>true</span> (the default), the localized name as it appears in the UI is returned. Otherwise the non-localized name is returned.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt; isUsedInScene &lt;MAXWrapper&gt; skipCustAttributes:&lt;false&gt; includeXrefScenes:&lt;false&gt;\n\
</pre></div><p>This function returns true if the MAXWrapper is used by the scene, other than by Scene Material Library (which in some cases can contain materials not being used by the scene). The scene includes the material editor, renderer, render effects, and so on. Specify <strong>skipCustAttributes</strong> as true to skip over any MAXWrapper objects held in Custom Attributes. Set <strong>includeXrefScenes</strong> as true to search any Xrefed scenes as well.</p>\n\
<p>Available in <strong>3ds Max 2018 and higher</strong>.</p>\n\
<div class=\'section\'><a id=\"example\"></a><h3 id=\"example\">Example</h3></div>\n\
<div class=\'codeBlock\'><pre>mat = StandardMaterial()\n\
--&gt; Standardmaterial:Standard\n\
isUsedInScene mat\n\
--&gt; false\n\
s = sphere material:mat\n\
--&gt;$Sphere:Sphere001 @ [0.000000,0.000000,0.000000]\n\
isUsedInScene mat\n\
--&gt;true\n\
&lt;MAXClass&gt;getMAXClass &lt;scid&gt; #(&lt;cid_a&gt;, &lt;cid_b&gt;) create:&lt;boolean&gt; \n\
</pre></div><p>Returns MAXClass corresponding to the specified superclass ID and class ID. The superclass ID is specified as an integer value, and the class ID is specified as a 2 element array of integers. If <span class=\'code\'>create:true</span> is specified, a new MAXClass is created if it doesn&#39;t already exist.</p>\n\
<p>Available in <strong>3ds Max 2018 and higher</strong>.</p>\n\
<div class=\'section\'><a id=\"dependencies\"></a><h2 id=\"dependencies\">Dependencies</h2></div>\n\
<p>An important internal mechanism in <strong>3ds Max</strong> defines the dependency relationship between <strong>3ds Max</strong> objects. For example, a material depends on its various maps, a path controller depends on its percent controller, a scene node depends on its base object, and so on.</p>\n\
<p>The <span class=\'code\'>refs</span> struct provides methods to access and manage MaxWrapper object references. These methods are provided primarily for debugging and investigating reference hierarchies. They are not required for general scripting and plug-in development. The &quot;Get&quot; methods are safe to use. The &quot;Set/Replace&quot; methods are extremely unsafe, and should only be used if you really know what you are doing.</p>\n\
<p>The following method returns the MAXWrapper objects that depend on a specified MAXWrapper object.</p>\n\
<div class=\'codeBlock\'><pre>refs.dependents&amp;&lt;MAXWrapper_object&gt;[ immediateOnly:&amp;&lt;boolean&gt;] \n\
</pre></div><p>Returns an array of the <strong>3ds Max</strong> MAXWrapper objects depending on the specified MAXWrapper object. The specified MAXWrapper object can be any MAXWrapper object such as, a scene node, controller, material, modifier, and so on.</p>\n\
<p>If the optional keyword <span class=\'code\'>immediateOnly</span> is supplied and set to true, only the immediate dependents of the specified object will be returned.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` refs.dependents $foo.material.diffuseMap</p>\n\
<p>```</p>\n\
<p><strong>CAN RETURN</strong></p>\n\
<p>``` #(Material_#3, Material_#2, Map_#2:Noise, Material_#1)</p>\n\
<p>```</p>\n\
<p>which shows that the diffuseMap in <span class=\'code\'>$foo</span> is referenced in material #1, material #2, material #3, and noise TextureMap #2.</p>\n\
</blockquote>\n\
<p>The following example shows several objects being created, and sets up controllers on the objects which depend on other objects.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` theSphere=sphere ()-- create a sphere theCone=cone radius1:0 radius2:20-- create a cone theHelix=helix height:100 pos:[100,100,0]-- create a helix theCone.target=theSphere-- assign theSphere as target of theCone -- a look at controller is automatically -- assigned to theCone -- assign path controller to theSphere, path to follow is the helix theSphere.position.controller=path path:theHelix refs.dependents theSphere-- show dependents of the sphere refs.dependents theCone-- show dependents of the cone refs.dependents theHelix-- show dependents of the helix</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` $Sphere:Sphere002 @ [0.000000,0.000000,0.000000]-- result line 1 $Cone:Cone002 @ [0.000000,0.000000,0.000000]-- result line 2 $Helix:Helix002 @ [100.000000,100.000000,0.000000]-- result line 3 $Sphere:Sphere002 @ [0.000000,0.000000,0.000000]-- result line 4 Controller:Path_Constraint-- result line 8 #(Controller:Look_At, $Cone:Cone002 @ [0.000000,0.000000,0.000000])-- result line 9 #()-- result line 10 -- following is output of line 11 #(ReferenceTarget:ParamBlock2, Controller:Path_Constraint, Controller:Position_Rotation_Scale, $Sphere:Sphere002 @ [135.000000,100.000000,0.000000], Controller:Look_At, $Cone:Cone002 @ [0.000000,0.000000,0.000000])</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>refs.dependsOn &lt;MAXWrapper_object&gt; \n\
</pre></div><p>Returns an array of the <strong>3ds Max</strong> MAXWrapper objects that the specified MAXWrapper object directly depends on.</p>\n\
<p>The specified MAXWrapper object can be any MAXWrapper object such as, a scene node, controller, material, or modifier.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` b = box() refs.dependsOn b</p>\n\
<p>```</p>\n\
<p><strong>RETURNS</strong></p>\n\
<p>``` #(Controller::Position_Rotation_Scale, Box)</p>\n\
<p>```</p>\n\
<p>This shows that the node directly depends on its transform controller and its base object. The node will also be indirectly dependent on the MAXWrapper objects that these objects depend on (the position, rotation, and scale controllers for the transform controller).</p>\n\
</blockquote>\n\
<p><span class=\'code\'>refs.dependson</span> also returns the Custom Attributes of an object. In versions prior to <strong>3ds Max 7</strong>, Custom Attributes were not considered by this method as technically they are not dependent on the object.</p>\n\
<div class=\'codeBlock\'><pre>refs.dependencyLoopTest &lt;MAXWrapper_object&gt; &lt;MAXWrapper_object&gt; \n\
</pre></div><p>Returns true if the two MAXWrapper objects create a dependency loop, false otherwise.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` a = box pos:[-100,0,0] --&gt; $Box:Box001 @ [-100.000000,0.000000,0.000000] b = box pos:[100,0,0] --&gt; $Box:Box002 @ [100.000000,0.000000,0.000000] a.material = standardMaterial() --&gt; Standardmaterial:Standard refs.dependencyLoopTest a b --&gt; false refs.dependencyLoopTest a a.material --&gt; true</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>refs.dependentNodes &lt;MAXObject&gt; firstOnly: &lt;boolean&gt; baseObjectOnly: &lt;boolean&gt; \n\
</pre></div><p>Returns node(s) that are dependent on the specified MAXObject.</p>\n\
<p>If <span class=\'code\'>firstOnly:</span> is true, and if no nodes are dependent on the specified MAXObject, a value of &#39;undefined&#39; is returned, otherwise a MAXNode value corresponding to the first dependent node found is returned.</p>\n\
<p>If <span class=\'code\'>firstOnly:</span> is false or not specified, the return value is always an array.</p>\n\
<p>If <span class=\'code\'>baseObjectOnly:</span> is true, only nodes where the MAXObject is the base object will be returned.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>refs.replaceReference  &lt;max_obj&gt; &lt;int&gt; {&lt;max_obj&gt; | undefined} \n\
</pre></div><p>Replaces the reference at index <span class=\'code\'>&lt;int&gt;</span> with either a new reference or undefined (effectively removing the reference). <strong>Note</strong>: this is an unsafe method and will crash 3ds Max if you do not know what you are doing.</p>\n\
<div class=\'codeBlock\'><pre>refs.setIndirectReference &lt;MaxWrapper&gt; &lt;int&gt; {&lt;MaxWrapper | undefined} \n\
</pre></div><p>Replaces the indirect reference at index <span class=\'code\'>&lt;int&gt;</span> with either a new reference or undefined (effectively removing the reference). <strong>Note</strong>: this is an unsafe method and will crash 3ds Max if you do not know what you are doing.</p>\n\
<div class=\'codeBlock\'><pre>refs.getReference &lt;MaxWrapper&gt; &lt;int&gt; \n\
</pre></div><p>Gets the reference at index <span class=\'code\'>&lt;int&gt;</span> in the object’s reference array.</p>\n\
<p><strong>Example</strong>:</p>\n\
<div class=\'codeBlock\'><pre>s = sphere()\n\
-- $Sphere:Sphere001 @ [0.000000,0.000000,0.000000]\n\
refs.GetReference s 1\n\
-- Controller:Position_Rotation_Scale\n\
refs.getIndirectReference &lt;MaxWrapper&gt; &lt;int&gt; \n\
</pre></div><p>Gets the indirect reference at index <span class=\'code\'>&lt;int&gt;</span> in the objects reference array.</p>\n\
<div class=\'codeBlock\'><pre>refs.getAddr &lt;MaxWrapper&gt;\n\
</pre></div><p>Returns the address of the MaxWrapper as an IntegerPtr value. Available in <strong>in 3ds Max 2017 and higher</strong>.</p>\n\
<p><strong>Example</strong>:</p>\n\
<div class=\'codeBlock\'><pre>s = sphere()\n\
-- $Sphere:Sphere001 @ [0.000000,0.000000,0.000000]\n\
refs.getAddr s\n\
-- 1530273376P\n\
refs.getNumRefs &lt;MaxWrapper&gt; \n\
</pre></div><p>Returns the number of references held by the specified MaxWrapper object.</p>\n\
<p><strong>Example</strong>:</p>\n\
<div class=\'codeBlock\'><pre>s = sphere()\n\
-- $Sphere:Sphere003 @ [0.000000,0.000000,0.000000]\n\
refs.getNumRefs s\n\
-- 16\n\
refs.getNumIndirectRefs &lt;MaxWrapper&gt; \n\
</pre></div><p>Returns the number of indirect references held by the specified MaxWrapper object. Note that you can’t create indirect references with MaxScript.</p>\n\
<p><strong>Example</strong>:</p>\n\
<div class=\'codeBlock\'><pre>n = NodeTransformMonitor()\n\
-- ReferenceTarget:NodeTransformMonitor\n\
refs.getNumIndirectRefs n\n\
-- 1\n\
notifyDependents &lt;MAXObject&gt; partIDmsg: &lt;name&gt;: &lt;int&gt; propogate: &lt;boolean&gt; \n\
</pre></div><p>Sends notification message to the dependents of the object.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<p>Valid partID values and their SDK equivalents are:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">partID</th>\n\
<th align=\"left\">SDK</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><strong>#topo</strong></td>\n\
<td align=\"left\"><strong>PART_TOPO</strong></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><strong>#geom</strong></td>\n\
<td align=\"left\"><strong>PART_GEOM</strong></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><strong>#texmap</strong></td>\n\
<td align=\"left\"><strong>PART_TEXMAP</strong></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><strong>#mtl</strong></td>\n\
<td align=\"left\"><strong>PART_MTL</strong></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><strong>#TM</strong></td>\n\
<td align=\"left\"><strong>PART_TM</strong></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><strong>#obj</strong></td>\n\
<td align=\"left\"><strong>PART_OBJ</strong></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><strong>#objectType</strong></td>\n\
<td align=\"left\"><strong>PART_OBJECT_TYPE</strong></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><strong>#select</strong></td>\n\
<td align=\"left\"><strong>PART_SELECT</strong></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><strong>#subSelType</strong></td>\n\
<td align=\"left\"><strong>PART_SUBSEL_TYPE</strong></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><strong>#display</strong></td>\n\
<td align=\"left\"><strong>PART_DISPLAY</strong></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><strong>#vertColor</strong></td>\n\
<td align=\"left\"><strong>PART_VERTCOLOR</strong></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><strong>#gfxData</strong></td>\n\
<td align=\"left\"><strong>PART_GFX_DATA</strong></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><strong>#dispApprox</strong></td>\n\
<td align=\"left\"><strong>PART_DISP_APPROX</strong></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><strong>#extension</strong></td>\n\
<td align=\"left\"><strong>PART_EXTENSION</strong></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><strong>#TMchannel</strong></td>\n\
<td align=\"left\"><strong>PART_TM_CHAN</strong></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><strong>#MTLChannel</strong></td>\n\
<td align=\"left\"><strong>PART_MTL_CHAN</strong></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><strong>#all</strong></td>\n\
<td align=\"left\"><strong>PART_ALL</strong></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><strong>#putInFG</strong></td>\n\
<td align=\"left\"><strong>PART_PUT_IN_FG</strong></td>\n\
</tr>\n\
</table>\n\
<p>The default partID is #all.</p>\n\
<p>The msg value corresponds to one of the REFMSG values specified in maxsdk\\include\\ref.h, and documented in the SDK Help topic &quot;List of Reference Messages and their PartID parameters&quot;. The default msg value is 0x050 (REFMSG_CHANGE), unless partID is #putInFG, in which case the default is 0x070 (REFMSG_FLAGDEPENDENTS).</p>\n\
<p>If <span class=\'code\'>propogate:</span> is true (the default), the messages are propagated to the dependents of the dependents, recursively.</p>\n\
<p>This method is useful for notifying scripted controllers that a value used in the controller has changed.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE, RUN:</strong></p>\n\
<p>``` globalmySphereRadius = 10 s=sphere() s.radius.controller = float_script() s.radius.controller.script =&quot;mySphereRadius&quot;</p>\n\
<p>```</p>\n\
<p><strong>NOW RUN:</strong></p>\n\
<p>``` mySphereRadius = 50</p>\n\
<p>```</p>\n\
<p>The viewport will not update to reflect the change.</p>\n\
<p><strong>NOW RUN:</strong></p>\n\
<p>``` notifydependents s.radius.controller</p>\n\
<p>```</p>\n\
<p>The viewport updates to reflect that the dependents of the controller (the sphere base object and node) are notified about the controller change.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>disableRefMsgs() \n\
enableRefMsgs() \n\
</pre></div><p>Disable/enable reference notification system. Must be paired.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<blockquote>\n\
<p>Warning: USE WITH EXTREME CAUTION</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";