var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Modifier Common Properties, Operators, and Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Modifier Common Properties, Operators, and Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"modifier-common-properties-operators-and-methods\"></a></div>\n\
<p><strong>Properties</strong></p>\n\
<p>All modifiers have the following properties:</p>\n\
<div class=\'codeBlock\'><pre>&lt;modifier&gt;.name: string\n\
</pre></div><p>Get and set modifier name</p>\n\
<div class=\'codeBlock\'><pre>&lt;modifier&gt;.enabled: boolean\n\
\n\
&lt;modifier&gt;.enabledInViews: boolean\n\
</pre></div><p>Lets you control the modifier’s enabled/disabled state. These are read/write properties that let you determine and set the enabled state of the given modifier,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` $foo.modifiers[2].enabled = false-- turn off 2nd modifier</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The <span class=\'code\'>enabledInViews</span> property controls viewport display, <span class=\'code\'>enabled</span> controls both viewport and rendered display.</p>\n\
<div class=\'codeBlock\'><pre>&lt;modifier&gt;.enabledInRenders: boolean\n\
</pre></div><p>Get/Set whether the modifier is enabled in renders.</p>\n\
<p>When set to <span class=\'code\'>true</span> , the modifier is enabled in renders, when <span class=\'code\'>false</span> it is disabled.</p>\n\
<p><strong>Associated Methods</strong></p>\n\
<p>The modifier stack on a scene node can be manipulated using the following <span class=\'code\'>&lt;node&gt;</span> methods:</p>\n\
<div class=\'codeBlock\'><pre>validModifier( &lt;node&gt; | &lt;objectset&gt;) (&lt;modifier | &lt;modifier_class&gt;)\n\
</pre></div><p>Tests whether a particular modifier or modifier class may be added the given <span class=\'code\'>&lt;node&gt;</span> or <span class=\'code\'>&lt;objectset&gt;</span> . Returns <span class=\'code\'>true</span> if so, <span class=\'code\'>false</span> if not.</p>\n\
<p>The <span class=\'code\'>validModifier()</span> method operates exactly as does the Modify panel in determining modifier applicability. Any modifier that takes a deformable object will return <span class=\'code\'>true</span> for all scene objects except Helpers. This corresponds to the Modify panel’s behavior of allowing modifiers such as Bend, Taper, etc. to be applied to lights and cameras, space warp objects, etc., as well as geometry types like box, sphere, etc., but not helpers such as dummys or bones.</p>\n\
<p>It is recommended that classes be used in RCMenus and macroScripts using <strong>validModifier()</strong> to reduce resource usage.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` if validModifier $ Edit_Mesh then ...</p>\n\
<p>```</p>\n\
<p>instead of</p>\n\
<p>``` if validModifier $ (Edit_Mesh()) then ...</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The MAXScript <span class=\'code\'>isValidModifier</span> function will check if it has been passed a modifier that doesn&#39;t exist at runtime. It returns <span class=\'code\'>false</span> in this case. It uses the ClassEntry to determine the InputType() of the modifier.</p>\n\
<div class=\'codeBlock\'><pre>addModifier &lt;node&gt; &lt;modifier&gt; [before:index] -- mapped\n\
</pre></div><p>Adds the modifier to <strong>all instances</strong> of the node to which the function is applied.</p>\n\
<p>The optional <span class=\'code\'>before:</span> keyword argument can be used to insert the modifier into the node’s modifier stack just before the indexed modifier, counting from the top of the stack.</p>\n\
<p>The added modifier will apply to any appropriate active sub-object selection in the node only if the node is <strong>currently selected and open</strong> in the Modify panel at the desired sub-object level.</p>\n\
<p>You can use the <strong>3ds Max</strong> System global variable, <span class=\'code\'>subObjectLevel</span> to test and set the level for the object currently open in the Modify panel.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` max modify mode-- open mod panel select $box01-- select box01 into mod panel subObjectLevel = 3-- subobject level to Face addModifier $box01 (ffd_2x2x2())-- add FFD mod to those faces</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>If the <span class=\'code\'>before:</span> keyword argument would place a modifier in an invalid position in the stack, the modifier will be placed at the nearest valid position.</p>\n\
<p>For example, if you tried to place a SpacewarpModifier class object below a Modifier class object, the SpacewarpModifier object would be placed below any SpacewarpModifier objects, and above any Modifier objects.</p>\n\
<p>If <span class=\'code\'>&lt;node&gt;</span> is a collection, an instance of the modifier is placed on each of the nodes in the collection.</p>\n\
<p>Unlike interactively applying a modifier to a selection, the position and size of each modifier instance’s gizmo corresponds to position and size of the node the modifier instance is applied to.</p>\n\
<p>To apply a modifier to a collection in the same manner that <strong>3ds Max</strong> applies modifiers, use the <span class=\'code\'>modPanel.addModToSelection()</span> described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Command-Panels/Modify-Panel.html\' title=\'\'>Modify Panel</a>.</p>\n\
<p>A limitation of the <span class=\'code\'>addModifier()</span> function is that it cannot generally apply modifiers to sub-object selections, and so it disables any current sub-object levels.</p>\n\
<p>To apply a modifier to a sub-object selection in the same manner that <strong>3ds Max</strong> applies modifiers, use the <span class=\'code\'>modPanel.addModToSelection()</span> .</p>\n\
<p>This function correctly observes the currently selected sub-object level in the Modify panel.</p>\n\
<div class=\'codeBlock\'><pre>deleteModifier &lt;node&gt; &lt;modifier_or_index&gt;\n\
</pre></div><p>Lets you delete modifiers from the modifier stack.</p>\n\
<p>Takes either a modifier value present on the <span class=\'code\'>&lt;node&gt;</span> stack, or an index specifying the index of the modifier to delete, counting from the top of the stack.</p>\n\
<div class=\'codeBlock\'><pre>collapseStack &lt;node&gt; -- mapped\n\
</pre></div><p>Collapses the modifiers out of a stack, leaving the appropriate resultant editable base class, such as Editable Mesh, Editable Spline, NURBS Surface, etc., as the base object of the node.</p>\n\
<p>If there are no modifiers in the stack when this is called, no action is taken.</p>\n\
<p>If you want to force a stack collapse or conversion to editable base class form, use one of the node conversion functions, such as <span class=\'code\'>convertToMesh(),convertToSplineShape()</span> , etc.</p>\n\
<p>See the methods section in <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/Node-Common-Methods.html\' title=\'\'>Node Common Properties, Operators, and Methods</a> for more details.</p>\n\
<div class=\'codeBlock\'><pre>getModContextTM &lt;node&gt; &lt;modifier&gt;\n\
</pre></div><p>Returns a Matrix3 value giving the modifier’s context transform for the local coordinates used in modifier sub-object gizmos.</p>\n\
<p>Accessing the transform properties of a modifier sub-object such as a gizmo or a center in MAXScript yields values that are relative to that modifier’s context transform, equivalent to the values shown in track view for those properties.</p>\n\
<p>If the modifier is not operating on a sub-object selection, such as a face or vertex selection, or if the modifier was interactively applied to an object selection, this context TM is the local coordinate space of the object itself.</p>\n\
<p>However, if the modifier is operating on either an object selection set or a sub-object selection, the context transform gives the position and orientation of that selection, and so you can use <span class=\'code\'>getModContextTM()</span> to get the world-space transform properties of any of its sub-objects.</p>\n\
<div class=\'codeBlock\'><pre>getModContextBBoxMin&lt;node&gt; &lt;modifier&gt; getModContextBBoxMax&lt;node&gt; &lt;modifier&gt;\n\
</pre></div><p>These functions complement the <span class=\'code\'>getModContextTM()</span> function and can be used to derive the world-space coordinates of the bounding box of the modifier context.</p>\n\
<p>This can be used, for example, to determine the bounds of a modifier operating on a sub-selection or the bounds of an FFD lattice.</p>\n\
<p>This is particularly useful for scripting FFD control point placement, since these control points live in a 0-to-1 lattice space&amp;emdash;the mod context bounding box gives the world space bounds of this lattice space allowing you to compute scaled lattice space coordinates from world coordinates.</p>\n\
<p>The functions return Point3 values for the minimum and maximum extents of the bounding box.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";