var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Modifier Sub-Object Transform Properties</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Modifier Sub-Object Transform Properties</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"modifier-sub-object-transform-properties\"></a></div>\n\
<p>In MAXScript, the values of modifier sub-object transform properties, such as centers and gizmo position, rotation and scale, are <strong>not</strong> given in the current working coordinate system, but rather are typically in the coordinate system of the object to which it is applied. This is in contrast to scene node transform properties. The values given are exactly as would be seen in the sub-object’s corresponding track view or as might be referenced in an Expression controller track variable for that sub-object property. To convert from local to world coordinates, you multiply the local coordinates by the node’s <span class=\'code\'>objecttransform</span> matrix. To convert from world to local coordinates, you multiple the world coordinates by the inverse of the node’s <span class=\'code\'>objecttransform</span> matrix.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` obj=box pos:[10,20,30] addModifier obj (affect_region()) objTM=obj.objecttransform modTM=getModContextTM obj obj.affect_region --calculate world coordinates of end point obj.affect_region.end_point * (inverse modTM) * objTM --set end point at world coordinates [20,20,0] obj.affect_region.end_point = [20,20,0] * modTM * (inverse objTM)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"ffd-control-points\"></a><h2 id=\"ffd-control-points\">FFD Control Points</h2></div>\n\
<p>FFD control point sub-object properties are also accessible but have several special considerations. The control points properties are named as they appear in the track view, subject to the MAXScript convention of using <span class=\'code\'>&#39;_&#39;</span> underscores for spaces, so</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` $foo.ffd_2x2x2.control_point_1 $baz.ffd_3x3x3.control_point_32 = [1,2,3]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>There are two special considerations when accessing FFD control points. First, you can only access control points that have ALREADY been animated by hand, or by using the <span class=\'code\'>animateVertex()</span> or the <span class=\'code\'>animateAll()</span> MAXScript functions (see <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Scripting-Vertex-and-Control/Scripting-Vertex-and-Control-1.html\' title=\'\'>Scripting Vertex and Control Point Animation</a>). The FFD doesn’t actually create accessible control points until you do this, a behavior that shows up in the track view in normal <strong>3ds Max</strong> use - you cannot actually place control point keyframes in the track view until you’ve animated the control point.</p>\n\
<p>Second, control point coordinates are in FFD lattice space. This is a normalized space, with [0,0,0] at the lower left-hand corner (at control_point_1) and [1,1,1] at the opposite corner of the FFD lattice, so you have to be careful about computing and scaling correct coordinates when you set them. This is also reflected in the track view for FFD control points in normal <strong>3ds Max</strong> use - if you look at their values in a keyframe property dialog or a function graph, they are in this normalized lattice space, not world-space coordinates. You’d have to work in this space also if you tried to use expression controllers to control FFDs. The modifier utility functions <span class=\'code\'>getModContextBBoxMin()</span> and <span class=\'code\'>getModContextBBoxMin()</span> can be used to determine the world-space bounds of an FFD lattice allowing you to compute scaled lattice space coordinates from world coordinates. See details on these functions in <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Modifier-MAXWrapper-and/Modifier-Common-Properties/Modifier-Common-Properties-1.html\' title=\'\'>Modifier Common Properties, Operators, and Methods</a>.</p>\n\
<p>An example of accessing and converting coordinate systems for FFD control points is shown in the following script:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` b=box pos:[10,20,0] ffd=ffdbox() addModifier b ffd animateVertex ffd 64 cp64posL=ffd.control_point_64 objTM=b.objecttransform modTM=(getModContextTM b ffd)<em>ffd.lattice_transform.value modBBMin=getModContextBBoxMin b ffd modBBMax=getModContextBBoxMax b ffd cp64posW=(modBBMin+(cp64posL</em>(modBBMax-modBBMin)))* (inverse modTM) * objTM</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";