var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Modifier : MAXWrapper and SpacewarpModifier : MAXWrapper</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Modifier : MAXWrapper and SpacewarpModifier : MAXWrapper</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"modifier-maxwrapper-and-spacewarpmodifier-maxwrapper\"></a></div>\n\
<p>The Modifier and SpacewarpModifier families of classes can be created and added to an object’s modifier stack using the <span class=\'code\'>addModifier()</span> or <span class=\'code\'>modPanel.addModToSelection()</span> methods. Unless otherwise noted, the term modifier will be used to mean members of either class.</p>\n\
<p>By making a single modifier and adding it to several objects, you are sharing the modifier between the objects, as you would by applying a modifier to a selection of objects in the <strong>3ds Max</strong> user interface. The constructors in the following classes can take any of the listed properties as optional keyword arguments with the defaults as shown.</p>\n\
<div class=\'section\'><a id=\"accessing-existing-modifiers\"></a><h2 id=\"accessing-existing-modifiers\">Accessing Existing Modifiers</h2></div>\n\
<p>Existing modifiers can be accessed in two ways:</p>\n\
<div class=\'section\'><a id=\"node.property-access\"></a><h3 id=\"node.property-access\">Node.Property Access</h3></div>\n\
<p>Modifiers can be accessed as a property of a node.</p>\n\
<p>When you access properties on a <span class=\'code\'>&lt;node&gt;</span> scene object such as, its name, position, length, and so on, MAXScript will also consider modifiers on the object to be properties, for example:</p>\n\
<div class=\'codeBlock\'><pre>$box001.heightsegs --get creation parameter\n\
$box001.twist --get the twist modifier\n\
$box001.twist.angle --the twist’s angle\n\
\n\
</pre></div><p>You can then access modifier properties as sub-properties on the modifier as shown. If the modifier name has spaces in it, you can use underscore **‘_’** as space convention that pathnames use as follows:</p>\n\
<div class=\'codeBlock\'><pre>$box001.uvw_map --to get the ‘UVW Map’ modifier\n\
\n\
</pre></div><div class=\'section\'><a id=\"modifiers-array-access\"></a><h3 id=\"modifiers-array-access\">.Modifiers Array Access</h3></div>\n\
<p>The property access described above will work in simple situations, but there might be several modifiers with the same name, or a modifier with the same name as a creation parameter (the latter is always looked for first).</p>\n\
<p>In this situation, you can use the modifier array mechanism, which yields an array of modifiers you can index into in several ways:</p>\n\
<div class=\'codeBlock\'><pre>b = box()\n\
$box001.modifiers --get the array or modifiers\n\
$box001.modifiers[3] --get the 3rd modifier counted from top of the list\n\
$box001.modifiers[#twist] --get the modifier named &quot;twist&quot; using name literal\n\
$box001.modifiers[&quot;ffd 4x4x4&quot;] --get the FFD named &quot;ffs 4x4x4&quot; using string\n\
$box001.modifiers[bend] --get the Bend by class (Added in 3ds Max 2013)\n\
\n\
</pre></div><div class=\'section\'><a id=\"looping-through-the-modifiers\"></a><h4 id=\"looping-through-the-modifiers\">Looping Through The Modifiers</h4></div>\n\
<p>You can use a for loop over the .modifiers array to go through all existing modifiers and check their name, class, and properties to find the one you need.</p>\n\
<div class=\'section\'><a id=\"accessing-a-modifier-by-index\"></a><h4 id=\"accessing-a-modifier-by-index\">Accessing a Modifier By Index</h4></div>\n\
<p>You can access a modifier in the <span class=\'code\'>.modifiers</span> array by its index.</p>\n\
<p>The modifiers are listed as shown in the Modifier stack, indexed from top to bottom, starting with 1.</p>\n\
<p>If the index is out of range, either higher than the number of modifiers in the array or less than 1, the value of <span class=\'code\'>undefined</span> will be returned.</p>\n\
<blockquote>\n\
<p><strong>FOR LOOP AND INDEX EXAMPLES SETUP</strong></p>\n\
<p>``` t=teapot() --create a teapot addmodifier t (bend angle:30) --add a Bend modifier with Angle 30 addmodifier t (bend angle:60 direction:90) --add a Bend modifier with angle 60 and dir 90 addmodifier t (twist angle:180) --add a Twist modifier with Angle 180</p>\n\
<p>```</p>\n\
<p><strong>FOR LOOP AND INDEX EXAMPLES:</strong></p>\n\
<p>``` --The following will find all Bend modifiers with Angle less than 90 and change the Angle to 90 for m in t.modifiers where classof m == Bend and m.angle &lt; 90 do m.angle = 90</p>\n\
<p>--The following will find all modifiers (in this case both the Bends and the Twist) --with an Angle property and change it to 0 for m in t.modifiers where isProperty m #Angle do m.angle = 0</p>\n\
<p>--The following will delete modifiers that have a direction property other than 0. --On our case this is the second, upper Bend modifier. --Note that we must count backwards from bottom of the stack because deleting a modifier --will renumber the modifiers array and we could otherwise miss a modifier: for m = t.modifiers.count to 1 by -1<br> where isProperty t.modifiers[m] #Direction and t.modifiers[m].direction != 0 do deleteModifier t m</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"accessing-a-modifier-by-a-name-literal\"></a><h4 id=\"accessing-a-modifier-by-a-name-literal\">Accessing a Modifier By a Name Literal</h4></div>\n\
<p>You can access a modifier in the <span class=\'code\'>.modifiers</span> array by a name literal.</p>\n\
<p>Use underscore **‘_’** in place of spaces in the name like with properties access.</p>\n\
<p>If two modifiers have the same name, the top-most will be returned.</p>\n\
<p>If a modifier with the specified name does not exist in the array, the value of <span class=\'code\'>undefined</span> will be returned.</p>\n\
<div class=\'section\'><a id=\"accessing-a-modifier-by-a-name-string\"></a><h4 id=\"accessing-a-modifier-by-a-name-string\">Accessing a Modifier By a Name String</h4></div>\n\
<p>You can access a modifier in the <span class=\'code\'>.modifiers</span> array by a name string.</p>\n\
<p>The name string access is case-insensitive.</p>\n\
<p>If two modifiers have the same name, the top-most will be returned.</p>\n\
<p>If a modifier with the specified name does not exist in the array, the value of <span class=\'code\'>undefined</span> will be returned.</p>\n\
<blockquote>\n\
<p><strong>NAME LITERAL AND NAME STRING ACCESS EXAMPLES</strong></p>\n\
<p>``` t=teapot() --create a teapot addmodifier t (ffd_4x4x4()) --add a FFD 4x4x4 modifier with default name addmodifier t (ffd_2x2x2 name:&quot;My FFD&quot;) --add a FFD 2x2x2 modifier with custom name addmodifier t (twist angle:90 name:&quot;My Twist&quot;) --add a twist with custom name</p>\n\
<p>t.modifiers[#ffd_4x4x4] --try to access by name literal t.modifiers[#ffd_2x2x2] --try to access by name literal - that name does not exist! t.modifiers[#My_FFD] --try to access by the custom name - that works t.modifiers[#My_Twist] --try to access by the custom name - also works</p>\n\
<p>t.modifiers[&quot;ffd 4x4x4&quot;] --same as above, but with string, so we can use spaces t.modifiers[&quot;ffd 2x2x2&quot;] --that name does not exist, so we get undefined back t.modifiers[&quot;My FFD&quot;] --this is the correct name, so we get it now t.modifiers[&quot;My Twist&quot;] --this is also the correct name, so we get the Twist t.modifiers[&quot;mY tWiSt&quot;] --the names are case-insensitive, so this returns the same Twist t.modifiers[&quot;My_Twist&quot;] --we can even replace spaces with underscores in string names! theName = #My_Twist --in other words, if we have a name literal, t.modifiers[theName] --we can use it as name literal, t.modifiers[theName as string] --or as string and both will produce the same result!</p>\n\
<p>```</p>\n\
<p><strong>MAXSCRIPT LISTENER OUTPUT:</strong></p>\n\
<p>``` $Teapot:Teapot001 @ [0.000000,0.000000,0.000000] OK OK OK FFD_4x4x4:FFD 4x4x4 undefined FFD_2x2x2:My FFD Twist:My Twist FFD_4x4x4:FFD 4x4x4 undefined FFD_2x2x2:My FFD Twist:My Twist Twist:My Twist Twist:My Twist Twist:My Twist Twist:My Twist OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"accessing-a-modifier-by-class\"></a><h4 id=\"accessing-a-modifier-by-class\">Accessing a Modifier By Class</h4></div>\n\
<p>In <strong>3ds Max 2013 and higher</strong>, you can access a modifier in the <span class=\'code\'>.modifiers</span> array using its class instead of its name.</p>\n\
<p>If two modifiers have the same class, the top-most will be returned.</p>\n\
<p>If a modifier with the specified class does not exist in the array, the value of <span class=\'code\'>undefined</span> will be returned.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES</strong></p>\n\
<p>``` t=teapot() --create a teapot addmodifier t (bend name:&quot;MyBendAtBottom&quot;) --add a Bend modifier addmodifier t (bend name:&quot;MyBendOnTop&quot;) --add another Bend modifier addmodifier t (twist name:&quot;MyTwist&quot;) --add a Twist modifier t.modifiers[twist] --access the Twist t.modifiers[bend] --access the top-most Bend (&quot;MyBendOnTop&quot;) t.modifiers[skew] --undefined, because no Skew was added</p>\n\
<p>```</p>\n\
<p><strong>LISTENER OUTPUT:</strong></p>\n\
<p><span class=\'code\'>$Teapot:Teapot001 @ [0.000000,0.000000,0.000000]   OK   OK   OK   Twist:MyTwist   Bend:MyBendOnTop   undefined</span></p>\n\
</blockquote>\n\
<p>The classes derived directly from the Modifier and SpacewarpModifier classes are described in <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Modifier-MAXWrapper-and/Modifier-and-SpacewarpModifier/Modifier-and-SpacewarpModifier-1.html\' title=\'\'>Modifier and SpacewarpModifier Types</a>.</p>\n\
<p>The properties, operators, and methods that are common to all classes derived directly from the Modifier and SpacewarpModifier classes are described in <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Modifier-MAXWrapper-and/Modifier-Common-Properties/Modifier-Common-Properties-1.html\' title=\'\'>Modifier Common Properties, Operators, and Methods</a>.</p>\n\
<p>The Modifier and SpacewarpModifier classes are derived from the MAXWrapper class, and inherits the properties and methods defined for that class. These properties and methods are described in <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXWrapper-Value/MAXWrapper-Common-Properties.html\' title=\'\'>MAXWrapper Common Properties, Operators, and Methods</a>.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";