var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>NURBSSelection : Value</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>NURBSSelection : Value</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"nurbsselection-value\"></a></div>\n\
<p>A <strong>NURBSSelection</strong> represents a set of NURBS sub-objects for a scene NURBS node as a virtual array. As such, you can access a sub-object by index, iterate over the sub-objects, and apply mapped functions to the sub-objects. The NURBSSelection array is dynamic (its contents will change as the sub-objects of the NURBS node change). NURBSSelection values are mappable.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.selectedCurveCVs \n\
&lt;node&gt;.selectedCurves \n\
&lt;node&gt;.selectedImports \n\
&lt;node&gt;.selectedPoints \n\
&lt;node&gt;.selectedSurfaces \n\
&lt;node&gt;.selectedSurfCVs \n\
&lt;node&gt;.curveCVs -- read-only \n\
&lt;node&gt;.curves -- read-only \n\
&lt;node&gt;.imports -- read-only \n\
&lt;node&gt;.surfaces -- read-only \n\
&lt;node&gt;.surfCVs -- read-only \n\
&lt;node&gt;.points -- read-only   \n\
</pre></div><p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbsselection&gt;.count: Integer, read-only   \n\
</pre></div><p>Returns the number of sub-objects in the NURBSSelection array.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbsselection&gt;.selSetNames: Array of names, read-only \n\
</pre></div><p>Returns an array of names of the current named selection sets corresponding to the NURBSSelection level for the object the NURBSSelection is associated with.</p>\n\
<p>The following property is present for singleton selections (of the form $foo.curveCVs[n]):</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbsselection&gt;.index: Integer, read-only \n\
</pre></div><p>Returns the index of the selected sub-object in the NURBS object,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>``` $foo.selectedcurveCVs[2].index</p>\n\
<p>```</p>\n\
<p>returns the curve CV index of the second curve CV in the current selection.</p>\n\
</blockquote>\n\
<p>Note: Iterating over a selection yields singleton selections in the loop body:</p>\n\
<div class=\'codeBlock\'><pre>sCVs = for i in $foo.selectedcurveCVs collect i.index\n\
</pre></div><p>sCVs contains selected curve CVs as array.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.selectedCurveCVs = (&lt;array&gt; | &lt;bitarray&gt;) \n\
&lt;node&gt;.selectedCurves = (&lt;array&gt; | &lt;bitarray&gt;) \n\
&lt;node&gt;.selectedImports = (&lt;array&gt; | &lt;bitarray&gt;) \n\
&lt;node&gt;.selectedPoints = (&lt;array&gt; | &lt;bitarray&gt;) \n\
&lt;node&gt;.selectedSurfaces = (&lt;array&gt; | &lt;bitarray&gt;) \n\
&lt;node&gt;.selectedSurfCVs = (&lt;array&gt; | &lt;bitarray&gt;) \n\
</pre></div><p>Selects the specified sub-objects.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbsselection&gt; [&lt;integer&gt;] \n\
</pre></div><p>Retrieves the indexed sub-object as a singleton NURBSSelection. Index starts at 1.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbsselection&gt; [(&lt;integer_array&gt; | &lt;bitarray&gt;)] \n\
</pre></div><p>Retrieves the indexed sub-objects as a NURBSSelection. Index starts at 1.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbsselection&gt; [(&lt;#name&gt; | &lt;string&gt;)] \n\
</pre></div><p>Retrieves the sub-object level named selection set, where the name of the named selection set can be specified as a name or string value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbsselection&gt; [(&lt;#name&gt; | &lt;string&gt;)] = (&lt;nurbsselection&gt; | &lt;integer_array&gt; | &lt;bitarray&gt;) \n\
</pre></div><p>Sets the sub-object level named selection set to the specified edges. The name of the named selection set can be specified as a name or string value, and the edges can be specified as an array, bitArray, or a NURBSSelection from the same object and of the same sub-object level.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>move &lt;nurbsselection&gt; &lt;point3&gt; \n\
</pre></div><p>Moves the sub-objects in the NURBSSelection.</p>\n\
<div class=\'codeBlock\'><pre>rotate &lt;nurbsselection&gt; &lt;quat_or_other_rotation_form&gt; \n\
</pre></div><p>Rotates the sub-objects in the NURBSSelection.</p>\n\
<div class=\'codeBlock\'><pre>scale &lt;nurbsselection&gt; &lt;point3&gt; \n\
</pre></div><p>Scales the sub-objects in the NURBSSelection.</p>\n\
<div class=\'codeBlock\'><pre>select &lt;nurbsselection&gt; \n\
</pre></div><p>Selects the sub-objects in the NURBSSelection.</p>\n\
<div class=\'codeBlock\'><pre>deselect &lt;nurbsselection&gt; \n\
</pre></div><p>Deselects the sub-objects in the NURBSSelection.</p>\n\
<div class=\'codeBlock\'><pre>delete &lt;nurbsselection&gt; \n\
</pre></div><p>Deletes the sub-objects in the NURBSSelection.</p>\n\
<div class=\'codeBlock\'><pre>append &lt;nurbsselection&gt; (&lt;nurbsselection&gt; | &lt;integer&gt;) \n\
</pre></div><p>Appends the sub-objects(s) to the NURBSSelection.</p>\n\
<div class=\'codeBlock\'><pre>findItem &lt;nurbsselection&gt; (&lt;nurbsselection[&lt;integer&gt;] | &lt;integer&gt;) \n\
</pre></div><p>Returns the selection index of the matching item or 0 if not found. The item is selection index or singleton NURBSSelection.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES</strong></p>\n\
<p>``` $foo.surfCVs[#baz] -- retrieves the surf CV selection named baz move $foo.curves[#bar] [0,0,10] -- moves the &quot;bar&quot; curve selection 10 in Z move $foo.selectedSurfCVs [0,0,10] -- moves the current surface CV selection 10 in Z coordsys local scale $foo.surfaces [#baz] [2,2,2] select $foo.curveCVs[#(1,2,3,4,5)] -- select the specified curve CVs deselect $foo.curves-- deselect all curves delete $foo.points[#{1..31, 40..50}] -- delete the specified points $foo.curveCVs[#fred] = $foo.selectedCurveCVs -- &quot;snapshot&quot; the selected curve CVs</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";