var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>NURBSSet : Value</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>NURBSSet : Value</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"nurbsset-value\"></a></div>\n\
<p>This is the class used to create NURBS objects, or retrieve data from existing NURBS objects. The NURBSSet acts as a container for the other objects.</p>\n\
<p>This class contains a table of the various NURBSObject derived entities (points, curves, surfaces) used to make up the set. Additionally it has two &#39;fuse&#39; tables: one for fuse curves and one for fuse surfaces. These are used to allow the CVs in the curves or surfaces to be &#39;stitched&#39; or &#39;fused&#39; together so that if one curve or surface moves the other moves with it. This class also has the surface-approximation properties that control the object&#39;s tessellation into triangle meshes for use in the viewports and the production renderer.</p>\n\
<p>NURBSSet values are mappable.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>NURBSSet [&lt;property&gt;:&lt;val&gt;]...   \n\
</pre></div><p>any of the object&#39;s properties may be set via optional keyword arguments on the constructor</p>\n\
<div class=\'codeBlock\'><pre>getNURBSSet &lt;node&gt; [     #relational]   \n\
</pre></div><p>This function is used to retrieve a NURBSSet that corresponds to the specified NURBS scene node. This allows access the internal objects inside a <strong>3ds Max</strong> editable NURBS object.</p>\n\
<p>If the optional <span class=\'code\'>#relational</span> parameter is <strong>not</strong> supplied, the returned NURBSSet will contain only independent curves and surfaces, all dependent objects will be decomposed into corresponding independent objects. So for example, if you pass an object that has a relational model (perhaps two CV surfaces and a dependent blend surface) it will decompose them into three CV surfaces. This will be the CV surfaces that represent the two surfaces and the blend, but you won&#39;t have the blend relational data. If the <span class=\'code\'>#relational</span> argument <strong>is</strong> supplied, you get back two CV surfaces and a NURBS blend surface and the NURBSSet is an <strong>active</strong> representative for the scene object -- any changes you make to the properties of it&#39;s constituent NURBSObjects will be reflected directly in the source scene object.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbsset&gt;.numObjects : integer, read-only \n\
&lt;nurbsset&gt;.count : integer, read-only \n\
</pre></div><p>The number of internal objects in the NURBSSet.</p>\n\
<p>The following properties control the surface approximation tessellation. There are dual sets of properties, one for controlling viewport tessellation, the other for controlling renderer tessellation. The properties correspond directly to the surface approximation controls in the NURBS surface modifier panel. See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/NURBS/The-NURBS-Classes/NURBS-Associated-Classes/NURBSSurfaceApproximation-Value.html\' title=\'\'>NURBSSurfaceApproximation</a> for a description of these properties.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbsset&gt;.viewConfig : #isoOnly, #isoAndMesh, #meshOnly \n\
&lt;nurbsset&gt;.viewIsoULines : integer \n\
&lt;nurbsset&gt;.viewIsoVLines : integer \n\
&lt;nurbsset&gt;.viewMeshUSteps : integer \n\
&lt;nurbsset&gt;.viewMeshVSteps : integer \n\
&lt;nurbsset&gt;.viewMeshApproxType : #parametric, #spatial, #curvature, #regular, #spatialAndCurvature \n\
&lt;nurbsset&gt;.viewSpacialEdge : float \n\
&lt;nurbsset&gt;.viewCurvatureAngle : float \n\
&lt;nurbsset&gt;.viewCurvatureDistance : float \n\
&lt;nurbsset&gt;.viewViewDependent : boolean \n\
&lt;nurbsset&gt;.renderConfig : #isoOnly, #isoAndMesh, #meshOnly, #regular, #spatialAndCurvature \n\
&lt;nurbsset&gt;.renderIsoULines : integer \n\
&lt;nurbsset&gt;.renderIsoVLines : integer \n\
&lt;nurbsset&gt;.renderMeshUSteps : integer \n\
&lt;nurbsset&gt;.renderMeshVSteps : integer \n\
&lt;nurbsset&gt;.renderMeshApproxType : #parametric, #spatial, #curvature, #regular, #spatialAndCurvature \n\
&lt;nurbsset&gt;.renderSpacialEdge : float \n\
&lt;nurbsset&gt;.renderCurvatureAngle : float \n\
&lt;nurbsset&gt;.renderCurvatureDistance : float \n\
&lt;nurbsset&gt;.renderViewDependent : boolean \n\
&lt;nurbsset&gt;.display : NURBSDisplay \n\
</pre></div><p>Takes and returns instances of the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/NURBS/The-NURBS-Classes/NURBS-Associated-Classes/NURBSDisplay-Value.html\' title=\'\'>NURBSDisplay</a> class that controls visibility of various components of a NURBS object&#39;s display in the viewports.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbsset&gt;.viewApproximation : NURBSSurfaceApproximation \n\
&lt;nurbsset&gt;.renderApproximation : NURBSSurfaceApproximation \n\
</pre></div><p>These properties are used to access and control surface approximation using the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/NURBS/The-NURBS-Classes/NURBS-Associated-Classes/NURBSSurfaceApproximation-Value.html\' title=\'\'>NURBSSurfaceApproximation</a> class, instances of which encapsulate all the approximation settings for either viewports or rendering. You can construct a surface approximation setup in one of these instances and use it to set the surface approximation for many objects.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbsset&gt;.merge : float \n\
</pre></div><p>Controls the tessellation of surface sub-objects whose edges are joined or very nearly joined. When input to a modifier as Mesh Select which requires a mesh, and when NURBS surfaces are tessellated for production rendering, by default <strong>3ds Max</strong> adjusts the tessellation of adjoining surfaces to match each other in terms of the number of faces along the edges. The <span class=\'code\'>merge</span> value controls how this is done. If <span class=\'code\'>merge</span> is zero, adjoining faces are unchanged. Increasing the value of <span class=\'code\'>merge</span> increases the distance <strong>3ds Max</strong> uses to calculate how edges should match, guaranteeing no gaps between the surfaces when they are rendered.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbsset&gt;[&lt;index&gt;] &lt;nurbsset&gt;[&lt;index&gt;] = &lt;nurbsobj&gt; \n\
</pre></div><p>The sub-objects in a NURBSSet can be accessed using the standard MAXScript array indexing operator, <span class=\'code\'>\\[\\]</span> . This is equivalent to using the <span class=\'code\'>getObject()</span> and <span class=\'code\'>setObject()</span> methods described below.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>appendObject &lt;nurbsset&gt; &lt;nurbsobj&gt; \n\
</pre></div><p>Appends the given NURBSObject (instances of any of the subclasses of NURBSObject and their subclasses, all the points, curves, surfaces) as a new sub-object to the NURBSSet. The new sub-object receives the next available index.</p>\n\
<div class=\'codeBlock\'><pre>setObject &lt;nurbsset&gt; &lt;index&gt; &lt;nurbsobj&gt; \n\
</pre></div><p>Set the indexed sub-object to the given NURBSObject; indexes are 1-based. You use this function to replace a previously appended object.</p>\n\
<div class=\'codeBlock\'><pre>getObject &lt;nurbsset&gt; (&lt;index&gt; | &lt;NURBSSelection&gt;) \n\
</pre></div><p>Retrieves the indexed sub-object or the set of sub-objects specified by the NURBSSelection from the NURBSSet; sub-object indexes are 1-based. If the NURBSSelection specifies no sub-objects, <span class=\'code\'>undefined</span> is returned. If one sub-object is specified, a value of that sub-object’s class is returned. If multiple sub-objects are specified, a NURBSSet value is returned.</p>\n\
<div class=\'codeBlock\'><pre>removeObject &lt;nurbsset&gt; &lt;index&gt; \n\
</pre></div><p>Removes the given sub-object from the NURBSSet. The indexes of all the remaining higher-indexed sub-objects are renumbered down.</p>\n\
<div class=\'codeBlock\'><pre>disconnect &lt;nurbsset&gt; \n\
</pre></div><p>Disconnect a relational NURBS set from its scene object, turning it into a non-relational set.</p>\n\
<div class=\'codeBlock\'><pre>deleteObjects &lt;nurbsset&gt; \n\
</pre></div><p>This method deletes all the NURBSObjects in a NURBSSet, and frees its memory.</p>\n\
<div class=\'codeBlock\'><pre>getProdTess &lt;nurbsset&gt; &lt;tessType_name&gt; \n\
setProdTess &lt;nurbsset&gt; &lt;tessType_name&gt; &lt;NURBSSurfaceApproximation&gt; \n\
getViewTess &lt;nurbsset&gt; &lt;tessType_name&gt; \n\
setViewTess &lt;nurbsset&gt; &lt;tessType_name&gt; &lt;NURBSSurfaceApproximation&gt; \n\
</pre></div><p>These methods get and set renderer and viewport NURBSSurfaceApproximation values for individual surfaces, where <span class=\'code\'>&lt;tessType_name&gt;</span> is one of <span class=\'code\'>#surface</span> , <span class=\'code\'>#displacement</span> , or <span class=\'code\'>#curve</span> corresponding to the 3 kinds of tessellation that can be controlled on a surface.</p>\n\
<div class=\'codeBlock\'><pre>clearProdTess &lt;nurbsset&gt; &lt;tessType_name&gt; \n\
clearViewTess &lt;nurbsset&gt; &lt;tessType_name&gt; \n\
</pre></div><p>Resets the surface approximation settings for the surfaces in the NURBSet for the given tessellation type, where <span class=\'code\'>&lt;tessType_name&gt;</span> is one of <span class=\'code\'>#surface</span> , <span class=\'code\'>#displacement</span> , or <span class=\'code\'>#curve</span> corresponding to the 3 kinds of tessellation that can be controlled on a surface.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";