var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>NURBSCVCurve : NURBSCurve</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>NURBSCVCurve : NURBSCurve</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"nurbscvcurve-nurbscurve\"></a></div>\n\
<p>This class defines an independent NURBS CV Curve. The position and weight of the control vertices (CVs) controls the shape of the curve. Unlike spline vertices, CVs don’a t necessarily lie on the curve they define. The CVs define a control lattice which surrounds the curve.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>NURBSCVCurve [&lt;property&gt;:&lt;val&gt;] [closed:&lt;boolean&gt;]...    \n\
</pre></div><p>Any of the object&#39;s properties may be set via optional keyword arguments on the constructor. If <span class=\'code\'>closed:true</span> is specified, the curve is created as a closed curve, otherwise it is an open curve.</p>\n\
<div class=\'codeBlock\'><pre>getObject &lt;nurbsset&gt; &lt;index&gt;   \n\
</pre></div><p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbscvcurve&gt;.order: integer \n\
</pre></div><p>The order of the curve. This is one more than the degree of polynomial of any segment of the curve. All curves have a degree. The degree of a curve is the highest exponent in the equation used to represent it. A linear equation is degree 1, a quadratic equation degree 2. NURBS curves typically are represented by cubic equations and have a degree of 3.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbscvcurve&gt;.numKnots: integer \n\
</pre></div><p>The number of knots in the curve. If this value is changed, the previous knot data is NOT maintained. Because they are generated mathematically, NURBS curves have a parameter space in addition to the 3D geometric space in which they are displayed. Specifically, an array of values called knots specifies the extent of influence of each control vertex (CV) on the curve or surface.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbscvcurve&gt;.numCVs: integer \n\
</pre></div><p>The number of control vertices in the curve. If this value is changed, the previous control vertex data is NOT maintained.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbscvcurve&gt;.transform: matrix3 \n\
</pre></div><p>The transformation matrix for the NURBSCVCurve. This controls the relative position of the item within a NURBSSet.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbscvcurve&gt;.endsOverlap: boolean, read-only \n\
</pre></div><p><span class=\'code\'>true</span> if the ends of the curve overlap even though the curve may not be closed (that is, the tangents match at the ends), <span class=\'code\'>false</span> otherwise.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbscvcurve&gt;.autoParam:#notAutomatic, #autoCentripetal, #autoUniform \n\
</pre></div><p><span class=\'code\'>#notAutomatic</span> , <span class=\'code\'>#autoCentripetal</span> , and <span class=\'code\'>#autoUniform</span> correspond to the Automatic Reparam options in the CV Curve rollouts: none, chord length and uniform, respectively. Defaults to <span class=\'code\'>#notAutomatic</span> .</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>close &lt;nurbscvcurve&gt; \n\
</pre></div><p>Forces the curve to be closed.</p>\n\
<div class=\'codeBlock\'><pre>getKnot &lt;nurbscvcurve&gt; &lt;index&gt; setKnot &lt;nurbscvcurve&gt; &lt;index&gt; &lt;float&gt; \n\
</pre></div><p>Get and set the indexed knot’s value, indexes are 1-based. Knots are a mathematical construct that helps define the span of control of CVs and blending functions that define NURBS Curves and Surfaces. The knots are an array of values that determines the parameterization of a curve. Values in the knot vector are nondecreasing. The knots specify the region of influence of the CVs on the curve. It is a way of partitioning the parameter space up into different segments. A B-spline curve or a NURBS curve is a curve that is defined by a series of segments. On each one of the segments the curve is like a polynomial, or in the case of a rational one, it&#39;s like the ratio of polynomials. The knot vector describes how to partition the parameter space of the curve up for each of the different pieces of the polynomial.</p>\n\
<div class=\'codeBlock\'><pre>getCV &lt;nurbscvcurve&gt; &lt;cv_index&gt; \n\
</pre></div><p>Get the indexed CV as a NURBSControlVertex, indexes are 1-based.</p>\n\
<div class=\'codeBlock\'><pre>setCV &lt;nurbscvcurve&gt; &lt;cv_index&gt; &lt;NURBSControlVertex&gt; \n\
</pre></div><p>Sets the indexed CV to the given NURBSControlVertex, indexes are 1-based.</p>\n\
<div class=\'codeBlock\'><pre>refine &lt;nurbscvcurve&gt; &lt;u_param&gt; \n\
</pre></div><p>Add a new, interpolated CV at the given parametric point along the curve.</p>\n\
<div class=\'codeBlock\'><pre>reparameterize &lt;nurbscvcurve&gt; (#centripetal | #uniform) \n\
</pre></div><p>Reparameterizes the curve by chord length ( <span class=\'code\'>#centripetal</span> ) or uniform ( <span class=\'code\'>#uniform</span> ) uniform parameterization.</p>\n\
<p>Note:</p>\n\
<p>CV curves and surfaces must obey the relationship that &quot;order + number of CVs = number of knots&quot;. If this is not the case in most cases no object will be created and in some cases an assertion fault might be generated.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";