var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>NURBSCVSurface : NURBSSurface</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>NURBSCVSurface : NURBSSurface</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"nurbscvsurface-nurbssurface\"></a></div>\n\
<p>This class defines an independent surface that uses control vertices (CVs) to describe its shape. The CVs define a control lattice which surrounds the surface.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>NURBSCVSurface[&lt;property&gt;:&lt;val&gt;]...      \n\
</pre></div><p>Any of the object&#39;s properties may be set via optional keyword arguments on the constructor.</p>\n\
<div class=\'codeBlock\'><pre>getObject &lt;nurbsset&gt; &lt;index&gt;   \n\
</pre></div><p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbscvsurface&gt;.uOrder: integer &lt;nurbscvsurface&gt;.  vOrder: integer \n\
</pre></div><p>The order of the surface in the U and V directions.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbscvsurface&gt;.numUKnots: integer &lt;nurbscvsurface&gt;.numVKnots: integer \n\
</pre></div><p>The number of knots in the surface in the U and V directions. If this value is changed, the previous knot data is NOT maintained. Because they are generated mathematically, NURBS surfaces have a parameter space in addition to the 3D geometric space in which they are displayed. Specifically, an array of values called knots specifies the extent of influence of each control vertex (CV) on the surface.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbscvsurface&gt;.numCVs: point2 \n\
</pre></div><p>The number of control vertices for the surface in the U and V directions. If this value is changed, the previous control vertex data is NOT maintained.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbscvsurface&gt;.transform: matrix3 \n\
</pre></div><p>The transformation matrix for the NURBSCVSurface. This controls the relative position of the item within a NURBSSet.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbscvsurface&gt;.uEdgesOverlap: boolean, read-only &lt;nurbscvsurface&gt;.vEdgesOverlap: boolean, read-only \n\
</pre></div><p><span class=\'code\'>true</span> if the edges of the surface overlap in U and/or V even though the surface may not be closed (that is, the tangents match at the edges), <span class=\'code\'>false</span> otherwise.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbscvsurface&gt;.autoParam:#notAutomatic, #autoCentripetal, #autoUniform \n\
</pre></div><p><span class=\'code\'>#notAutomatic</span> , <span class=\'code\'>#autoCentripetal</span> , and <span class=\'code\'>#autoUniform</span> correspond to the Automatic Reparam options in the CV Surface rollouts: none, chord length and uniform, respectively. Defaults to <span class=\'code\'>#notAutomatic</span> .</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbscvsurface&gt;.rigid: boolean \n\
</pre></div><p><span class=\'code\'>true</span> if the surface is &#39;rigid&#39;; otherwise <span class=\'code\'>false</span> . The only editing allowed on a rigid surface is to transform it at the Surface sub-object level. You can&#39;t move a rigid surface&#39;s points or CVs, or change the number of points or CVs. Rigid surfaces reduce the amount of memory used by the NURBS model. Making surfaces rigid improves performance, especially for large and complex models. When a surface is rigid, you can&#39;t see its points or CVs when you are at the Point or Surface CV sub-object levels. If the model has no nonrigid surfaces and no point curves, the Point and Surface CV sub-object levels aren&#39;t available at all.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>closeU &lt;nurbscvsurface&gt; \n\
</pre></div><p>Closes the surface in the U direction.</p>\n\
<div class=\'codeBlock\'><pre>closeV&lt;nurbscvsurface&gt; \n\
</pre></div><p>Closes the surface in the V direction.</p>\n\
<div class=\'codeBlock\'><pre>getUKnot &lt;nurbscvsurface&gt; &lt;u_index&gt; \n\
</pre></div><p>Get the indexed U-direction knot; knot indexes are 1-based.</p>\n\
<div class=\'codeBlock\'><pre>setUKnot &lt;nurbscvsurface&gt; &lt;u_index&gt; &lt;float&gt; \n\
</pre></div><p>Sets the indexed U-direction knot to the given value; knot indexes are 1-based.</p>\n\
<div class=\'codeBlock\'><pre>getVKnot &lt;nurbscvsurface&gt; &lt;v_index&gt; \n\
</pre></div><p>Get the indexed V-direction knot; knot indexes are 1-based.</p>\n\
<div class=\'codeBlock\'><pre>setVKnot &lt;nurbscvsurface&gt; &lt;v_index&gt; &lt;float&gt; \n\
</pre></div><p>Get the indexed V-direction knot to the given value; knot indexes are 1-based.</p>\n\
<div class=\'codeBlock\'><pre>getCV &lt;nurbscvsurface&gt; &lt;u_index&gt; &lt;v_index&gt; \n\
</pre></div><p>Get the CV at the given U and V index as a NURBSControlVertex; CV indexes are 1-based.</p>\n\
<div class=\'codeBlock\'><pre>setCV &lt;nurbscvsurface&gt; &lt;u_index&gt; &lt;v_index&gt; &lt;NURBSControlVertex&gt; \n\
</pre></div><p>Sets the CV at the given U and V index to the supplied NURBSControlVertex; CV indexes are 1-based.</p>\n\
<div class=\'codeBlock\'><pre>refineU &lt;nurbscvsurface&gt; &lt;v_param&gt; \n\
</pre></div><p>Adds new row of interpolated CVs in the U direction on the surface at the given parametric V point.</p>\n\
<div class=\'codeBlock\'><pre>refineV &lt;nurbscvsurface&gt; &lt;u_param&gt; \n\
</pre></div><p>Adds new column of interpolated CVs in the V direction on the surface at the given parametric U point.</p>\n\
<div class=\'codeBlock\'><pre>refine &lt;nurbscvsurface&gt; &lt;u_param&gt; &lt;v_param&gt; \n\
</pre></div><p>Adds a new row and column of interpolated CVs on the surface at the given parametric UV position.</p>\n\
<div class=\'codeBlock\'><pre>reparameterize &lt;nurbscvsurface&gt; (#centripetal | #uniform) \n\
</pre></div><p>Reparameterizes the surface by chord length (#centripetal) or uniform (#uniform) uniform parameterization.</p>\n\
<p>Note:</p>\n\
<p>CV curves and surfaces must obey the relationship that &quot;order + number of CVs = number of knots&quot;. If this is not the case in most cases no object will be created and in some cases an assertion fault might be generated.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";