var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>NURBSSurface : NURBSObject</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>NURBSSurface : NURBSObject</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"nurbssurface-nurbsobject\"></a></div>\n\
<p>This is the parent class for all the NURBS surface classes and so is not directly constructable. The class describes the common properties of all NURBS surfaces. This includes its material ID, texture/tiling options, renderable state, and open/closed state, and normal inverted state. The <span class=\'code\'>evalPos()</span> , <span class=\'code\'>evalUTangent()</span> , and <span class=\'code\'>evalVTangent()</span> methods are used to compute points and tangents on the surface.</p>\n\
<p><strong>Properties</strong></p>\n\
<p>All NURBS surface classes have the following properties.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbssurface&gt;.renderable : boolean      \n\
</pre></div><p>Specifies whether the surface is renderable. <span class=\'code\'>true</span> if the surface is renderable, <span class=\'code\'>false</span> if not.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbssurface&gt;.flipNormals : boolean   \n\
</pre></div><p>Specifies whether all the surface’s surface normals are flipped. <span class=\'code\'>true</span> if the surface normals are to be flipped, <span class=\'code\'>false</span> if not.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbssurface&gt;.generateUVs1 : boolean \n\
</pre></div><p>If <span class=\'code\'>true</span> , enables the generation of UV mapping coordinates for UVW channel 1. See the <span class=\'code\'>getGenerateUVs()</span> and <span class=\'code\'>setGenerateUVs()</span> methods for generalized mapping channel access.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbssurface&gt;.generateUVs2 : boolean \n\
</pre></div><p>If <span class=\'code\'>true</span> , enables the generation of UV mapping coordinates for UVW channel 2. See the <span class=\'code\'>getGenerateUVs()</span> and <span class=\'code\'>setGenerateUVs()</span> methods for generalized mapping channel access.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbssurface&gt;.matID : integer \n\
</pre></div><p>The material ID of the surface.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbssurface&gt;.closedInU : boolean, read-only \n\
</pre></div><p><span class=\'code\'>true</span> if the surface is closed in the U direction, <span class=\'code\'>false</span> if open.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbssurface&gt;.closedInV : boolean, read-only \n\
</pre></div><p><span class=\'code\'>true</span> if the surface is closed in the V direction, <span class=\'code\'>false</span> if open.*</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbssurface&gt;.uParameterRangeMin : float, read-only &lt;nurbssurface&gt;.uParameterRangeMax : float, read-only \n\
</pre></div><p>Contains the minimum and maximum valid values for <span class=\'code\'>&lt;u_parm&gt;</span> in the methods associated with NURBS Surfaces.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbssurface&gt;.vParameterRangeMin : float, read-only &lt;nurbssurface&gt;.vParameterRangeMax : float, read-only \n\
</pre></div><p>Contains the minimum and maximum valid values for <span class=\'code\'>&lt;v_param&gt;</span> in the methods associated with NURBS Surfaces.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nurbssurface&gt;.textureSurface1 : NURBSTextureSurface &lt;nurbssurface&gt;.textureSurface2 : NURBSTextureSurface \n\
</pre></div><p>Used to get and set the texture surfaces for the two mapping channels. These properties take and return instances of the NURBSTextureSurface class. <span class=\'code\'>.textureSurface1</span> accesses mapping channel 1 and <span class=\'code\'>.textureSurface2</span> accesses mapping channel 2. See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/NURBS/The-NURBS-Classes/NURBS-Associated-Classes/NURBSTextureSurface-Value.html\' title=\'\'>NURBSTextureSurface : Value</a>. See the <span class=\'code\'>getTextureSurface()</span> and <span class=\'code\'>setTextureSurface()</span> methods for generalized mapping channel access.</p>\n\
<p>It is not possible to assign texture surfaces to NURBS objects present in the scene. You can create new NURBSSets and the texture surface is used when you call <span class=\'code\'>createNURBSObject()</span> . However, if you do a <span class=\'code\'>getNURBSSet()</span> and assign a NURBSTextureSurface to these properties, nothing happens.</p>\n\
<p><strong>Methods</strong></p>\n\
<p>All NURBS surface classes have the following methods:</p>\n\
<div class=\'codeBlock\'><pre>evalPos &lt;nurbssurface&gt; &lt;u_param&gt; &lt;v_param&gt; \n\
</pre></div><p>Returns the coordinates in space of the point at the given U and V parametric position on the surface.</p>\n\
<div class=\'codeBlock\'><pre>evalUTangent &lt;nurbssurface&gt; &lt;u_param&gt; &lt;v_param&gt; \n\
</pre></div><p>Returns the U tangent vector of the surface at the given U and V parametric position on the surface.</p>\n\
<div class=\'codeBlock\'><pre>evalVTangent &lt;nurbssurface&gt; &lt;u_param&gt; &lt;v_param&gt; \n\
</pre></div><p>Returns the V tangent vector of the surface at the given U and V parametric position on the surface.</p>\n\
<div class=\'codeBlock\'><pre>getTiling &lt;nurbssurface&gt; [channel:&lt;index&gt;] setTiling &lt;nurbssurface&gt; &lt;ut&gt; &lt;vt&gt; [channel:&lt;index&gt;] \n\
</pre></div><p>These methods get and set the tiling factor on the surface in the u and v directions. These methods return or take a point2 value, with u tiling in the x component and v tiling in the y component of the point2. The optional <span class=\'code\'>channel</span> keyword argument can be used to select the mapping channel which defaults to 1.</p>\n\
<div class=\'codeBlock\'><pre>getTilingOffset &lt;nurbssurface&gt; [channel:&lt;index&gt;] setTilingOffset &lt;nurbssurface&gt; &lt;uo&gt; &lt;vo&gt; [channel:&lt;index&gt;] \n\
</pre></div><p>These methods get and set the tiling offset on the surface for the selected channel. These methods return or take a point2 value, with u offset in the x component and v offset in the y component of the point2. The optional <span class=\'code\'>channel</span> keyword argument can be used to select the mapping channel which defaults to 1.</p>\n\
<div class=\'codeBlock\'><pre>getGenerateUVs &lt;nurbssurface&gt; &lt;channel_index&gt; setGenerateUVs &lt;nurbssurface&gt; &lt;channel_index&gt; &lt;boolean&gt; \n\
</pre></div><p>These methods get and set whether the generation of UV mapping coordinates for the selected channel is enabled.</p>\n\
<div class=\'codeBlock\'><pre>getTextureUVs &lt;nurbssurface&gt; &lt;index&gt; [channel:&lt;index&gt;] setTextureUVs &lt;nurbssurface&gt; &lt;index&gt; &lt;point2&gt; [channel:&lt;index&gt;] \n\
</pre></div><p>These methods get and set the texture UV as a point2 value for the indexed coordinate and selected channel. The 1-based index of the texture coordinate must be &gt;= 1 and &lt;= 4. The optional <span class=\'code\'>channel</span> keyword argument can be used to select the mapping channel which defaults to 1.</p>\n\
<div class=\'codeBlock\'><pre>getTextureSurface &lt;nurbssurface&gt; &lt;channel_index&gt; setTextureSurface &lt;nurbssurface&gt; &lt;channel_index&gt; &lt;NURBSTextureSurface&gt; \n\
</pre></div><p>These methods get and set texture surfaces for the selected channel. These methods return or take an instance of the NURBSTextureSurface class. See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/NURBS/The-NURBS-Classes/NURBS-Associated-Classes/NURBSTextureSurface-Value.html\' title=\'\'>NURBSTextureSurface : Value</a>.</p>\n\
<div class=\'codeBlock\'><pre>getProdTess &lt;nurbssurface&gt; &lt;tessType_name&gt; setProdTess &lt;nurbssurface&gt; &lt;tessType_name&gt; &lt;NURBSSurfaceApproximation&gt; getViewTess &lt;nurbssurface&gt; &lt;tessType_name&gt; setViewTess &lt;nurbssurface&gt; &lt;tessType_name&gt; &lt;NURBSSurfaceApproximation&gt; \n\
</pre></div><p>These methods get and set renderer and viewport NURBSSurfaceApproximation values for individual surfaces, where <span class=\'code\'>&lt;tessType_name&gt;</span> is one of <span class=\'code\'>#surface</span> , <span class=\'code\'>#displacement</span> , or <span class=\'code\'>#curve</span> corresponding to the 3 kinds of tessellation that can be controlled on a surface.</p>\n\
<div class=\'codeBlock\'><pre>clearProdTess &lt;nurbssurface&gt; &lt;tessType_name&gt; clearViewTess &lt;nurbssurface&gt; &lt;tessType_name&gt; \n\
</pre></div><p>Resets the surface approximation settings for the surface for the given tessellation type, where <span class=\'code\'>&lt;tessType_name&gt;</span> is one of <span class=\'code\'>#surface</span> , <span class=\'code\'>#displacement</span> , or <span class=\'code\'>#curve</span> corresponding to the 3 kinds of tessellation that can be controlled on a surface.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";