var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Creating NURBS Scene Objects</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Creating NURBS Scene Objects</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"creating-nurbs-scene-objects\"></a></div>\n\
<p>The following functions create new nodes in the <strong>3ds Max</strong> scene. The main function is <span class=\'code\'>NURBSNode()</span> which takes an arbitrary NURBSSet and instantiates a NURBS object in the scene based on the definition in the NURBSSet. The other two functions are shorthand ways of creating lathe and extrude NURBS surfaces based on existing shapes in the scene.</p>\n\
<div class=\'codeBlock\'><pre>NURBSNode &lt;nurbsset&gt; {node_creation_parameters}      \n\
</pre></div><p>Takes a NURBSSet object and creates a <strong>3ds Max</strong> NURBS object in the scene corresponding to the definitions in that NURBSSet. After the function call, the supplied NURBSSet becomes an active representative for the new scene node, all the NURBSId properties are filled-in and you can modify the scene object by modifying the properties of the NURBSSet component objects.</p>\n\
<p>Any of the standard <span class=\'code\'>&lt;node&gt;</span> constructor keyword arguments can be added, such as <span class=\'code\'>.name</span> , <span class=\'code\'>.prefix</span> , <span class=\'code\'>.pos</span> , <span class=\'code\'>.rotation</span> , <span class=\'code\'>.wireColor</span> , etc. See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-MAXWrapper-1.html\' title=\'\'>Node class</a> for details.</p>\n\
<div class=\'codeBlock\'><pre>NURBSLatheNode &lt;curve&gt; &lt;axis&gt; &lt;sweep&gt; [  capStart:&lt;boolean&gt;] \\ [     capEnd:&lt;boolean&gt;] [     capType:&lt;integer&gt;] \\ [  weldCore:&lt;boolean&gt;] [   flipNormals:&lt;boolean&gt;] \\ [  mapCoords:&lt;boolean&gt;] [  segs:&lt;integer&gt;] \\ [     matIDs:&lt;boolean&gt;] [     shapeIDs:&lt;boolean&gt;] \\ {node_creation_parameters}   \n\
</pre></div><p>This function generates a NURBS object based on the specified lathe (surface of revolution) definition and returns a pointer to it. This is used by the lathe modifier.</p>\n\
<div class=\'codeBlock\'><pre>curve &lt;node&gt; \n\
</pre></div><p>The shape object to revolve. Note that if the curve pointed to is a bezier spline then capping won&#39;t work properly.</p>\n\
<div class=\'codeBlock\'><pre>axis &lt;Matrix3&gt; \n\
</pre></div><p>This specifies the axis of revolution.</p>\n\
<div class=\'codeBlock\'><pre>sweep &lt;float&gt; \n\
</pre></div><p>The angle for the surface of revolution in degrees.</p>\n\
<div class=\'codeBlock\'><pre>capStart: &lt;boolean&gt; \n\
</pre></div><p>Specifies if the surface should be capped at the beginning: <span class=\'code\'>true</span> to cap; <span class=\'code\'>false</span> to leave open.</p>\n\
<div class=\'codeBlock\'><pre>capEnd: &lt;boolean&gt; \n\
</pre></div><p>Specifies if the surface should be capped at the ending: <span class=\'code\'>true</span> to cap; <span class=\'code\'>false</span> to leave open.</p>\n\
<div class=\'codeBlock\'><pre>capType: &lt;integer&gt; \n\
</pre></div><p>This parameter is not currently used and the value specified is ignored.</p>\n\
<div class=\'codeBlock\'><pre>weldCore: &lt;boolean&gt; \n\
</pre></div><p><span class=\'code\'>true</span> to collapse any coincident vertices at the center of the surface; otherwise <span class=\'code\'>false</span> .</p>\n\
<div class=\'codeBlock\'><pre>flipNormals: &lt;boolean&gt; \n\
</pre></div><p><span class=\'code\'>true</span> to invert the orientation of surface normals; otherwise <span class=\'code\'>false</span> .</p>\n\
<div class=\'codeBlock\'><pre>mapCoords: &lt;boolean&gt; \n\
</pre></div><p><span class=\'code\'>true</span> to generate mapping coordinates; otherwise <span class=\'code\'>false</span> .</p>\n\
<div class=\'codeBlock\'><pre>segs: &lt;integer&gt; \n\
</pre></div><p>The number of segments in the surface of revolution.</p>\n\
<div class=\'codeBlock\'><pre>matIDs: &lt;boolean&gt; \n\
</pre></div><p>If <span class=\'code\'>true</span> special material IDs are assigned to the surfaces and caps.</p>\n\
<div class=\'codeBlock\'><pre>shapeIDs: &lt;boolean&gt; \n\
</pre></div><p>If <span class=\'code\'>true</span> shape IDs are used. When on, this function uses the material ID values assigned to segments in the spline to be lathed, or curve sub-objects in the NURBS curve to be lathed. This is available only when matIds is <span class=\'code\'>true</span> .</p>\n\
<div class=\'codeBlock\'><pre>NURBSExtrudeNode &lt;shape&gt; &lt;amount&gt; [capStart:&lt;boolean&gt;] \\ [capEnd:&lt;boolean&gt;] [capType:&lt;integer&gt;] \\ [mapCoords:&lt;boolean&gt;] [matIDs:&lt;boolean&gt;] \\ [shapeIDs:&lt;boolean&gt;] {node_creation_parameters} \n\
</pre></div><p>This function generates a NURBS object based on the specified extrusion definition and returns a pointer to it. This is used by the extrude modifier.</p>\n\
<div class=\'codeBlock\'><pre>shape &lt;node&gt; \n\
</pre></div><p>The shape node to extrude. Note that if the shape pointed to is a bezier spline then capping won&#39;t work properly.</p>\n\
<div class=\'codeBlock\'><pre>amount &lt;float&gt; \n\
</pre></div><p>Specifies the height of the extrusion.</p>\n\
<div class=\'codeBlock\'><pre>capStart: &lt;boolean&gt; \n\
</pre></div><p>Specifies if the surface should be capped at the beginning: <span class=\'code\'>true</span> to cap; <span class=\'code\'>false</span> to leave open.</p>\n\
<div class=\'codeBlock\'><pre>capEnd: &lt;boolean&gt; \n\
</pre></div><p>Specifies if the surface should be capped at the ending: <span class=\'code\'>true</span> to cap; <span class=\'code\'>false</span> to leave open.</p>\n\
<div class=\'codeBlock\'><pre>capType: &lt;integer&gt; \n\
</pre></div><p>This parameter is not currently used and the value specified is ignored.</p>\n\
<div class=\'codeBlock\'><pre>matIDs: &lt;boolean&gt; \n\
</pre></div><p>If <span class=\'code\'>true</span> , special material IDs are assigned to the surfaces and caps.</p>\n\
<div class=\'codeBlock\'><pre>shapeIDs: &lt;boolean&gt; \n\
</pre></div><p>If <span class=\'code\'>true</span> shape IDs are used. When on, this function uses the material ID values assigned to segments in the spline to be extruded, or curve sub-objects in the NURBS curve to be extruded. This is available only when matIds is <span class=\'code\'>true</span> .</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";