var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>NURBS Node Properties and Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>NURBS Node Properties and Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"nurbs-node-properties-and-methods\"></a></div>\n\
<p><strong>Properties</strong></p>\n\
<p>There are several properties on <span class=\'code\'>&lt;node&gt;</span> objects that give access to sub-object selections in NURBS objects:</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.selectedCurveCVs \n\
&lt;node&gt;.selectedCurves \n\
&lt;node&gt;.selectedImports \n\
&lt;node&gt;.selectedPoints \n\
&lt;node&gt;.selectedSurfaces \n\
&lt;node&gt;.selectedSurfCVs \n\
&lt;node&gt;.curveCVs \n\
&lt;node&gt;.curves \n\
&lt;node&gt;.imports \n\
&lt;node&gt;.surfaces \n\
&lt;node&gt;.surfCVs \n\
&lt;node&gt;.points \n\
</pre></div><p>These all return a <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/NURBS/The-NURBS-Classes/NURBS-Associated-Classes/NURBSSelection-Value.html\' title=\'\'>NURBSSelection Value</a>, and enable sub-object manipulation in a manner similar to that provided for Editable Meshes.</p>\n\
<p><strong>Methods</strong></p>\n\
<p>The following NURBS-related methods operate on scene nodes:</p>\n\
<div class=\'codeBlock\'><pre>getNURBSSet &lt;node&gt; [#relational] \n\
</pre></div><p>This function is used to retrieve a NURBSSet that corresponds to the specified NURBS scene node. This allows access the internal objects inside a <strong>3ds Max</strong> editable NURBS object.</p>\n\
<p>If the optional <span class=\'code\'>#relational</span> parameter is <strong>not</strong> supplied, the returned NURBSSet will contain only independent curves and surfaces, all dependent objects will be decomposed into corresponding independent objects. So for example, if you pass an object that has a relational model (perhaps two CV surfaces and a dependent blend surface) it will decompose them into three CV surfaces. This will be the CV surfaces that represent the two surfaces and the blend, but you won&#39;t have the blend relational data. If the <span class=\'code\'>#relational</span> argument <strong>is</strong> supplied, you get back two CV surfaces and a NURBS blend surface and the NURBSSet is an <strong>active</strong> representative for the scene object -- any changes you make to the properties of it&#39;s constituent NURBSObjects will be reflected directly in the source scene object.</p>\n\
<div class=\'codeBlock\'><pre>addNURBSSet &lt;node&gt; &lt;nurbsSet&gt; \n\
</pre></div><p>This function adds the supplied NURBSSet to the specified NURBS scene object, creating subobjects within the scene node corresponding to the definitions in the NURBSSet. After the function call, the supplied NURBSSet becomes an active representative for the new scene node subobjects, all the NURBSId properties are filled-in and you can modify the associated scene sub-object by modifying the properties of the NURBSSet component objects.</p>\n\
<div class=\'codeBlock\'><pre>transform &lt;node&gt; &lt;nurbsId_or_Id_array&gt; &lt;matrix3&gt; \n\
</pre></div><p>Transforms the specified sub-objects by the matrix supplied in the node&#39;s local space. The sub-objects to be transformed are identified by their NURBSId property which is set up when you instantiate a NURBSSet with the <span class=\'code\'>NURBSNode()</span> function or if you extract a <strong>relational</strong> NURBSSet from an existing NURBS scene node using the <span class=\'code\'>getNURBSSet()</span> function.</p>\n\
<div class=\'codeBlock\'><pre>breakCurve &lt;node&gt; &lt;nurbsId&gt; &lt;u_param&gt; \n\
</pre></div><p>Breaks the specified sub-object curve at the parametric point along the curve defined by the <span class=\'code\'>&lt;u_param&gt;</span> float argument. The sub-object to be broken is identified by its NURBSId property which is set up when you instantiate a NURBSSet with the <span class=\'code\'>NURBSNode()</span> function or if you extract a <strong>relational</strong> NURBSSet from an existing NURBS scene node using the <span class=\'code\'>getNURBSSet()</span> function.</p>\n\
<div class=\'codeBlock\'><pre>breakSurface &lt;node&gt; &lt;nurbsId&gt; (#U |#V) &lt;u_or_v_param&gt; \n\
</pre></div><p>Breaks the specified sub-object surface at the parametric point defined by the <span class=\'code\'>&lt;u_or_v_param&gt;</span> argument in the u or v direction depending on whether <span class=\'code\'>#U</span> or <span class=\'code\'>#V</span> is supplied for the third argument. The sub-object to be broken is identified by its NURBSId property which is set up when you instantiate a NURBSSet with the <span class=\'code\'>NURBSNode()</span> function or if you extract a <strong>relational</strong> NURBSSet from an existing NURBS scene node using the <span class=\'code\'>getNURBSSet()</span> function.</p>\n\
<div class=\'codeBlock\'><pre>joinCurves &lt;node&gt; &lt;nurbsId1&gt; &lt;nurbsId2&gt; &lt;tolerance_float&gt; [flip1:&lt;boolean&gt;] [flip2:&lt;boolean&gt;] \n\
</pre></div><p>Joins two curve sub-objects in the specified scene node and makes a single curve out of them. That is, the endpoints of the two curve objects are connected by new segments, and the two original curves are replaced by a single curve.</p>\n\
<p>The supplied tolerance is a distance in <strong>3ds Max</strong> units. If the gap between the curves you are joining is greater than this value, this function creates the join by first creating a blend curve and then joining the three parts. If the gap is less than this value, or if the curves are overlapping or coincident, no blend is created.</p>\n\
<p>Creating a blend and then joining the three curves into a single curve is the better technique. The result matches the parent curves well. Without the blend step, the resulting curve can deviate from the parent curves, in order to maintain smoothness. (The amount of deviation depends on how far from tangent the two input curves were at the join.)</p>\n\
<p>A problem arises when there is a gap but it is too small. In this case, this function generates the blend but because there isn’t enough room for it, the resulting curve has a loop in it. To avoid this loop, set this parameter higher than the gap distance.</p>\n\
<p>If you the tolerance to 0.0, the function chooses a value to use for the tolerance.</p>\n\
<p>The sub-objects to be joined are identified by their NURBSId property which is set up when you instantiate a NURBSSet with the <span class=\'code\'>NURBSNode()</span> function or if you extract a <strong>relational</strong> NURBSSet from an existing NURBS scene node using the <span class=\'code\'>getNURBSSet()</span> function.</p>\n\
<div class=\'codeBlock\'><pre>joinSurfaces &lt;node&gt; &lt;nurbsId1&gt; &lt;nurbsId2&gt; &lt;edge1_integer&gt; &lt;edge2_integer&gt; &lt;tolerance_float&gt; \n\
</pre></div><p>Joins two surface sub-objects in the specified scene node and makes a single surface from them. The specified edges of the two surface objects are connected by a new surface, and the two original surfaces are replaced by a single surface.</p>\n\
<p>The edges are identified by edge index numbers.</p>\n\
<p>The tolerance is a distance in <strong>3ds Max</strong> units. If the gap between the surfaces you are joining is greater than this value, this function creates the join by first creating a blend surface. If the gap is less than this value, or if the surfaces are overlapping or coincident, <strong>3ds Max</strong> doesn’t create the blend.</p>\n\
<p>Creating a blend and then joining the three surfaces into a single surface is the better technique. The result matches the parent surfaces well. Without the blend step, the resulting surface can deviate from the parent surfaces, in order to maintain smoothness. (The amount of deviation depends on how far from tangent the two input surfaces were at the join.)</p>\n\
<p>A problem arises when there is a gap but it is too small. In this case, this function generates the blend but because there isn’t enough room for it, the resulting surface has a loop in it. To avoid this loop, set the tolerance parameter higher than the gap distance.</p>\n\
<p>If you set the tolerance to 0.0, the function chooses a value to use for the tolerance.</p>\n\
<p>The sub-objects to be joined are identified by their NURBSId property which is set up when you instantiate a NURBSSet with the <span class=\'code\'>NURBSNode()</span> function or if you extract a <strong>relational</strong> NURBSSet from an existing NURBS scene node using the <span class=\'code\'>getNURBSSet()</span> function.</p>\n\
<div class=\'codeBlock\'><pre>makeIndependent &lt;node&gt; &lt;nurbsId&gt; \n\
</pre></div><p>This function takes a dependent sub-object (fillet, offset, blend, etc.) and turns it into a CV variant of itself such that it is independent (no longer dependent on a parent).</p>\n\
<p>The sub-object to be made independent is identified by its NURBSId property which is set up when you instantiate a NURBSSet with the <span class=\'code\'>NURBSNode()</span> function or if you extract a <strong>relational</strong> NURBSSet from an existing NURBS scene node using the <span class=\'code\'>getNURBSSet()</span> function.</p>\n\
<div class=\'codeBlock\'><pre>setViewApproximation &lt;node&gt; &lt;surfaceApproximation&gt; setRenderApproximation &lt;node&gt; &lt;surfaceApproximation&gt; setSurfaceDisplay &lt;node&gt; &lt;nurbsdisplay&gt; \n\
</pre></div><p>These methods work NURBS curve and surface scene nodes. They take instances of the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/NURBS/The-NURBS-Classes/NURBS-Associated-Classes/NURBSSurfaceApproximation-Value.html\' title=\'\'>NURBSSurfaceApproximation</a> and <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/NURBS/The-NURBS-Classes/NURBS-Associated-Classes/NURBSDisplay-Value.html\' title=\'\'>NURBSDisplay</a> classes and set the display or curve/surface approximation settings of the given NURBS scene node to those specified in the approximation or display control instance.</p>\n\
<p><strong>Associated Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>canConvertTo &lt;node&gt; &lt;class&gt; \n\
</pre></div><p>Allows you to test whether a given node is convertible into a given class. Returns <span class=\'code\'>true</span> or <span class=\'code\'>false</span> . For example:</p>\n\
<p>if canConvertTo $foo NURBSSurface then ...</p>\n\
<p>The kinds of classes you can convert objects to are the generic editable forms including Mesh, SplineShape, NURBSCurve, NURBSSurface, etc.</p>\n\
<div class=\'codeBlock\'><pre>convertTo &lt;node&gt; &lt;class&gt; -- mapped \n\
</pre></div><p>This function is a general form of the existing specific conversion functions such as <span class=\'code\'>convertToMesh()</span> , <span class=\'code\'>convertToSplineShape()</span> , etc. For example, <span class=\'code\'>convertToSplineShape()</span> can be written:</p>\n\
<div class=\'codeBlock\'><pre>convertTo $circle01 SplineShape\n\
</pre></div><p>If the conversion is not supported, the function returns the value <span class=\'code\'>undefined</span> .</p>\n\
<div class=\'codeBlock\'><pre>convertToNURBSSurface &lt;node&gt; -- mapped convertToNURBSCurve &lt;node&gt; -- mapped \n\
</pre></div><p>These functions work on those primitive geometry and shape classes that support conversion to NURBS (such as boxes, spheres, circles, lines, etc.). If an object does not support conversion, the function returns <span class=\'code\'>undefined</span> .</p>\n\
<div class=\'codeBlock\'><pre>isPointSelected &lt;node&gt; &lt;point_index&gt; \n\
</pre></div><p>Returns true if the specified point is selected, false if not.</p>\n\
<p>The definition of a &#39;point&#39; varies depending on the object type.</p>\n\
<p>For meshes, it is the mesh vertex.</p>\n\
<p>For NURBS objects, it is the vertex or control point.</p>\n\
<p>For a spline, it is the knot and its In and Out bezier handles. The spline will appear to have 3 times more knots and if a knot is selected, its bezier handles will also be considered selected. Thus, the <span class=\'code\'>&lt;point_index&gt;</span> must be multiplied by 3 to query the correct knot value. For example, if in an Editable Spline knot 1 is selected and knot 2 is not, indices 1, 2 and 3 will all return True, indices 4, 5 and 6 will return False.</p>\n\
<div class=\'codeBlock\'><pre>pointSelection &lt;node&gt; &lt;point_index&gt; \n\
</pre></div><p>Returns a floating point weighted point selection if the object supports it. Most object types just return 1.0 if the point is selected and 0.0 if not. Only NURBS objects currently support weighted point selection.</p>\n\
<div class=\'codeBlock\'><pre>stopCreating &lt;node&gt; \n\
</pre></div><p>This method stops the creation of the current object, if any. This method is primarily used to ensure that a NURBS scene objects is fully created, which it will not be until the creation is stopped. The NURBSSet returned for a NURBS scene object will not be complete if the object is still in creation mode. This method will also deactivated any activated object create buttons in the Create panel.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";