var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Working with the NURBS Classes</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Working with the NURBS Classes</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"working-with-the-nurbs-classes\"></a></div>\n\
<p>Unlike other parts of MAXScript that let you script <strong>3ds Max</strong> scene objects directly, the NURBS family of classes provides an indirect means of working with <strong>3ds Max</strong> NURBS objects. They allow you to build an idealized structure representing <strong>3ds Max</strong> NURBS objects and then use this structure to either create new or add to scene NURBS objects or to access certain parts of existing scene objects.</p>\n\
<p>The structure is made up of instances of the MAXScript NURBS classes, listed in <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/NURBS/The-NURBS-Classes/The-NURBS-Classes-1.html\' title=\'\'>NURBS Classes</a>. The main class for this is <span class=\'code\'>NURBSSet</span> . It is the structure that corresponds to a scene NURBS object and contains a collection of NURBS items such as curves, surfaces, dependent surfaces, points, and so on, which are themselves instances of the other MAXScript NURBS classes. You construct a NURBSSet object describing a NURBS object and then have it be instantiated as a real scene object. Conversely, you can ask for a NURBSSet to be created that corresponds to a given scene NURBS object and use it to examine the component NURBS items and to modify certain properties directly on the scene object it describes.</p>\n\
<p><strong>Parameter Validity</strong></p>\n\
<p>The <strong>3ds Max</strong> NURBS SDK methods and the corresponding MAXScript methods and properties perform very little parameter validation. As a result, passing invalid parameters to the functions or accessing invalid ranges will generate Assertion Failures easily. In most cases <strong>3ds Max</strong> will not crash if Retry or Ignore is selected. An example of this is:</p>\n\
<ol>\n\
<li><p>Create a CV surface and select it.</p></li>\n\
<li><p>Enter in MAXScript:</p></li>\n\
</ol>\n\
<div class=\'codeBlock\'><pre>s = getnurbsset $ #relational\n\
obj = getobject s 1\n\
tess = getviewtess obj #displacement\n\
\n\
</pre></div><p>This is invalid because the viewport does not support displacement approximation, only the production renderer does. Therefore, this will generate an Assertion Failure.</p>\n\
<p><strong>NURBSId&#39;s and Indexes</strong></p>\n\
<p>An important concept to understand when working with NURBSSets and the other NURBS classes, is the way you identify component items in the set. Before a NURBSet is instantiated as a scene NURBS object, the individual curves and points and surfaces are identified by an index number. As you append objects to the set they are assigned successive indexes, starting at 1. When you want to refer to a particular item, for example to specify the parent surfaces in a blend surface, you use this index. Once an object has been added to a NURBSSet, its index can determined through the <span class=\'code\'>.index</span> property. This is a read-only property.</p>\n\
<p>However, once a NURBSet is associated with a scene object, either by being instantiated or because it was directly created from an existing scene object, this index is <strong>no longer valid</strong>. Instead, a different number, called a <span class=\'code\'>NURBSId</span> , is assigned to each item and you must use that Id when referring to items from then on. The NURBSId of any item in an instantiated NURBSSet can be obtained through the <span class=\'code\'>.NURBSId</span> property on that object.</p>\n\
<p>These identifiers, indexes or NURBSId&#39;s, are used in many places to specify the parent objects for other dependent objects. Often, these are specified using the <span class=\'code\'>.parent</span> or <span class=\'code\'>.parentID</span> properties on a dependent object. You must be sure to use the correct property depending on whether the containing NURBSSet has been associated with a scene object or not: <span class=\'code\'>.parent</span> for non-associated NURBSSets, <span class=\'code\'>.parentID</span> for associated NURBSSets. Remember that indexes used in <span class=\'code\'>.parent</span> settings are 1-based.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";