var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>General Node Properties</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>General Node Properties</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"general-node-properties\"></a></div>\n\
<p>{{toc}}</p>\n\
<p>All the properties listed here are accessible on any node subclass.</p>\n\
<p>Unless otherwise noted, these properties can not be animated.</p>\n\
<div class=\'section\'><a id=\"object-information-properties\"></a><h2 id=\"object-information-properties\">Object Information Properties</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.name String default: varies   \n\
</pre></div><p>Get or set the scene object&#39;s name.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.baseObject  A subclass of Node  default: varies   \n\
</pre></div><p>Access the base object in a scene node. This has relevance in nodes that have modifiers present that change the node type as it is processed up the stack. For example, a line with an extrude modifier starts out as a Shape and turns into an Editable Mesh at the top of the stack, its so-called <strong>world state</strong>. The <span class=\'code\'>baseObject</span> property gives you access to the base object in the modifier stack. Because the <span class=\'code\'>classOf()</span> function on scene node objects returns the class of the world state object (the top of the stack), you can use the <span class=\'code\'>baseObject</span> property to determine the class of the original object used to create the node.</p>\n\
<p><span class=\'code\'>&lt;node&gt;.baseObject</span> is writable since <strong>3ds Max 5.1</strong>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` s=sphere() b=box() s.baseobject = b.baseobject</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.material Material default: undefined \n\
</pre></div><p>Get or set the object&#39;s material.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.parent Node default: undefined \n\
</pre></div><p>Get or set the parent of the object. If the object is a top-level object, accessing the parent property will return <span class=\'code\'>undefined</span> .</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` foo_mom = $foo.parent $foo.parent = $baz</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Setting this property has the effect of detaching <span class=\'code\'>&lt;node&gt;</span> from its original parent and attaching it as a child of the specified node.</p>\n\
<p>You can detach an object and make it a top-level object by assigning <span class=\'code\'>undefined</span> to the parent property:</p>\n\
<blockquote>\n\
<p>``` $foo.parent = undefined</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.children NodeChildrenArray default: undefined \n\
</pre></div><p>This yields a special array subclass, <span class=\'code\'>NodeChildrenArray</span> . See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/NodeChildrenArray-Values.html\' title=\'\'>NodeChildrenArray Values</a>. A <span class=\'code\'>NodeChildrenArray</span> can be accessed using normal MAXScript array indexing and can be sequenced over in a <strong>for</strong> loop or with collection-mapped functions,</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` c = $foo.children[i] move $foo.children [10,10,10] for c in $baz.children do print c</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>You can get the number of children via the <span class=\'code\'>count</span> property:</p>\n\
<blockquote>\n\
<p>``` num_children = $foo.children.count</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>You <strong>cannot</strong> directly set a child by indexing into <span class=\'code\'>NodeChildrenArray</span> , but you can append new children using the <span class=\'code\'>append()</span> function and delete children using the <span class=\'code\'>deleteItem()</span> function,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p><span class=\'code\'>$foo.children[$foo.children.count+1]=$baz-- does not work   append $foo.children $baz-- works   deleteItem $foo.children $baz-- removes $baz as child</span></p>\n\
</blockquote>\n\
<p>The ordering of child indexes corresponds to the ordering shown in the <strong>3ds Max</strong> hierarchy view, which is the order in which the children were added to the parent.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.mesh TriMesh \n\
</pre></div><p>For scene nodes or base objects that are Editable Mesh objects, or are convertable to Editable Mesh objects, this property yields a TriMesh containing a copy of the source object&#39;s mesh after any modifiers have been applied, but before any space warps have been applied. This property is read-only unless the scene node or base object is an Editable Mesh object, in which case the specified TriMesh replaces the base object. See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Editable_Mesh-GeometryClass-and.html\' title=\'\'>Editable_Mesh : GeometryClass and TriMesh : Value</a> for more information on TriMesh and Editable Mesh.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.boundingBox\n\
</pre></div><p><img src=\'developer/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/What-s-New-in-MAXScript-in-3ds.html\' title=\'\'>NEW</a> <strong>in 3ds Max 2022:</strong>: Read-only. Returns a Box3 value representing the bounding box of the node.</p>\n\
<div class=\'section\'><a id=\"layer-related-properties\"></a><h2 id=\"layer-related-properties\">Layer Related Properties</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.displayByLayer Boolean default: true \n\
</pre></div><p>When <span class=\'code\'>true</span> , object visibility will be controlled by the Layer.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.motionByLayer Boolean default: true \n\
</pre></div><p>When <span class=\'code\'>true</span> , Motion Blur will be controlled by the Layer.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.renderByLayer Boolean default: true \n\
</pre></div><p>When <span class=\'code\'>true</span> , Rendering will be controlled by the Layer.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.colorByLayer Boolean default: true \n\
</pre></div><p>When <span class=\'code\'>true</span> , the object will use the Layer&#39;s color. When <span class=\'code\'>false</span> , the object&#39;s color will be used instead.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.globalIlluminationByLayer Boolean default: true \n\
</pre></div><p>When <span class=\'code\'>true</span> , the advanced lighting inclusion/exclusion will be controlled by the layer.</p>\n\
<div class=\'section\'><a id=\"targetlookat-related-properties\"></a><h2 id=\"targetlookat-related-properties\">Target/LookAt Related Properties</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.isTarget Boolean default: false \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if then node is the target of another object&#39;s LookAt controller, <span class=\'code\'>false</span> if it is not. If the object is the automatically created target object of a light&#39;s or camera&#39;s LookAt controller, and you set this property to <span class=\'code\'>false</span> , you can delete the target object without causing the light or target to be deleted.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.lookAt Node default: undefined \n\
</pre></div><p>Get a node that is looking at <span class=\'code\'>&lt;node&gt;</span> , or set a node to look at <span class=\'code\'>&lt;node&gt;</span> . This is the converse of the <span class=\'code\'>&lt;node&gt;.target</span> property. If <span class=\'code\'>&lt;node&gt;</span> is not the target of some object&#39;s LookAt controller, the value <span class=\'code\'>undefined</span> is returned. If <span class=\'code\'>&lt;node&gt;</span> is the target of more than one object, only one such object is returned. If this property is used to set <span class=\'code\'>&lt;node&gt;</span> as the target of another object, a LookAt controller is automatically assigned to that object.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.target Node default: undefined \n\
</pre></div><p>Get or set the target node for <span class=\'code\'>&lt;node&gt;</span> &#39;s LookAt controller. Returns <span class=\'code\'>undefined</span> if there is no target or the node does not have a LookAt controller. If this property is used to set an object as the target of <span class=\'code\'>&lt;node&gt;</span> , a LookAt controller is automatically assigned to <span class=\'code\'>&lt;node&gt;</span> . Exercise care if you assign a node to the <span class=\'code\'>target</span> property. When you specify a target object, <strong>3ds Max</strong> stores with the target object the last object it was assigned as a target of. If you delete the target object, the behavior of <strong>3ds Max</strong> is to also delete the object looking at it. If the target object is a targetobject class object, deleting an object looking at it will also delete the target object, even if another object is also looking at it.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.targetDistance Float default: undefined \n\
</pre></div><p>Get or set the distance from the node to its target. Returns <span class=\'code\'>undefined</span> if <span class=\'code\'>&lt;node&gt;</span> does not have a target. Setting this property moves the target along the object-to-target vector to the distance specified.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` $spot01.targetDistance $cam2.targetDistance = 100</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"interactivity---hiden-frozen-properties\"></a><h2 id=\"interactivity---hiden-frozen-properties\">Interactivity - Hiden / Frozen Properties</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.isHidden Boolean default: false \n\
</pre></div><p>Get or set whether the node is flagged as hidden in the viewports. A node may be hidden even if this property is <span class=\'code\'>false</span> . If the node is flagged as frozen and <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/M/Interface-maxOps.html\' title=\'\'>Hide Frozen Objects</a> is on in the Hide rollout in the Display panel, the node will be hidden regardless of this property&#39;s value.</p>\n\
<p>A node is hidden in the viewport if:</p>\n\
<p>1. The node&#39;s hidden flag is set,</p>\n\
<p>2. The node&#39;s layer hidden flag is set,</p>\n\
<p>3. The node&#39;s category is hidden via Hide By Category, or</p>\n\
<p>4. The node is frozen and Hide Frozen Objects is enabled</p>\n\
<p>The node&#39;s <span class=\'code\'>isHidden</span> property reflects a combination of conditions 1 and 2. The property returns <span class=\'code\'>true</span> if either condition 1 or 2 is <span class=\'code\'>true</span> . Setting the property to <span class=\'code\'>true</span> sets the node&#39;s hidden flag. Setting the property to <span class=\'code\'>false</span> clears both the node&#39;s and the node&#39;s layer&#39;s hidden flag.</p>\n\
<p>Condition 2 can be handled by getting the node&#39;s layer and checking the layer&#39;s <span class=\'code\'>isHidden</span> property using <span class=\'code\'>theNode.INodeLayerProperties.layer.isHidden</span></p>\n\
<p>For handling Condition 3, see the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/HideByCategory-Properties-and.html\' title=\'\'>hideByCategory</a> structure added in <strong>3ds Max 6</strong>.</p>\n\
<p>Condition 4 can be handled by getting the node&#39;s frozen status using <span class=\'code\'>theNode.isFrozen</span> and checking the <span class=\'code\'>maxOps.hideFrozenObjects</span> property.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.isNodeHidden Boolean default: false \n\
</pre></div><p>The node&#39;s <span class=\'code\'>isNodeHidden</span> property reflects only condition 1 listed above. The property returns <span class=\'code\'>true</span> if the node&#39;s hidden flag is set, <span class=\'code\'>false</span> if not. Setting the property sets only the node&#39;s hidden flag.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.isHiddenInVpt Boolean default: false \n\
</pre></div><p>This is a read-only property that returns <span class=\'code\'>true</span> if any of the 4 conditions is <span class=\'code\'>true</span> , that is, the node is hidden in the viewport for some reason.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.isFrozen Boolean default: false \n\
</pre></div><p>Get or set whether the node is frozen in the viewports.</p>\n\
<p>A node is frozen in the viewport if:</p>\n\
<p>1. The node&#39;s frozen flag is set, or</p>\n\
<p>2. The node&#39;s layer frozen flag is set</p>\n\
<p>The node&#39;s <span class=\'code\'>isFrozen</span> property reflects a combination of conditions 1 and 2. The property returns <span class=\'code\'>true</span> if either condition 1 or 2 is <span class=\'code\'>true</span> . Setting the property to <span class=\'code\'>true</span> sets the node&#39;s frozen flag. Setting the property to <span class=\'code\'>false</span> clears both the node&#39;s and the node&#39;s layer&#39;s frozen flag.</p>\n\
<p>Condition 2 can be handled by getting the node&#39;s layer and checking the layer&#39;s <span class=\'code\'>isFrozen</span> property using <span class=\'code\'>theNode.INodeLayerProperties.layer.isFrozen</span></p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.isNodeFrozen Boolean default: false \n\
</pre></div><p>This property reflects only condition 1 described above. The property returns <span class=\'code\'>true</span> if the node&#39;s frozen flag is set, <span class=\'code\'>false</span> if not. Setting the property sets only the node&#39;s frozen flag.</p>\n\
<div class=\'section\'><a id=\"display-related-properties\"></a><h2 id=\"display-related-properties\">Display Related Properties</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.isSelected Boolean default: false \n\
</pre></div><p>Get or set whether the node is selected.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.xray Boolean default: false \n\
</pre></div><p>Get or set whether the node is displayed in See Through mode in shaded viewports.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.boxMode Boolean default: false \n\
</pre></div><p>Get or set whether the node is displayed in box mode in the viewports.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.allEdges Boolean default: false \n\
</pre></div><p>Get or set whether all the node&#39;s edges are displayed in the viewports.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.vertexTicks Boolean default: false \n\
</pre></div><p>Get or set whether all the node&#39;s vertices will be displayed as ticks in the viewports.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.backFaceCull Boolean default: false \n\
</pre></div><p>Get or set whether the node&#39;s back faces are culled (not displayed) in the viewports.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.showTrajectory Boolean default: false \n\
</pre></div><p>Get or set whether the node&#39;s trajectory is displayed in the viewports.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.ignoreExtents Boolean default: false \n\
</pre></div><p>Get or set whether the extents of the node is ignored when performing a zoom extents.</p>\n\
<div class=\'codeBlock\'><pre>node&gt;.showFrozenInGray Booleandefault:true \n\
</pre></div><p>Get/Set whether the node will be displayed as gray when frozen.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.wireColor Color default: random color \n\
</pre></div><p>Get or set the node&#39;s wireframe color</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.showLinks Boolean default: false \n\
</pre></div><p>Get or set whether to display a wireframe representation of the hierarchical link(s) from the node to its children.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.showLinksOnly Boolean default: false \n\
</pre></div><p>Get or set whether to display only the wireframe representation of the hierarchical link(s) for the node. Setting this property to <span class=\'code\'>true</span> a lso sets showLinks to <span class=\'code\'>true</span> .</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.showVertexColors Boolean default: false \n\
</pre></div><p>Get or set whether to display the effect of assigned vertex colors for the node in shaded viewports.</p>\n\
<p>Exposed by the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Node-Interfaces/Node-Interfaces-Documentation/Interface-INode.html\' title=\'\'>INode Interface</a>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.vertexColorType Name \n\
\n\
vertexColorType enums: {#color|#illum|#alpha|#color_plus_illum} \n\
</pre></div><p>Get/set the vertex color display type.</p>\n\
<p>Exposed by the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Node-Interfaces/Node-Interfaces-Documentation/Interface-INode.html\' title=\'\'>INode Interface</a>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` $Sphere01.vertexColorType = #illum</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.vertexColorsShaded Boolean default: false \n\
</pre></div><p>Get or set whether the vertex color display for the node is shaded in the viewports. When <span class=\'code\'>true</span> , the colors are unshaded and appear in their pure RGB values. When <span class=\'code\'>false</span> , the colors appear like any other assigned color in the viewports.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.isDependent Boolean default: false \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the node has its dependent flag set, otherwise returns <span class=\'code\'>false</span> . A node is dependent in the sense of <strong>3ds Max</strong> &#39;s Views/Show Dependencies mode. When the Modify panel is open, Show Dependencies will show all the nodes that are dependent on the current modifier or object being editing by highlighting them in green, and the dependent flag for the node is set. This property will always return <span class=\'code\'>false</span> if the Modify panel is closed, or if Views/Show Dependencies is off. This property is read-only.</p>\n\
<div class=\'section\'><a id=\"rendering-related-properties\"></a><h2 id=\"rendering-related-properties\">Rendering Related Properties</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.visibility Boolean default: true -- animatable \n\
</pre></div><p>This is a boolean property (unlike its value as a signed float in the <strong>3ds Max</strong> Track View) - <span class=\'code\'>true</span> or <span class=\'code\'>on</span> denotes visible, <span class=\'code\'>false</span> or <span class=\'code\'>off</span> invisible. Animate this property to control an node&#39;s visibility at render-time,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` my_node=box() animate on ( at time 0 my_node.visibility =on at time 35 my_node.visibility =off at time 57 my_node.visibility =on )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>By default, there is no controller assigned to the visibility track. Accessing the <span class=\'code\'>.controller</span> property of the visibility track will throw an error. In order to be able to add keys and manipulate them, there must be a controller assigned. Animating the property as shown above will force<strong>3ds Max</strong>to assign a controller automatically. You can also assign a controller manually to the <span class=\'code\'>.visibility</span> property:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` --assigns a controller: my_node.visibility = bezier_float() --set the current value to semi-visible: my_node.visibility.controller.value = 0.5 --animate the value to 0 on frame 100 animate on at time 100 my_node.visibility.controller.value = 0.0</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The controller for this property is stored in the 1 st subAnim of the node. You can also access this controller (if existing) as:</p>\n\
<blockquote>\n\
<p><span class=\'code\'>&lt;node&gt;[1].controller -- the visibility controller</span></p>\n\
</blockquote>\n\
<p>You can also get a node&#39;s visibility controller using the <span class=\'code\'>getVisController()</span> method.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.renderable Boolean default: true \n\
</pre></div><p>Get or set whether the node is renderable.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.inheritVisibility Boolean default: true \n\
</pre></div><p>Get or set whether the node inherits the visibility of its parent object (if any). This property parallels the Inherit Visibility property in an object&#39;s right-click Object Properties dialog.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.primaryVisibility: boolean : Read|Write \n\
</pre></div><p>Gets/Sets the node’s Visible to Camera option.</p>\n\
<p>Exposed by the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Node-Interfaces/Node-Interfaces-Documentation/Interface-INode.html\' title=\'\'>INode Interface</a>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.secondaryVisibility: boolean : Read|Write \n\
</pre></div><p>Gets/Sets the node’s Visible to Reflection/Refraction option.</p>\n\
<p>Exposed by the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Node-Interfaces/Node-Interfaces-Documentation/Interface-INode.html\' title=\'\'>INode Interface</a>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.receiveShadows Boolean default: true \n\
</pre></div><p>Get or set whether the node receives shadows when rendered. This property parallels the Receive Shadows property in an object&#39;s right-click Object Properties dialog.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.castShadows Boolean default: true \n\
</pre></div><p>Get or set whether the node casts shadows when rendered. This property parallels the Cast Shadows property in an object&#39;s right-click Object Properties dialog.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.applyAtmospherics: boolean : Read|Write \n\
</pre></div><p>Gets/Setswhether the node will be affected by atmospheric effects.</p>\n\
<p>Exposed by the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Node-Interfaces/Node-Interfaces-Documentation/Interface-INode.html\' title=\'\'>INode Interface</a>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.renderOccluded Boolean default: false \n\
</pre></div><p>Get or set whether to Render Occluded Objects behind the node. This property parallels the Render Occluded Objects property in an object&#39;s right-click Object Properties dialog.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.gbufferChannel Integer default: 0 \n\
</pre></div><p>Get or set the node&#39;s g-buffer Object ID channel value. Valid object ID values in <strong>3ds Max</strong> range from 0 to 65535. This property parallels the G-Buffer Object Channel property in an object&#39;s right-click Object Properties dialog.</p>\n\
<div class=\'section\'><a id=\"motion-blur\"></a><h2 id=\"motion-blur\">Motion Blur</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.imageMotionBlurMultiplier Float default: 1.0 -- animatable \n\
</pre></div><p>Get or set the node&#39;s image motion blur multiplier value. The controller for this property is stored in the 6 th subAnim of the node. You can access this controller as:</p>\n\
<blockquote>\n\
<p><span class=\'code\'>&lt;node&gt;[6].controller-- the imageMotionBlurMultiplier controller</span></p>\n\
</blockquote>\n\
<p>You can also get and set a node&#39;s imageMotionBlurMultiplier controller using the <span class=\'code\'>getImageBlurMultController()</span> and <span class=\'code\'>setImageBlurMultController()</span> methods.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.motionBlurOn Boolean default: true \n\
</pre></div><p>Get or set whether motion blur is enabled for the object. This property parallels the Motion Blur Enabled property in an object&#39;s right-click Object Properties dialog.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.motionBlurOnController Controller default: undefined \n\
</pre></div><p>Get or set the motion blur on/off controller used for the node.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.motionBlur Name default: #none \n\
</pre></div><p>Get or set the type of motion blur to be used for the node. Valid parameter values are: <span class=\'code\'>#none</span> , <span class=\'code\'>#object</span> , and <span class=\'code\'>#image</span> . For backward compatibility, this property can also be set to <span class=\'code\'>false</span> for none or <span class=\'code\'>true</span> for object motion blur. This property parallels the Motion Blur type specified in an object&#39;s right-click Object Properties dialog.</p>\n\
<div class=\'section\'><a id=\"mental-ray-indirect-illumination-properties\"></a><h2 id=\"mental-ray-indirect-illumination-properties\">mental ray Indirect Illumination Properties</h2></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-B51CA473-FFDB-463D-A637-842EB070A5EA-low.gif\' title=\'\'></div>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.generatecaustics Boolean default: false \n\
</pre></div><p>Get or set whether the node generates caustics. Caustics are not supported by the <strong>3ds Max</strong> scanline renderer.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.rcvcaustics Boolean default: true \n\
</pre></div><p>Get or set whether the node receives caustics. Caustics are not supported by the <strong>3ds Max</strong> scanline renderer.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.generateGlobalIllum Boolean default: false \n\
</pre></div><p>Get or set whether the node generates global illumination. Global illumination is not supported by the <strong>3ds Max</strong> scanline renderer.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.rcvGlobalIllum Boolean default: true \n\
</pre></div><p>Get or set whether the node receives global illumination. Global illumination is not supported by the <strong>3ds Max</strong> scanline renderer.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";