var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Modifier Stack Related Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Modifier Stack Related Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"modifier-stack-related-methods\"></a></div>\n\
<div class=\'codeBlock\'><pre>validModifier [&lt;node&gt; | &lt;objectset&gt; | &lt;group&gt; ] &lt;modifier |modifier_class&gt; \n\
</pre></div><p>Tests whether a particular modifier or modifier class might be added the given <span class=\'code\'>&lt;node&gt;</span> or to all of the objects in the objectset or group. Returns <span class=\'code\'>true</span> if so, <span class=\'code\'>false</span> if not.</p>\n\
<p>The <span class=\'code\'>validModifier()</span> method operates exactly as does the Modify panel in determining modifier applicability. Any modifier that takes a deformable object will return <span class=\'code\'>true</span> for all scene objects except Helpers. This corresponds to the Modify panel&#39;s behavior of allowing modifiers such as, Bend, Taper, and so on to be applied to lights and cameras, space warp objects, and others as well as geometry types such as, box, sphere, and so on, but not helpers such as, dummys or bones.</p>\n\
<p>The <span class=\'code\'>validModifier()</span> method will return <span class=\'code\'>true</span> if an empty <span class=\'code\'>&lt;objectset&gt;</span> is specified, or if a <span class=\'code\'>&lt;group&gt;</span> is specified and the modifier is valid for all members of the group. In these cases, applying the modifier using the <span class=\'code\'>addModifier()</span> method will fail because the <span class=\'code\'>&lt;objectset&gt;</span> is empty in the first case or the modifier cannot be applied to the dummy object that is the parent object of the objects in the group. You will need to test for these conditions in your script or use the <span class=\'code\'>modPanel.addModToSelection()</span> method described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Command-Panels/Modify-Panel.html\' title=\'\'>Modify Panel</a>.</p>\n\
<div class=\'codeBlock\'><pre>addModifier &lt;node&gt; &lt;modifier&gt; [before:index] -- mapped \n\
</pre></div><p>Applies the modifier to <strong>all instances</strong> of the node(s) to which the function is applied. The optional <span class=\'code\'>before:</span> keyword argument can be used to insert the modifier into the node&#39;s modifier stack just before the indexed modifier, counting from the top of the stack.</p>\n\
<p>Since <strong>3ds Max 3</strong>, <span class=\'code\'>addModifier()</span> does not preserve the sub-object selection that might be active in the modifier stack when adding the modifier. If you want to add a modifier and preserve the sub-object selection, use the <span class=\'code\'>modPanel.addModToSelection()</span> method described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Command-Panels/Modify-Panel.html\' title=\'\'>Modify Panel</a>.</p>\n\
<p>If <span class=\'code\'>&lt;node&gt;</span> is a collection, an instance of the modifier is placed on each of the nodes in the collection. Unlike interactively applying a modifier to a selection, the position and size of each modifier instance&#39;s gizmo corresponds to position and size of the node the modifier instance is applied to. To apply a modifier to a collection in the same manner that <strong>3ds Max</strong> applies modifiers, use the <span class=\'code\'>modPanel.addModToSelection()</span> method described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Command-Panels/Modify-Panel.html\' title=\'\'>Modify Panel</a>.</p>\n\
<p>Note: This method does not copy any local data, so, for example, using it to copy a modifier on an existing node that has been manipulated to another node will not also copy the changes. See <span class=\'code\'>addModifierWithLocalData()</span> below to handle this situation.</p>\n\
<p>Also see <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Modifier-MAXWrapper-and/Modifier-MAXWrapper-and-1.html\' title=\'\'>Modifier and SpacewarpModifier</a> for more details.</p>\n\
<div class=\'codeBlock\'><pre>addModifierWithLocalData &lt;destnode&gt; &lt;dest modifier&gt; &lt;srcnode&gt; &lt;src modifier_or_index&gt; [before:index]\n\
</pre></div><p>This method copies the destination modifier to a destination node. The two modifiers must be of the same type. The local data of the source (if any) is cloned and attached to the destination modifier. If the source modifier has no local data, the destination modifier will contain whatever its default local data is (just as if it had been added by the <span class=\'code\'>addModifier()</span> method).</p>\n\
<p>For example:</p>\n\
<div class=\'codeBlock\'><pre>addModifierWithLocalData destNode srcMmodifier srcNode srcMmodifier -- instance the modifier\n\
addModifierWithLocalData destNode (copy srcMmodifier) srcNode srcMmodifier -- copy the modifier\n\
addModifierWithLocalData destNode ((classof srcMmodifier)()) srcNode srcMmodifier -- new instance of the modifier&#39;s class\n\
deleteModifier &lt;node&gt; &lt;modifier_or_index&gt; -- mapped \n\
</pre></div><p>Lets you delete modifiers from the modifier stack. Takes either a modifier value that is present on the <span class=\'code\'>&lt;node&gt;</span> stack, or an index specifying the index of the modifier to delete, counting from the top of the stack.</p>\n\
<div class=\'codeBlock\'><pre>collapseStack &lt;node&gt; -- mapped \n\
</pre></div><p>Collapses the modifiers out of a stack, leaving a resultant editable base object corresponding to the class of the node(s) on top of their stack. If there are no modifiers in the stack when this is called, no action is taken. If you want to force an object to be an editable mesh, use the function <span class=\'code\'>convertToMesh()</span> .</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";