var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Node Deformable Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Node Deformable Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"node-deformable-methods\"></a></div>\n\
<div class=\'codeBlock\'><pre>isDeformable &lt;node&gt; \n\
</pre></div><p>Returns true if the node&#39;s object is deformable. Available in <strong>3ds Max 2008 and higher</strong>.</p>\n\
<p><strong>What are deformable objects?</strong></p>\n\
<p>A deformable object is an object with points that can be modified. Internally, these points can be stored in any form the object wants. They are accessed through a virtual array interface with methods to get and set the &#39;i-th&#39; point.</p>\n\
<p>This abstraction layer allows <strong>3ds Max</strong> to apply the same modifiers to the various Geometry classes like Editable Meshes, Editable Poly, Splines, Patches, and Nurbs without specific knowledge of the internal structures of these classes. The modifier simply operates on points provided by the object using the virtual array interface methods, but these points can be vertices, Bezier spline knots and tangents, Patch knots and tangents, and so on.</p>\n\
<p>See the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/Scripted-SimpleMod-Plug-ins.html\' title=\'\'>simpleMod Scripted Plugin</a> for a scripted modifier that can operate on points in this manner by implementing the <span class=\'code\'>&#39;on map &lt;index&gt; &lt;point&gt; do&#39;</span> handler.</p>\n\
<p>Note:</p>\n\
<p>While isDeformable might return true for some nodes, this does not necessarily mean that they can be deformed. For example, all legacy particle systems like Snow, Superspray, and Blizzard return true, but are not affected by deformations, while all geometry primitives return false, but can be deformed.</p>\n\
<p>The method simply wraps the SDK method and returns the value provided by the object when asked wether it is deformable or not.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` for g in geometryClass.classes do ( try ( o = execute (g as string +&quot;()&quot;) if isDeformable o then format &quot;% is Deformable.\\n&quot; g else format &quot;% is NOT Deformable.\\n&quot; g )catch(format &quot;Failed To Create %\\n&quot; g) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>numPoints &lt;node&gt; \n\
</pre></div><p>Returns the number of deformable points for the node&#39;s object. Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>getPointPos &lt;node&gt; &lt;index&gt; \n\
</pre></div><p>Returns the position of the indexed point for the node&#39;s object. Position is returned in current coordinate system. Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";