var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Node Utility Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Node Utility Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"node-utility-methods\"></a></div>\n\
<div class=\'codeBlock\'><pre>isDeleted &lt;MAXWrapper_object&gt; \n\
</pre></div><p>This function yields the result <span class=\'code\'>true</span> if the object has been deleted and <span class=\'code\'>false</span> if it still exists in the scene. Using the function only makes sense in situations where references to <strong>3ds Max</strong> objects are held in variables or arrays, or passed as parameters and you want to determine whether the object has been deleted from the scene. Performing an operation on a deleted <strong>3ds Max</strong> object referenced in a variable or array otherwise generates an exception. Any kind of <strong>3ds Max</strong> object can be tested in this way such as, scene objects, modifiers, controllers, materials, and others.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` sel = selection as array-- snapshot selection --... -- <one or=\"\" more=\"\" objects=\"\" in=\"\" the=\"\" selection=\"\" are=\"\" deleted,=\"\" --=\"\" by=\"\" the=\"\" user=\"\" or=\"\" other=\"\" scripts=\"\"> --... for obj in sel where not isDeleted obj do move obj [10,0,0]<p>\n\
<p>```</p>\n\
</one></blockquote>\n\
<p>When a node has been deleted,</p>\n\
<p><node> == undefined returns <strong>false</strong><p>\n\
<p><node> != undefined returns <strong>true</strong><p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` if mynode != undefined and not isdeleted myNode do...</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>distance &lt;node&gt; &lt;node&gt; \n\
</pre></div><p>Computes the distance between the pivot points of the two specified nodes.</p>\n\
<div class=\'codeBlock\'><pre>intersectRay &lt;node&gt; &lt;ray&gt; \n\
</pre></div><p>Computes the closest intersection of the ray and the surface of the given node. Returns another Ray which defines the position of intersection in 3D space and the surface normal direction vector at that point. The intersection test respects the face normals of the node. If a face&#39;s normal points away from the ray&#39;s source, an intersection test is not performed on that face . <span class=\'code\'>intersectRay()</span> works if the world state of the node (the state of the node at the top of the node&#39;s stack) has a surface such as, an editable mesh, a Standard, Extended, or Compound Primitive, a Patch, or a NURBS surface object. Splines and NURBS curves do not have a surface. Returns <span class=\'code\'>undefined</span> if the ray does not intersect the node, the faces it does intersect point away from the ray&#39;s position, or the node does not have a surface.</p>\n\
<div class=\'codeBlock\'><pre>intersectRayEx &lt;node&gt; &lt;ray&gt; \n\
</pre></div><p>Takes a ray and computes the closest intersection to the surface of the given node. It returns an array with the following three elements.</p>\n\
<ol>\n\
<li><p>A Ray defining the position of intersection in 3-space and the surface normal direction vector at the point.</p></li>\n\
<li><p>The index of the face the ray intersects with.</p></li>\n\
<li><p>The barycentric coordinates of the face that was hit.</p></li>\n\
</ol>\n\
<p>This method only works if the world state of the node is a mesh, either because it started as an editable mesh or it has modifiers applied that convert the node to a mesh. Unlike <span class=\'code\'>intersectRay()</span> , this method will not work if the node is a Standard or Extended Primitive; the node&#39;s stack must evaluate to a mesh. The intersection test respects the face normals of the node. If a face&#39;s normal points away from the ray&#39;s source, an intersection test is not performed on that face. Returns <span class=\'code\'>undefined</span> if the ray does not intersect the node, the faces it intersects point away from the ray&#39;s position, or the node is not a mesh.</p>\n\
<blockquote>\n\
<p><strong>WHAT ARE BARYCENTRIC COORDINATES?</strong></p>\n\
<p>Barycentric coordinates are the coordinates relative to the triangular face. The barycentric coordinates of a point <span class=\'code\'>p</span> relative to a triangle describe that point as a weighted sum of the vertices of the triangle.</p>\n\
<p>If the barycentric coordinates are <span class=\'code\'>b0</span> , <span class=\'code\'>b1</span> , and <span class=\'code\'>b2</span> , then</p>\n\
<p>``` p = b0<em>p0 + b1</em>p1 + b2*p2</p>\n\
<p>```</p>\n\
<p>where, <span class=\'code\'>p0</span> , <span class=\'code\'>p1</span> , and <span class=\'code\'>p2</span> are the positions of the vertices of the triangle.</p>\n\
<p>The Point3 returned by this method has the barycentric coordinate stored in its three component values. The coordinate is relative to the triangular face that was intersected.</p>\n\
<p>Barycentric coordinates can also be used to interpolate any quantity whose value is known at the vertices of the triangle.</p>\n\
</blockquote>\n\
<p>Following is an example of finding the UV coordinates at the intersection point:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` s = geosphere material:(standardMaterial diffuseMap:(checker())) showTextureMap s.material s.material.diffuseMap on -- -- Add a normal modifier to make the sphere into a mesh addModifier s (normalModifier()) r = ray [-100,5,0] (s.center-[-100,5,0]) -- -- Get the Intersection details arr = (intersectRayEx s r) -- -- Create a dummy at the point of intersection dummy pos:(arr[1]).pos -- -- Get the texture face tf = getTVFace s arr[2] -- -- Get the UVW verts of the face tv1 = getTVert s tf.x tv2 = getTVert s tf.y tv3 = getTVert s tf.z -- -- Calculate the texture vertices at point of intersection from -- the barycentric coordinates tv = tv1<em>arr[3].x + tv2</em>arr[3].y + tv3*arr[3].z -- -- Delete the modifier deleteModifier s 1</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>intersectRayScene &lt;ray&gt; \n\
</pre></div><p>Performs intersectRay on all nodes in the scene.</p>\n\
<p>Returns an array of results, one entry per node hit, where each entry is a 2 element array containing the node and the intersectRay result for that node.</p>\n\
<p>The intersection is performed for all geometry objects including hidden ones.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` ( local r = ray [0,0,0] [1,0,0]--define a ray along X for i = 0 to 4 do--loop 5 times ( box pos:[i * 30, 0,0]--create a box ) local hits = intersectRayScene r--intersect withscene print hits --Misses box 1 because ray originates inside the box )</p>\n\
<p>-- output</p>\n\
<p>--&gt; #(\\(Box:Box02 @ [30.000000,0.000000,0.000000], (ray [17.5,0,0] [-1,0,0]))  --&gt; #(\\)Box:Box03 @ [60.000000,0.000000,0.000000], (ray [47.5,0,0] [-1,0,0])) --&gt; #(\\(Box:Box04 @ [90.000000,0.000000,0.000000], (ray [77.5,0,0] [-1,0,0]))  --&gt; #(\\)Box:Box05 @ [120.000000,0.000000,0.000000], (ray [107.5,0,0] [-1,0,0])) --&gt; OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>intersects &lt;node&gt; &lt;node&gt; \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the bounding boxes of the two specified nodes overlap, or <span class=\'code\'>false</span> if they do not overlap.</p>\n\
<div class=\'codeBlock\'><pre>printStack &lt;node&gt; \n\
</pre></div><p>Prints a representation of the current modifier stack for the given node.</p>\n\
<div class=\'codeBlock\'><pre>getLastMergedNodes()\n\
</pre></div><p>Returns an array of nodes loaded by the last merge operation, for example by <span class=\'code\'>mergeMAXFile()</span>.</p>\n\
</node></node>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";