var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Node User-Defined Properties and Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Node User-Defined Properties and Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"node-user-defined-properties-and-methods\"></a></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-02ADD04B-DC3F-4E59-A48B-EAD697B25BBE-low.gif\' title=\'\'></div>\n\
<p>The functions described in this topic give you access to scene object user properties, accessible in the <strong>3ds Max</strong> user interface in the <strong>User Defined</strong> tab in the <strong>Object Properties Dialog</strong>.</p>\n\
<p>There are two sets of MAXScript methods for setting and getting individual keyed properties, and two methods that let you treat the property text as a single big string. The user defined properties in the Object Properties dialog are accessed as one single string representing the entire contents or as key/property pairs in the form:</p>\n\
<div class=\'codeBlock\'><pre>&lt;key1&gt; = &lt;property1&gt;&lt;key2&gt; = &lt;property2&gt;...\n\
</pre></div><p>where, the keys are identifiers (Name or String values, though Names are not recommended, see the note below) and the properties can be values. For the old methods, these can be numbers, booleans, or text strings. For the new methods, any value where <span class=\'code\'>(val==execute(val as string))</span> is true can be used.</p>\n\
<p>Note: The <span class=\'code\'>setUserProp()</span>/<span class=\'code\'>getUserProp()</span> methods do not always produce predictable results. The <span class=\'code\'>setUserPropVal()</span>/<span class=\'code\'>getUserPropVal()</span> methods are the preferred way to get/set user properties, as of <strong>3ds Max 2019.1 Update</strong>.</p>\n\
<p>Note: The key is case sensitive. If a name value is used, it is converted to the string originally used to define the name value, which might be different than the case of the specified name value itself. For this reason, we do not recommend you use name values as keys for any of these methods.</p>\n\
<p>The <span class=\'code\'>&lt;node&gt;</span> methods are:</p>\n\
<div class=\'codeBlock\'><pre>getUserPropVal &lt;node&gt; &lt;key_string&gt; [asString:&lt;boolean&gt;] [decodeCRLF:&lt;boolean&gt;]\n\
</pre></div><p>Retrieves the node&#39;s user property, where the property key corresponds to <span class=\'code\'>&lt;key_string&gt;</span>. Available in <strong>3ds Max 2019.1 Update and higher</strong>. The property value&#39;s string is evaluated as a MaxScript value if <strong>asString</strong> is not specified, or is specified as false. If the evaluation of the value&#39;s string is successful, that value is returned, otherwise the value&#39;s string is returned as a string value. If <strong>asString</strong> is specified as true, the property value&#39;s string is always returned as a string value.</p>\n\
<p>The node parameter can be specified as <span class=\'code\'>rootNode</span> or an XRef root node (the <span class=\'code\'>.tree</span> property), which gets a user defined property for that root node. Available in <strong>3ds Max 2019.2 Update and higher</strong></p>\n\
<p>When returning a string value, if the first and last character of the string are quotes, those quotes are removed from the string. When returning a string value, if <strong>decodeCRLF</strong> is not specified or is specified as true, any carriage return or line feed hex representations in the property value&#39;s string are converted to carriage return or line feed characters, otherwise they are not. That is, &#39;\\xd\\xa&#39; would be converted to &#39;\\r\\n&#39;.</p>\n\
<p>If the property key does not exist, a value of undefined is returned. If the property key exists but no value is present, a value of &#39;emptyVal&#39; is returned.</p>\n\
<p>Note: Using <span class=\'code\'>getUserPropVal()</span> to retrieve properties written either in the Object Properties dialog or with <span class=\'code\'>setUserProp()</span> may give unexpected results. For example:<span class=\'code\'>setUserProp &quot;p1&quot; &quot;xxx&quot;; v=getUserPropVal &quot;p1&quot;</span>. In this case, v will most likely be &#39;undefined&#39;, because it was not saved in quotes, so is considered a value representation (a global variable name), and the contents of the variable name are returned. This is essentially the same as <span class=\'code\'>v=execute &quot;xxx&quot;</span>.</p>\n\
<p>Note: The special value type <span class=\'code\'>emptyVal</span> (a distinguished instance of the <span class=\'code\'>Empty</span> class) is used to indicate properties that have a key but no value. For example, if the property key &quot;xxx&quot; is defined without a value, calling <span class=\'code\'>getUserPropVal()</span> returns an &#39;emptyVal&#39;. For keys that are not defined, the same call returns &#39;undefined&#39;.</p>\n\
<div class=\'codeBlock\'><pre>setUserPropVal &lt;node&gt; &lt;key_string&gt; &lt;value&gt;  [quoteString:&lt;boolean&gt;] \n\
</pre></div><p>Sets a user property on node, where the property key corresponds to <span class=\'code\'>&lt;key_string&gt;</span> and the property value is corresponds to <span class=\'code\'>&lt;value&gt;</span>. Available in <strong>3ds Max 2019.1 Update and higher</strong>. Any value type where <span class=\'code\'>(val == execute (val as string))</span> can be used. If <span class=\'code\'>&lt;value&gt;</span> is a string, and <strong>quoteStrings</strong> is not specified or is specified as true, the property value&#39;s string is enclosed in quotes, otherwise it is not. If <span class=\'code\'>&lt;value&gt;</span> is a string, and <strong>encodeCRLF</strong> is not specified or is specified as true, any carriage return or line feed characters in the property value&#39;s string are converted to hex representations, otherwise they are not. That is, &#39;\\r\\n&#39; would be converted to &#39;\\xd\\xa&#39;. If a value of &#39;emptyVal&#39; is used, the key is written but no value is written.</p>\n\
<p>The node parameter can be specified as <span class=\'code\'>rootNode</span> or an XRef root node (the <span class=\'code\'>.tree</span> property), which sets a user defined property for that root node. Available in <strong>3ds Max 2019.2 Update and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>getUserProp &lt;node&gt; &lt;key_string&gt;      \n\
</pre></div><p>Retrieves the node&#39;s user property, where the property key corresponds to <span class=\'code\'>&lt;key_string&gt;</span>. If the key does not exist, a value of <span class=\'code\'>undefined</span> is returned. MAXScript tries to convert the property value to a number, if that fails then to a boolean, and if that fails it returns the value as a text string. This can cause incorrect conversions in some cases. For example, if the property value was set to &quot;1m&quot;, <span class=\'code\'>getUserProp()</span> returns a Time value of 1800f since &quot;1m&quot; is interpreted as a Time literal of 1 minute. For this reason you should use <strong>getUserPropVal()</strong> instead.</p>\n\
<p>The node parameter can be specified as <span class=\'code\'>rootNode</span> or an XRef root node (the <span class=\'code\'>.tree</span> property), which gets the user defined properties for that root node. Available in <strong>3ds Max 2019.2 Update and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>setUserProp &lt;node&gt; &lt;key_string&gt; &lt;value&gt;   \n\
</pre></div><p>Sets the node&#39;s user property with the given key to the string representation of the given value.</p>\n\
<p>The node parameter can be specified as <span class=\'code\'>rootNode</span> or an XRef root node (the <span class=\'code\'>.tree</span> property), which sets a user defined property buffer for that root node. Available in <strong>3ds Max 2019.2 Update and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;doesUserPropExist &lt;node&gt; &lt;key_string&gt;\n\
</pre></div><p>Returns true if the specified user property exists on the node. Available in <strong>3ds Max 2019.1 Update and higher</strong>.</p>\n\
<p>The node parameter can be specified as <span class=\'code\'>rootNode</span> or an XRef root node (the <span class=\'code\'>.tree</span> property), which looks for user defined property for that root node. Available in <strong>3ds Max 2019.2 Update and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;deleteUserProp &lt;node&gt; &lt;key_string&gt; \n\
</pre></div><p>Deletes specified user property on node. Available in <strong>3ds Max 2019.1 Update and higher</strong>. Returns true if the property existed.</p>\n\
<p>The node parameter can be specified as <span class=\'code\'>rootNode</span> or an XRef root node (the <span class=\'code\'>.tree</span> property), which deletes a user defined property for that root node. Available in <strong>3ds Max 2019.2 Update and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>getUserPropBuffer &lt;node&gt; \n\
</pre></div><p>Retrieves the entire user property buffer as a string containing all the user property settings. This is effectively the contents of the User Defined Properties box in the <strong>3ds Max</strong> Object Properties dialog.</p>\n\
<p>The node parameter can be specified as <span class=\'code\'>rootNode</span> or an XRef root node (the <span class=\'code\'>.tree</span> property), which gets the user defined properties for that root node. Available in <strong>3ds Max 2019.2 Update and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>setUserPropBuffer &lt;node&gt; &lt;string&gt; \n\
</pre></div><p>Sets the user property buffer to the given string.</p>\n\
<p>The node parameter can be specified as <span class=\'code\'>rootNode</span> or an XRef root node (the <span class=\'code\'>.tree</span> property), which sets a user defined property buffer for that root node. Available in <strong>3ds Max 2019.2 Update and higher</strong>.</p>\n\
<p>Note:</p>\n\
<p>To include new line characters in a multi-line User Property Buffer string, you have to use the combination <strong>\\r\\n</strong> (carriage return and new line). See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Literal-Constants/String-Literals.html\' title=\'\'>String Literals</a> for a list of control characters.</p>\n\
<p>The following two example code fragments save and load user properties for objects in a scene.</p>\n\
<p>The first code fragment creates a file and loops through all objects outputting for each the object name and user property buffer string. Note that the object name goes out in a form that will come back in (through a <span class=\'code\'>readValue()</span> ) as a direct reference to a scene object. Also, the user property string is output using <span class=\'code\'>print()</span> , so it will be in a quoted form to be read as one (long) string literal by a corresponding <span class=\'code\'>readValue()</span> .</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` -- create file and for all objects, -- dump object name and user props f = createFile &quot;foo.dat&quot; for o in objects do ( format &quot;$%\\n&quot; o.name to:f -- output name in a pathname form print (getUserPropBuffer o) to:f -- output buffer as a string literal ) close f</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The second code fragment reads in the file created by the first piece and applies the user properties to any same-named object in the current scene. Note that <span class=\'code\'>readValue()</span> can read in pathnames ( <span class=\'code\'>$&lt;name&gt;</span> ) and will yield either the named scene object or <span class=\'code\'>undefined</span> if the named object is not in the scene. The <span class=\'code\'>readValue()</span> function can also read in a multiline string literal in one pass.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` -- open file and read in object names and -- user properties to set f = openFile &quot;foo.dat&quot; while not eof f do ( o = readValue f-- read object if o != undefined then-- if present, read and set user prop string setUserPropBuffer o (readValue f) ) close f</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>You can access the user property buffer on an XRef by first getting the XRef with <span class=\'code\'>xrefs.getXRefFile()</span>, and then getting the XRef root node with the <span class=\'code\'>.tree</span> property.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p><span class=\'code\'>-- Properties on an xref scene   i = 1  -- index value   z = xrefs.getXRefFile i   getUserPropBuffer (z.tree)</span></p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";