var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Using Node Transform Properties</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Using Node Transform Properties</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"using-node-transform-properties\"></a></div>\n\
<p>This topic provides information on three transforms related to nodes: the Node Transform Matrix, the Object-Offset Transform Matrix, and the Object Transform Matrix. The Node and Object-Offset Transform Matrices are stored by <strong>3ds Max</strong>. The Object Transform Matrix is derived from these two matrices. This topic also presents information on how these transforms are constructed, how they are used by <strong>3ds Max</strong>, and how they can be accessed and manipulated in MAXScript.</p>\n\
<div class=\'section\'><a id=\"the-pivot-pointthe-node-transform-matrix\"></a><h3 id=\"the-pivot-pointthe-node-transform-matrix\">The Pivot Point—The Node Transform Matrix</h3></div>\n\
<p>The transform center or pivot point is the location about which a rotation takes place, or to and from which a scale occurs. All nodes in <strong>3ds Max</strong> have a pivot point. You can think of the pivot point as representing a node&#39;s local center and local coordinate system. The pivot point of a node is used for a number of purposes:</p>\n\
<ul>\n\
<li><p>As the center for rotation and scaling.</p></li>\n\
<li><p>Defines the transform origin for linked children.</p></li>\n\
<li><p>Defines the joint location for Inverse Kinematics.</p></li>\n\
</ul>\n\
<p>The thing that most users think of as the pivot point is graphically represented in <strong>3ds Max</strong> by the axis tripod that is displayed when a node is selected and the coordinate system is set to local is actually just a visual representation of the node&#39;s transform matrix.</p>\n\
<p>The node&#39;s transform matrix is what is controlled by the transform controller that places the node in the scene. The transform controller controls the transform relative to the node&#39;s parent.</p>\n\
<div class=\'section\'><a id=\"construction-of-the-node-transform-matrix-for-the-prs-transform-controller\"></a><h3 id=\"construction-of-the-node-transform-matrix-for-the-prs-transform-controller\">Construction of the Node Transform Matrix for the PRS Transform Controller</h3></div>\n\
<p>The PRS controller uses sub-controllers to create the final transform. There are three sub-controllers: one for Position, one for Rotation, and one for Scale. The PRS controller is passed the transform matrix of the node&#39;s parent. If the node has no parent, the matrix starts out as the identity matrix. The PRS controller first calls the position controller, then the rotation controller, and then the scale controller. First the position controller pre-multiplies the input matrix by the position value. If the matrix passed is the identity matrix, this is equivalent to setting the bottom row (the translation row) of the matrix. Next, the rotation controller pre-multiplies the matrix by the rotation value. Finally, the scale controller pre-multiplies the matrix by the scale value.</p>\n\
<p>Some position controllers can actually apply more than just position to the matrix. For example, the Path Controller when the Follow switch is active, actually applies some rotation to have the node remain tangent to the path it is following. Thus, when the rotation controller receives the matrix, the matrix already has some rotation applied.</p>\n\
<p>After the position, rotation, and scale controllers have updated the matrix, it becomes the Node Transform Matrix that <strong>3ds Max</strong> uses to position, rotate, and scale nodes in the scene. Thus, the entire transform is:</p>\n\
<blockquote>\n\
<p><strong>Node Transform Matrix = Controller Scale * Controller Rotation * Controller Position * Parent Transform Matrix</strong></p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"the-object-offset-transform-matrix\"></a><h3 id=\"the-object-offset-transform-matrix\">The Object-Offset Transform Matrix</h3></div>\n\
<p>The Object-Offset Transform Matrix provides an offset of the geometry of an object from its node.</p>\n\
<p>You can see a node&#39;s pivot point graphically represented in <strong>3ds Max</strong> by selecting a node, going to the Hierarchy branch of the Hierarchy panel, selecting the &#39;Pivot&#39; button, and choosing either the &#39;Affect Pivot Only&#39; or &#39;Affect Object Only&#39; button. This displays a large axis tripod that shows the location and orientation of the node&#39;s pivot point. By choosing one of these buttons and using the Move/Rotate/Scale toolbar controls, a user can manipulate the position of the geometry of the object independent of the pivot point or can manipulate the pivot point independent of the geometry of the object.</p>\n\
<p>The way the user is able to independently manipulate the pivot and the object is managed internally using the Object-Offset Transform Matrix. The Object-Offset Transform Matrix affects how the geometry of the object is related to the node. The Object-Offset Transform Matrix transforms the geometry of the object itself some amount from the node.</p>\n\
<p>To understand how the Object-Offset Transform Matrix is used, consider the following example from the <strong>3ds Max</strong> user interface. In the Hierarchy branch under &#39;Pivot&#39;, when the user has chosen the &#39;Affect Object Only&#39; button they are free to move the geometry of the object around independent of the node. The pivot point does not move—only how the geometry of the object is oriented relative to the pivot. What is happening internally is that the Object-Offset Transform Matrix is being manipulated. This transform is simply an additional offset that is applied to the geometry of the object that is independent of the node. The Object-Offset Transform Matrix is not inherited by any child nodes.</p>\n\
<p>As another example consider the use of the &#39;Affect Pivot Only&#39; button. This mode lets the user move the pivot without affecting the position of the geometry of the object. When the user moves the pivot point, what is actually happening is the Node Transform Matrix is being altered (to re-orient the pivot point), then the Object-Offset Transform Matrix is adjusted to counter the node transform. This lets the geometry of the object stay in the same place while the pivot point moves around.</p>\n\
<div class=\'section\'><a id=\"construction-of-the-object-offset-transform-matrix\"></a><h3 id=\"construction-of-the-object-offset-transform-matrix\">Construction of the Object-Offset Transform Matrix</h3></div>\n\
<p>The Object-Offset Transform Matrix consists of separate position, rotation, and scale transforms. Like the Node Transform Matrix, these are applied by pre-multiplying position, then rotation, and then scale. Thus, the Object-Offset Transform Matrix is:</p>\n\
<blockquote>\n\
<p><strong>Object-Offset Transform Matrix = Offset Scale * Offset Rotation * Offset Position</strong></p>\n\
</blockquote>\n\
<p>Unlike the Node Transform Matrix, the Object-Offset Transform Matrix is not inherited by children of the node.</p>\n\
<div class=\'section\'><a id=\"the-object-transform-matrix\"></a><h3 id=\"the-object-transform-matrix\">The Object Transform Matrix</h3></div>\n\
<p>The Object Transform Matrix is the transform matrix an object&#39;s geometry needs to be multiplied by to transform it into world space. This transform matrix includes the parent transform, the Node Transform, and the Object Offset Transform. Thus, the entire transform used to transform the points of any object is:</p>\n\
<blockquote>\n\
<p><strong>Object Transform Matrix = Object-Offset Transform Matrix * Node Transform Matrix</strong></p>\n\
</blockquote>\n\
<p>This matrix can be used, for example, if you have a mesh object and want to get the world space coordinate of one of its vertices. You can do this by taking the vertex coordinate in object space and multiplying it by the Object Transform Matrix.</p>\n\
<div class=\'section\'><a id=\"using-the-node-transforms-in-maxscript\"></a><h3 id=\"using-the-node-transforms-in-maxscript\">Using the Node Transforms in MAXScript</h3></div>\n\
<p>The node transform properties are derived from and modify the values of the transform controllers associated with the node. They are not associated directly with the node&#39;s main transformation matrix. This has a number of consequences:</p>\n\
<ol>\n\
<li><p>Assigning to a transform property (such as, <span class=\'code\'>pos</span> or <span class=\'code\'>rotation</span> ) with animation enabled plants keyframes only in the associated controller. If you modify the node&#39;s transform matrix directly, keyframes are generated for <strong>all</strong> the transform controllers for that node.</p></li>\n\
<li><p>Rotation properties and all rotation-related functions in MAXScript reflect the direction convention used in the <strong>3ds Max</strong> user interface. This convention is the <strong>right-hand rule</strong>, namely, positive angles rotate counter-clockwise about positive axes. Internally, <strong>3ds Max</strong> stores rotations in node matrices using the <strong>left-hand rule</strong>. It is important to remember this inversion when working directly with node transform matrices using the <span class=\'code\'>transform</span> and <span class=\'code\'>objectTransform</span> properties. You will need to invert rotations (for example, by multiplying axes by [-1,-1,-1] or using the <span class=\'code\'>inverse()</span> function on quaternions) when mixing them with <strong>3ds Max</strong> and MAXScript standard rotations.</p></li>\n\
<li><p>Certain controllers such as, the path controller with bank or follow enabled, affect the rotation of a node by adjusting the node&#39;s transform matrix directly and this rotation <strong>is not</strong> reflected in rotation controller values. This means, in this example for instance, that bank and follow rotations are not directly accessible through the <strong>rotation</strong> property. You need to access them directly in the node&#39;s transformation matrix using something like:</p>\n\
<blockquote>\n\
<p>``` r = $foo.transform.rotationPart</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>This returns a quaternion. Remember that the <strong>3ds Max</strong> rotation direction convention is not reflected when directly accessing a transform matrix, so to use this value in other rotation operations you will need to invert it:</p>\n\
<blockquote>\n\
<p>``` $baz.rotation = inverse r</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>A node&#39;s <span class=\'code\'>transform</span> property contains the Node Transform Matrix and reflects the position, rotation, and scale of the node&#39;s pivot point. Accessing the <span class=\'code\'>pivot</span> property will return the same value as the <span class=\'code\'>pos</span> property. Setting the <span class=\'code\'>pivot</span> property will move the pivot point location to the specified coordinates, but the node&#39;s geometry will not be moved.</p>\n\
<p>A node&#39;s <span class=\'code\'>objectoffsetpos</span> , <span class=\'code\'>objectoffsetrot</span> , and <span class=\'code\'>objectoffsetscale</span> properties contain the component parts of the Object-Offset Transform Matrix. A node&#39;s <span class=\'code\'>objecttransform</span> property contains the Object Transform Matrix. As this matrix is a combination of the Node Transform and Object-Offset Transform Matrices, this property is read only. Note that these properties are always returned in the World coordinate system context.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` fn DumpXForms obj = (-- output node transform properties format &quot;%:\\t%\\n&quot; &quot;transform&quot; obj.transform format &quot;%:\\t%\\n&quot; &quot;position &quot; obj.pos format &quot;%:\\t%\\n&quot; &quot;rotation &quot; obj.rotation -- output node&#39;s pivot point location format &quot;%:\\t%\\n&quot; &quot;pivot &quot; obj.pivot -- output object offsets format &quot;%:\\t%\\n&quot; &quot;objectoffsetpos&quot; obj.objectoffsetpos format &quot;%:\\t%\\n&quot; &quot;objectoffsetrot&quot; obj.objectoffsetrot format &quot;%:\\t%\\n&quot; &quot;objectoffsetscale&quot; obj.objectoffsetscale -- output object transform format &quot;%:\\t%\\n&quot; &quot;objecttransform &quot; obj.objecttransform -- output vertex position in local and world coordinates format &quot;%:\\t%\\n&quot; &quot;vert 1 (local) &quot;(in coordsys local getvert obj 1) format &quot;%:\\t%\\n&quot; &quot;vert 1 (world1) &quot;(in coordsys world getvert obj 1) -- calculate and output vertex position in world coordinates local v_pos = (in coordsys local getvert obj 1)* obj.objecttransform format&quot;%:\\t%\\n&quot; &quot;vert 1 (world2) &quot; v_pos ) -- define function for rotating only the pivot point fn RotatePivotOnly obj rotation = (local rotValInv=inverse (rotation as quat) animate off in coordsys local obj.rotation<em>=RotValInv obj.objectoffsetpos</em>=RotValInv obj.objectoffsetrot*=RotValInv ) -- ( b=box pos:[75,75,0]-- create a 25x25x25 box, vertex 1 at [62.5,62.5,0] (world) convertToMesh b-- convert box to mesh so we can access the vertex location DumpXForms b-- print transforms b.pivot=[50,50,0]-- move pivot only to [50,50,0] DumpXForms b-- print transforms RotatePivotOnly b (EulerAngles 0 0 35)-- rotate pivot only 35 degrees about local Z DumpXForms b-- print transforms )</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT</strong></p>\n\
<p>``` DumpXForms()-- function definition RotatePivotOnly()-- function definition transform: (matrix3 [1,0,0], [0,1,0], [0,0,1], [75,75,0])-- initial transforms position : [75,75,0] rotation : (quat 0 0 0 1) pivot : [75,75,0] objectoffsetpos : [0,0,0] objectoffsetrot : (quat 0 0 0 1) objectoffsetscale: [1,1,1] objecttransform : (matrix3 [1,0,0], [0,1,0], [0,0,1], [75,75,0]) vert 1 (local) : [-12.5,-12.5,0] vert 1 (world1) : [62.5,62.5,0] vert 1 (world2) : [62.5,62.5,0] transform: (matrix3 [1,0,0], [0,1,0], [0,0,1], [50,50,0])-- transforms after move position : [50,50,0] rotation : (quat 0 0 0 1) pivot : [50,50,0] objectoffsetpos : [25,25,0] objectoffsetrot : (quat 0 0 0 1) objectoffsetscale: [1,1,1] objecttransform : (matrix3 [1,0,0], [0,1,0], [0,0,1], [75,75,0]) vert 1 (local) : [-12.5,-12.5,0] vert 1 (world1) : [62.5,62.5,0] vert 1 (world2) : [62.5,62.5,0] transform: (matrix3 [0.819152,0.573576,0], [-0.573576,0.819152,0], [0,0,1], [50,50,0])-- transforms after rotate position : [50,50,0] rotation : (quat 0 0 0.300706 0.953717) pivot : [50,50,0] objectoffsetpos : [34.8182,6.13939,0] objectoffsetrot : (quat 0 0 0.300706 0.953717) objectoffsetscale: [1,1,1] objecttransform : (matrix3 [1,0,0], [0,1,0], [0,0,1], [75,75,0]) vert 1 (local) : [-12.5,-12.5,0] vert 1 (world1) : [62.5,62.5,0] vert 1 (world2) : [62.5,62.5,0]</p>\n\
<p>```</p>\n\
</blockquote></li>\n\
</ol>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";