var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Particle System Common Properties, Operators, and Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Particle System Common Properties, Operators, and Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"particle-system-common-properties-operators-and-methods\"></a></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-CBA66C53-542D-4D90-8240-8B2DAD4BF9B0-low.gif\' title=\'\'></div>\n\
<p>Five <span class=\'code\'>&lt;node&gt;</span> functions work with the legacy particle system objects in <strong>3ds Max</strong> to allow you to get or set individual particle information. These functions return or set information about particles at the time set by the current &#39;at time&#39;context clause, or the current time slider if there is not time context active.</p>\n\
<p>Note:</p>\n\
<p>The <strong>Particle Flow</strong> system in <strong>3ds Max 6 and higher</strong> provides extensive MAXScript access.</p>\n\
<p>For Particle Flow-relared MAXScript methods, see <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/MAXScript-Extensions/MAXScript-Extensions-for/Particle-Flow-and-MAXScript.html\' title=\'\'>Particle Flow and MAXScript</a></p>\n\
<p>A quick note about how the legacy particle systems in <strong>3ds Max</strong> work will help you use these functions.</p>\n\
<p>The particle system keeps an array of particles big enough to hold all those alive at any one time.</p>\n\
<p>Each particle is identified by an index in this array. When one dies, it may be &#39;born&#39; again sometime later and appear to be a different particle.</p>\n\
<p>Over the course of an animation, the same &#39;particle&#39; may live and die many times as its indexed slot in the array gets re-used.</p>\n\
<p>Some of the functions described below use this index to identify particles, so you can have a situation where the &#39;same&#39; particle (by index) becomes a new particle in the animation as its slot gets re-used.</p>\n\
<p>The way you can check this is by looking at the &#39;age&#39; of the particle - if it cycles around to zero (or a lower number depending on time resolution), you know it has become a &#39;new&#39; particle.</p>\n\
<p>If a particle is actually not alive at a given time, for example at the beginning of an animation or when you set up an &#39;explosive&#39; emission, the functions below that get position, velocity and age return <span class=\'code\'>undefined</span> .</p>\n\
<p>This tells you that the particle is not currently alive.</p>\n\
<p><strong>These arethe particle system functions:</strong></p>\n\
<div class=\'codeBlock\'><pre>particleCount &lt;particlesys_node&gt;     \n\
</pre></div><p>Returns the number of current particle slots in the system as an integer. This value is the number of particles that are to be drawn to the viewports unless the scene is currently being rendered. If the scene is being rendered, the number returned can be either the render count or the viewport count, depending on whether the particle system has been evaluated for rendering or not.</p>\n\
<div class=\'codeBlock\'><pre>particleSize &lt;particlesys_node&gt;   \n\
</pre></div><p>Returns the size of the particles in the system as float. This is set in the particle system parameter rollout - there is one size for all particles in a particle system. If you are using these functions to attach objects to particles, you can of course, make the individual objects any size you want.</p>\n\
<div class=\'codeBlock\'><pre>particlePos &lt;particlesys_node&gt; &lt;particle_index_integer&gt; \n\
</pre></div><p>Returns the position coordinate of the indexed particle at the current time as a point3. Indexes are 1-based. The coordinate returned is in the current working coordinate system. Returns <span class=\'code\'>undefined</span> if the particle is not alive at the current time.</p>\n\
<div class=\'codeBlock\'><pre>particleVelocity &lt;particlesys_node&gt; &lt;particle_index_integer&gt; \n\
</pre></div><p>Returns the current velocity vector for the indexed particle as a point3. The vector returned is rotated into the current working coordinate system. Returns <span class=\'code\'>undefined</span> if the particle is not alive at the current time.</p>\n\
<div class=\'codeBlock\'><pre>particleAge &lt;particlesys_node&gt; &lt;particle_index_integer&gt; \n\
</pre></div><p>Returns the current age of the indexed particle as a time value, relative to when it was last born. Remember, particles get recycled and you can detect this by looking at the age value cycling round. Returns <span class=\'code\'>undefined</span> if the particle is not alive at the current time.</p>\n\
<div class=\'codeBlock\'><pre>particleLife &lt;particlesys_node&gt; &lt;particle_index_integer&gt; \n\
</pre></div><p>Returns the life of the particle -- the length of time the particle will be &#39;alive&#39;. Returns undefined if the particle is not alive at the current time.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a> .</p>\n\
<div class=\'codeBlock\'><pre>particleCenter &lt;particlesys_node&gt; &lt;particle_index_integer&gt; \n\
</pre></div><p>Returns a value indicating where the particle geometry (mesh) lies in relation to the particle position. Returns undefined if the particle is not alive at the current time.</p>\n\
<p>This is used by Particle Motion Blur for example. It gets the point in world space of the point it is shading, the size of the particle from ParticleSize(), and the position of the mesh from ParticleCenter(). Given this information, it can know where the point is, and it makes the head and the tail more transparent.</p>\n\
<p>Return Values:</p>\n\
<p>PARTCENTER_HEAD - The particle geometry lies behind the particle position.</p>\n\
<p>PARTCENTER_CENTER - The particle geometry is centered around particle position.</p>\n\
<p>PARTCENTER_TAIL - The particle geometry lies in front of the particle position.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a> .</p>\n\
<div class=\'codeBlock\'><pre>particleSize2 &lt;particlesys_node&gt; &lt;particle_index_integer&gt; \n\
</pre></div><p>Returns the world space size of the specified particle. Returns undefined if the particle is not alive at the current time.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a> .</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";