var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Shape Common Properties, Operators, and Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Shape Common Properties, Operators, and Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"shape-common-properties-operators-and-methods\"></a></div>\n\
<p><strong>General Methods</strong>:</p>\n\
<div class=\'codeBlock\'><pre>numKnots&lt;shape&gt; [ &lt;spline_index_integer&gt; ]   \n\
</pre></div><p>Returns the number of knots (also known vertices or control points) in the indexed spline as an integer. If the spline index is not specified, returns the number of knots in the entire shape.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>y = donut()   numKnots y</span></p>\n\
</blockquote>\n\
<p><strong>Interpolation Methods</strong>:</p>\n\
<p>There are a number of interpolation functions that operate on <strong>shape</strong> scene objects. They provide capabilities such as stepping along a curve within a shape getting coordinates on the curve, getting curve lengths or determining the closest point on a curve to a given coordinate. These are useful for placing cloned objects along a curve or keeping a set of objects in formation near a &#39;spine&#39;curve as it animates, etc.</p>\n\
<p>The interpolators all take a shape scene object (for example, a line), an optional curve number in case there are several curves in the shape, defaulting to 1, and a <strong>parameter</strong> in the range <strong>0.0</strong> to <strong>1.0</strong>, that specifies a spot on the curve as a proportion along its length. There are two types of interpolator provided:</p>\n\
<ul>\n\
<li><p>One interpolator matches the <strong>3ds Max</strong> Path controller in which the percentage along the path is not uniform, but weighted by the vertex spacing. This simple interpolation is interpolating based on parameter space. If a spline has 4 segments, the first segment is parameter values 0-0.25, the second 0.25-0.5, the third 0.5-0.75 and the fourth 0.75-1.0. This is regardless of the length of each segment.</p></li>\n\
<li><p>Another interpolator that gives you a <strong>uniform</strong> interpolation along the length of the curve. This interpolation normalizes the parameter space to distance along the length of a spline. So parameter space 0 is the start, 1.0 is the end and 0.5 is halfway along the actual length of the curve.</p></li>\n\
</ul>\n\
<p>The non-uniform Path interpolator in <strong>3ds Max</strong> gives rise to the varying velocity of a path-animated object when the path has unevenly spaced control points. The arc-length interpolators provided here give a uniform placing along the curve no matter how uneven the control point placement. The advantage of the Path interpolator is that it is computationally much more efficient than a uniform arc-length interpolator. The length interpolator uses some caches to speed it up, but you have to help manage them in the way described below.</p>\n\
<p>The optional <strong>steps:</strong> keyword argument for the methods listed below lets you specify the integration steps. The default <strong>steps</strong> value is 5 times the curve&#39;s <strong>3ds Max</strong> unit length, which usually is more than enough. For example, if a curve has a length of 100 <strong>3ds Max</strong>units, the default step size would be 500. The interpolation algorithm has an accuracy of no better than + or - <strong>(1/steps) 3ds Max</strong> units. These methods employ a cache to speed up their operation in the common case where you step gradually along a single curve. The cache remembers the state for the last point on the curve and picks up there if you call again on the same curve at the same animation time. This can exponentially speed up interpolation processing. However, MAXScript does not have a way of knowing if you&#39;ve edited the curve from one call to the next, so you have to be sure to reset the cache with the <strong>resetLengthInterp()</strong> method if the user can edit the curve between calls in your code.</p>\n\
<p>All coordinates are in the current coordinate system.</p>\n\
<div class=\'codeBlock\'><pre>pathInterp&lt;shape&gt; [ &lt;curve_num&gt; ] &lt;parameter&gt;   \n\
</pre></div><p>Return a point3 coordinate on the numbered curve (defaults to 1) corresponding to the parameter value (0.0 to 1.0) that matches the <strong>3ds Max</strong> Path controller percentage (vertex-based) interpolation.</p>\n\
<div class=\'codeBlock\'><pre>lengthInterp&lt;shape&gt; [ &lt;curve_num&gt; ] &lt;parameter&gt; [  steps:&lt;integer&gt; ] \n\
</pre></div><p>Return a point3 coordinate on the numbered curve (defaults to 1) corresponding to the parameter value (0.0 to 1.0) that is that fraction along the curve&#39;s total length.</p>\n\
<div class=\'codeBlock\'><pre>resetLengthInterp () \n\
</pre></div><p>Clear length interpolation cache. Use this if the curve you are length-interpolating along might have been edited between calls.</p>\n\
<div class=\'codeBlock\'><pre>curveLength&lt;shape&gt; [ &lt;curve_num&gt; ] \n\
</pre></div><p>Return the arc length of the numbered curve. This length does not reflect any transform level scaling performed on the shape.</p>\n\
<div class=\'codeBlock\'><pre>pathTangent&lt;shape&gt; [ &lt;curve_num&gt; ] &lt;parameter&gt; \n\
</pre></div><p>Return the tangent direction vector at the <strong>3ds Max</strong> Path (vertex-based) interpolated point along the specified curve. You can use this function, for example, to set an object&#39;s direction to follow the curve.</p>\n\
<div class=\'codeBlock\'><pre>lengthTangent&lt;shape&gt; [ &lt;curve_num&gt; ] &lt;parameter&gt; [steps:&lt;integer&gt; ] \n\
</pre></div><p>Return the tangent direction vector at the arc-length-interpolated point along the specified curve. You can use this function to set an object&#39;s direction to follow the curve.</p>\n\
<div class=\'codeBlock\'><pre>nearestPathParam&lt;shape&gt; [ &lt;curve_num&gt; ] &lt;point3&gt; [steps:&lt;integer&gt; ] \n\
</pre></div><p>Return the interpolation parameter value (0.0 to 1.0) corresponding to the point along the curve that is closest to the given <span class=\'code\'>&lt;point3&gt;</span> coordinate. The parameter is given as a <strong>3ds Max</strong>Path (vertex-based) interpolation parameter value. You can then use <span class=\'code\'>pathInterp</span> with this value to find the nearest point&#39;s coordinates, or use one of the following functions for converting between arc-length parameters and <strong>3ds Max</strong> Path percentage parameters.</p>\n\
<div class=\'codeBlock\'><pre>pathToLengthParam&lt;shape&gt; [ &lt;curve_num&gt; ] &lt;parameter&gt; [steps:&lt;integer&gt; ] \n\
</pre></div><p>Return the uniform arc-length length parameter corresponding to the given <strong>3ds Max</strong> Path (vertex-based) parameter for this curve.</p>\n\
<div class=\'codeBlock\'><pre>lengthToPathParam&lt;shape&gt; [ &lt;curve_num&gt; ] &lt;parameter&gt; [steps:&lt;integer&gt; ] \n\
</pre></div><p>Return the <strong>3ds Max</strong> Path (vertex-based) parameter corresponding to the given uniform arc-length parameter for this curve.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";