var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>XRefObject : Node</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>XRefObject : Node</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"xrefobject-node\"></a></div>\n\
<p>An <strong>XRefObject</strong> value represents an XRef object in <strong>3ds Max</strong>. An XRefObject value is returned when the <span class=\'code\'>*xrefs.addNewXRefObject()*</span> function is called. There are two objects associated with an XRef object in <strong>3ds Max</strong> - the non-proxy object and the proxy object. The proxy object is typically a lower resolution object that is used as a standin for the non-proxy object in the viewports.</p>\n\
<p>Note: In <strong>3ds Max 8</strong> and newer, the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/N-O/Interface-objXRefMgr.html\' title=\'\'>objXrefMgr</a> is the preferred way of working with XRefs in MAXScript. Scripts that use both <span class=\'code\'>XRefObject</span> and <span class=\'code\'>objXrefMgr</span> methods on the same XRefObject may not work correctly.</p>\n\
<p><strong>Constructor:</strong></p>\n\
<div class=\'codeBlock\'><pre>xrefs.addNewXRefObject &lt;filename&gt; {&lt;objectname&gt; | &lt;objectname_array&gt;} [#proxy] \\\n\
 modifiers:{#xref | #merge | #drop} manipulators: {     #xref | #merge }        \\\n\
dupMtlNameAction: {#prompt |    #useXRefed |    #useScene | #autoRename} \\\n\
reparentAction: {#promptReparent|#alwaysReparent|#neverReparent}\n\
</pre></div><p>Loads the specified node object from the specified scene file as an XRef object. The case of <span class=\'code\'>*objectname_string*</span> must match the object&#39;s name in the scene file.</p>\n\
<p>If an array of object names is specified, the return value will be an array of the XRef&#39;ed objects. Note that if a manipulator&#39;s name is specified in the array, and manipulator: <span class=\'code\'>*#merge*</span> is specified, the merged manipulator is not included in the result array since it isn&#39;t an XRef Object.</p>\n\
<p>If <span class=\'code\'>*#proxy*</span> is specified, the node object is loaded as the proxy object, otherwise it is loaded as the non-proxy object.</p>\n\
<p>The XRefObject is always loaded at world center.</p>\n\
<p>References between XRef objects brought in as a single operation are maintained, so that if you have a object parameter controlled by a manipulator, and you XRef in both the object and the manipulator, the manipulator will still control the object&#39;s parameter.</p>\n\
<p><strong>Modifiers:</strong></p>\n\
<ul>\n\
<li><strong>#xref</strong> - XRef Object contains any modifiers on object (default)</li>\n\
<li><strong>#merge</strong> - XRef Object contains base object, any modifiers on object are applied to the XRef Object</li>\n\
<li><strong>#drop</strong> - XRef Object contains base object, any modifiers on object are dropped</li>\n\
</ul>\n\
<p><strong>Manipulators:</strong></p>\n\
<ul>\n\
<li><p><strong>#xref</strong> - bring manipulator in as an xref</p></li>\n\
<li><p><strong>#merge</strong> - bring in manipulator as a manipulator</p></li>\n\
</ul>\n\
<p><strong>dupMtlNameAction:</strong> (available in <strong>3ds Max 2010 and higher</strong>)</p>\n\
<ul>\n\
<li><p><strong>#prompt</strong> - Prompts the user to define the duplicated material names action (default)</p></li>\n\
<li><p><strong>#useXRefed</strong> - Uses the material from the XRef.</p></li>\n\
<li><p><strong>#useScene</strong> - Uses the scene material.</p></li>\n\
<li><p><strong>#autoRename</strong> - Rename the material to avoid dupilication.</p></li>\n\
</ul>\n\
<p><strong>reparentAction:</strong> (available in <strong>3ds Max 2019.1 Update and higher</strong>)</p>\n\
<ul>\n\
<li><strong>#promptReparent</strong> - Prompt the user to re-parent the xref (the default).</li>\n\
<li><strong>#alwaysReparent</strong> - Always re-parent the xref, and do not prompt the user. This is the default if 3ds Max is running in quiet mode (for example, running as Max Batch).</li>\n\
<li><strong>#neverReparent</strong> - Never reparent the xref, and do not prompt the user.</li>\n\
</ul>\n\
<p>In <strong>3ds Max 6 and higher,</strong> <span class=\'code\'>*xrefs.addNewXRefObject*</span> returns undefined when the argument is a file with DRF extension.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefObject&gt;.proxyFileName String default: varies   \n\
</pre></div><p>The file name of the proxy object.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefObject&gt;.fileName String default: varies \n\
</pre></div><p>The file name of the non-proxy object.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefObject&gt;.currentFileName String default: varies \n\
</pre></div><p>The file name of the non-proxy object if the <span class=\'code\'>*useProxy*</span> property is <span class=\'code\'>*false*</span> , the file name of the proxy object if the <span class=\'code\'>*useProxy*</span> property is <span class=\'code\'>*true*</span> .</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefObject&gt;.objectName String default: varies \n\
</pre></div><p>The name of the non-proxy object.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefObject&gt;.proxyObjectName String default: varies \n\
</pre></div><p>The name of the proxy object.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefObject&gt;.currentObjectName String default: varies \n\
</pre></div><p>The name of the non-proxy object if the <span class=\'code\'>*useProxy*</span> property is <span class=\'code\'>*false*</span> , the name of the proxy object if the <span class=\'code\'>*useProxy*</span> property is <span class=\'code\'>*true*</span> .</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefObject&gt;.useProxy Boolean default: varies \n\
</pre></div><p>If <span class=\'code\'>*true*</span> , the proxy object will be displayed in the viewports, otherwise the non-proxy object will be displayed.</p>\n\
<p>If the XRef object is added to the scene using the <span class=\'code\'>*xrefs.addNewXRefObject()*</span> method, this parameters default value will be <span class=\'code\'>*true*</span> if <span class=\'code\'>*#proxy*</span> is specified, <span class=\'code\'>*false*</span> otherwise.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefObject&gt;.renderProxy Boolean default: false \n\
</pre></div><p>If <span class=\'code\'>*true*</span> , the proxy object will be rendered, otherwise the non-proxy object will be rendered.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefObject&gt;.updateMaterial Boolean default: false \n\
</pre></div><p>If <span class=\'code\'>*true*</span> , sets the Update Material option on.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefObject&gt;.ignoreAnimation Boolean default: false \n\
</pre></div><p>If <span class=\'code\'>*true*</span> , sets the Ignore Animation option on.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefObject&gt;.actualBaseObject -- read-only \n\
</pre></div><p>Returns the actual base object of the referenced object as opposed to the base object of the XRefObject.</p>\n\
<p>If &#39;Use Proxy&#39; is turned on for the XRefObject, the proxy base object is returned if a proxy object is defined, otherwise a value of &#39;undefined&#39; is returned.</p>\n\
<p>Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>updateXRef &lt;XRefObject&gt; \n\
</pre></div><p>Reloads the XRef object.</p>\n\
<p>The following XRefObject interfaces are available in <strong>3ds Max 8 and higher</strong>:</p>\n\
<div class=\'section\'><a id=\"xrefobject-interfaces\"></a><h2 id=\"xrefobject-interfaces\">XRefObject interfaces:</h2></div>\n\
<div class=\'codeBlock\'><pre>Interface:IXRefItem \n\
</pre></div><p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>.srcFileName : filename : Read \n\
</pre></div><p>Contains the source file name.</p>\n\
<p>Read-only.</p>\n\
<div class=\'codeBlock\'><pre>.srcItemName : string : Read \n\
</pre></div><p>Contains the name of the source item.</p>\n\
<p>Read-only.</p>\n\
<div class=\'codeBlock\'><pre>.xrefRecord : Interface : Read \n\
</pre></div><p>Contains the XRef record Interface.</p>\n\
<p>Read-only.</p>\n\
<div class=\'codeBlock\'><pre>.unresolved : boolean : Read \n\
</pre></div><p>Contains true if the XRef is unresolved, false otherwise.</p>\n\
<p>Read-only.</p>\n\
<div class=\'codeBlock\'><pre>.nested : boolean : Read \n\
</pre></div><p>Contains true if the XRef is nested, false otherwise.</p>\n\
<p>Read-only.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;maxObject&gt;GetSrcItem resolveNested:&lt;boolean&gt; \n\
\n\
resolveNested default value: false \n\
</pre></div><p>Returns the source item object of the XRef Object.</p>\n\
<p>If the object is being referenced from nested files (in other words, the object is referenced from a Max file containing an XRef of the object from another file instead of the actual object) and <span class=\'code\'>resolveNested</span> is set to true, nested XRef files will be resolved.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;GetParentItems &lt;&amp;maxObject array&gt;parentItems \n\
\n\
parentItems is Out parameter \n\
</pre></div><p>Returns an array of parent items in the by-reference Out parameter.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;GetRootItems &lt;&amp;maxObject array&gt;rootItems \n\
\n\
rootItems is Out parameter \n\
</pre></div><p>Returns an array of root items in the by-reference Out parameter.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;GetChildItems &lt;&amp;maxObject array&gt;childItems \n\
\n\
childItems is Out parameter \n\
</pre></div><p>Returns an array of child items in the by-reference Out parameter.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;GetNodes &lt;&amp;node array&gt;xrefNodes \n\
\n\
xrefNodes is Out parameter \n\
</pre></div><p>Returns an array of XRef nodes in the by-reference Out parameter.</p>\n\
<div class=\'codeBlock\'><pre>Interface:IXRefProxy \n\
</pre></div><p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>.proxyFileName : filename : Read \n\
</pre></div><p>Contains the proxy file name.Read-only.</p>\n\
<div class=\'codeBlock\'><pre>.proxyItemName : string : Read \n\
</pre></div><p>Contains the proxy item name.Read-only.</p>\n\
<div class=\'codeBlock\'><pre>.proxyRecord : Interface : Read \n\
</pre></div><p>Contains the proxy record Interface.Read-only.</p>\n\
<div class=\'codeBlock\'><pre>.displayProxy : boolean : Read|Write \n\
</pre></div><p>When set to True, the proxy will be used in the viewport.</p>\n\
<div class=\'codeBlock\'><pre>.renderProxy : boolean : Read|Write \n\
</pre></div><p>When set to True, the proxy will be used by the production renderer.</p>\n\
<div class=\'codeBlock\'><pre>.useLocal : boolean : Read|Write\n\
</pre></div><p>Get/set the state of the <strong>&quot;Enable/Use Local&quot;</strong> property in the <strong>&quot;Proxy Object&quot;</strong> rollout.</p>\n\
<p>When set to False (default), the Proxy Object will not be used and the XRef content will be loaded instead.</p>\n\
<p>When set to True, the local Proxy Object will be loaded.</p>\n\
<p>Available in <strong>3ds Max 2016 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>Interface:IXRefObject \n\
</pre></div><p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>.activeFileName : filename : Read \n\
</pre></div><p>Contains the active file name.Read-only.</p>\n\
<div class=\'codeBlock\'><pre>.activeObjName : string : Read \n\
</pre></div><p>Contains the active object name.Read-only.</p>\n\
<div class=\'codeBlock\'><pre>.activeRecord : Interface : Read \n\
</pre></div><p>Contains the active record Interface.Read-only.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;maxObject&gt;GetSourceObject &lt;boolean&gt;resolveNestedXRef modifiers:&lt;&amp;maxObject array&gt; \n\
\n\
modifiers default value: #() \n\
modifiers is Out parameter \n\
</pre></div><p>Returns the source object. The optional modifiers: by-reference parameter will return the array of modifiers applied to the source object.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";