var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>XRefScene Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>XRefScene Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"xrefscene-values\"></a></div>\n\
<p>An <strong>XRefScene</strong> value represents an XRef Scene object in <strong>3ds Max</strong>. An XRefScene value is returned when the <span class=\'code\'>*xrefs.addNewXRefFile()*</span> and <span class=\'code\'>*xrefs.getXRefFile()*</span> functions are called.</p>\n\
<p>XRef Scene objects can be nested. For example, scene file A can contain an XRef Scene object specifying XRef file B, and XRef file B can contain an XRef Scene object specifying XRef file C (eg: A xrefs B, and B xrefs C). To provide access to the nested XRef scene objects, the applicable XRefScene methods provide an optional root keyword parameter. If this argument is provided then these methods act on the root node of the specified XRefScene value, otherwise they act on root node of the current scene. To get to C from A, you load A and do something like:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` bXref = xrefs.getXRefFile 1-- taken from root node of current scene cXref = xrefs.getXRefFile 1 root:bXref-- taken from root of bXref cRoot = cXref.tree -- to get root of C</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note:</p>\n\
<p>Scenes with a script controller whose script has explicit references ($sphere01, etc.) to objects in an incoming xref scene have a problem where the objects in the xref scene are invisible to MAXScript, and so the script will fail. This is actually a general problem with xrefs, you cannot have scripts of any kind in the xref scene (scripts controllers, param wires, callback scripts, etc.) that depend on explicit scene object references.</p>\n\
<p>This problem has been solved in <strong>3ds Max 8</strong> and higher where scripted controllers store references using parameter blocks and can resolve them within nested xrefs.</p>\n\
<p><strong>Constructor</strong></p>\n\
<div class=\'codeBlock\'><pre>xrefs.addNewXRefFile &lt;filename_string&gt; [        #noLoad] [      root: &lt;XRefScene&gt;]   \n\
</pre></div><p>Adds a new XRef Scene object and returns a XRefScene value. If <span class=\'code\'>*#noLoad*</span> is not specified, the XRef Scene file is loaded immediately and the scene updated. If <span class=\'code\'>*#noLoad*</span> is specified, the scene is not updated until the user requests it. Use the <span class=\'code\'>*updateXRef()*</span> method to load the XRef Scene object.</p>\n\
<p>If <span class=\'code\'>*root:&lt;XRefScene&gt;*</span> is specified, the XRef Scene object is treated in the current file during the current session as if it was an XRef Scene object in the file corresponding to the XRefScene value specified. If the specified root XRef Scene object is reloaded, either because the current scene was saved and then reloaded, or because <span class=\'code\'>*updateXRef()*</span> was executed on the root XRef Scene object, the XRef Scene object is deleted from the scene.</p>\n\
<p><span class=\'code\'>*xrefs.addNewXRefFile*</span> does not return an error when passed a DRF file - it will return a value different from undefined, and the xref-ed DRF file will appear in red, meaning that there is a &quot;problem&quot; with it. This behaviour is the same as if the user would have opened a DRF file in the File Xref Scene | Add dialog after choosing the All Files filter (<em>.</em>)</p>\n\
<div class=\'codeBlock\'><pre>xrefs.getXRefFile &lt;index&gt; [  root: &lt;XRefScene&gt;]   \n\
</pre></div><p>If <span class=\'code\'>*root*</span> is not specified, returns the XRefScene value corresponding to the indexed XRef Scene object in the XRef Scenes dialog. If the <span class=\'code\'>*root:&lt;XRefScene&gt;*</span> is specified, the XRefScene value corresponding to a nested XRef Scene object within the XRefScene&#39;s XRef Scene object is returned. The index is 1-based, and corresponds to the order of the XRef Scene objects listed in the XRef Scenes dialog. You can use the <span class=\'code\'>*xrefs.getXRefFileCount()*</span> method to determine the number of XRef Scene objects in the scene.</p>\n\
<div class=\'codeBlock\'><pre>&lt;RootNode&gt; as XRefScene\n\
</pre></div><p>Available in <strong>3ds Max 2018 and higher</strong>: The &quot;owning&quot; XRefScene for this XRef Scene object. This is a read-only property. If this is a top level XRefScene, this returns undefined .</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>aXref = xrefs.getXRefFile 1 --&gt; XRefScene:&quot;xrefed_teapot.max&quot;   bXref = xrefs.getXRefFile 1 root:aXref --&gt; XRefScene:&quot;teapot.max&quot;   aXref.owner --&gt; $&lt;root&gt;   classof aXref.owner --&gt; MAXRootNode   aXref.root --&gt; undefined   bXref.owner --&gt; $&lt;root&gt;   classof bXref.owner --&gt; MAXRootNode   bXref.root --&gt; XRefScene:&quot;xrefed_teapot.max&quot;   classof bXref.root --&gt; XRefScene</span></p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;XRefScene&gt;.tree : MAXRootNode\n\
</pre></div><p>The root node of the XRef Scene object. This is a read-only property. You can access the children objects in an XRef Scene object using this property.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` aXref=xrefs.getXRefFile 1-- returns first XRef Scene object aXref.tree.children-- objects in the XRef Scene object, -- for example, may return: -- #children($Box01, $Box02) aXref.tree.children[1].width-- returns width value of $Box01 -- Get user defined properties getUserPropBuffer (aXref.tree)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;XRefScene&gt;.parent Node default: undefined \n\
</pre></div><p>The parent of the XRef Scene object. By default this is <span class=\'code\'>*undefined*</span> but can be set to any node in the scene.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefScene&gt;.autoUpdate Boolean default: false \n\
</pre></div><p>If <strong>true</strong>, automatic XRef file updating is on.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefScene&gt;.boxDisp Boolean default: false \n\
</pre></div><p>If <strong>true</strong>, all nodes the in the XRef Scene object are displayed in Box display mode.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefScene&gt;.hidden Boolean default: false \n\
</pre></div><p>If <strong>true</strong>, the XRef Scene object is hidden.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefScene&gt;.disabled Boolean default: false \n\
</pre></div><p>If <strong>true</strong>, the XRef Scene object is disabled.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefScene&gt;.ignoreLights Boolean default: false \n\
</pre></div><p>If <strong>true</strong>, the lights in the XRef Scene object will not be displayed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefScene&gt;.ignoreCameras Boolean default: false \n\
</pre></div><p>If <strong>true</strong>, the cameras in the XRef Scene object will not be displayed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefScene&gt;.ignoreShapes Boolean default: false \n\
</pre></div><p>If <strong>true</strong>, the shapes in the XRef Scene object will not be displayed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefScene&gt;.ignoreHelpers Boolean default: false \n\
</pre></div><p>If <strong>true</strong>, the helpers in the XRef Scene object will not be displayed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefScene&gt;.ignoreAnimation Boolean default: false \n\
</pre></div><p>If <strong>true</strong>, any animation in the XRef Scene object will be ignored.</p>\n\
<div class=\'codeBlock\'><pre>&lt;XRefScene&gt;.overlay Boolean default: false \n\
</pre></div><p>If <strong>true</strong>, treats the XRef scene as an overlay. Overlays allow multiple scene references without the risk of creating circular dependencies. The XRef scene with <strong>overlay = true</strong> is loaded only into the main scene that references it, and is not visible in other scenes that might XRef the main file that uses the overlay.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>delete &lt;XRefScene&gt; \n\
</pre></div><p>Deletes the XRef Scene object.</p>\n\
<div class=\'codeBlock\'><pre>merge &lt;XRefScene&gt; \n\
</pre></div><p>Merges the nodes in the XRef Scene object into the scene and deletes the XRef Scene object.</p>\n\
<div class=\'codeBlock\'><pre>updateXRef &lt;XRefScene&gt; \n\
</pre></div><p>Tries to reload the XRef Scene object. Returns <span class=\'code\'>*true*</span> if the operation is successful, <span class=\'code\'>*false*</span> otherwise.</p>\n\
<div class=\'codeBlock\'><pre>flagChanged &lt;XRefScene&gt; \n\
</pre></div><p>This method indicates that the specified XRef Scene object has been changed and should be updated. Use the <span class=\'code\'>*xrefs.updateChangedXRefs()*</span> method to update the changed XRef Scene objects.</p>\n\
<p><strong>Associated Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>xrefs.getXRefFileCount [root: &lt;XRefScene&gt;] \n\
</pre></div><p>If <span class=\'code\'>*root*</span> is not specified, returns the total number of top-level XRef Scene objects in the scene. If the <span class=\'code\'>*root:&lt;XRefScene&gt;*</span> is specified, the total number of XRef Scene objects in the nested XRef file within the XRefScene&#39;s XRef file is returned.</p>\n\
<div class=\'codeBlock\'><pre>xrefs.deleteAllXRefs [root: &lt;XRefScene&gt;] \n\
</pre></div><p>If <span class=\'code\'>*root*</span> is not specified, deletes all XRef Scene objects. If the <span class=\'code\'>*root:&lt;XRefScene&gt;*</span> is specified, only the specified XRefScene&#39;s XRef Scene object, and its nested XRef Scene objects, are deleted.</p>\n\
<div class=\'codeBlock\'><pre>xrefs.updateChangedXRefs [#noRedraw] [root: &lt;XRefScene&gt;] \n\
</pre></div><p>If <span class=\'code\'>*root*</span> is not specified, updates all XRef Scene objects flagged as changed. If the <span class=\'code\'>*root:&lt;XRefScene&gt;*</span> is specified, only the specified XRefScene&#39;s XRef Scene objects flagged as changed are updated. If <span class=\'code\'>*#noRedraw*</span> is specified, the viewports won&#39;t be updated after the XRef Scene objects are loaded. Returns <span class=\'code\'>*true*</span> if the XRef Scene objects were loaded okay, otherwise <span class=\'code\'>*false*</span> .</p>\n\
<div class=\'codeBlock\'><pre>xrefs.findUnresolvedXRefs [root: &lt;XRefScene&gt;] \n\
</pre></div><p>If <span class=\'code\'>*root*</span> is not specified, returns an array of file name strings for all the unresolved XRef Scene objects. If the <span class=\'code\'>*root:&lt;XRefScene&gt;*</span> is specified, only the unresolved XRef Scene objects within the specified XRefScene&#39;s XRef Scene object are returned.</p>\n\
<div class=\'codeBlock\'><pre>xrefs.attemptUnresolvedXRefs [root: &lt;XRefScene&gt;] \n\
</pre></div><p>If <span class=\'code\'>*root*</span> is not specified, tries to load any XRef Scene objects that are currently unresolved. If the <span class=\'code\'>*root:&lt;XRefScene&gt;*</span> is specified, only the unresolved XRef Scene objects within the specified XRefScene&#39;s XRef Scene object are loaded.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";