var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Vector_Map TextureMap and MAXScript</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Vector_Map TextureMap and MAXScript</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"vector_map-texturemap-and-maxscript\"></a></div>\n\
<div class=\'section\'><a id=\"introduction\"></a><h2 id=\"introduction\">Introduction</h2></div>\n\
<p>The <strong><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-textureMap.html\' title=\'\'>Vector_Map TextureMap</a></strong> available in <strong>3ds Max 2014 and higher</strong> provides support for scalable vector graphics file formats including the standard SVG XML open standard developed by the World Wide Web Consortium. It also supports compressed SVG in .SVGZ format, Adobe Illustrator .AI files, Adobe Portable Document Format (.PDF) files and Autodesk AutoCAD Pattern (.PAT) files.</p>\n\
<p>In addition to the exposure of the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-textureMap.html\' title=\'\'>Vector_Map TextureMap</a> object to MAXScript documented here, the <strong>3ds Max</strong> implementation provides exclusive support for MAXScript functions and expressions inside the actual SVG XML file, allowing for a much tighter integration of vector graphics with the actual scene content. This includes the creation of dynamic vector graphics reacting the scene animation or depending on scene objects properties, text rendering and much more.</p>\n\
<p>This topic discusses the creation of SVG files using MAXScript, the inclusion of MAXScript commands inside the SVG XML source files, and provides some examples demonstrating the power of this feature.</p>\n\
<div class=\'section\'><a id=\"writing-svg-files\"></a><h2 id=\"writing-svg-files\">Writing SVG Files</h2></div>\n\
<div class=\'section\'><a id=\"basic-format-structure\"></a><h3 id=\"basic-format-structure\">Basic Format Structure</h3></div>\n\
<p>The SVG file is a XML text file. Its content is enclosed in <span class=\'code\'>&lt;svg&gt;</span> tags, which identifies the content as Scalable Vector Graphics definition.</p>\n\
<p>Inside the body of the SVG file, one or more entities can be defined, including rectangles, circles, ellipses, lines, polylines, polygons, images and texts.</p>\n\
<p>The outside color (stroke color) and inside color (fill color) can be defined as hexadecimal values. Patterns and Gradients can also be used instead of solid colors.</p>\n\
<p>Various properties specific for each entity can be defined, otherwise they will be assumed to have default values.</p>\n\
<p>Entities can be transformed and grouped for convenience.</p>\n\
<blockquote>\n\
<p><strong>SIMPLEST EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>&lt;svg  xmlns=&quot;http://www.w3.org/2000/svg&quot;         xmlns:xlink=&quot;http://www.w3.org/1999/xlink&quot;&gt;       &lt;rect x=&quot;255&quot; y=&quot;255&quot; height=&quot;512&quot; width=&quot;512&quot;             style=&quot;stroke:#ff8800; fill: #0000aa&quot;/&gt;   &lt;/svg&gt;</span></p>\n\
<p>Save this code in a new text file under the name &quot;Rectangle.svg&quot; in your 3ds Max UserScripts folder.</p>\n\
<p>Then create a Vector_Map TextureMap and load this code as the Vector File.</p>\n\
<p>Then render the resulting map into bitmaps with different resolutions - 160x160, 320x320 and 640x320.</p>\n\
<p>You can do this manually, or using MAXScript:</p>\n\
<p>``` theSVGMap = VectorMap() theSVGMap.vectorfile = GetDir #userscripts + &quot;\\rectangle.svg&quot; for i in #([160,160], [320,320], [640,480]) do display (renderMap theSVGMap size:i filter:true)</p>\n\
<p>```</p>\n\
<p>Evaluating the above MAXScript will render 3 images with different resolutions from the same scalable graphics definition.</p>\n\
<p>Here are the resulting images:</p>\n\
<p><img src=\'developer/images/GUID-2BEAD532-739D-4D92-98C3-D344446A35B4-low.png\' title=\'\'> <img src=\'developer/images/GUID-ACFB8CDF-C131-4B3E-AD86-C92451244472-low.png\' title=\'\'></p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-BBE441AB-CBDC-4E79-BB27-648AB9DB9263-low.png\' title=\'\'></div>\n\
</blockquote>\n\
<p>Let&#39;s discuss the content of the SVG file to understand how it works.</p>\n\
<p>The 3ds Max Vector_Map TextureMap assumes that the Canvas the graphics are drawn into is 1024x1024 units in size.</p>\n\
<p>The origin [0,0] is the upper left corner, just like in MAXScript Bitmap values. The coordinate of the bottom right corner is [1023,1023]</p>\n\
<p>Thus, when specifying the Position and Size of an entity, we have to assume that the center of the Canvas is at [511,511]. Specifying the upper left corner of the Rectangle at x=255 and y=255 and giving it a width and height of 512 units aligns it at the Canvas&#39; center.</p>\n\
<p>This Canvas size assumption is specific for 3ds Max and does not necessarily apply to SVG and other vector graphics files coming from other sources. That&#39;s why the Vector_Map provides Cropping controls to extract only a portion of the rasterized bitmap if the entities were defined in other coordinates.</p>\n\
<div class=\'section\'><a id=\"applying-transformations\"></a><h3 id=\"applying-transformations\">Applying Transformations</h3></div>\n\
<p>Let&#39;s rotate the rectangle that we created at 45 degrees about its center.</p>\n\
<blockquote>\n\
<p><strong>TRANSFORMATIONS EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>&lt;svg  xmlns=&quot;http://www.w3.org/2000/svg&quot;         xmlns:xlink=&quot;http://www.w3.org/1999/xlink&quot;&gt;       &lt;rect x=&quot;255&quot; y=&quot;255&quot; height=&quot;512&quot; width=&quot;512&quot;             style=&quot;stroke:#ff8800; fill: #0000aa&quot;             transform=&quot;rotate(45 511 511)&quot; /&gt;   &lt;/svg&gt;</span></p>\n\
<p>Re-save this code in the same text file under the name &quot;Rectangle.svg&quot; in your 3ds Max UserScripts folder.</p>\n\
<p>Update the Vector_Map either manually in the Material Editor, or via MAXScript using <span class=\'code\'>theSVGMap.reload()</span></p>\n\
<p>Render the resulting map into a bitmap with resolutions of 320x320.</p>\n\
<p><span class=\'code\'>theSVGMap.reload()   display (renderMap theSVGMap size:[320,320] filter:true)</span></p>\n\
<p>Evaluating this script will render the scalable graphics definition and display the bitmap.</p>\n\
<p>Here are the resulting image:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-E7224255-4D6D-4902-874B-0502CBAEF679-low.png\' title=\'\'></div>\n\
<p>Let&#39;s also translate the shape 150 units along X before we have rotated it.</p>\n\
<p>When multiple transformations are specified, each one modifies the current coordinate system in the given order:</p>\n\
<p><span class=\'code\'>&lt;svg  xmlns=&quot;http://www.w3.org/2000/svg&quot;         xmlns:xlink=&quot;http://www.w3.org/1999/xlink&quot;&gt;       &lt;rect x=&quot;255&quot; y=&quot;255&quot; height=&quot;512&quot; width=&quot;512&quot;             style=&quot;stroke:#ff8800; fill: #0000aa&quot;             transform=&quot;translate(150) rotate(45 511 511)&quot; /&gt;   &lt;/svg&gt;</span></p>\n\
<p>Saving the SVG definition and running the same MAXScript as above produces the following:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-A2774E00-DEF1-4CA4-B644-2944EA37559C-low.png\' title=\'\'></div>\n\
<p>In the above case, the translation was applied before the rotation, so the coordinate system was first shifted to the right, then the rotation was performed.</p>\n\
<p>If we were to specify the Translation after the rotation, the rotation will occur first, then the translation will occur in the already rotated coordinate system.</p>\n\
<p><span class=\'code\'>&lt;svg  xmlns=&quot;http://www.w3.org/2000/svg&quot;         xmlns:xlink=&quot;http://www.w3.org/1999/xlink&quot;&gt;       &lt;rect x=&quot;255&quot; y=&quot;255&quot; height=&quot;512&quot; width=&quot;512&quot;             style=&quot;stroke:#ff8800; fill: #0000aa&quot;             transform=&quot;rotate(45 511 511) translate(150)&quot; /&gt;   &lt;/svg&gt;</span></p>\n\
<p>In this case, the X axis is pointing at the bottom right corner, and the rectangle is shifted diagonally 150 units in that direction:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-8BDB0C8E-C1CF-4465-85A1-0ED22E32102F-low.png\' title=\'\'></div>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"creating-text\"></a><h3 id=\"creating-text\">Creating Text</h3></div>\n\
<blockquote>\n\
<p><strong>TEXT EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>&lt;svg  xmlns=&quot;http://www.w3.org/2000/svg&quot;     xmlns:xlink=&quot;http://www.w3.org/1999/xlink&quot;&gt;     &lt;rect x=&quot;255&quot; y=&quot;255&quot; height=&quot;512&quot; width=&quot;512&quot;       transform=&quot;rotate(45 511 511)&quot;       style=&quot;stroke:#ffff00; fill:#001166&quot;&gt;     &lt;/rect&gt;         &lt;text x=&quot;255&quot; y=&quot;255&quot;       transform=&quot;rotate(45 511 511) translate(15 280)&quot;       style=&quot;stroke:#000000; fill:#008800; font-size:100; font-family:Arial&quot;&gt;       MAXScript     &lt;/text&gt;            &lt;/svg&gt;</span></p>\n\
<p>Save this code in a new text file under the name &quot;RectangleText.svg&quot; in your 3ds Max UserScripts folder.</p>\n\
<p>Run the following MAXScript.</p>\n\
<p>``` theSVGMap = VectorMap() theSVGMap.vectorfile = GetDir #userscripts + &quot;\\RectangleText.svg&quot; display (renderMap theSVGMap size:[320,320] filter:true)</p>\n\
<p>```</p>\n\
<p>Evaluating this script will render the following image:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-BF055C8A-C9C2-4024-943D-00F3B1E70BCD-low.png\' title=\'\'></div>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"defining-gradients-stroke-width-and-corner-radii\"></a><h3 id=\"defining-gradients-stroke-width-and-corner-radii\">Defining Gradients, Stroke Width And Corner Radii</h3></div>\n\
<p>Instead of filling the shape with a solid color, we could define a named Gradient and use it in place of the color for the rectangle&#39;s fill: parameter.</p>\n\
<p>This Gradient will have the id &quot;LinearGradient&quot; and will interpolate linearly along the Y axis from a dark blue color with zero opacity to a brighter blue color with full opacity.</p>\n\
<p>In the Rectangle&#39;s definition, we will use the id &quot;LinearGradient&quot; to pass this definition to the fill: parameter.</p>\n\
<p>We will also set the corner radii to 30 units and the stroke width of both the rectangle and the text to 3 units.</p>\n\
<blockquote>\n\
<p><strong>GRADIENT EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>&lt;svg  xmlns=&quot;http://www.w3.org/2000/svg&quot;     xmlns:xlink=&quot;http://www.w3.org/1999/xlink&quot;&gt;     &lt;defs&gt;       &lt;linearGradient id=&quot;LinearGradient1&quot;         x1=&quot;0%&quot; y1=&quot;0%&quot;         x2=&quot;0%&quot; y2=&quot;100%&quot;         spreadMethod=&quot;pad&quot;&gt;         &lt;stop offset=&quot;0%&quot;   stop-color=&quot;#001166&quot; stop-opacity=&quot;0&quot;/&gt;         &lt;stop offset=&quot;100%&quot; stop-color=&quot;#0055aa&quot; stop-opacity=&quot;1&quot;/&gt;       &lt;/linearGradient&gt;     &lt;/defs&gt;          &lt;rect x=&quot;255&quot; y=&quot;255&quot; height=&quot;512&quot; width=&quot;512&quot; rx=&quot;30&quot; ry=&quot;30&quot;       transform=&quot;rotate(45 511 511)&quot;       style=&quot;stroke:#ffff00; fill:url(#LinearGradient1); stroke-width: 10&quot;&gt;     &lt;/rect&gt;          &lt;text x=&quot;255&quot; y=&quot;255&quot;        transform=&quot;rotate(45 511 511) translate(15 280)&quot;       style=&quot;stroke:#000000; stroke-width:3; fill:#008800; font-size : 100; font-family:Arial&quot;&gt;       MAXScript     &lt;/text&gt;            &lt;/svg&gt;</span></p>\n\
<p>Save this code in a new text file under the name &quot;RectangleGradientAndText.svg&quot; in your 3ds Max UserScripts folder.</p>\n\
<p>Run the following MAXScript. We are now rendering into a pre-created bitmap in order to produce a correct Alpha channel.</p>\n\
<p>``` theSVGMap = VectorMap alphasource:0 --enable Alpha theSVGMap.vectorfile = GetDir #userscripts + &quot;\\RectangleGradientAndText.svg&quot; theImage = bitmap 320 320 --create a bitmap with the desired size renderMap theSVGMap into:theImage filter:true --render into that bitmap display theImage --display the bitmap</p>\n\
<p>```</p>\n\
<p>Evaluating this script will render the following image, and the alpha channel will reflect correctly the gradient&#39;s varying opacity:</p>\n\
<p><img src=\'developer/images/GUID-59FC9887-A93D-4600-98E6-CED9151EAAD1-low.png\' title=\'\'> <img src=\'developer/images/GUID-A1877FD3-AA69-4A2F-B871-0575E1BFBA4F-low.png\' title=\'\'></p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"online-documentation\"></a><h3 id=\"online-documentation\">Online Documentation</h3></div>\n\
<p>The official website of the SVG format http://www.w3.org/Graphics/SVG/ contains the current specification.</p>\n\
<p>Several SVG Introductions and Tutorials can be found online.</p>\n\
<div class=\'section\'><a id=\"generating-svg-files-using-maxscript\"></a><h2 id=\"generating-svg-files-using-maxscript\">Generating SVG Files Using MAXScript</h2></div>\n\
<p>Instead of typing the SVG text files by hand, we can employ MAXScript&#39;s ability to write ASCII Text Files to create SVG files procedurally.</p>\n\
<p>For example, let&#39;s create a function for outputting a circle with specific radius and colors at a user-defined position and call that function multiple times using MAXScript FOR loops.</p>\n\
<p>We will also need a function to convert a MAXScript color value to a Hexadecimal color value as used by XML and HTML.</p>\n\
<p>Note: &#39;Single quotes&#39; can be used in place of &quot;double quotes&quot; inside the SVG file - this makes the MAXScript output easier since we don&#39;t have to escape them as \\&quot;</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` ( --The following function converts a MAXScript color value to a Hexadecimal color value fn ColorToHex col = ( theComponents = #(bit.intAsHex col.r, bit.intAsHex col.g, bit.intAsHex col.b) theValue = &quot;#&quot; for i in theComponents do theValue += (if i.count == 1 then &quot;0&quot; else &quot;&quot;) + i theValue )</p>\n\
<p>--The following function outputs a basic circle definition to a given SVG file: fn createSVGCircle SVGFile pos radius:100 stroke:yellow fill:red thick:1 = ( format &quot;&lt;circle cx=&#39;%&#39; cy=&#39;%&#39; r=&#39;%&#39; \\n&quot; pos.x pos.y radius to:SVGFile format &quot;\\tstyle=&#39;stroke:%; fill:%; stroke-width:%&#39; &gt;\\n&quot; (ColorToHex stroke) (ColorToHex fill) thick to:SVGFile format &quot;\\n&quot; to:SVGFile )</p>\n\
<p>theSVGFilename = GetDir #userScripts + &quot;\\Circles.svg&quot; --Define an output file name theSVGFile = createFile theSVGFilename --Create a text file format &quot;&lt;svg xmlns=&quot;http://www.w3.org/2000/svg&quot;\\n&quot; to:theSVGfile --Output the SVG header lines format &quot;\\t\\txmlns:xlink=&quot;http://www.w3.org/1999/xlink&quot;&gt;\\n&quot; to:theSVGfile</p>\n\
<p>theStep = 100 --This is the step in pixels along both X and Y for y = 0 to 1024 by theStep do --Loop along Y and X with the given Step for x = 0 to 1024 by theStep do --and create circles with position and fill color based on the loops: createSVGCircle theSVGFile [x,y] radius:(theStep/2) stroke:white fill:(color (x/4) (y/4) 100) thick:5</p>\n\
<p>format &quot;\\n&quot; to:theSVGfile --End of the SVG body definition close theSVGfile --Close the file</p>\n\
<p>theSVGMap = VectorMap() --Create a new Vector_Map instance theSVGMap.vectorFile = theSVGFilename --Assign the output file to the new map display (renderMap theSVGMap size:[512,512] filter:true) --Render the map at 512 resolution and display ) ```</p>\n\
<p>Here is the resulting map rendered as image:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-C85B1FE6-964D-4221-A095-EDFDD1F8E9EA-low.png\' title=\'\'></div>\n\
<p>By just changing theStep variable from 100 to 50, we can easily produce more and smaller circles:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-23E33D80-F709-4A54-A407-F2641EC6E6D3-low.png\' title=\'\'></div>\n\
<p>Let&#39;s modify the loop further - we can shift every second row by half the step to the side and reduce the Y loop to use half the step.</p>\n\
<p>We will also use a Stroke Thickness of 2 to produce finer outlines:</p>\n\
<p><span class=\'code\'>--Partial Code Fragment - insert in the above script!   theStep = 50   cnt = 0 --introduce a counter variable   for y = 0 to 1024 by theStep/2 do --divide the vertical step by two   (       cnt = 1-cnt --change the counter between 0 and 1 after each row       for x = 0 to 1024 by theStep do --shift the X by half the step multiplied by the counter (0 or 1):       (           createSVGCircle theSVGFile [x+(theStep/2*cnt),y] radius:(theStep/2) stroke:white fill:(color (x/4) (y/4) 100) thick:2       )   )   --End Code Fragment</span></p>\n\
<p>The result looks like scales!</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-1F74973D-77A8-4C4D-B40B-0BC27CB3BD86-low.png\' title=\'\'></div>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"including-static-scene-properties\"></a><h2 id=\"including-static-scene-properties\">Including Static Scene Properties</h2></div>\n\
<p>Since MAXScript can easily read properties of scene objects, we could output scene geometry (for example spline shapes) to SVG and thus turn the 3ds Max viewports into a simple SVG Editor!</p>\n\
<p>For example, we can take the Circle drawing function above and implement similar functions for the other typical shapes including Rectangle, Ellipse etc.</p>\n\
<p>Then, we can run through the <strong>3ds Max</strong> scene and when we encounter a matching spline primitive, we can grab its properties and output to the SVG file.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` ( fn ColorToHex col = ( theComponents = #(bit.intAsHex col.r, bit.intAsHex col.g, bit.intAsHex col.b) theValue = &quot;#&quot; for i in theComponents do theValue += (if i.count == 1 then &quot;0&quot; else &quot;&quot;) + i theValue )</p>\n\
<p>fn getFillColor obj = ( if classof obj.material == Standard then obj.material.diffusecolor else obj.wirecolor )</p>\n\
<p>fn getPos obj = ( [obj.pos.x, -obj.pos.y] )</p>\n\
<p>fn createSVGCircle SVGFile pos radius:100 stroke:yellow fill:red thick:1 = ( format &quot;&lt;circle cx=&#39;%&#39; cy=&#39;%&#39; r=&#39;%&#39; \\n&quot; pos.x pos.y radius to:SVGFile format &quot;\\tstyle=&#39;stroke:%; fill:%; stroke-width:%&#39; &gt;\\n&quot; (ColorToHex stroke) (ColorToHex fill) thick to:SVGFile format &quot;\\n&quot; to:SVGFile )</p>\n\
<p>fn createSVGEllipse SVGFile pos rx:100 ry:50 stroke:yellow fill:green thick:1 = ( format &quot;&lt;ellipse cx=&#39;%&#39; cy=&#39;%&#39; rx=&#39;%&#39; ry=&#39;%&#39;\\n&quot; pos.x pos.y rx ry to:SVGFile format &quot;\\tstyle=&#39;stroke:%; fill:%; stroke-width:%&#39; &gt;\\n&quot; (ColorToHex stroke) (ColorToHex fill) thick to:SVGFile format &quot;\\n&quot; to:SVGFile )</p>\n\
<p>fn createSVGRect SVGFile pos w:100 h:100 rx:0 stroke:yellow fill:blue thick:1 = ( format &quot;&lt;rect x=&#39;%&#39; y=&#39;%&#39; width=&#39;%&#39; height=&#39;%&#39; rx=&#39;%&#39; ry=&#39;%&#39;\\n&quot; pos.x pos.y w h rx rx to:SVGFile format &quot;\\tstyle=&#39;stroke:%; fill:%; stroke-width:%&#39; &gt;\\n&quot; (ColorToHex stroke) (ColorToHex fill) thick to:SVGFile format &quot;\\n&quot; to:SVGFile )</p>\n\
<p>fn createSVGText SVGFile pos textString:&quot;SVG&quot; fontSize:100 stroke:green fill:orange thick:1 = ( format &quot;&lt;text x=&#39;%&#39; y=&#39;%&#39;\\n&quot; pos.x pos.y to:SVGFile format &quot;\\tstyle=&#39;font-size:%; font-family:Arial; stroke:%; fill:%; stroke-width:%&#39; &gt;\\n&quot; fontSize (ColorToHex stroke) (ColorToHex fill) thick to:SVGFile format &quot;%\\n&quot; textString to:SVGFile )</p>\n\
<p>theSVGFilename = GetDir #userScripts + &quot;\\MaxShapes.svg&quot; theSVGFile = createFile theSVGFilename format &quot;&lt;svg xmlns=&quot;http://www.w3.org/2000/svg&quot;\\n&quot; to:theSVGfile format &quot;\\t\\txmlns:xlink=&quot;http://www.w3.org/1999/xlink&quot;&gt;\\n&quot; to:theSVGfile</p>\n\
<p>for obj in objects do ( local o = obj.baseobject if superclassof o == Shape do (<br> case classof o of ( Circle: createSVGCircle theSVGFile [obj.pos.x,-obj.pos.y] radius:o.radius stroke:obj.wirecolor fill:(getFillColor obj) thick:o.thickness Ellipse: createSVGEllipse theSVGFile [obj.pos.x,-obj.pos.y] rx:(o.width/2) ry:(o.length/2) stroke:obj.wirecolor fill:(getFillColor obj) thick:o.thickness Rectangle: createSVGRect theSVGFile [obj.min.x,-obj.max.y] w:o.width h:o.length rx:o.cornerRadius stroke:obj.wirecolor fill:(getFillColor obj) thick:o.thickness Text: createSVGText theSVGFile [obj.min.x,-obj.min.y] textString:o.text fontSize:o.size stroke:obj.wirecolor fill:(getFillColor obj) thick:o.thickness ) ) ) format &quot;\\n&quot; to:theSVGfile close theSVGfile</p>\n\
<p>theSVGMap = VectorMap() theSVGMap.vectorFile = theSVGFilename display (renderMap theSVGMap size:[512,512] filter:true) ) ```</p>\n\
<p>Here is a screenshot of a scene containing a green Circle, a dark red Rectangle, a purple Ellipse and an orange Text shape.</p>\n\
<p>The Circle has a Radius of 100 and no material or modifiers.</p>\n\
<p>The Rectangle is 300x200 units and has Corner Radius of 50; its Renderable property checked, has a Thickness of 5 and a Standard Material with blue diffuse color assigned.</p>\n\
<p>The Ellipse with size 200x150 has its Thickness set to 10, a MeshSelect modifier on the stack, and has a yellow Standard Material assigned.</p>\n\
<p>The Text has no material and a MeshSelect modifier on the stack.</p>\n\
<p>These objects were placed in the bottom right quadrant of the World Origin, so that their Y coordinates are negative, with the origin in the upper left corner. A green Point Helper shows the position of the 1023,1023 coordinate.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-EA9F58F0-6A4F-4A96-94FF-B89578286132-low.png\' title=\'\'></div>\n\
<p>Running the above script produces the following image:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-1C836F95-75B3-4499-AFB7-1EF70A74ACD9-low.png\' title=\'\'></div>\n\
<p>Note that the order of object creation was reflected in the order of shape drawing. The stroke color was taken from the wireframe (object) color; the fill color was taken from the Standard Material&#39;s diffuse color, or from the wirecolor property when there was no Material. The Renderable Thickness property was also respected.</p>\n\
<p>Also note that the above script would not take rotations into account and would require significant modifications to support them due to the difference in coordinate systems and object pivot points between 3ds Max and SVG.</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"setting-the-svg-definition-without-external-file\"></a><h2 id=\"setting-the-svg-definition-without-external-file\">Setting the SVG Definition Without External File</h2></div>\n\
<p>The <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-textureMap.html\' title=\'\'>Vector_Map TextureMap</a> provides a dedicated method <span class=\'code\'>.SetSvgString()</span> which can be used to pass the SVG XML definition as a string value without pointing at a file on disk.</p>\n\
<p>This means that MAXScript could build a complete SVG description in a String variable or a StringStream and then pass that to the Vector_Map directly.</p>\n\
<div class=\'section\'><a id=\"using-the-mxs-token-in-svg-files\"></a><h2 id=\"using-the-mxs-token-in-svg-files\">Using the MXS Token In SVG Files</h2></div>\n\
<p>MAXScript can not only be used to generate SVG files, the <strong>3ds Max</strong> <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-textureMap.html\' title=\'\'>Vector_Map TextureMap</a> includes advanced support for MAXScript code embedded in the SVG file itself!</p>\n\
<p>The special <strong>mxs</strong> token (short for MAXScript) can be used inside the SVG file to include the result of any MAXScript expression in the XML description, as long as it is a String value.</p>\n\
<p>This opens the door for much deeper integration of SVG maps with MAXScript and <strong>3ds Max</strong>.</p>\n\
<p>Not only can SVG objects access <strong>3ds Max</strong> scene values dynamically, but the Vector_Map will be updated on time changes, allowing for animated maps based on animated scene parameters!</p>\n\
<blockquote>\n\
<p><strong>ANIMATED SVG EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>&lt;svg xmlns=&quot;http://www.w3.org/2000/svg&quot;           xmlns:xlink=&quot;http://www.w3.org/1999/xlink&quot;&gt;   &lt;rect x=&#39;0.0&#39; y=&#39;800.0&#39; width=&#39;1024.0&#39; height=&#39;100.0&#39;       style=&#39;stroke:#e4d699; fill:#e4d699; stroke-width:1.0&#39; &gt;   &lt;/rect&gt;   &lt;ellipse cx=&#39;mxs(at time currentTime $Ellipse001.pos.x as string)&#39;        cy=&#39;mxs(at time currentTime (-$Ellipse001.pos.y) as string)&#39;        rx=&#39;mxs(at time currentTime ($Ellipse001.width/2) as string)&#39;        ry=&#39;mxs(at time currentTime ($Ellipse001.length/2) as string)&#39;       style=&#39;stroke:#ffffff; fill:#b8e499; stroke-width:3.0&#39; &gt;   &lt;/ellipse&gt;   &lt;/svg&gt;</span></p>\n\
<p>Saving the above SVG file and loading it with a Vector_Map will produce an animated texture following the Position and Radius animation of an Ellipse001 object in the scene.</p>\n\
<p>Assigning that Vector_Map texture to the Diffuse channel of a Standard Material and assigning it to a Plane produces a dynamic real-time rendering &quot;screen&quot; in the viewport showing the same animation. In addition, the Map display in the Material Editor will also render and show the animation:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-5D1D691F-A033-4F48-A0E4-C804956FA082-low.gif\' title=\'\'></div>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"including-maxscript-.ms-files-in-svg-files\"></a><h2 id=\"including-maxscript-.ms-files-in-svg-files\">Including MAXScript .MS Files In SVG Files</h2></div>\n\
<p>Instead of using inline MAXScript expressions, the <span class=\'code\'>mxs()</span> token inside the SVG file can contain function calls to MAXScript functions defined in an external .MS file. This makes the most sense in cases where the calculations are more complex, or the script code has to be modified often and it would be more convenient to separate the MAXScript calculation from the SVG definition.</p>\n\
<p>The SVG file has to call the MAXScript <span class=\'code\'>include()</span> function just once with that external .MS file as argument, and any functions defined in it will be accessible to the rest of the SVG body to be called via <span class=\'code\'>mxs()</span> . These functions must return String values to be included in the SVG stream.</p>\n\
<p>Note: The <span class=\'code\'>include()</span> call <strong>requires double-quotes</strong> for the file name. If the <span class=\'code\'>include()</span> call has to be inserted within an SVG property value, the SVG value <strong>must</strong> be in <strong>single quotes</strong> to co-exist with the MAXScript call.</p>\n\
<blockquote>\n\
<p><strong>MAXSCRIPT INCLUDE FILE:</strong></p>\n\
<p><span class=\'code\'>fn getUserName =   (       sysinfo.username --this is already a string   )   fn getComputerName =    (       sysinfo.computername --this is already a string   )   fn getNumCPUs =   (       sysinfo.cpucount as string --this is an Integer, so needs conversion to string   )</span></p>\n\
<p>Save the above code to &quot;TextIncludeFn.ms&quot; in your UserScripts folder (getDir #userscripts)</p>\n\
<p><strong>SVG FILE:</strong></p>\n\
<p><span class=\'code\'>&lt;svg  xmlns=&quot;http://www.w3.org/2000/svg&quot;     xmlns:xlink=&quot;http://www.w3.org/1999/xlink&quot;&gt;     &lt;text x=&#39;100&#39; y=&#39;300&#39;       style=&#39;stroke:#00FF88; fill:#005588; font-size:70; font-family:Arial&#39;&gt;       Hello mxs(include &quot;TextIncludeFn.ms&quot; getUserName())!     &lt;/text&gt;              &lt;text x=&#39;100&#39; y=&#39;400&#39;       style=&#39;stroke:#00FF88; fill:#005588; font-size:70; font-family:Arial&#39;&gt;       Your Computer mxs(getComputerName())     &lt;/text&gt;              &lt;text x=&#39;100&#39; y=&#39;500&#39;       style=&#39;stroke:#00FF88; fill:#005588; font-size:70; font-family:Arial&#39;&gt;       has mxs(getNumCPUs()) CPUs     &lt;/text&gt;            &lt;/svg&gt;</span></p>\n\
<p>Save the above SVG definition as &quot;TextIncludeFn.svg&quot; in the same folder as the .MS file - (getDir #userscripts)</p>\n\
<p>Note that the include() call is performed just once before the first use of getUserName(), all further mxs function calls don&#39;t need the .MS file re-included!</p>\n\
<p><strong>CREATE VECTORMAP TEXTUREMAP:</strong></p>\n\
<p><span class=\'code\'>theVMap = VectorMap() --create a vector map   theSVGFileName = GetDir #userScripts + &quot;\\\\TextIncludeFn.svg&quot; --define the file name of the SVG map source   theVMap.vectorfile = theSVGFileName --assign the SVG file to the map   theTextImage = bitmap 512 512 --create an image for the text   renderMap theVMap into:theTextImage filter:true --render the Vector Map into the image   display theTextImage --display the resulting image</span></p>\n\
<p><strong>RESULT EXAMPLE:</strong></p>\n\
<div class=\'codeBlock\'><pre>![](../../../../images/GUID-23DC48D7-904C-41C4-92C4-84C10055D83D-low.png)\n\
</pre></div></blockquote>\n\
<div class=\'section\'><a id=\"using-svg-to-render-text-to-bitmap\"></a><h2 id=\"using-svg-to-render-text-to-bitmap\">Using SVG To Render Text To Bitmap</h2></div>\n\
<p>In the following example, we will use the text rendering capabilities of the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-textureMap.html\' title=\'\'>Vector_Map TextureMap</a> to generate a bitmap containing render time information.</p>\n\
<p>We will create a bitmap using the <span class=\'code\'>renderMap()</span> function and overlay it on top of an image produced using the <span class=\'code\'>render()</span> function.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>renderW = 640 --define the render output width   renderH = 480 --define the render output height   textSize = 20 --define the overlay text&#39;s height in pixels   theImage = bitmap renderW renderH --define a bitmap for the render output   st = timestamp() --get a timestamp before rendering   render to:theImage vfb:off --render the scene into the existing bitmap   et = timestamp() --get a time stamp after rendering   theTime = &quot;Image Render Time: &quot; +((et-st)/1000.0) as string + &quot; seconds.&quot; --define the text to overlay   theVMap = VectorMap() --create a vector map   theSVGFileName = GetDir #userScripts + &quot;\\\\RenderInfoMap.svg&quot; --define the file name of the SVG map source   theSVGFileHandle = createFile theSVGFileName --create a new text file with that name   format &quot;&lt;svg xmlns=\\&quot;http://www.w3.org/2000/svg\\&quot;\\n&quot; to:theSVGFileHandle --define the svg header   format &quot;\\txmlns:xlink=\\&quot;http://www.w3.org/1999/xlink\\&quot;&gt;\\n&quot; to:theSVGFileHandle   format &quot;\\t&lt;text x=&#39;0&#39; y=&#39;%&#39;\\n&quot; textSize to:theSVGFileHandle --define the text position   format &quot;\\t\\tstyle=&#39;font-size : %;\\n&quot; textSize to:theSVGFileHandle --define the text font size   format &quot;\\t\\tfont-family: Arial; \\n&quot; to:theSVGFileHandle --define the text font family   --format &quot;\\t\\tstroke: #ffffff;\\n&quot; to:theSVGFileHandle --define the text outline. Bad Idea, makes it too thick   format &quot;\\t\\tfill: #ffffff\\n&quot; to:theSVGFileHandle --define the fill color of the text as white   format &quot;\\t\\t&#39;\\n&quot; to:theSVGFileHandle --close the font style definition   format &quot;\\t&gt;%&lt;/text&gt;\\n&quot; theTime to:theSVGFileHandle --output the text to display   format &quot;&lt;/svg&gt;\\n&quot; to:theSVGFileHandle --end the SVG definition   close theSVGFileHandle --close the SVG file   theVMap.vectorfile = theSVGFileName --assign the SVG file to the map   theVMap.alphasource = 0 --enable Alpha output   theTextImage = bitmap 1000 1000 --create an image for the text   renderMap theVMap into:theTextImage filter:true --render the Vector Map into the image   --composite the text from the image onto the rendered image   pasteBitmap theTextImage theImage (box2 0 0 1000 (textSize*2.0)) [5,renderH-(textSize*1.5)] type:#composite   display theImage --display the result</span></p>\n\
<p><strong>RESULT EXAMPLE:</strong></p>\n\
<div class=\'codeBlock\'><pre>![](../../../../images/GUID-373A756F-BDD6-43CC-917B-34A95FBC8083-low.png)\n\
</pre></div></blockquote>\n\
<div class=\'section\'><a id=\"learn-more-about-svg-and-vector_map\"></a><h2 id=\"learn-more-about-svg-and-vector_map\">Learn More About SVG and Vector_Map</h2></div>\n\
<p>A three-part tutorial in the How To... section demonstrates the use of the Vector_Map and the SVG format to render geometry objects as polygons:</p>\n\
<ul>\n\
<li><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-An-SVG-Polygon/How-To-Develop-An-SVG-Polygon-1.html\' title=\'\'>How To ... Develop An SVG Polygon Renderer - Part 1</a> - Basic Flat Rendering</li>\n\
<li><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-An-SVG-Polygon/How-To-Develop-An-SVG-Polygon-2.html\' title=\'\'>How To ... Develop An SVG Polygon Renderer - Part 2</a> - Back-To-Front Sorted Rendering</li>\n\
<li><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-An-SVG-Polygon/How-To-Develop-An-SVG-Polygon-3.html\' title=\'\'>How To ... Develop An SVG Polygon Renderer - Part 3</a> - Facets with Blinn Lighting and Shading</li>\n\
</ul>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";