var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>BakeToTexture : UtilityPlugin</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>BakeToTexture : UtilityPlugin</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"baketotexture-utilityplugin\"></a></div>\n\
<p>Provides access to the <strong>Bake To Texture</strong> dialog and it&#39;s functionality. <strong>Available in 3ds Max 2021 and higher.</strong>Note: there are some new additions in <strong>3ds Max 2021.1 Update</strong>, as indicated below.</p>\n\
<p><strong>Constructor:</strong></p>\n\
<div class=\'codeBlock\'><pre>class instances not creatable by MAXScript\n\
</pre></div><p><strong>Interface: BakeToTexture</strong></p>\n\
<p>This interface provides access to the functionality of the Bake to Texture dialog, including output file options, file types and sizes, and the baking process. The <span class=\'code\'>BakeToTextureMap</span> interface (described below) exposes the functionality of individual bake maps themselves.</p>\n\
<p>See <a href=\'BakeToTexture-UtilityPlugin.html#full-example\' title=\'\'>the sample</a> at the end of this topic for an illustration of how to use some of these APIs together.</p>\n\
<p><strong>Properties:</strong>:</p>\n\
<div class=\'codeBlock\'><pre>BakeToTexture.outputPath : string : Read|Write\n\
</pre></div><p>Gets or sets the output path for baked map files.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTexture.autoCloseProgressDialog : boolean : Read|Write\n\
</pre></div><p>Gets or sets whether the progress dialog closes immediately after all the maps in the queue have been baked. If set to false, the dialog remains open after the process completes.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTexture.showFrameBuffer : boolean : Read|Write\n\
</pre></div><p>Specifies whether to show the frame buffer window during the baking process.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTexture.alwaysOverwriteExistingFiles : boolean : Read|Write\n\
</pre></div><p>Specifies whether to overwrite existing map files.</p>\n\
<p>When <strong>true</strong> existing files are replaced when new files are generated in the baking process, and the <span class=\'code\'>alwaysSkipExistingFiles</span> property is set to <strong>false</strong>.</p>\n\
<p>When <strong>false</strong>, existing files are not replaced. If both this property and the <span class=\'code\'>alwaysSkipExistingFiles</span> property are false, a warning is displayed and the user must make the decision whether to overwrite or skip each file.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTexture.alwaysSkipExistingFiles : boolean : Read|Write\n\
</pre></div><p>Specifies whether to skip existing map files. <strong>Available in 3ds Max 2021.1 Update and higher.</strong> When <strong>true</strong>, existing files are not baked again in the baking process. Also the <span class=\'code\'>alwaysOverwriteExistingFiles</span> property is set to false.</p>\n\
<p>When <strong>false</strong>, existing files are not skipped. Therefore, if both this property and the <span class=\'code\'>alwaysOverwriteExistingFiles</span> property are false, a warning is displayed and the user must make the decision whether to overwrite or skip each file.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;BakeToTexture.getMapsCount &lt;node&gt;object\n\
</pre></div><p>Returns the total number of maps configured for the specified object.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node by value array&gt;BakeToTexture.getObjects()\n\
</pre></div><p>Returns and array that contains all the scene objects that have bake to texture maps associated with them.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Interface by value array&gt;BakeToTexture.getAllMaps()\n\
</pre></div><p>Returns an array of all the maps configured for objects in the Bake to Texture dialog.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Interface by value array&gt;BakeToTexture.getMaps &lt;node&gt;object\n\
</pre></div><p>Returns an array of all the maps configured for the specified object.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;BakeToTexture.bakeableMapsAreValid()\n\
</pre></div><p>Returns true if all of the maps set as renderable are valid. This means they do not generate warnings and are compatible with the currently configured renderer.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;BakeToTexture.bake onMapBakedCallback:&lt;value&gt;\n\
</pre></div><p>Starts the baking process. The <span class=\'code\'>onMapBakedCallback</span> callback function is called after each map file is saved.</p>\n\
<p>A map can be a single file or multiple files (as in the case of UDIM tiles or animated frames), and the callback is called after each file. <strong>Available in 3ds Max 2021.1 Update and higher.</strong> The callback function receives two parameters:</p>\n\
<ol>\n\
<li><span class=\'code\'>successfulBake</span>: a boolean that indicates whether a map file was successfully baked and saved.</li>\n\
<li><span class=\'code\'>bakeFilePath</span>: a string containing the full file path of the baked map&#39;s image file.</li>\n\
</ol>\n\
<p>The callback function should return a boolean value indicating if the baking process should continue with the next map file (for multi-file maps) or the map in the queue. True indicates the process should continue, while false halts the process.</p>\n\
<p>For example:</p>\n\
<div class=\'codeBlock\'><pre>fn onMapBaked successfulBake MapFileString = \n\
(\n\
     if successfulBake and doesFileExist(MapFileString) then\n\
     (\n\
          print MapFileString\n\
          return true\n\
     ) else return false\n\
)\n\
BakeSuccess = BakeToTexture.bake onMapBakedCallback:onMapBaked\n\
&lt;Interface&gt;BakeToTexture.addMap &lt;node&gt;object &lt;enum&gt;mapTypeEnum\n\
mapTypeEnum enums: {#AlphaMap|#BlendMap|#CavityMap|#CompleteMap|#DensityMap|#DiffuseMap|#DustMap|\n\
#HeightMap|#LightMap|#NormalMap|#OcclusionMap|#ShadowMap|#SpecularMap|#SubSurfaceMap|#OverrideMap}\n\
</pre></div><p>Adds a map of a type specified by <span class=\'code\'>mapTypeEnum</span> to the specified object. This function returns the map that was created and added. The map implements the <span class=\'code\'>BakeToTextureMap</span> interface (see below).</p>\n\
<p>Note: Not all map types are compatible with all renderers. To get a list of map types compatible with the current renderer, use <span class=\'code\'>getCompatibleMapTypes()</span> described below.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Interface&gt;BakeToTexture.addMapByClassID &lt;node&gt;object &lt;integer64 array&gt;classID\n\
</pre></div><p>Adds a map of a type specified by classID to the specified object. This function returns the map that was created and added. The map implements the <span class=\'code\'>BakeToTextureMap</span> interface (see below).</p>\n\
<p>Note: Not all map types are compatible with all renderers. To get a list of map types compatible with the current renderer, use <span class=\'code\'>getCompatibleMapTypes()</span> described below.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Interface&gt;BakeToTexture.getMapById &lt;integer&gt;mapID\n\
</pre></div><p>Returns the map with the specified <span class=\'code\'>mapID</span>. The map implements the <span class=\'code\'>BakeToTextureMap</span> interface (see below).</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;BakeToTexture.deleteMapById &lt;integer&gt;mapID\n\
</pre></div><p>Removes the map with the specified <span class=\'code\'>mapID</span> from the Bake to Texture list.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;BakeToTexture.deleteAllMaps()\n\
</pre></div><p>Removes all the maps from the Bake to Texture list.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;BakeToTexture.openOutputLocation()\n\
</pre></div><p>Opens the Bake to Texture output directory in the Windows File Explorer.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string array&gt;BakeToTexture.getCompatibleMapTypes()\n\
</pre></div><p>Returns a list of all the map types that are compatible with the current renderer. The list is an array of strings, each string containing the name of the map and it&#39;s classID.</p>\n\
<p>Note: The list of compatible maps for the current renderer is populated when the Bake to Texture utility is initialized. If the call to this function happens before any other call (such as <span class=\'code\'>BakeToTexture.showDialog()</span>), this list will not be complete.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;BakeToTexture.showDialog()\n\
</pre></div><p>Opens the Bake to Texture dialog.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;BakeToTexture.hideDialog()\n\
</pre></div><p>Closes the Bake to Texture dialog.</p>\n\
<div class=\'codeBlock\'><pre>&lt;enum&gt;getOutputTo &lt;node&gt;object\n\
       getOutputTo enums: {#FilesOnly|#OriginalMaterial|#DuplicateOriginalMaterial|#CreateNewMaterial|#InvalidType\n\
</pre></div><p>Gets the &quot;Output to&quot; mode for the specified object. <strong>Available in 3ds Max 2021.1 Update and higher.</strong></p>\n\
<div class=\'codeBlock\'><pre>    &lt;boolean&gt;setOutputTo &lt;node&gt;object &lt;enum&gt;output material:&lt;material&gt;\n\
       output enums: {#FilesOnly|#OriginalMaterial|#DuplicateOriginalMaterial|#CreateNewMaterial|#InvalidType}\n\
       material default value: undefined\n\
</pre></div><p>Sets the &quot;Output to&quot; mode for the specified object. If the mode is set to <span class=\'code\'>#CreateNewMaterial</span> the material must also be provided with the <span class=\'code\'>material:&lt;material&gt;</span> argument. <strong>Available in 3ds Max 2021.1 Update and higher.</strong> If the material is created directly in the command by passing the material&#39;s constructor, the material constructor needs to be in parenthesis. For example:</p>\n\
<div class=\'codeBlock\'><pre>BakeToTexture.SetOutputTo $Teapot001 #CreateNewMaterial material:(Physical_Material())\n\
&lt;material&gt;getNewMaterial &lt;node&gt;object\n\
</pre></div><p>Returns the material that is set to be the new material when <span class=\'code\'>#CreateNewMaterial</span> is chosen as the &quot;Output To&quot; mode. <strong>Available in 3ds Max 2021.1 Update and higher.</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;string array&gt;getTargetMaterialSlots &lt;node&gt;object\n\
</pre></div><p>Gets the list of all the material input slots that can be used as targets for the object&#39;s maps. The function returns an array of strings that can be used as target definitions for the map&#39;s &quot;Output To&quot; function. <strong>Available in 3ds Max 2021.1 Update and higher.</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;clearShellKeepBaked nodes:&lt;&amp;node array&gt;\n\
       nodes default value: #()\n\
       nodes is In and Out parameter\n\
</pre></div><p>Clears all Shell materials in the scene or on a specific array of nodes, and replaces the material on the objects by the baked material connected to the shell material. It makes sure that the <strong>baked material</strong> is directly assigned to the object rather than the shell material. This is a quick way to prepare a scene for export. <strong>Available in 3ds Max 2021.1 Update and higher.</strong> If no array of nodes is provided, the Shell materials in the whole scene are cleared. If an array of nodes is provided, only the Shell materials assigned to those nodes is cleared.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;clearShellKeepOriginal nodes:&lt;&amp;node array&gt;\n\
       nodes default value: #()\n\
       nodes is In and Out parameter\n\
</pre></div><p>Clears all Shell materials in the scene or on a specific array of nodes, and replaces the material on the objects by the original material connected to the Shell material. It makes sure that the <strong>original material</strong> is directly assigned to the object rather than the Shell material. This is a quick way to prepare a scene for export. <strong>Available in 3ds Max 2021.1 Update and higher.</strong> If no array of nodes is provided, the Shell materials in the whole scene are cleared. If an array of node is provided, only the Shell material assigned to those nodes is cleared.<br><strong>Interface: BakeToTextureMap</strong></p>\n\
<p>This interface is implemented by the various types of texture maps created on objects in the Bake to Texture dialog. For example, the maps returned by <span class=\'code\'>BakeToTexture.addMap()</span> and <span class=\'code\'>BakeToTexture.getMaps()</span> implement this interface.</p>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.sceneObject : node : Read\n\
</pre></div><p>Returns the object associated with the map.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.id : integer : Read\n\
</pre></div><p>The map&#39;s unique ID.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.mapTypeID : integer64 array : Read\n\
</pre></div><p>The map&#39;s classID.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.mapTypeName : string : Read\n\
</pre></div><p>The map&#39;s type name, as a string. This is the same name displayed in the Bake to Texture dialog.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.renderable : boolean : Read|Write\n\
</pre></div><p>Gets or sets whether the map is in the baking queue.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.frozen : boolean : Read\n\
</pre></div><p>The map&#39;s support status. If the map is not supported in the current renderer, this property is true, otherwise it is false. When this property is true, the map is not baked in the baking process.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.bakeable : boolean : Read\n\
</pre></div><p>Gets whether the map can be baked. This means all the properties and parameters for the map are valid, and the map type is compatible with the current renderer. If false, the map will not be baked in the baking process.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.fileName : filename : Read|Write\n\
</pre></div><p>The name of the file associated with this map. By default this is &quot;[object name]_[map name]&quot;, for example, &quot;Teapot001_normals&quot;.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.fileType : string : Read|Write\n\
</pre></div><p>The image file type extension associated with the map.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.uvChannel : integer : Read|Write\n\
</pre></div><p>The UV channel of the map.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.imageWidth : integer : Read|Write|Validated by Range: 1 to 65535\n\
</pre></div><p>The width, in pixels, of the map&#39;s output image.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.imageHeight : integer : Read|Write|Validated by Range: 1 to 65535\n\
</pre></div><p>The height, in pixels, of the map&#39;s output image.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.edgePadding : integer : Read|Write|Validated by Range: 0 to 128\n\
</pre></div><p>The edge padding of the map&#39;s output image, in pixels.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.backgroundColor : color : Read|Write\n\
</pre></div><p>The background color of the map&#39;s output image.</p>\n\
<p>Note: The background color cannot be changed for surface maps.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.projectionModifierIndex : integer : Read|Write\n\
</pre></div><p>The index of the projection modifier used on the map, in order of bottom to top of the projection modifier stack. An index of 0 indicates &quot;Self&quot;.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.projectionModifierName : string : Read\n\
</pre></div><p>The name of the projection modifier used on the map, as a string.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.projectionMethod : integer : Read|Write|Validated by Range: 0 to 2\n\
</pre></div><p>The projection method for the map, where:</p>\n\
<ul>\n\
<li>0 = Cage</li>\n\
<li>1 = Raytrace</li>\n\
<li>2 = UV Match</li>\n\
</ul>\n\
<p>Note: You should ensure that the projection method for the map is not &quot;Self&quot; before accessing this property, as this will cause a MAXScript runtime error.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.projectionMaxRayDistance : float : Read|Write|Validated by Range: 0.0 to 10000.0\n\
</pre></div><p>The maximum ray distance.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.projectionResolveHitType : integer : Read|Write|Validated by Range: 0 to 1\n\
</pre></div><p>The Projection Resolve Hit Type for the map, where:</p>\n\
<ul>\n\
<li>0 = Closest</li>\n\
<li>1 = Furthest</li>\n\
</ul>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.projectionHitOnlyMatchingMatID : boolean : Read|Write\n\
</pre></div><p>Specifies whether the Hit Only Matching Material ID setting is enabled.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.projectionRayMissColorType : integer : Read|Write|Validated by Range: 0 to 2\n\
</pre></div><p>The Projection Ray Miss Color setting, where:</p>\n\
<ul>\n\
<li>0 = Background</li>\n\
<li>1 = Self (Color / Normals)</li>\n\
<li>2 = Use Color for Diagnostic - uses the <span class=\'code\'>projectionDiagnosticColor</span> property for the color (see below).</li>\n\
</ul>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.projectionDiagnosticColor : color : Read|Write\n\
</pre></div><p>The color used for the Color Diagnostic setting if <span class=\'code\'>projectionRayMissColorType</span> is set to 2 (Use Color for Diagnostic).</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.UDIMEnabled : boolean : Read|Write\n\
</pre></div><p><img src=\'developer/3ds-Max-Objects-and-Interfaces/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> <a href=\'#!/url=./developer/What-is-New-in-MAXScript/What-s-New-in-MAXScript-in-3ds.html\' title=\'\'>NEW</a> <strong>in 3ds Max 2021.1 Update:</strong>Specifies whether UDIM Tiles baking is enabled for the map.</p>\n\
<div class=\'codeBlock\'><pre>BakeToTextureMap.UDIMFilePattern : enum : Read|Write\n\
       UDIMFilePattern enums: {#UDIM|#ZBrush|#Mudbox}\n\
</pre></div><p>Specifies the filename format for UDIM files when they are saved for the map. The file formats are: <strong>Available in 3ds Max 2021.1 Update and higher.</strong> - <span class=\'code\'>#UDIM</span> - the file suffix will be <strong>UDIM number</strong>, with the filename pattern: Map.1001.png, Map.1002.png, Map.1003.png, etc - <span class=\'code\'>#ZBrush</span> - file suffix will be <strong>u0_v0</strong> (base 0), with the filename pattern: Map.u0_v0.png, Map.u1_v1.png, Map.u2_v2.png, etc - <span class=\'code\'>#Mudbox</span> - file suffix will be <strong>u1_v1</strong> (base 1), with the filename pattern: Map.u1_v1.png, Map.u2_v2.png, Map.u3_v3.png, etc<br><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;BakeToTextureMap.setImageSize &lt;integer&gt;width &lt;integer&gt;height\n\
 width Validated by Range: 1 to 65535\n\
 height Validated by Range: 1 to 65535\n\
     \n\
</pre></div><p>Sets the map&#39;s width and height.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;BakeToTextureMap.applyImageTypeSettings()\n\
</pre></div><p>Applies the current BitmapIO class settings to the matching image type defined for this map. Returns true if successful, false if there was an error.</p>\n\
<p>For example, to change an existing map <span class=\'code\'>map1</span> to png output, and set some png settings:</p>\n\
<div class=\'codeBlock\'><pre>map1.setImageType &quot;png&quot;\n\
map1.setFilename &quot;Map1&quot;\n\
-- Enable Alpha and use 48bit color\n\
pngio.setAlpha(true)\n\
pngio.SetType(#true48)\n\
map1.applyImageTypeSettings()   \n\
</pre></div><p>See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/BitmapIO-MAXWrapper.html\' title=\'\'>BitmapIO : MAXWrapper</a> for a list of classes that hold image format settings.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;BakeToTextureMap.getProjectionModifiersCount()\n\
</pre></div><p>Returns the total number of projection modifiers available for the map.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;BakeToTextureMap.getOptionsCount()\n\
</pre></div><p>Returns the total number of options available for this map&#39;s type.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;BakeToTextureMap.getOptionName &lt;index&gt;index\n\
</pre></div><p>Returns the name, as a string, of the map option specified by index.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;BakeToTextureMap.getOptionType &lt;index&gt;index\n\
</pre></div><p>Returns the type of the option specified by index, where:</p>\n\
<ul>\n\
<li>0 = float</li>\n\
<li>1 = integer (this could also be the index from a list of choices)</li>\n\
<li>4 = boolean</li>\n\
<li>15 = Map</li>\n\
<li>8215 = color</li>\n\
</ul>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;BakeToTextureMap.isOptionReadOnly &lt;index&gt;index\n\
</pre></div><p>Returns true if the map option specified by index is read only, false if it can be modified.</p>\n\
<div class=\'codeBlock\'><pre>&lt;value&gt;BakeToTextureMap.getOptionValue &lt;index&gt;index\n\
</pre></div><p>Returns the current value for the map option specified by index.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;BakeToTextureMap.setOptionValue &lt;index&gt;index &lt;value&gt;value\n\
</pre></div><p>Sets the value for the map option specified by index, and returns true if the value was successfully set, otherwise false.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;BakeToTextureMap.getTargetMapSlot()\n\
</pre></div><p>Gets the name of the Target Slot on the material of the object. This is where the map is connected to when baked. <strong>Available in 3ds Max 2021.1 Update and higher.</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;BakeToTextureMap.setTargetMapSlot &lt;string&gt;slot\n\
</pre></div><p>Sets the Target Slot on the material of the object. This defines where the map will be connected when baked. The target map slots are defined as strings and the valid target map slots for the parent object can be obtained by using <span class=\'code\'>BakeToTexture.getTargetMaterialSlots()</span>.<br> <strong>Available in 3ds Max 2021.1 Update and higher.</strong>## Full example</p>\n\
<p>The following example creates some objects and creates bake to texture maps for them. It sets some options on the maps, and then kicks off the bake process.</p>\n\
<div class=\'codeBlock\'><pre>-- Bake to texture example\n\
resetMaxFile #noprompt\n\
\n\
-- set up our object:\n\
t = Teapot()\n\
s = Sphere pos:[40,40,0]\n\
pm = PhysicalMaterial()\n\
cm = OSL_Checker()\n\
pm.base_color_map = cm\n\
t.material = pm \n\
\n\
-- need uvw for baking maps\n\
u = uvwmap()\n\
addModifier t u\n\
\n\
-- open the dialog:\n\
BakeToTexture.showDialog()                 \n\
-- set up some maps:\n\
-- first, let&#39;s see what&#39;s compatible with the current renderer\n\
-- this example assumes Arnold is the current renderer\n\
compatible_maps = BakeToTexture.getCompatibleMapTypes()\n\
compatible_map_names = for s in compatible_maps collect ((filterString s &quot; :&quot;)[1])\n\
\n\
-- we can get a map from addMap() for native 3ds Max maps\n\
if findItem compatible_map_names &quot;Lighting&quot; &gt; 0 do \n\
    ( light_map = BakeToTexture.addMap t #LightMap )\n\
\n\
-- we can also get it later by index and add from a class ID for non native 3ds max maps:\n\
if findItem compatible_map_names &quot;Arnold_albedo&quot; &gt; 0 do\n\
    ( \n\
        BakeToTexture.addMapByClassID t #(1236154164, -1994915067) \n\
        albedo_map = (BakeToTexture.getMaps t)[2]\n\
    )  \n\
\n\
-- let&#39;s change some settings on the maps \n\
albedo_map.fileType = &quot;jpg&quot;\n\
albedo_map.setImageSize 512 512\n\
light_map.setImageSize 512 512\n\
\n\
-- turn off shadows option if it is present\n\
for i = 1 to light_map.getOptionsCount() do \n\
    (\n\
        if light_map.getOptionName i == &quot;Shadows&quot; do \n\
        ( light_map.setOptionValue i 0 )\n\
    )\n\
\n\
BakeToTexture.showDialog()\n\
\n\
-- start bake process, without a callback:\n\
bake_success = BakeToTexture.bake()\n\
</pre></div><p><strong>Projection Map Example:</strong></p>\n\
<div class=\'codeBlock\'><pre>-- Add projection modifier maps\n\
-- Create two objects\n\
-- Note, this is not a real-world example, the map will be &quot;flat&quot;\n\
-- we are just illustrating how to set things up\n\
myBoxLowRes = Box mapCoords:True name:&quot;Low Res&quot;\n\
myBoxHighRes= Box mapCoords:true name:&quot;High Res&quot;\n\
\n\
-- Add Projection Modifier to one\n\
modPanel.addModToSelection (Projection name:&quot;My Projection 1&quot;) ui:on\n\
addPModObjects  myBoxLowRes false true objList:myBoxHighRes\n\
\n\
-- Add a normal map:\n\
map =   BakeToTexture.addMap myBoxLowRes #NormalMap\n\
\n\
-- Get various Projection properties\n\
map.projectionModifierName -- should return #(Projection:Projection)\n\
map.projectionModifierIndex -- should return 1\n\
map.projectionMethod -- should return 0\n\
map.projectionMaxRayDistance -- should return 10.0\n\
map.projectionResolveHitType -- should return 1\n\
map.projectionHitOnlyMatchingMatID -- should return false\n\
map.projectionRayMissColorType -- should return 0\n\
map.projectionDiagnosticColor -- should return (color 255 0 0)\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";