var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How do I understand the function definitions in this document?</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How do I understand the function definitions in this document?</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-do-i-understand-the-function-definitions-in-this-document\"></a></div>\n\
<p><a href=\'#!/url=./developer/MAXScript-Introduction/Syntax-Definitions-in-This/Syntax-Definitions-in-This-1.html\' title=\'\'>Syntax Definitions in This Document</a></p>\n\
<p>The above topic explains the general syntax used in the MAXScript Online Reference, but practice has shown that many users have difficulties applying the function definitions to actual code.</p>\n\
<p>Below are some guidelines to help you understand the syntax.</p>\n\
<p>Here is a typical function definition taken from the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Meshop-Face-Methods.html\' title=\'\'>Meshop Face Methods</a>:</p>\n\
<div class=\'codeBlock\'><pre>meshop.detachFaces &lt;Mesh mesh&gt; &lt;facelist&gt; delete:&lt;boolean=true&gt; asMesh:&lt;boolean=false&gt;\n\
</pre></div><p>Detaches the specified faces.</p>\n\
<p>If <span class=\'code\'>delete</span> is <span class=\'code\'>true</span> , the faces are deleted after being detached. If <span class=\'code\'>delete</span> is <span class=\'code\'>false</span> , the faces are not deleted.</p>\n\
<p>If <span class=\'code\'>asMesh</span> is <span class=\'code\'>true</span> , the faces are detached and returned as a Mesh value. If <span class=\'code\'>asMesh</span> is <span class=\'code\'>false</span> , the faces are detached as an element in the mesh and a value of OK is returned.</p>\n\
<p>First of all, this function is part of a structure called meshop. A structure can be used to group related functions. This function has been implemented using the SDK, but you can organize your own MAXScript functions by putting them into a structure, too. See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Structure-Definition/Defining-Local-Functions-in.html\' title=\'\'>Defining Local Functions in Structures</a> for more info.</p>\n\
<p>The name of the function is <span class=\'code\'>detachFaces</span>. It is written in <strong>bold</strong> because according to the <a href=\'#!/url=./developer/MAXScript-Introduction/Syntax-Definitions-in-This/Syntax-Definitions-in-This-1.html\' title=\'\'>Syntax Definitions in This Document</a> topic, bold denotes code written &quot;as is&quot;. Actually, the name of the structure (meshop) would have to be in bold too, but this would make it more difficult to read the documentation. Now you can easily spot any function or keyword by quickly browsing a page and looking for bold letters.</p>\n\
<p>Next, two arguments (parameters) to the function are described. These two arguments are compulsory and the function will issue an error message if the parameters are not supplied or the classes of the provided values do not match the requirements.</p>\n\
<p><span class=\'code\'>&lt;Mesh mesh&gt;</span> defines a <strong>rule</strong>. Any text written inside of &lt;&gt; describes what should be used in place of the rule. In this case, it tells you to replace the rule with a mesh object.</p>\n\
<p>The next rule, <span class=\'code\'>&lt;facelist&gt;</span>, tells you to provide a list of faces. A face list can be either a regular <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/Array-Values.html\' title=\'\'>Array</a> containing indices of the faces to affect, for example #(1,3,10,11,12,13,14,15), or a <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/BitArray-Values.html\' title=\'\'>bitArray</a> with bits set for any face to be affected, for example, #{1,3,10..15}.</p>\n\
<p>Then, two <strong>optional parameters</strong> are described. While the order of the first two parameters is significant (the function always expects the mesh to be the first and the facelist to be the second parameter), optional named parameters can come in any order - they are recognized by their name.</p>\n\
<p>Note:</p>\n\
<p>In the syntax definitions of this document, optional parameters are written inside of [] brackets. Typically, when defining a function, any <strong>named</strong> parameters are optional. This is why in some function definitions, optional parameters might not have been listed inside of [] brackets.</p>\n\
<p>When a value is not provided for an optional parameter, the special value of <span class=\'code\'>unsupplied</span> will be sent to the function instead. The function will check whether the value is supplied or not and replace an <span class=\'code\'>unsupplied</span> value with a default value. To learn more about <span class=\'code\'>unsupplied</span> values, see <a href=\'#!/url=./developer/Frequently-Asked-Questions/MAXScript-Syntax-and-Terminology/What-is-the-difference-between.html\' title=\'\'>What is the difference between &#39;undefined&#39; and &#39;unsupplied&#39; values?</a> and <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Special-Data-Values/Unsupplied-Value.html\' title=\'\'>Unsupplied Value</a> topics.</p>\n\
<p>In the case of the <span class=\'code\'>delete:</span> parameter, the definition tells you that the name of the parameter should be written as is, and a boolean value ( <span class=\'code\'>true</span> or <span class=\'code\'>false</span> ) is expected after the colon &#39; <span class=\'code\'>:</span> &#39;. A value of <span class=\'code\'>true</span> will be assumed by default if the parameter is not supplied.</p>\n\
<p>Finally, the <span class=\'code\'>asMesh:</span> parameter is also optional and will be <span class=\'code\'>false</span> by default if not supplied.</p>\n\
<blockquote>\n\
<p><strong>A TYPICAL CALL TO THIS FUNCTION WOULD LOOK LIKE:</strong></p>\n\
<p><span class=\'code\'>meshop.detachFaces $MyMesh02 #{1..25}</span></p>\n\
<p>In this case, the function is being told to detach faces with indices from 1 to 25 from the EditableMesh object named &quot;MyMesh02&quot;. The faces will be deleted by default from the original mesh and a new element inside of MyMesh02 will be created because the two optional parameters will be used with default values.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>IF YOU CHANGE THE LINE TO</strong></p>\n\
<p><span class=\'code\'>meshop.detachFaces $MyMesh02 #{1..10,40..55} delete:false</span></p>\n\
<p>the faces with indices from 1 to 10 and from 40 to 55 will be cloned to element inside of the mesh - a new element will be created (asMesh is false by default), but the original faces will not be deleted from the mesh.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>IF YOU CHANGE THE CODE AGAIN TO</strong></p>\n\
<p><span class=\'code\'>newMesh = meshop.detachFaces $MyMesh02 #(1,2,3,4,5,10,11,15) delete:false asMesh:true</span></p>\n\
<p>then this time the faces with indices described by the regular array will be cloned to a new TriMesh without being deleted from the original object. The function will return the TriMesh value and will store it into the newMesh user variable. See the second example provided for this function in the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Meshop-Face-Methods.html\' title=\'\'>Meshop Face Methods</a> topic for more info on using the returned TriMesh value to create a new object.</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";