var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>When do I use () after a function?</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>When do I use () after a function?</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"when-do-i-use-after-a-function\"></a></div>\n\
<p>A user-defined MAXScript function is stored in a variable which points at a location in memory where the function definition is stored.</p>\n\
<p>Some functions take no arguments (parameters, values passes to the function to operate on), others can expect one or more arguments.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>Let&#39;s define a custom function that prints &quot;Hello World!&quot;</p>\n\
<p>``` fn printHello = ( format &quot;Hello World!\\n&quot;)</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` printHello()</p>\n\
<p>```</p>\n\
<p>MAXScript is telling us that we have defined a new function and shows us how to call the function.</p>\n\
</blockquote>\n\
<p>If we type in only the name of the function, we are not actually calling the function but asking MAXScript to print the function value itself.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>Let&#39;s type in only the name of the function without ()</p>\n\
<p>``` printHello</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` printHello()</p>\n\
<p>```</p>\n\
<p>MAXScript is showing us that the variable printHello points at a definition of a function that can be called as shown.</p>\n\
</blockquote>\n\
<p>Since our function does not take any arguments to operate on, we can just do as instructed and call the function:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>Let&#39;s type the function name with ()</p>\n\
<p>``` printHello()</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` Hello World! OK</p>\n\
<p>```</p>\n\
<p>MAXScript executed the function, resulting in the string &quot;Hello World!&quot; being printed to the Listener, followed by the return value of the function which is OK.</p>\n\
</blockquote>\n\
<p>If we would define a function that expects one argument, we could still use the parentheses around the argument. In some other languages, the parentheses around the arguments are mandatory. In such languages, the () form is a special case of the argument passing, just without any arguments.</p>\n\
<p>In the case of MAXScript though, the parentheses are optional except when no arguments are passed to the function:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>Let&#39;s define a custom function that prints &quot;Hello World&quot;</p>\n\
<p>``` fn printAValue theValue = ( format &quot;The Value Is %\\n&quot; theValue)</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` printAValue()</p>\n\
<p>```</p>\n\
<p>MAXScript is telling us that we have defined a new function and shows us how to call the function, but it does not tell us anything about the number of arguments yet. The return value only shows that a MAXScript function was defined.</p>\n\
</blockquote>\n\
<p>Now if we would try to call the function like before with () but no argument, the function will tell us what it expects in an error message:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>Let&#39;s type the function name with ()</p>\n\
<p>``` printAValue()</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` -- Argument count error: printAValue wanted 1, got 0</p>\n\
<p>```</p>\n\
<p>MAXScript tries to execute the function, but finds that the arguments are not enough and complains.</p>\n\
</blockquote>\n\
<p>We can put the argument value inside the parentheses to make the function work as desired:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>Let&#39;s provide the argument inside the parentheses:</p>\n\
<p>``` printAValue(pi)</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` The Value Is 3.14159 OK</p>\n\
<p>```</p>\n\
<p>MAXScript executes the function and finds that the arguments are enough, so the function produces the correct result.</p>\n\
</blockquote>\n\
<p>But as mentioned, MAXScript does not mandate the parentheses around an argument, so we can omit them.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>Let&#39;s provide the argument without the parentheses:</p>\n\
<p>``` printAValue pi</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` The Value Is 3.14159 OK</p>\n\
<p>```</p>\n\
<p>As we can see, the result is the same.</p>\n\
</blockquote>\n\
<p>The same applies to functions implemented by plugins and by MAXScript itself, like for example the constructor functions of geometry primitives.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>Type in the constructor of a Box without ()</p>\n\
<p>``` box</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` Box</p>\n\
<p>```</p>\n\
<p>MAXScript is telling us that &#39;box&#39; contains the constructor function Box which, when called without parameters would make a new box object.</p>\n\
</blockquote>\n\
<p>In order to call the function without any arguments, we have to tell the function that no parameters are going to be passed to it.</p>\n\
<p>To do this, we add the pair of parentheses to the end of the function name like we did with the user-defined function above.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>Type in the constructor of a Box with ()</p>\n\
<p>``` box()</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` $Box:Box01 @ [0.000000,0.000000,0.000000]</p>\n\
<p>```</p>\n\
<p>MAXScript executes the Box constructor function without parameters, thus using defaults for all properties like position, size etc.</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";