var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How do I change a property in multiple objects at once?</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How do I change a property in multiple objects at once?</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-do-i-change-a-property-in-multiple-objects-at-once\"></a></div>\n\
<p>One of the most often used applications of MAXScript is the mass-changing of object properties. This can save tremendous amounts of clicks and time.</p>\n\
<p>To change a property in multiple objects, you need to:</p>\n\
<ol>\n\
<li><p>Get the correct objects to change</p></li>\n\
<li><p>Assign a value to the correct property</p></li>\n\
</ol>\n\
<p>The simplest situation imaginable is a selection of similar objects. For example, a large number of sphere primitives. MAXScript lets you easily access the current selection in the scene. In addition, an object property assignment is &quot;mappable&quot;. This means that MAXScript applies the value on the right side of the assignment operator &#39;=&#39; to every single object in the selection automatically without the need of an explicit MAXScript for loop. See <a href=\'#!/url=./developer/Frequently-Asked-Questions/MAXScript-Syntax-and-Terminology/What-Are-Mapped-Operations-in.html\' title=\'\'>What Are Mapped Operations in MAXScript?</a> for more details on mapped operations.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` -- select a large number of spheres in the scene with the mouse, -- then change the radius of all selected objects to 10.0 units -- by typing in the Listener: selection.radius = 10 OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In case you have selected some object that does not have a property called radius such as, a Box primitive or some EditableMesh object, the above code causes an error:</p>\n\
<blockquote>\n\
<p><strong>ERROR EXAMPLE</strong></p>\n\
<p>``` selection.radius = 10 -- Unknown property: &quot;radius&quot; in $Box:Box01 @ [0. 000000, 0. 000000,0.000000]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In such a case, you need to make sure that the collection of objects is filtered by your script before an assignment is made. See the <a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/For-Loop.html\' title=\'\'>For Loop</a> topic for more information. A possible way is:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` -- select any number of objects in the scene with the mouse, -- then change the radius of all objects that have a .radius property -- by typing in the Listener: for i inselection where hasProperty i &quot;radius&quot; do i.radius = 10 OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>If you want to change the radius of any object in the scene that has such a property instead of selecting objects manually, you can let MAXScript filter the scene for you. This affects all Spheres, GeoSpheres, Cylinders, and so on, but ignores any Boxes that do not have a &quot;radius&quot; property.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` -- Go through all geometry objects, filter those that have a .radius property -- and change the radius to 10 units by typing in the Listener: for i inGeometry where hasProperty i &quot;radius&quot; do i.radius = 10 OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>If you want to affect only the GeoSpheres in the scene and exclude all other classes, you can check the class of the objects instead. In this case, you do not have to check for a property named &quot;radius&quot; because any GeoSphere has this property. The <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/Node-Common-Methods.html\' title=\'\'>classOf</a> function returns the object&#39;s class, so you can compare it to the class you want to affect.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` -- Go through all geometry objects, filter the GeoSpheres -- and change their radius to 10 units by typing in the Listener: for i in Geometry where classOf i == GeoSphere do i.radius = 10 OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>If you have no idea what the correct MAXScript name of a property is, you can either consult this Help File or use the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Identifying-and-Accessing/Class-and-Object-Inspector.html\' title=\'\'>showProperties</a> inspector function in the Listener to print a list of all exposed object properties.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` -- Select a single sphere in the scene using the mouse and -- type in the Listener: showProperties $ .smooth : boolean .radius : float .mapCoords : boolean .segs : integer .slice : boolean .hemisphere : float .sliceFrom : angle .sliceTo : angle .chop : integer .recenter : boolean false</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";