var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How do I build Unconnected Edges Selections from EPoly Edge Selection?</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How do I build Unconnected Edges Selections from EPoly Edge Selection?</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-do-i-build-unconnected-edges-selections-from-epoly-edge-selection\"></a></div>\n\
<div class=\'section\'><a id=\"a-user-asked\"></a><h2 id=\"a-user-asked\">A user asked:</h2></div>\n\
<p>I want to filter the edge selection and create arrays containing connected edges, something like &quot;edge selection elements&quot;. Edges from two arrays will never be connected, in other words will not share vertices.</p>\n\
<div class=\'section\'><a id=\"answer\"></a><h2 id=\"answer\">Answer:</h2></div>\n\
<p>The following pseudo-code describes a possible approach:</p>\n\
<ul>\n\
<li><p>Get the current edge selection into a main selection array.</p></li>\n\
<li><p>Create an empty array to hold the unconnected selections.</p></li>\n\
<li><ol>\n\
<li>Append a new empty array to it as a sub-array.</li>\n\
</ol></li>\n\
<li><p>Note the index of the current sub-array.</p></li>\n\
<li><p>Get the first edge from the main selection array.</p></li>\n\
<li><p>Delete it from the main selection array, append to the current sub-array of the unconnected selections array.</p></li>\n\
<li><p>For every edge in the new sub-array, get its corresponding vertices that define the edge.</p></li>\n\
<li><p>For each of the two vertices, get their edges - this gives you all neighbor edges sharing a vertex with the current edge.</p></li>\n\
<li><p>Loop through the neighbors and see if they appear in the main selection array.</p></li>\n\
<li><p>If an edge is in the main selection array, delete it from there and append it to the current sub-array.</p></li>\n\
<li><p>Finish the loop when you have checked all edges from the sub-array.</p></li>\n\
<li><p>At this point, if all edges are connected, the main array will be empty. If it is not empty, there are edges unconnected to the selections you already collected.</p></li>\n\
<li><p>Add a new empty sub-array to the collection array.</p></li>\n\
<li><p>Repeat starting with (A).</p></li>\n\
</ul>\n\
<p>The function is ready when there are no edges left in the main array.</p>\n\
<p>This will give you as many sub-arrays as there are unconnected edge selections.</p>\n\
<p>The following function implements the pseudo-code in MAXScript code:</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` fn getEPolyUnconnectedEdgesSelections thePoly = ( --get the edge selection mainSelection = (polyOp.getEdgeSelection thePoly) as array --init. an array to collect sub-arrays with selections &quot;elements&quot; unconnectedSelections = #() --repeat until the main selection array is empty while mainSelection.count &gt; 0 do ( --append a new empty sub-array: append unconnectedSelections #() --remember the current sub-array&#39;s index: currentSelCount = unconnectedSelections.count --append the first edge from the main selectionarray to the sub-array: append unconnectedSelections[currentSelCount] mainSelection[1] --and remove the first edge from the main selectionarray: deleteItem mainSelection 1 --initialize a counter: cnt = 0 --while the counter is less than the edges in the sub-array while cnt &lt; unconnectedSelections[currentSelCount].count do ( cnt += 1--increase the counter by 1 --get the vertices of the current edge in the current sub-array: currentEdgeVerts = (polyOp.GetVertsUsingEdge thePoly unconnectedSelections[currentSelCount][cnt]) as array neigborEdges = #()--init. an array to collect neighbor --for every vertex in the current edge, for v in currentEdgeVerts do --add the edges used by the vertex to the neighbors array join neigborEdges ((polyOp.GetEdgesUsingVert thePoly v) as array) --for each neighbor edge, for edge in neigborEdges do ( --see if the edge is in the main selection array checkInSelection = findItem mainSelection edge --if it is, if checkInSelection &gt; 0 do ( --delete the edge from the main array deleteItem mainSelection checkInSelection --and add it to the current sub-array append unconnectedSelections[currentSelCount] edge )--end if )--end for edge loop )--end while cnt )--end while mainSelection.count --finally, return the array containing the sub-arrays of connected edges: unconnectedSelections )--end fn</p>\n\
<p>-- create box and mesh: b = box() convertTo b editable_poly select b getEPolyUnconnectedEdgesSelections $Box001--call the function</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";