var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How do I instance Modifiers and Controllers inside the same object?</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How do I instance Modifiers and Controllers inside the same object?</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-do-i-instance-modifiers-and-controllers-inside-the-same-object\"></a></div>\n\
<div class=\'section\'><a id=\"a-user-asked\"></a><h2 id=\"a-user-asked\">A user asked:</h2></div>\n\
<p>Is there a function for copying a modifier and then pasting an instance of it onto the same object? I can copy and paste it but not as an instance.</p>\n\
<div class=\'section\'><a id=\"answer\"></a><h2 id=\"answer\">Answer:</h2></div>\n\
<p>Reading an existing modifier through MAXScript and applying the SAME modifier will create an instance automatically.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` b = Box heightsegs:10 height:100--creates a high box addModifier b (Bend())--adds a bend modifier to it addModifier b (b.bend)--instances the same modifier on top</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>So you just read ANY value in MAXScript - using it again means INSTANCE it.</p>\n\
<blockquote>\n\
<p><strong>IF YOU TRY</strong></p>\n\
<p>``` for i in selection do addModifier i (Bend())</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>you are adding a unique modifier to every object, because the constructor expression (Bend()) is evaluated n times where n is the number of selected objects.</p>\n\
<blockquote>\n\
<p><strong>BUT IF YOU USE</strong></p>\n\
<p>``` theBend = Bend() for i in selection do addModifier i theBend</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>then you are creating a single modifier, storing it into a variable and then applying an instance of it to each object in the selection.</p>\n\
<p>Even better, <strong>mapped operations</strong> are also good for instancing. The same result as above can be achieved with much less code:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` addModifier selection (Bend())</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>adds the SAME Bend modifier as instance to all selected objects, because the constructor expression (Bend()) is evaluated only once and is then applied in an internal loop as instance to every object in the collection.</p>\n\
<p>Obviously, you can instance between objects, too.</p>\n\
<p>You can also apply the same technique to controllers. For example, if you want to instance the controller of the X_Position and assign it to the Bend Angle, then you can say:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` theBox = Box heightsegs:10 height:100 theBox.bend.angle.controller = theBox.position.x_position.controller</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Now if you move the object along X, the bend angle will change accordingly.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";