var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How do I access UI elements to change their properties?</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How do I access UI elements to change their properties?</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-do-i-access-ui-elements-to-change-their-properties\"></a></div>\n\
<div class=\'section\'><a id=\"a-user-asked\"></a><h2 id=\"a-user-asked\">A user asked:</h2></div>\n\
<p>I have built a UI with buttons and progressBars. The progressBars are actually being used as small color indicators of availability. I want to change the color of the progress bars according to the files found.</p>\n\
<p>But I get &#39;undefined&#39; if I put it after the creation of the rollout with the progress bars. I want to change the color of these progress bars after they are created based on the data collected.</p>\n\
<div class=\'section\'><a id=\"answer\"></a><h2 id=\"answer\">Answer:</h2></div>\n\
<p>Consider that you are creating a UI rollout with some progressbar in it.</p>\n\
<blockquote>\n\
<p>``` macroScript TestUI category:&quot;MXS Help&quot; ( -- note that the mactoscript itself defines a scope rollout testUI_Rollout&quot;Testing...&quot; ( progressbar Indicator01 width:20 height:20 color:green value:100 ) createDialog testUI_Rollout 100 100 )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>You have three ways to access the Indicator01:</p>\n\
<ol>\n\
<li><p>Inside the rollout</p></li>\n\
<li><p>Before the rollout is created</p></li>\n\
<li><p>After the rollout is created</p></li>\n\
</ol>\n\
<p>The first way is obvious and is not explained here.</p>\n\
<p>The second way is rather interesting because you can access values that are not yet defined, but are at least pre-initialized.</p>\n\
<blockquote>\n\
<p>``` macroScript TestUI category:&quot;MXS Help&quot; ( local testUI_Rollout -- this defines a variable -- which has a memory address but still not valid value. -- If you create a function that accesses the variable, the -- evaluation will proceed as it sees the variable and assumes -- it is a valid rollout. Later, when the actual execution of -- the script happens, the variable will REALLY point at a valid -- rollout, so everybody is happy!</p>\n\
<div class=\'codeBlock\'><pre>fn changeTheLamp theColor =\n\
(\n\
  testUI_Rollout.Indicator01.color = theColor\n\
  -- the function is outside of the rollout context,\n\
  -- so it has to prefix the UI element access.\n\
)\n\
\n\
-- This rollout is defined even before the rollout with the lamp\n\
-- Still, it will be able to change the lamp to yellow using the\n\
-- above function!\n\
rollout Changer_Rollout&quot;Testing...&quot;\n\
(\n\
  button changeIt&quot;CHANGE STATE&quot;\n\
  on changeIt pressed do changeTheLamp [255,255,0]\n\
)\n\
\n\
rollout testUI_Rollout&quot;Testing...&quot;\n\
(\n\
  progressbar Indicator01 width:20 height:20 color:green value:100\n\
)\n\
createDialog Changer_Rollout 100 30 100 100\n\
createDialog testUI_Rollout 100 100 100 200\n\
</pre></div><p>)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In the third way, consider that you want to access the value of Indicator01 or change its color after the dialog was created. In this case, because the variable TestUi_Rollout points at the rollout definition, you have to access Indicator01 by prefixing it with the rollout name:</p>\n\
<blockquote>\n\
<p>``` macroScript TestUI category:&quot;MXS Help&quot; ( -- note that the mactoscript itself defines a scope rollout testUI_Rollout &quot;Testing...&quot; ( progressbar Indicator01 width:20 height:20 color:green value:100 ) createDialog testUI_Rollout 100 100 TestUI_rollout.Indicator01.color = red )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note that the line is inside the scope of the macroScript where TestUI_rollout is visible. If you want to access the rollout from another script, you must define the rollout as a global variable:</p>\n\
<blockquote>\n\
<p>``` macroScript TestUI category:&quot;MXS Help&quot; ( global testUI_Rollout --now the rollout is visible to anyone outside! rollouttestUI_Rollout&quot;Testing...&quot; ( progressbar Indicator01 width:20 height:20 color:green value:100 ) createDialog testUI_Rollout 100 100 ) macroScript ChangeStatusTestUI category:&quot;MXS Help&quot; ( TestUI_rollout.Indicator01.color = red )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>If you execute the first macro, a rollout with green light appears.</p>\n\
<p>If you execute the second one, the lamp turns red.</p>\n\
<p>As you can see, you can access anything from anywhere, provided that you have defined the respective rollouts as local or global variables in upper scopes to make them &quot;visible&quot;. Even better, you can declare the variables prior to defining their actual contents and access them before the point they are defined.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";