var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Disable Undo system when possible</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Disable Undo system when possible</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"disable-undo-system-when-possible\"></a></div>\n\
<p>The undo system can consume large amounts of memory and slow down processing.</p>\n\
<ul>\n\
<li><p>MAXScript commands run from Listener. Script Editor or Macro Script are run within an undo on context.</p></li>\n\
<li><p>MAXScript commands run from scripted UI controls are <strong>not</strong> run within an undo on context.</p></li>\n\
<li><p>Do not delete nodes with undo off, unless you also created the nodes with undo off and did not do anything to the node with undo on.</p></li>\n\
<li><p>When working with meshes, you typically want to use meshop methods as they support undo/redo. But typically you do not want to store undo records for all operations in a loop, just the first and last.</p></li>\n\
<li><p>When working with EPoly, you want to store undo records for all operations in a loop.</p></li>\n\
</ul>\n\
<blockquote>\n\
<p><strong>TEST CASE:</strong></p>\n\
<p>``` em = mesh() meshop_setvert = meshop.setvert fn test7 holdAll = ( local nVerts = getnumverts em for i = 1 to nVerts do with undo (holdAll or (i == 1 or i == nVerts)) meshop_setvert em i ([1,1,1]*i) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>FOR 100,000 ITERATIONS:</strong></p>\n\
<p>``` test7 true -- 85313 msec., 229 MB test7 false-- 7609 msec., 11 MB</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Every operation that creates an undo record will cost time and memory as it will create internal copies of the changing objects to allow an undo later. When making multiple changes in a loop like for example attaching multiple objects together, the Undo system would attempt to create a single undo copy of each resulting object and might even run out of memory. Disabling Undo explicitly using the <span class=\'code\'>Undo off ()</span> context can help to speed up scripts significantly in such cases.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/undo.html\' title=\'\'>undo</a></p>\n\
<p>The following extreme example shows the difference. In both cases, 1000 boxes will be created using MAXScript and then attached to a single mesh using the attach function. In the first case, each attach call will generate by default an undo record. In the second case, the undo will be explicitly disabled.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE 1 - UNOPTIMIZED SCRIPT:</strong></p>\n\
<p>``` delete $Box*--delete any existing boxes box_array = #()--initialize an array for i = 1 to 1000 do--repeat 1000 times box_array[i] = box pos:[i*30,0,0]--create 1000 boxes st = timestamp()--get the start time in milliseconds main_box = convertToMesh box_array[1]--collapse the first box to mesh for i = 2 to 1000 do--go through all other boxes attach main_box box_array[i]--attach each box to the mesh et = timestamp()--stop the time print (et-st)--print the resulting time gc()--call Garbage Collection &amp;endash; you will needed it!</p>\n\
<p>```</p>\n\
<p>On a 800MHz PC, the execution of the attaching part of the script took more than a minute mainly because the system run out of memory and the OS had to swap to disk. Memory usage for <strong>3ds Max</strong> went up with about 300 MB!</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>EXAMPLE 2 - OPTIMIZED SCRIPT:</strong></p>\n\
<p>``` delete $Box* box_array = #() for i = 1 to 1000 do box_array[i] = box pos:[i*30,0,0] st = timestamp() undo off--the only difference - the undo (--has been turned off main_box = convertToMesh box_array[1] for i = 2 to 1000 do attach main_box box_array[i] )--end undo off et = timestamp() print (et-st) --call Garbage Collection - you will needed it!</p>\n\
<p>```</p>\n\
<p>On the same 800MHz machine, the execution of the attaching part of the script took only 3685 milliseconds, almost 20 times faster! There were no memory consumption changes visible in the Windows Task Manager.</p>\n\
</blockquote>\n\
<p><strong>Previous Tip</strong></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Writing-Better-and-Faster/How-To-Make-It-Faster-/Disable-Viewport-Redraws-when.html\' title=\'\'>Disable Viewport Redraws when making changes to scene objects</a></p>\n\
<p><strong>Next Tip</strong></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Writing-Better-and-Faster/How-To-Make-It-Faster-/Modify-Panel-can-be-slow-change.html\' title=\'\'>Modify Panel can be slow -change to Create Panel when possible</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";