var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>For Loop By Index Vs For Loop Through Collection Performance</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>For Loop By Index Vs For Loop Through Collection Performance</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"for-loop-by-index-vs-for-loop-through-collection-performance\"></a></div>\n\
<div class=\'section\'><a id=\"a-user-asked\"></a><h2 id=\"a-user-asked\">A user asked:</h2></div>\n\
<p>What is the difference between using</p>\n\
<div class=\'codeBlock\'><pre>for i = 1 to theArray.count do( ... )\n\
</pre></div><p>and</p>\n\
<div class=\'codeBlock\'><pre>for i in theArray do( ... )\n\
</pre></div><p>Are they the same? Is one faster than the other ? Anything else to be aware of?</p>\n\
<div class=\'section\'><a id=\"answer\"></a><h2 id=\"answer\">Answer:</h2></div>\n\
<p>Both can be used to do the same, but have different strengths and performance characteristics.</p>\n\
<p>The first version gives you an index. So, if you want to drive a progress bar display, or use the index to access another array with the same amount of elements, it is usually the one to use - you can still get the i-th object, but you also have the number of objects that you have processed so far for free.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` theArray = for i = 1 to 10 collect i ( for i = 1 to theArray.count do ( --assuming prg_bar is a progressbar UI control: --prg_bar.value = 100.0*i/theArray.count --some more code here... ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In the second case, you have to add your own counter local variable to keep track of the current indexes:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` ( cnt = 0 for i in theArray do ( cnt+=1 --prg_bar.value = 100.0*cnt/theArray.count --some more code... ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Also, the first form allows you to loop backwards, which is essential if you are removing elements from the array while processing it. The following example creates an array of 1000 random integers and then in the second for loop it deletes any elements with a value less than 50:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` ( theArray =for i = 1 to 1000 collect random 1 100 for i = theArray.count to 1 by -1 where theArray[i] &lt; 50 do deleteItem theArray i )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>When it comes to speed though, the direct loop through the array elements is faster. Let us create an array of 10000 elements and loop through it 1000 times to get a significant time value to measure. The inner loop itself does not perform any actual work, only loops through the array and accesses the i-th element.</p>\n\
<blockquote>\n\
<p><strong>LOOP BY INDEX:</strong></p>\n\
<p>``` ( theArray = for i = 1 to 10000 collect random 1 100 st = timestamp() for j = 1 to 1000 do for i = 1 to theArray.count do theArray[i] format &quot;% ms\\n&quot; (timestamp()-st) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>This code executes on a particular machine in 5.6 seconds (+/- 0.1 seconds).</p>\n\
<p>Removing the actual access to the array element by index (theArray[i]) reduces this time to 4.6 seconds. For example, if you were running from 1 to the array count, but not using the array elements for anything, which is highly improbable.</p>\n\
<blockquote>\n\
<p><strong>IN COMPARISON, LOOPING THROUGH THE COLLECTION</strong></p>\n\
<p>``` ( theArray =for i = 1 to 10000 collect random 1 100 st = timestamp() for j = 1 to 1000 do for i in theArray do i format &quot;% ms\\n&quot; (timestamp()-st) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>This executes on the same machine in 4.3 seconds (+/- 0.1 sec.), which is 1.3 times faster. Because the variable i already contains the n-th element, it does not matter whether we actually use the array element value for anything or not.</p>\n\
<p>Now, if you do need the counter for something else like progress updates, the first approach is almost four times faster than the second.</p>\n\
<blockquote>\n\
<p><strong>SLOW</strong></p>\n\
<p>``` ( theArray =for i = 1 to 10000 collect random 1 100 st = timestamp() for j = 1 to 1000 do ( cnt = 0 for i in theArray do cnt +=1 ) format &quot;% ms\\n&quot; (timestamp()-st) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The above code executes in 14.3 seconds on the same machine because of the memory overhead involved in overwriting the value of the variable cnt 10 million times.</p>\n\
<p>In other words, if the counter variable is significant for your code, you can use the form <strong>for i = 1 to theArray.count do()</strong>, otherwise use the direct loop through the collection as it is slightly faster in the general case.</p>\n\
<p><strong>Previous Tip</strong></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Writing-Better-and-Faster/How-To-Make-It-Faster-/Try-not-to-use-Execute-function.html\' title=\'\'>Try not to use Execute function if there is an alternative</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";