var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Never get a single pixel when you can get a whole line</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Never get a single pixel when you can get a whole line</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"never-get-a-single-pixel-when-you-can-get-a-whole-line\"></a></div>\n\
<p>The <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Bitmap-Values/Bitmap-Values-1.html\' title=\'\'>getPixels and setPixels functions</a> for reading and writing pixels from / to bitmaps are rather slow.</p>\n\
<p>When changing a large number or even all pixels of a bitmap, it is a good idea to perform the <span class=\'code\'>getPixels()</span> and <span class=\'code\'>setPixels()</span> just once for each horizontal line and do the rest of the work with the resulting array elements.</p>\n\
<p>In the following examples, a 1000x1000 pixels bitmap should be altered by changing every single pixel. This means reading and writing back one million pixels.</p>\n\
<p>In the first example, every single pixel will be read separately, multiplied by a number and written back. We will stop the time in order to compare to the optimized version.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE 1 - UNOPTIMIZED SCRIPT:</strong></p>\n\
<p>``` b = bitmap 1000 1000 color:red--create new bitmap with red background st = timestamp()--get start time in milliseconds for y = 1 to 1000 do--go through all lines in the bitmap ( for x = 1 to 1000 do--go through all pixels in a line ( pixels = getPixels b [x-1,y-1] 1--read one pixel from X,Y pixels[1] *= (x+y)/2000.0--alter the pixel setPixels b [x-1,y-1] pixels--write modified pixel back )--end x loop )--end y loop et = timestamp()--get end time in milliseconds print (et-st)--print time to finish display b--show a nice black-red gradient</p>\n\
<p>```</p>\n\
<p>Running this script on a 2.1GHz system resulted in a time stamp of 16094 milliseconds.</p>\n\
</blockquote>\n\
<p>In the second example, instead of reading every single pixel, will be read every line and process all its pixels inside the array returned by <span class=\'code\'>getPixels()</span> before writing the whole line back to the bitmap. This means we will make only 1000 read and 1000 write calls instead of one million reads and one million writes.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE 2 - OPTIMIZED SCRIPT:</strong></p>\n\
<p>``` b = bitmap 1000 1000 color:red--create new bitmap with red background st = timestamp()--get start time in milliseconds for y = 1 to 1000 do--go through all lines in the bitmap ( pixels = getPixels b [0,y-1] 1000--read all 1000 pixels of a single line for x = 1 to 1000 do--go through all pixels in the line ( pixels[x] *= (x+y)/2000.0--alter the pixel ) setPixels b [0,y-1] pixels--write back the complete modified line ) et = timestamp()--get end time in milliseconds print (et-st)--print time to finish display b--show the same nice black-red gradient</p>\n\
<p>```</p>\n\
<p>Running the optimized script on the same 2.1GHz system resulted in a time stamp of 4937 milliseconds - more than three times faster!</p>\n\
</blockquote>\n\
<p>Since <strong>3ds Max 2010</strong>, <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Bitmap-Values/Bitmap-Values-1.html\' title=\'\'>the pasteBitmap() function</a> can be used in a custom <span class=\'code\'>function:</span> mode to perform per-pixel operations using a MAXScript function. This method does not involve the <span class=\'code\'>getPixels()</span> and <span class=\'code\'>setPixels()</span> calls but does the same and is also great for bothcompositing two bitmaps together and for manipulating pixels ina single bitmap as in our test example.We simply pass the same bitmap twice. The result is normally stored in the second bitmap, in this case it is identical to the first bitmap so we effectively read and write using one bitmap value:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE 3 - ALTERNATIVE SCRIPT:</strong></p>\n\
<p>``` fn compfn c1 p1 c2 p2 = ( c1 * ((p1.x+p1.y)/2000.0) ) b = bitmap 1000 1000 color:red--create new bitmap with red background st = timestamp()--get start time in milliseconds pasteBitmap b b [0,0] [0,0] type:#function function:compfn--call the function per pixel et = timestamp()--get end time in milliseconds print (et-st)--print time to finish display b--show the same nice black-red gradient</p>\n\
<p>```</p>\n\
<p>Running the alternative script on the same 2.1GHz system resulted in a time stamp of 3828 milliseconds - a second faster than the optimized script above!</p>\n\
</blockquote>\n\
<p>The following table shows the times in milliseconds for the three examples at different image resolutions:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\"></th>\n\
<th align=\"left\">2000x2000</th>\n\
<th align=\"left\">1000x1000</th>\n\
<th align=\"left\">500x500</th>\n\
<th align=\"left\">250x250</th>\n\
<th align=\"left\">125x125</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><strong>EXAMPLE 1</strong></td>\n\
<td align=\"left\">64657</td>\n\
<td align=\"left\">16094</td>\n\
<td align=\"left\">3578</td>\n\
<td align=\"left\">906</td>\n\
<td align=\"left\">203</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><strong>EXAMPLE 2</strong></td>\n\
<td align=\"left\">20000</td>\n\
<td align=\"left\">4937</td>\n\
<td align=\"left\">1266</td>\n\
<td align=\"left\">344</td>\n\
<td align=\"left\">62</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><strong>EXAMPLE 3</strong></td>\n\
<td align=\"left\">15187</td>\n\
<td align=\"left\">3828</td>\n\
<td align=\"left\">906</td>\n\
<td align=\"left\">172</td>\n\
<td align=\"left\">47</td>\n\
</tr>\n\
</table>\n\
<p><strong>Previous Tip</strong></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Writing-Better-and-Faster/How-To-Make-It-Faster-/Use-the-flagForeground-node.html\' title=\'\'>Use the &#39;flagForeground&#39; node viewport state method</a></p>\n\
<p><strong>Next Tip</strong></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Writing-Better-and-Faster/How-To-Make-It-Faster-/Only-calculate-once-if-possible.html\' title=\'\'>Only calculate once if possible</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";