var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Only calculate once if possible</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Only calculate once if possible</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"only-calculate-once-if-possible\"></a></div>\n\
<p>MAXScript does no code optimization. You must do your own optimizations.</p>\n\
<p>Try to avoid running the same calculation more than once, or interrogating the same value in the same node more than once.</p>\n\
<blockquote>\n\
<p><strong>TEST CASE:</strong></p>\n\
<p>``` fn test4a inVal = ( local res = 0 for i = 1 to 100 do res += ((inVal * 10) + i) res ) --show the same nice black-red gradient</p>\n\
<p>```</p>\n\
<p>``` fn test4b inVal = ( local res = 0 local temp = inVal * 10 for i = 1 to 100 do res += (temp + i) res )</p>\n\
<p>```</p>\n\
<p><strong>FOR 100,000 ITERATIONS:</strong></p>\n\
<p>``` test4a 0 -- 20562 msec. test4b 0 -- 17797 msec.</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In another example, a typical example of a script that you want to be as fast as possible is a Particle Flow Script Operator. In a typical Script Operator, you usually go through all particles in the Particle Container of the current Event and perform some operations on each one of them.</p>\n\
<p>The Proceed handler typically looks like the following:</p>\n\
<blockquote>\n\
<p><strong>GOOD CODE:</strong></p>\n\
<p>``` on Proceed pCont do ( count = pCont.NumParticles() for i in 1 to count do ( pCont.particleIndex = i pCont.particleVector = pCont.ParticlePosition ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note that the &#39;count&#39; variable containing the number of particles to be processed is evaluated only once and then used as the top limit of the i loop.</p>\n\
<p>Writing the same as the following:</p>\n\
<blockquote>\n\
<p><strong>BAD CODE:</strong></p>\n\
<p>``` on Proceed pCont do ( for i in 1 to pCont.NumParticles() do ( pCont.particleIndex = i pCont.particleVector = pCont.ParticlePosition ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>This will be <strong>a bad idea</strong> because in the case of 1 million particles, the expression <span class=\'code\'>pCont.NumParticles()</span> will be evaluated 1 million times instead of just once.</p>\n\
<p><strong>Previous Tip</strong></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Writing-Better-and-Faster/How-To-Make-It-Faster-/Never-get-a-single-pixel-when.html\' title=\'\'>Never get a single pixel when you can get a whole line</a></p>\n\
<p><strong>Next Tip</strong></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Writing-Better-and-Faster/How-To-Make-It-Faster-/Cache-frequently-used-functions.html\' title=\'\'>Cache freqeuntly used functions and objects</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";