var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Optimizing Particle Flow Script Operator For Loops For Speed</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Optimizing Particle Flow Script Operator For Loops For Speed</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"optimizing-particle-flow-script-operator-for-loops-for-speed\"></a></div>\n\
<div class=\'section\'><a id=\"a-user-posted-this-code-used-inside-an-on-proceed-handler\"></a><h2 id=\"a-user-posted-this-code-used-inside-an-on-proceed-handler\">A user posted this code used inside an On Proceed() handler:</h2></div>\n\
<blockquote>\n\
<p>``` for i in 1 to count do ( pCont.particleIndex = i colmult = 80 pspeed = pCont.particlespeed pvel = sqrt (pspeed.x<em>pspeed.x+pspeed.y</em>pspeed.y+pspeed.z<em>pspeed.z) pCont.particleAge = pvel</em>colmult )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"performance-comments\"></a><h2 id=\"performance-comments\">Performance Comments:</h2></div>\n\
<p>The line,</p>\n\
<div class=\'codeBlock\'><pre>pvel = sqrt (pspeed.x*pspeed.x+pspeed.y*pspeed.y+pspeed.z*pspeed.z)\n\
\n\
</pre></div><p>is equivalent to,</p>\n\
<div class=\'codeBlock\'><pre>pvel = length pspeed\n\
\n\
</pre></div><p>but is 4 times slower. When calculating inside a Particle Flow operator, you want the fastest method because the code is called thousands and even millions of times, once for each particle.</p>\n\
<p>The first code block evaluates in 3360 ms when run on a particular machine.</p>\n\
<blockquote>\n\
<p>``` ( st = timestamp() pspeed = [10,2,3] for i = 1 to 1000000 do sqrt (pspeed.x<em>pspeed.x+pspeed.y</em>pspeed.y+pspeed.z*pspeed.z) format &quot;%\\n&quot; (timestamp()-st) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>However, the same code using the length() method,</p>\n\
<blockquote>\n\
<p>``` ( st = timestamp() pspeed = [10,2,3] for i = 1 to 1000000 do length pspeed format &quot;%\\n&quot; (timestamp()-st) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>evaluates in just 813 ms on the same machine, which is 4.13 times faster.</p>\n\
<p>In addition, assigning to a temporary variable pvel adds 200 ms to 1 million calls in both cases, so rewriting the original code block to</p>\n\
<blockquote>\n\
<p>``` ( for i = 1 to count do( pCont.particleIndex = i pCont.particleAge = length (pCont.particlespeed) * 80 ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>without any intermediate variables can shave off up to 600 ms per one million calls on top of the speed up from using the length() method.</p>\n\
<p>Here is another test to simulate this. It contains three variable assignments within the loop and the original velocity calculation:</p>\n\
<blockquote>\n\
<p>``` ( st = timestamp() for i = 1 to 1000000 do ( pspeed = [10,2,3] colmult = 80 pvel = sqrt (pspeed.x<em>pspeed.x+pspeed.y</em>pspeed.y+pspeed.z<em>pspeed.z) pvel </em> colmult ) format &quot;%\\n&quot; (timestamp()-st) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The above code is very similar to what the original code was doing (minus actually reading and writing particle values). It evaluates in 5750 ms.</p>\n\
<p>In contrast,</p>\n\
<blockquote>\n\
<p>``` ( st = timestamp() for i = 1 to 1000000 do ( pspeed = [10,2,3] colmult = 80 pvel = length pspeed pvel * colmult ) format &quot;%\\n&quot; (timestamp()-st) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>executes in 3200 ms just because we got rid of the three additions and three multiplications within the MAXScript code. Length() does the same internally, but is implemented in C++ and is thus much faster.</p>\n\
<p>The inline version of the test code without any intermediate variables that calculates the same value at the end needs only 1400 ms.</p>\n\
<blockquote>\n\
<p>``` ( st = timestamp() for i = 1 to 1000000 do ( length [10,2,3] * 80 ) format &quot;%\\n&quot; (timestamp()-st) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In short, avoid using local intermediate variables within your PFlow scripts and use built-in methods to get the best performance as in:</p>\n\
<blockquote>\n\
<p>``` ( for i = 1 to pCont,Numparticles() do ( pCont.particleIndex = i pCont.particleAge = length (pCont.particlespeed) * 80 ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Previous Tip</strong></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Writing-Better-and-Faster/How-To-Make-It-Faster-/For-Loop-Collect-Vs-For-Loop-Do.html\' title=\'\'>For Loop Collect Vs For Loop Do Performance</a></p>\n\
<p><strong>Next Tip</strong></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Writing-Better-and-Faster/How-To-Make-It-Faster-/Using-Bsearch-For-Fast-Table.html\' title=\'\'>Using Bsearch For Fast Table Lookup</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";