var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Access Windows System Data</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Access Windows System Data</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-access-windows-system-data\"></a></div>\n\
<p>MAXScript lets you access some system information like file attributes, files and directories etc. Still, most areas of the system environment outside of <strong>3ds Max</strong> are not directly covered by MAXScript itself. Fortunately, there is also the dosCommand method which lets you execute DOS commands in the command prompt console.</p>\n\
<p>In the following example, we will use the dosCommand method to get the PATH environment variables set in Windows.</p>\n\
<p><strong>Related Topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/Interaction-With-The-Operating/System-Information.html\' title=\'\'>System Information</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Miscellaneous-Functions/Executing-External-Commands.html\' title=\'\'>Executing External Commands using DOScommand</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/External-Files-Access/External-File-Methods.html\' title=\'\'>External File Methods</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/FileStream-Values.html\' title=\'\'>FileStream Values</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Create a function to reuse the code in the future.</p>\n\
<p>Execute the Path command from the Command Prompt and redirect output to file.</p>\n\
<p>Read the resulting file and collect all paths between the starting = and the following ; characters.</p>\n\
<p>Store the paths in a list and when ready, return the list as result of the function.</p>\n\
<p>Delete the temporary file to reduce disk pollution.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>MAXSCRIPT</strong></p>\n\
<p>``` fn getEnvironmentPaths = ( dosCommand &quot;path &gt;env.txt&quot; path_array = #() in_text = openfile &quot;env.txt&quot; skipToString in_text &quot;=&quot; while not eof in_text do ( str = readDelimitedString in_text &quot;;&quot; if str != &quot;\\n&quot; then append path_array str ) close in_text deleteFile &quot;env.txt&quot; path_array )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>fn getEnvironmentPaths = (\n\
</pre></div><p>This is going to be a user-defined function without any arguments.</p>\n\
<div class=\'codeBlock\'><pre>DosCommand &quot;path &gt;env.txt&quot;\n\
</pre></div><p>The <span class=\'code\'>dosCommand</span> method expects a string parameter containing the command to be executed. You can supply any command sequences you could type in the Windows Command Prompt. In this case, we execute the PATH command which shows the currently set OS environment paths. We also tell Windows to write the result to a text file called &quot;env.txt&quot;. Then we can use this file to read in the results.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Miscellaneous-Functions/Executing-External-Commands.html\' title=\'\'>Executing External Commands</a></p>\n\
<div class=\'codeBlock\'><pre>path_array = #()\n\
</pre></div><p>We will need an array to store the single path definitions. We will initialize the array to the empty array in the beginning.</p>\n\
<div class=\'codeBlock\'><pre>in_text = openfile &quot;env.txt&quot;\n\
</pre></div><p>Now let’s open the file created by the <span class=\'code\'>dosCommand</span> execution. The content of the file will look like this: &quot;PATH=D:\\WINDOWS\\SYSTEM32;D:\\WINDOWS; &quot; etc. The exact paths will of course vary from system to system. We can see that the first path starts after the &quot;=&quot; character and ends at the &quot;;&quot; character. Each path after the first starts after the &quot;;&quot; and ends with &quot;;&quot;.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/FileStream-Values.html\' title=\'\'>FileStream Values</a></p>\n\
<div class=\'codeBlock\'><pre>SkipToString in_text &quot;=&quot;\n\
</pre></div><p>So we skip to the position of the &quot;=&quot; sign to start reading the first path.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/FileStream-Values.html\' title=\'\'>FileStream Values</a></p>\n\
<div class=\'codeBlock\'><pre>while not eof in_text do (\n\
</pre></div><p>Using a <span class=\'code\'>while</span> loop which will repeat the code within the brackets until End Of File of <span class=\'code\'>in_text</span> has been detected, we will extract all paths found in the file.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/While-and-Do-Loops.html\' title=\'\'>While and Do Loops</a></p>\n\
<div class=\'codeBlock\'><pre>str = readDelimitedString in_text &quot;;&quot;\n\
</pre></div><p>Because we know that all all paths are delimited by a &quot;;&quot;, we can use the readDelimitedString function to read text fragments from the file. We will store them in the user variable str.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/FileStream-Values.html\' title=\'\'>FileStream Values</a></p>\n\
<div class=\'codeBlock\'><pre>if str != &quot;\\n&quot; then append path_array str\n\
</pre></div><p>Next we will have to check whether the <strong>str</strong> variable does not contain the last End Of Line symbol before the End Of File and if it doesn’t, we can add the string to the array of paths.</p>\n\
<div class=\'codeBlock\'><pre>) close in_text\n\
</pre></div><p>Now we are ready with the reading and can close the file.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/FileStream-Values.html\' title=\'\'>FileStream Values</a></p>\n\
<div class=\'codeBlock\'><pre>DeleteFile &quot;env.txt&quot;\n\
</pre></div><p>It was just a temporary file so we can delete it from the disk.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/External-Files-Access/External-File-Methods.html\' title=\'\'>External File Methods</a></p>\n\
<div class=\'codeBlock\'><pre>path_array\n\
</pre></div><p>Lastly, we can return the array with the collected paths as the result of the function.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
</pre></div><div class=\'section\'><a id=\"using-the-script\"></a><h2 id=\"using-the-script\">Using the Script</h2></div>\n\
<p>As this is a function, we have to call it. It has no parameters, so we just call it with ()</p>\n\
<div class=\'codeBlock\'><pre>env_paths = GetEnvironmentPaths()\n\
</pre></div><p>The variable <span class=\'code\'>env_paths</span> will contain an array of the environment paths set under Windows.</p>\n\
<div class=\'section\'><a id=\"where-to-go-from-here\"></a><h2 id=\"where-to-go-from-here\">Where to go from here</h2></div>\n\
<p>You could use the same method to develop variations of the script to access other OS-related data like the environment TEMP path name, the name of the Hard Disk Drive etc.</p>\n\
<p><strong>Back to</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Introduction-to-the.html\' title=\'\'>&quot;How To&quot; Tutorials Index Page</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";