var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Assign Materials Automatically</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Assign Materials Automatically</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-assign-materials-automatically\"></a></div>\n\
<p>MAXScript lets you create callback scripts which monitor scene events like object selection, start or stop of rendering etc. This would let you create scripts that perform certain actions automatically whenever monitored system events have been detected.</p>\n\
<p>The following script will automatically assign the material from slot one of the Material Editor to any selected or newly created object.</p>\n\
<p><strong>Related Topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Defining Macroscripts</a> and their <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Event Handlers</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism.html\' title=\'\'>Callback Scripts</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/General-Node-Properties.html\' title=\'\'>Assigning Materials</a></p>\n\
<p>Accessing <a href=\'#!/url=./developer/MAXScript-Language-Reference/Reserved-Keywords-Symbols/3ds-Max-System-Globals.html\' title=\'\'>Material Editor Materials</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Package the code as macroScript to be used as button, menu or shortcut.</p>\n\
<p>Show the macroScript button checked when the callback is active.</p>\n\
<p>When executed, see if it is already active or not – should remember the active state between executions.</p>\n\
<p>If not active, define a callback to go through all materials of selected objects and assign material editor slot one to all of them.</p>\n\
<p>If already active, delete the old callback</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>MAXSCRIPT</strong></p>\n\
<p>``` macroScript AutoMat category: &quot;HowTo&quot; ( local AutoMat_Enabled on isChecked return AutoMat_Enabled on Execute do ( if AutoMat_Enabled == undefined then AutoMat_Enabled = true else AutoMat_Enabled = not AutoMat_Enabled if AutoMat_Enabled then ( txt =&quot;if superclassof meditmaterials[1] != texturemap do \\n&quot; txt +=&quot;selection.material = meditmaterials[1]&quot; callbacks.addscript #selectionSetChanged txt<br> id:#AssignMaterial persistent:false ) else callbacks.removescripts id:#AssignMaterial updateToolbarButtons() )--end Execute )--end macroScript</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step:</h2></div>\n\
<div class=\'codeBlock\'><pre>macroScript AutoMat category:&quot;HowTo&quot;\n\
(\n\
</pre></div><p>The macroScript will be called <span class=\'code\'>AutoMat</span> . To use the script, you can use Customize... to drag the script from the category <span class=\'code\'>&quot;HowTo&quot;</span> to a toolbar, a menu, a quad menu or to assign to a keyboard shortcut.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Defining Macro Scripts</a></p>\n\
<div class=\'codeBlock\'><pre>local AutoMat_Enabled\n\
</pre></div><p>We need to store the state of the AutoMat script in a variable in order to keep track of whether it is active or not. The variable will be declared as local and will contain undefined in the beginning because we have not assigned a value to it yet.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Scope-of-Variables.html\' title=\'\'>Scope of Variables</a></p>\n\
<div class=\'codeBlock\'><pre>on isChecked return AutoMat_Enabled\n\
</pre></div><p>The <span class=\'code\'>isChecked</span> handler should return <span class=\'code\'>true</span> or <span class=\'code\'>true</span> and determines the state of the button. When <span class=\'code\'>true</span> , the button will appear pressed on the toolbar or will have a checkmark in the Menu / QuadMenu. When <span class=\'code\'>false</span> , it will be displayed normally. <span class=\'code\'>AutoMat_Enabled</span> is a local variable that will contain <span class=\'code\'>true</span> when the callback is active, <span class=\'code\'>false</span> when it is not active, and <span class=\'code\'>undefined</span> when the script has not been started yet.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Macroscript_Body_Event_Handlers</a></p>\n\
<div class=\'codeBlock\'><pre>on Execute do\n\
(\n\
</pre></div><p>The <span class=\'code\'>on Execute</span> handler will be executed each time the macroScript is executed (by pressing the button, selecting from the menu, pressing the shortcut etc.). The handler contains the &quot;body&quot; of the script.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Macroscript_Body_Event_Handlers</a></p>\n\
<div class=\'codeBlock\'><pre>if AutoMat_Enabled == undefined then\n\
AutoMat_Enabled = true\n\
else\n\
AutoMat_Enabled = not AutoMat_Enabled\n\
</pre></div><p>In case the script is started for the first time and the variable contains <span class=\'code\'>undefined</span> , we assign <span class=\'code\'>true</span> to it. Otherwise we invert the current value of the variable using the <a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Simple-Expressions/Logical-Expressions.html\' title=\'\'>Not</a> logical expression - if it was <span class=\'code\'>true</span> it will become <span class=\'code\'>false</span> and vice-versa.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/If-Expression.html\' title=\'\'>If Expression</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Simple-Expressions/Logical-Expressions.html\' title=\'\'>Logical Expressions</a></p>\n\
<div class=\'codeBlock\'><pre>if AutoMat_Enabled then\n\
(\n\
</pre></div><p>If the variable contains <span class=\'code\'>true</span> , we can go on and create our callback. Note that <span class=\'code\'>if</span> expects a Boolean value in order to evaluate either the expression after <span class=\'code\'>then</span> or the expression after <span class=\'code\'>else</span> . So we don&#39;t have to say <span class=\'code\'>AutoMat_Enabled == true</span> as the variable itself contains <span class=\'code\'>true</span> or <span class=\'code\'>false</span> which is enough for <span class=\'code\'>if</span> to make the right decision. Both forms would be valid though.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/If-Expression.html\' title=\'\'>If Expression</a></p>\n\
<div class=\'codeBlock\'><pre>txt = &quot;if superclassof meditmaterials[1] != texturemap do \\n&quot;\n\
</pre></div><p>The callback requires a string containing the script to be executed. When the script text is longer than a single line, it is a good idea to store it in a string variable, in our case the variable <span class=\'code\'>txt</span> . <span class=\'code\'>&quot;\\\\n&quot;</span> is used to denote the new line/carriage return inside the string.</p>\n\
<p>Since the MaterialEditor can display both materials and maps in its slots, we have to make sure that the slot 1 currently does not contain a texturemap. So we check the superclass of the object in slot 1 against textureMap and only go on when it isn’t a texturteMap.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Identifying-and-Accessing/Class-and-Object-Inspector.html\' title=\'\'>Class and Object Inspector Functions</a></p>\n\
<div class=\'codeBlock\'><pre>txt +=&quot;selection.material = meditmaterials[1]&quot;\n\
</pre></div><p>This line of code adds a string to the string already defined in the previous line and makes it &quot;grow&quot;. Because the first line&#39;s string contained &quot;\\n&quot; at the end, the new string added will be on a new line when the string is evaluated or printed to the Listener.</p>\n\
<p>The code inside the string assigns the object found in slot 1 of the Material Editor to the <span class=\'code\'>.material</span> property of the current selection. The .material property is &quot;mappable&quot; which means that MAXScript will iterate internally through all objects found in the selection and assign the material to each one of them. See also <a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Remove-All-Materials.html\' title=\'\'>How To ... Remove All Materials</a> for a similar case.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Reserved-Keywords-Symbols/3ds-Max-System-Globals.html\' title=\'\'>Material_Editor_meditMaterials</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/General-Node-Properties.html\' title=\'\'>General Node Properties</a></p>\n\
<div class=\'codeBlock\'><pre>callbacks.addscript #selectionSetChanged txt id:#AssignMaterial persistent:false\n\
</pre></div><p>Now we can add the script to the scene callback scripts. The script will be executed when the selection set changes, will have a unique ID <span class=\'code\'>#AssignMaterial</span> so we can remove it later by name, and will not be saved with the MAX scene (it is not persistent) which means it will not run if you save the scene and load it again later.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism.html\' title=\'\'>General Event Callback Mechanism</a></p>\n\
<div class=\'codeBlock\'><pre>)\n\
else\n\
callbacks.removescripts id:#AssignMaterial\n\
</pre></div><p>In case the variable <span class=\'code\'>AutoMat_Enabled</span> contains <span class=\'code\'>false</span> , we have to disable the script by removing the callback. Having the unique ID, we can easily remove the script from the list of callbacks by supplying its user-defined name <span class=\'code\'>#AssignMaterial</span></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism.html\' title=\'\'>Callbacks.removeScripts</a></p>\n\
<div class=\'codeBlock\'><pre>updateToolbarButtons ()\n\
</pre></div><p>To make sure that the button state is updated in the toolbar, we force an update of the toolbar buttons.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Reserved-Keywords-Symbols/3ds-Max-System-Globals.html\' title=\'\'>updateToolbarButtons</a></p>\n\
<div class=\'codeBlock\'><pre>)--end Execute\n\
)--end macroScript\n\
</pre></div><div class=\'section\'><a id=\"using-the-script\"></a><h2 id=\"using-the-script\">Using the Script</h2></div>\n\
<p>After evaluating the script and customizing a toolbar, you can do a test. You will need some material (for example with a texture map) in the first Material Editor slot. You can also check the Show Map in Viewport icon in the Material Editor to see the map.</p>\n\
<p>If you create some geometry (for example a box) without pressing the script&#39;s button, it will have no material as usual. After pressing the button and selecting the same object, the material will be assigned to it automatically.</p>\n\
<p>Newly created objects will also have the material assigned immediately as they become the current selection during creation and trigger the selection callback event inside of <strong>3ds Max</strong>.</p>\n\
<p>To disable the script you will have to press the button again – the button / menu item will become unchecked and the callback will be removed. Now you can select and create objects as usual.</p>\n\
<p><strong>Back to</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Introduction-to-the.html\' title=\'\'>&quot;How To&quot; Tutorials Index Page</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";