var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Change Objects At Render Time</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Change Objects At Render Time</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-change-objects-at-render-time\"></a></div>\n\
<p>Using callback scripts, you can let MAXScript perform specific operations whenever certain system events occur. In the following example, we will increase the segment count of all spheres in the scene prior rendering, and decrease again after finishing. This will implement a kind of custom render resolution control for spheres. You can use similar approach to implement other pre-render preparations.</p>\n\
<p><strong>Related Topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Defining MacroScripts</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism.html\' title=\'\'>General Event Callback Mechanism</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Package the code as macroScript to be able to use as a button, menu item or shortcut.</p>\n\
<p>Remove any existing callbacks with our unique id.</p>\n\
<p>Create a string containing the callback script for increasing the segment count of spheres.</p>\n\
<p>In the script, loop through all geometry objects, check for sphere class of the base object and increase the segment count value 8 times.</p>\n\
<p>Register a callback to be called before Rendering starts, give it a unique id.</p>\n\
<p>Create a second string containing the callback script for decreasing the segment count of spheres.</p>\n\
<p>In the script, loop through all geometry objects, check for sphere class of the base object and decrease the segment count value 8 times.</p>\n\
<p>Register a callback to be called after Rendering finishes, give it the same unique id.</p>\n\
<p>Create a second macroScript that removes our callbacks by id.</p>\n\
</blockquote>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-15E55659-1BE5-4343-8A9C-DFC84676195A-low.gif\' title=\'\'></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-FECED988-73E8-490F-A7A5-90D37C2AF8BE-low.gif\' title=\'\'></div>\n\
<blockquote>\n\
<p><strong>MAXSCRIPT</strong></p>\n\
<p>``` macroscript SphereSegsOn category: &quot;HowTo&quot; ( callbacks.removescripts id:#sphere_segs txt =&quot;for o in geometry do(\\n&quot; txt +=&quot;if classof o.baseObject == Sphere then \\n&quot; txt +=&quot;o.baseObject.segments *= 8.0\\n&quot; txt +=&quot;)\\n&quot;</p>\n\
<p>callbacks.addscript #preRender txt id:#sphere_segs txt =&quot;for o in geometry do(\\n&quot; txt +=&quot;if classof o.baseObject == Sphere then \\n&quot; txt +=&quot;o.baseObject.segments /= 8.0\\n&quot; txt +=&quot;)\\n&quot;</p>\n\
<p>callbacks.addscript #postRender txt id:#sphere_segs )</p>\n\
<p>```</p>\n\
<p>``` macroscript SphereSegsOff category: &quot;HowTo&quot; ( callbacks.removescripts id:#sphere_segs )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>macroscript SphereSegsOn category:&quot;HowTo&quot;\n\
(\n\
</pre></div><p>The macroScript will be called <span class=\'code\'>SphereSegsOn</span> . To use the script, you can go to Customize... and drag the script from the category &quot;HowTo&quot; to a toolbar, a menu, a quad menu or assign to a keyboard shortcut.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Defining Macro Scripts</a></p>\n\
<div class=\'codeBlock\'><pre>callbacks.removescripts id:#sphere_segs\n\
</pre></div><p>Before creating new callbacks, we try to remove any existing ones from a previous session. It is allowed to call <span class=\'code\'>callbacks.removescripts</span> even if no callbacks with the specified id exist in the moment. If there are none, the call does nothing. If there are any, they will be removed.</p>\n\
<p>We are going to use the same id <span class=\'code\'>#sphere_segs</span> throughout the code. This way, we can affect only our callbacks without touching any others callbacks.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism.html\' title=\'\'>Callbacks.removeScripts</a></p>\n\
<div class=\'codeBlock\'><pre>txt = &quot;for o in geometry do(\\n&quot;\n\
txt +=&quot;if classof o.baseObject == Sphere then \\n&quot;\n\
txt +=&quot;o.baseObject.segments *= 8.0\\n&quot;\n\
txt +=&quot;)\\n&quot;\n\
</pre></div><p>In order to define a callback, we will need a string containing the code to be executed. We define a new user variable called txt and assign our code to it. The backslash n sequence denotes a new line. The script will loop through all geometry objects in the scene and ask each one for its base object (the object at the bottom of the modifier stack). If the class of the base object is Sphere, then we multiply the existing number of segments by 8. This means that the spheres will be changed even if there are modifiers like MeshSmooth, Bend etc. on the stack.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/String-Values.html\' title=\'\'>String Values</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/For-Loop.html\' title=\'\'>For Loop</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Identifying-and-Accessing/Class-and-Object-Inspector.html\' title=\'\'>Class and Object Inspector Functions</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/General-Node-Properties.html\' title=\'\'>General Node Properties</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Subclasses/GeometryClass-Node/Geometry-Standard-Objects/Sphere-GeometryClass.html\' title=\'\'>Sphere : GeometryClass</a></p>\n\
<div class=\'codeBlock\'><pre>callbacks.addscript #preRender txt id:#sphere_segs\n\
</pre></div><p>Now we can assign the code as a callback script. . The keyword <span class=\'code\'>#preRender</span> tells the callback that the script will be executed before rendering begins. The callback will have our unique id <span class=\'code\'>#sphere_segs</span> so we can remove it by id anytime.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism.html\' title=\'\'>General Event Callback Mechanism</a></p>\n\
<div class=\'codeBlock\'><pre>txt = &quot;for o in geometry do(\\n&quot;\n\
txt +=&quot;if classof o.baseObject == Sphere then \\n&quot;\n\
txt +=&quot;o.baseObject.segments /= 8.0\\n&quot;\n\
txt +=&quot;)\\n&quot;\n\
</pre></div><p>This is basically the same code as before, but instead of multiplying, we divide the segments by 8. This should return all spheres to their original state.</p>\n\
<div class=\'codeBlock\'><pre>callbacks.addscript #postRender txt id:#sphere_segs\n\
</pre></div><p>We assign the new code as a callback script again. The keyword <span class=\'code\'>#postRender</span> tells the callback that the script will be executed after the rendering finishes. The callback will have the same unique id.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
macroscript SphereSegsOff category:&quot;HowTo&quot;\n\
(\n\
</pre></div><p>We define a second macroScript for turning off the effect of the callbacks. It will appear in the same category and will have the name <span class=\'code\'>SphereSegsOff</span></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Defining Macro Scripts</a></p>\n\
<div class=\'codeBlock\'><pre>callbacks.removescripts id:#sphere_segs\n\
</pre></div><p>We remove any existing callbacks with our id. Rendering a scene with spheres should work as usual after calling this line.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism.html\' title=\'\'>Callbacks.removeScripts</a></p>\n\
<div class=\'codeBlock\'><pre>)\n\
</pre></div><div class=\'section\'><a id=\"using-the-script\"></a><h2 id=\"using-the-script\">Using the Script</h2></div>\n\
<p>Evaluate the code. To use the two scripts, you can use Customize... to drag the scripts from the category &quot;HowTo&quot; to a toolbar, a menu, a quad menu or to assign to a keyboard shortcut.</p>\n\
<p>To use the script, create a scene with a couple of spheres and set their segments count quite low (as low as 4). Render the scene – all spheres should look exactly as they do in the viewports. (See first image). Then execute the SphereSegsOn script – nothing will change in the viewport, but if you render the scene again, all spheres will appear completely smooth. (see second image). Execute the SphereSegsOff script and the rendering should return to normal.</p>\n\
<p><strong>Back to</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Introduction-to-the.html\' title=\'\'>&quot;How To&quot; Tutorials Index Page</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";