var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Create Custom Mesh Object</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Create Custom Mesh Object</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-create-custom-mesh-object\"></a></div>\n\
<p>MAXScript lets you create editable mesh objects by supplying lists of vertices and faces to the mesh constructor.</p>\n\
<p>This topic shows how to write a simple mesh-generation script to create a circular 2D mesh object, similar to a sun symbol.</p>\n\
<p><strong>Related Topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/Array-Values.html\' title=\'\'>Working with Arrays</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Editable_Mesh-GeometryClass-and.html\' title=\'\'>Creating Editable Mesh objects</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Define the basic parameters of the mesh object</p>\n\
<p>Generate all vertices of the mesh and store in an array</p>\n\
<p>Generate all faces by indexing the vertices and store in another array</p>\n\
<p>Call the mesh constructor with the two arrays as parameters.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>MAXSCRIPT</strong></p>\n\
<p>``` radius1 = 100 radius2 = 10 width = 10</p>\n\
<p>vert_array = #() face_array = #()</p>\n\
<p>vert_count = 0 num_faces = 10</p>\n\
<p>for a = 0 to (360-(360/num_faces)) by 360/num_faces do ( v1 = [radius1<em>cos(a+width),radius1</em>sin(a+width),0] v2 = [radius1<em>cos(a-width),radius1</em>sin(a-width),0] v3 = [radius2<em>cos(a),radius2</em>sin(a),0] append vert_array v1 append vert_array v2 append vert_array v3</p>\n\
<p>append face_array [vert_count+1,vert_count+3,vert_count+2] vert_count += 3 )</p>\n\
<p>m = mesh vertices:vert_array faces:face_array</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step:</h2></div>\n\
<div class=\'codeBlock\'><pre>radius1 = 100\n\
radius2 = 10\n\
width = 10\n\
</pre></div><p>First, we need some variables to define the geometry. The circular object has an inner and outer radius and a width value defining the outer size of the ray.</p>\n\
<div class=\'codeBlock\'><pre>vert_array = #()\n\
face_array = #()\n\
</pre></div><p>The two arrays store the vertex coordinates and the face definitions.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/Array-Values.html\' title=\'\'>Array Values</a></p>\n\
<div class=\'codeBlock\'><pre>vert_count = 0\n\
</pre></div><p>The user variable <span class=\'code\'>vert_count</span> is set to 0 and will be incremented while creating the faces of the mesh.</p>\n\
<div class=\'codeBlock\'><pre>num_faces = 10\n\
</pre></div><p>The number of steps is related to the number of faces to create. It is used as step in the following loop.</p>\n\
<div class=\'codeBlock\'><pre> for a = 0 to (360-(360/num_faces)) by 360/num_faces do\n\
(\n\
</pre></div><p>The <span class=\'code\'>for a</span> loop counts from 0 to 360 (degrees), minus one step to prevent overlap, with a user-defined step provided by the <span class=\'code\'>num_faces</span> variable. This variable defines the number of &quot;rays&quot; in the mesh. For example, to get 10 rays we need 360/10 = 36 degrees per ray. The <span class=\'code\'>a</span> value will be incremented nine times by the value of 36 to make a full turn in degrees.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/For-Loop.html\' title=\'\'>For Loop</a></p>\n\
<div class=\'codeBlock\'><pre>v1 = [radius1*cos(a+width),radius1*sin(a+width),0]\n\
v2 = [radius1*cos(a-width),radius1*sin(a-width),0]\n\
v3 = [radius2*cos(a),radius2*sin(a),0]\n\
</pre></div><p>Now we will define the 3 vertices for a single face.</p>\n\
<p>The Vertices v1 and v2 are at the outer side of the object.</p>\n\
<p>The Vertex v3 is closer to the center (at distance equal to radius2).</p>\n\
<p>When radius3 is 0, all v3 vertices of all faces are coincident at the center.</p>\n\
<p>We use the equation of the circle which is:</p>\n\
<p>X = CenterX + Radius * Cos(A); Y = CenterY + Radius * Sin(A); Z = 0.0</p>\n\
<p>where A is an angle changing from 0 to 2*Pi. In our case, CenterX and CenterY are 0.0.</p>\n\
<p>By adding and subtracting the width value to/from the angle <span class=\'code\'>a</span> , we get the outer two vertices offset from the actual angle used by the third vertex. The third coordinate Z is always 0 in our case – the mesh will reside on the ground XY plane.</p>\n\
<div class=\'codeBlock\'><pre>append vert_array v1\n\
append vert_array v2\n\
append vert_array v3\n\
</pre></div><p>We add all 3 new vertices to the vertex array.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/Array-Values.html\' title=\'\'>Array Values</a></p>\n\
<div class=\'codeBlock\'><pre>append face_array [vert_count+1,vert_count+3,vert_count+2]\n\
</pre></div><p>Now we can store a face in the face array, listing the 3 vertex indices as a Point3 value in Counter-Clockwise order. This will create the face with a normal pointing up. Since <span class=\'code\'>vert_count</span> is still 3 less than the number of vertices in the <span class=\'code\'>vert_array</span> , we can add 1, 2 and 3 to its current value to get the correct indices needed for the face definition.</p>\n\
<div class=\'codeBlock\'><pre>vert_count += 3\n\
</pre></div><p>Now we increase the vertex counter by 3. Next face definition will use the correct indices again. The same could be expressed as <span class=\'code\'>vert_count = vert_count + 3</span></p>\n\
<div class=\'codeBlock\'><pre>)\n\
m = mesh vertices:vert_array faces:face_array\n\
</pre></div><p>Now we can create a new Editable mesh by calling the <span class=\'code\'>mesh</span> constructor and supplying the vertex and face arrays.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Editable_Mesh-GeometryClass-and.html\' title=\'\'>Editable_Mesh : GeometryClass and TriMesh : Value</a></p>\n\
<div class=\'section\'><a id=\"using-the-script\"></a><h2 id=\"using-the-script\">Using the Script</h2></div>\n\
<p>If you evaluate the script now, a new mesh object will appear in the scene. Changing the initial radius and width values lets you create multiple variations of the mesh.</p>\n\
<div class=\'section\'><a id=\"where-to-go-from-here\"></a><h2 id=\"where-to-go-from-here\">Where to go from here</h2></div>\n\
<p>This was just a sketch of a mesh-creating script. In a second step, we will enhance this code to generate a real geometry plug-in script operating interactively from within the Create tab.</p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Create-Scripted-Geometry.html\' title=\'\'>How To ... Create Scripted Geometry Plug-in</a></p>\n\
<p>Possible things to try yourself would be assigning different material IDs to the separate faces, assigning UVW coordinates to the mesh etc.</p>\n\
<p><strong>Back to</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Introduction-to-the.html\' title=\'\'>&quot;How To&quot; Tutorials Index Page</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";