var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Develop An SVG Polygon Renderer - Part 1</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Develop An SVG Polygon Renderer - Part 1</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-develop-an-svg-polygon-renderer---part-1\"></a></div>\n\
<p>The following is <strong>part one</strong> of a three parts tutorials series demonstrating the use of MAXScript together with the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-textureMap.html\' title=\'\'>Vector_Map TextureMap</a>. MAXScript will be used to write an SVG XML file to disk containing polygon entities representing the faces of scene objects to be rendered. The SVG file can be loaded in any Web Browser or rendered to a bitmap via the <span class=\'code\'>renderMap()</span> function. For more information about the use of MAXScript to create SVG files, please see the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-TextureMap-and.html\' title=\'\'>Vector_Map TextureMap and MAXScript</a> topic.</p>\n\
<p>In <strong>this first part of the tutorial</strong>, we will simply output all camera-facing triangle faces of all geometry object.</p>\n\
<p>In <a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-An-SVG-Polygon/How-To-Develop-An-SVG-Polygon-2.html\' title=\'\'>the second part of the tutorial</a>, we will sort the polygons by depth to make sure the faces do not overlap incorrectly.</p>\n\
<p>In <a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-An-SVG-Polygon/How-To-Develop-An-SVG-Polygon-3.html\' title=\'\'>the third part of the tutorial</a>, we will add support for material colors and implement lighting.</p>\n\
<p><strong>Related topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-textureMap.html\' title=\'\'>Vector_Map TextureMap</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-TextureMap-and.html\' title=\'\'>Vector_Map TextureMap and MAXScript</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/Number-Values.htmlGUID-DF4741A6-F352-4E30-9EEF-35E4CDD45042\' title=\'\'>Number Values - bit methods</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Common-Properties.html\' title=\'\'>renderMap Method</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Define a function to convert MAXScript Colors to Hexadecimal values (Web Format)</p>\n\
<p>Create a new SVG text file and output its header.</p>\n\
<p>Collect information about the view transforms and size.</p>\n\
<p>Loop through all visible geometry scene objects</p>\n\
<p>Get the World Space TriMesh and loop through its faces</p>\n\
<p>Calculate the position of the three vertices of each face in image space and output them to SVG</p>\n\
<p>Close the SVG, create a new Vector_Map instance and render it into a bitmap to display.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` ( fn ColorToHex col = ( local theComponents = #(bit.intAsHex col.r, bit.intAsHex col.g, bit.intAsHex col.b) local theValue = &quot;#&quot; for i in theComponents do theValue += (if i.count == 1 then &quot;0&quot; else &quot;&quot;) + i theValue )</p>\n\
<p>local st = timestamp() local theFileName = (getDir #userscripts + &quot;\\PolygonRendering3.svg&quot;) local theSVGfile = createFile theFileName format &quot;&lt;svg xmlns=&quot;http://www.w3.org/2000/svg&quot;\\n&quot; to:theSVGfile format &quot;\\t\\txmlns:xlink=&quot;http://www.w3.org/1999/xlink&quot;&gt;\\n&quot; to:theSVGfile</p>\n\
<p>local theViewTM = viewport.getTM() theViewTM.row4 = [0,0,0]</p>\n\
<p>local theViewTM2 = viewport.getTM() local theViewSize = getViewSize() local theViewScale = getViewSize() theViewScale.x /= 1024.0 theViewScale.y /= 1024.0</p>\n\
<p>local theStrokeThickness = 3</p>\n\
<p>gw.setTransform (matrix3 1) for o in Geometry where not o.isHiddenInVpt and classof o != TargetObject do ( local theStrokeColor = white local theFillColor = o.wirecolor</p>\n\
<div class=\'codeBlock\'><pre>  local theMesh = snapshotAsMesh o\n\
  for f = 1 to theMesh.numfaces do\n\
  (\n\
      local theNormal = normalize (getFaceNormal theMesh f)\n\
      if (theNormal*theViewTM).z &gt; 0 do\n\
      (\n\
          local theFace = getFace theMesh f\n\
          local v1 = gw.transPoint (getVert theMesh theFace.x)\n\
          local v2 = gw.transPoint (getVert theMesh theFace.y)\n\
          local v3 = gw.transPoint (getVert theMesh theFace.z)\n\
          \n\
          v1.x /= theViewScale.x \n\
          v1.y /= theViewScale.y \n\
          v2.x /= theViewScale.x \n\
          v2.y /= theViewScale.y\n\
          v3.x /= theViewScale.x\n\
          v3.y /= theViewScale.y\n\
          \n\
          format &quot;\\t&lt;polygon points=&#39;%,%  %,%  %,%&#39; \\n&quot; v1.x v1.y v2.x v2.y v3.x v3.y to:theSVGfile\n\
          format &quot;\\tstyle=&#39;stroke:%; fill:%; stroke-width:%&#39;/&gt;\\n&quot; (ColorToHex theStrokeColor) (ColorToHex theFillColor) theStrokeThickness to:theSVGfile          \n\
      )--end if normal positive\n\
  )--end f loop\n\
</pre></div><p>)--end o loop</p>\n\
<p>format &quot;\\n&quot; to:theSVGfile close theSVGfile local theSVGMap = VectorMap vectorFile:theFileName alphasource:0 local theBitmap = bitmap theViewSize.x theViewSize.y renderMap theSVGMap into:theBitmap filter:true display theBitmap format &quot;Render Time: % sec.\\n&quot; ((timestamp()-st)/1000.0) ) ```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>(\n\
</pre></div><p>We open a bracket to ensure all following code will be evaluated in its own local scope.</p>\n\
<div class=\'codeBlock\'><pre>fn ColorToHex col = \n\
(\n\
    local theComponents = #(bit.intAsHex col.r, bit.intAsHex col.g, bit.intAsHex col.b)\n\
    local theValue = &quot;#&quot;\n\
    for i in theComponents do \n\
        theValue += (if i.count == 1 then &quot;0&quot; else &quot;&quot;) + i\n\
    theValue \n\
)\n\
</pre></div><p>This function takes a MAXScript Color Value as argument.</p>\n\
<p>It then creates an array where the Red, Green and Blue components of the Color Value are converted individually to Hexadecimal values (these are returned as Strings by the <span class=\'code\'>bit.intAsHex()</span> method).</p>\n\
<p>A String variable called theValue is initialized to &quot;#&quot; which is the prefix of Hexadecimal Colors used in Web HTML and XML files.</p>\n\
<p>A For Loop then iterates through the already converted components in the array and accumulates into the String variable. Where the String has a single character, a leading zero is included.</p>\n\
<p>The Loop produces the whole Hexadecimal value, for example Red turns into &quot;#ff0000&quot;.</p>\n\
<p>The variable theValue is returned as the result of the function.</p>\n\
<div class=\'codeBlock\'><pre>local st = timestamp()\n\
</pre></div><p>This variable takes the current system time in milliseconds.</p>\n\
<p>We will use it to calculate how long it took to output the SVG and render the resulting Vector_Map to an image in the end of the script.</p>\n\
<div class=\'codeBlock\'><pre>local theFileName = (getDir #userscripts + &quot;\\\\PolygonRendering1.svg&quot;) \n\
local theSVGfile = createFile theFileName\n\
</pre></div><p>We define a file name for our SVG file - it will be stored in the UserScripts folder.</p>\n\
<p>Then we use this file name to create a new ASCII Text file - we will output the SVG XML definition to it.</p>\n\
<div class=\'codeBlock\'><pre>format &quot;&lt;svg xmlns=\\&quot;http://www.w3.org/2000/svg\\&quot;\\n&quot; to:theSVGfile \n\
format &quot;\\t\\txmlns:xlink=\\&quot;http://www.w3.org/1999/xlink\\&quot;&gt;\\n&quot; to:theSVGfile\n\
</pre></div><p>Every SVG file must start with a header describing the content of the XML.</p>\n\
<p>We format this standard information to the newly created text file.</p>\n\
<div class=\'codeBlock\'><pre>local theViewTM =  viewport.getTM() \n\
theViewTM.row4 = [0,0,0]\n\
</pre></div><p>We will need the view transformation matrix of the current viewport, but without the translation part to transform Face Normals into view space to check for their orientation (facing the viewer, or facing away from the viewer).</p>\n\
<p>This is why we zero out the .row4 which contains the translation part.</p>\n\
<div class=\'codeBlock\'><pre>local theViewTM2 = viewport.getTM()\n\
</pre></div><p>We will also need the full view transformation matrix for the vertex coordinate transformations.</p>\n\
<div class=\'codeBlock\'><pre>local theViewSize = getViewSize() \n\
local theViewScale = getViewSize() \n\
theViewScale.x /= 1024.0 \n\
theViewScale.y /= 1024.0\n\
</pre></div><p>In order to convert the 1024x1024 canvas space of the Vertex_Texture, we will need to get the Viewport Size and the Viewport Scale.</p>\n\
<p>The View Size will contain the actual pixel resolution we want to render.</p>\n\
<p>The View Scale will contain the scaling factor to convert from the Vertex_Texture to the render output size.</p>\n\
<div class=\'codeBlock\'><pre>local theStrokeThickness = 3\n\
</pre></div><p>Since we will have a solid fill color without any shading, it is important to make the edges visible, so we set a variable to define the Stroke Thickness as 3.</p>\n\
<div class=\'codeBlock\'><pre>gw.setTransform (matrix3 1) \n\
</pre></div><p>We will be using a graphics window (gw) function to transform the vertices from world space to view space, so we have to ensure the gw transformation matrix is set to the identity matrix.</p>\n\
<div class=\'codeBlock\'><pre>for o in Geometry where not o.isHiddenInVpt and classof o != TargetObject do \n\
(\n\
</pre></div><p>This For Loop will visit all GeometryClass objects and filter out only those that are not hidden for some reason and are not of the TargetObject class which has no valid mesh.</p>\n\
<div class=\'codeBlock\'><pre>    local theStrokeColor = white\n\
    local theFillColor = o.wirecolor    \n\
</pre></div><p>The rendering will use two colors - white for the outlines (Stroke Color), and the object color (a.k.a. wireframe color) for the Fill Color.</p>\n\
<div class=\'codeBlock\'><pre>    local theMesh = snapshotAsMesh o\n\
</pre></div><p>We grab the world state of the current object&#39;s mesh into a variable.</p>\n\
<p>This will allow us to loop through its Faces and access Vertex and Normal data.</p>\n\
<div class=\'codeBlock\'><pre>    for f = 1 to theMesh.numfaces do\n\
    (\n\
</pre></div><p>This For Loop will go through all faces of the current mesh.</p>\n\
<div class=\'codeBlock\'><pre>        local theNormal = normalize (getFaceNormal theMesh f)\n\
</pre></div><p>First of all, we will need the face normal.</p>\n\
<p>Although it should be normalized already, it does not hurt to apply normalize() to it to be completely sure.</p>\n\
<div class=\'codeBlock\'><pre>        if (theNormal*theViewTM).z &gt; 0 do\n\
        (\n\
</pre></div><p>We want to make sure we only draw faces whose normals are pointing at the camera (also known as Backface Culling).</p>\n\
<p>To do this, we multiply the Normal which was originally in World Space by the View Transformation Matrix (the one with Translation part set to zero). This converts the Normal into View space.</p>\n\
<p>At this point, since the view is looking at the scene along its -Z axis, any Z values that are negative are parallel to the viewing direction (facing away from the viewer), while positive Z values mean &quot;facing the viewer&quot;.</p>\n\
<p>There are still some problems at the edges of the Geosphere because there is no sorting by depth (we will add this in Part 2).</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-4665CCAB-CBAF-4795-B77C-45B3CE53315A-low.png\' title=\'\'></div>\n\
<p>Inverting the test to <span class=\'code\'>if (theNormal*theViewTM).z &lt; 0 do</span> will cull the front faces and only draw the backfaces:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-7053E347-08A1-46B3-9FA4-4B46C87F814E-low.png\' title=\'\'></div>\n\
<p>Without this test, ALL faces of the mesh would be drawn, and since we are not performing any other sorting yet, the result would be very messy:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-CAE730F0-8717-4118-ADDB-DF97EF445F15-low.png\' title=\'\'></div>\n\
<div class=\'codeBlock\'><pre>            local theFace = getFace theMesh f\n\
</pre></div><p>We will need the face definition to access its vertices.</p>\n\
<div class=\'codeBlock\'><pre>            local v1 = gw.transPoint (getVert theMesh theFace.x)\n\
            local v2 = gw.transPoint (getVert theMesh theFace.y)\n\
            local v3 = gw.transPoint (getVert theMesh theFace.z)\n\
</pre></div><p>Now we can get each of the face&#39;s 3 vertices and transform them into the current view space.</p>\n\
<div class=\'codeBlock\'><pre>            v1.x /= theViewScale.x \n\
            v1.y /= theViewScale.y \n\
            v2.x /= theViewScale.x \n\
            v2.y /= theViewScale.y\n\
            v3.x /= theViewScale.x\n\
            v3.y /= theViewScale.y\n\
</pre></div><p>But since we have to provide the screen coordinates in the range from 0 to 1023 for the SVG to remap its own canvas to the current view, we have to divide the X and Y components of the transformed vertices by the View Scale factor we calculated in the beginning of the script. This way, a pixel with X at the right border of the viewport will map to 1023, and one at the center of the viewport will be placed exactly at the center of the SVG canvas, regardless of its viewport pixel coordinates.</p>\n\
<div class=\'codeBlock\'><pre>            format &quot;\\t&lt;polygon points=&#39;%,%  %,%  %,%&#39; \\n&quot; v1.x v1.y v2.x v2.y v3.x v3.y to:theSVGfile\n\
            format &quot;\\tstyle=&#39;stroke:%; fill:%; stroke-width:%&#39;/&gt;\\n&quot; (ColorToHex theStrokeColor) (ColorToHex theFillColor) theStrokeThickness to:theSVGfile          \n\
</pre></div><p>Now we can output an SVG polygon definition by providing the X and Y coordinates of the three transformed vertices.</p>\n\
<p>We also define the style of the polygon to use the stroke color we defined, the fill color set to the object&#39;s color, and the thickness of the stroke currently set to 3.</p>\n\
<div class=\'codeBlock\'><pre>        )--end if normal positive\n\
    )--end f loop \n\
)--end o loop\n\
</pre></div><p>We can close the IF test&#39;s body and the two nested loops - the one looping through all faces of the current object, and the other looping through all geometry objects.</p>\n\
<div class=\'codeBlock\'><pre>format &quot;&lt;/svg&gt;\\n&quot; to:theSVGfile \n\
close theSVGfile\n\
</pre></div><p>We can also end the SVG XML body with a closing tag and also close the text file.</p>\n\
<div class=\'codeBlock\'><pre>local theSVGMap = VectorMap vectorFile:theFileName alphasource:0 \n\
local theBitmap = bitmap theViewSize.x theViewSize.y \n\
renderMap theSVGMap into:theBitmap filter:true \n\
display theBitmap\n\
</pre></div><p>Now we can build a new VectorMap using the text file name we output to, and with Alpha channel enabled.</p>\n\
<p>We will output to a predefined bitmap with size based on the exact pixel size of the current viewport.</p>\n\
<p>Then we can render the VectorMap into that bitmap with filtering enabled and finally display the resulting bitmap value.</p>\n\
<div class=\'codeBlock\'><pre>format &quot;Render Time: % sec.\\n&quot; ((timestamp()-st)/1000.0)\n\
</pre></div><p>Before ending the script, we can print the time it took to save the SVG and render the map.</p>\n\
<p>Since the timestamp() is in milliseconds, we have to divide by 1000.0 to produce a value in seconds.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
</pre></div><p>Finally, we close the local scope of the script.</p>\n\
<div class=\'section\'><a id=\"using-the-script-to-render-geometry\"></a><h2 id=\"using-the-script-to-render-geometry\">Using The Script To Render Geometry</h2></div>\n\
<p>Let&#39;s try to render some geometry primitives through a Perspective viewport.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-F592D4BC-D170-4E6F-850D-77C52BEE6BA5-low.png\' title=\'\'></div>\n\
<p>As you can see, the Teapot which consists of 4 elements - Body, Lid, Handle and Spout - has severe sorting problems - the Spout is partially drawn over the Body.</p>\n\
<p>A <strong>similar problem</strong> occurs when rendering multiple individual objects depending on the position of the camera and the order of creation.</p>\n\
<p>In the following example, the Cylinder was created second after the Teapot, while the Sphere which is in fact located behind the Teapot, was created third:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-6CA661BB-5F9D-4EF6-A961-25FF811A75FD-low.png\' title=\'\'></div>\n\
<p>In the <a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-An-SVG-Polygon/How-To-Develop-An-SVG-Polygon-2.html\' title=\'\'>second part of the tutorial</a>, we will <strong>sort</strong> the polygons to avoid incorrect overlapping within a single object and between multiple objects to fix the problems illustrated above.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";