var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Develop An SVG Polygon Renderer - Part 2</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Develop An SVG Polygon Renderer - Part 2</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-develop-an-svg-polygon-renderer---part-2\"></a></div>\n\
<p>The following is <strong>part two</strong> of a three parts tutorials series demonstrating the use of MAXScript together with the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-textureMap.html\' title=\'\'>Vector_Map TextureMap</a>. MAXScript will be used to write an SVG XML file to disk containing polygon entities representing the faces of scene objects to be rendered. The SVG file can be loaded in any Web Browser or rendered to a bitmap using the <span class=\'code\'>renderMap()</span> function. For more information about the use of MAXScript to create SVG files, see the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-TextureMap-and.html\' title=\'\'>Vector_Map TextureMap and MAXScript</a> topic.</p>\n\
<p>In <a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-An-SVG-Polygon/How-To-Develop-An-SVG-Polygon-1.html\' title=\'\'>the first part of the tutorial</a>, we output all camera-facing triangle faces of all geometry objects.</p>\n\
<p>In <strong>this second part of the tutorial</strong>, we will sort the polygons by depth to make sure the faces do not overlap incorrectly.</p>\n\
<p>In <a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-An-SVG-Polygon/How-To-Develop-An-SVG-Polygon-3.html\' title=\'\'>the third part of the tutorial</a>, we will add support for material colors and implement lighting using Facets Shading and Blinn Specular Highlights.</p>\n\
<p><strong>Related topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-textureMap.html\' title=\'\'>Vector_Map TextureMap</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-TextureMap-and.html\' title=\'\'>Vector_Map TextureMap and MAXScript</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/Number-Values.htmlGUID-DF4741A6-F352-4E30-9EEF-35E4CDD45042\' title=\'\'>Number Values - bit methods</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/Array-Values.html\' title=\'\'>qsort Method</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Common-Properties.html\' title=\'\'>renderMap Method</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Define a function to sort array values by the 6th array element which will be the Z depth in camera space.</p>\n\
<p>Introduce an array to collect all polygon data to be drawn, so it can be pre-sorted.</p>\n\
<p>Calculate the Z-depth value and collect all necessary data in the new array.</p>\n\
<p>Sort the new array using <span class=\'code\'>qsort()</span> and the new sorting function.</p>\n\
<p>Loop through the sorted array and draw back to front.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` ( fn ColorToHex col = ( local theComponents = #(bit.intAsHex col.r, bit.intAsHex col.g, bit.intAsHex col.b) local theValue = &quot;#&quot; for i in theComponents do theValue += (if i.count == 1 then &quot;0&quot; else &quot;&quot;) + i theValue )</p>\n\
<p>fn compareFN v1 v2= ( if v1[6] &lt; v2[6] then -1 else 1 )</p>\n\
<p>local st = timestamp() local theFileName = (getDir #userscripts + &quot;\\PolygonRendering.svg&quot;) local theSVGfile = createFile theFileName format &quot;&lt;svg xmlns=&quot;http://www.w3.org/2000/svg&quot;\\n&quot; to:theSVGfile format &quot;\\t\\txmlns:xlink=&quot;http://www.w3.org/1999/xlink&quot;&gt;\\n&quot; to:theSVGfile</p>\n\
<p>local theViewTM = viewport.getTM() theViewTM.row4 = [0,0,0] local theViewTM2 = viewport.getTM() local theViewSize = getViewSize() local theViewScale = getViewSize() theViewScale.x /= 1024.0 theViewScale.y /= 1024.0</p>\n\
<p>local drawArray = #()</p>\n\
<p>local theStrokeThickness = 1</p>\n\
<p>gw.setTransform (matrix3 1) for o in Geometry where not o.isHiddenInVpt and classof o != TargetObject do ( local theStrokeColor = white local theFillColor = o.wirecolor</p>\n\
<div class=\'codeBlock\'><pre>  local theMesh = snapshotAsMesh o\n\
  for f = 1 to theMesh.numfaces do\n\
  (\n\
      local theNormal = normalize (getfaceNormal theMesh f) \n\
      if (theNormal*theViewTM).z &gt; 0 do\n\
      (\n\
          local theFace = getFace theMesh f\n\
          local v1 = gw.transPoint (getVert theMesh theFace.x)\n\
          local v2 = gw.transPoint (getVert theMesh theFace.y)\n\
          local v3 = gw.transPoint (getVert theMesh theFace.z)\n\
          \n\
          v1.x /= theViewScale.x \n\
          v1.y /= theViewScale.y \n\
          v2.x /= theViewScale.x \n\
          v2.y /= theViewScale.y\n\
          v3.x /= theViewScale.x\n\
          v3.y /= theViewScale.y\n\
          \n\
          local theFaceCenter = meshop.getFaceCenter theMesh f\n\
          local theZDepth = (theFaceCenter*theViewTM2).z\n\
          append drawArray #(v1, v2, v3, (ColorToHex theStrokeColor), (ColorToHex theLitFillColor), theZDepth)\n\
\n\
\n\
                  )--end if normal positive\n\
  )--end f loop\n\
</pre></div><p>)--end o loop</p>\n\
<p>qsort drawArray compareFN</p>\n\
<p>for d in drawArray do ( format &quot;\\t<polygon points=\'%,%  %,%  %,%\' \\n\"=\"\" d[1].x=\"\" d[1].y=\"\" d[2].x=\"\" d[2].y=\"\" d[3].x=\"\" d[3].y=\"\" to:thesvgfile=\"\" format=\"\" \"\\tstyle=\'stroke:%; fill:%; stroke-width:%\'></polygon>\\n&quot; d[4] d[5] theStrokeThickness to:theSVGfile )</p>\n\
<p>format &quot;\\n&quot; to:theSVGfile close theSVGfile local theSVGMap = VectorMap vectorFile:theFileName alphasource:0 local theBitmap = bitmap theViewSize.x theViewSize.y renderMap theSVGMap into:theBitmap filter:true display theBitmap format &quot;Render Time: % sec.\\n&quot; ((timestamp()-st)/1000.0) ) ```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<p>Code in <span class=\'code\'>*Italic*</span> is the same as in <a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-An-SVG-Polygon/How-To-Develop-An-SVG-Polygon-1.html\' title=\'\'>Part 1</a>. Code in <span class=\'code\'>Bold</span> is new.</p>\n\
<div class=\'codeBlock\'><pre>(\n\
fn ColorToHex col =\n\
(\n\
    local theComponents = #(bit.intAsHex col.r, bit.intAsHex col.g, bit.intAsHex col.b)\n\
    local theValue = &quot;#&quot;\n\
    for i in theComponents do \n\
        theValue += (if i.count == 1 then &quot;0&quot; else &quot;&quot;) + i\n\
    theValue\n\
)\n\
fn compareFN v1 v2=\n\
(\n\
    if v1[6] &lt; v2[6] then -1 else 1\n\
)\n\
</pre></div><p>This function will be used by the qsort() method to compare two elements of our sorting array.</p>\n\
<p>We will be storing the Z-Depth value of each polygon in the 6th element of the array, so this function will get two array items and will return -1 or 1 depending on whether the first one is farther or closer than the second one.</p>\n\
<div class=\'codeBlock\'><pre>local st = timestamp()\n\
local theFileName = (getDir #userscripts + &quot;\\\\PolygonRendering.svg&quot;)\n\
local theSVGfile = createFile theFileName\n\
format &quot;&lt;svg xmlns=\\&quot;http://www.w3.org/2000/svg\\&quot;\\n&quot; to:theSVGfile\n\
format &quot;\\t\\txmlns:xlink=\\&quot;http://www.w3.org/1999/xlink\\&quot;&gt;\\n&quot; to:theSVGfile\n\
\n\
local theViewTM =  viewport.getTM()\n\
theViewTM.row4 = [0,0,0]\n\
local theViewTM2 = viewport.getTM()\n\
local theViewSize = getViewSize()\n\
local theViewScale = getViewSize()\n\
theViewScale.x /= 1024.0\n\
theViewScale.y /= 1024.0\n\
local drawArray = #()\n\
</pre></div><p>This array will be populated with the polygons including vertices transformed into view space, colors to use for Stroke and Fill, as well as the Z-Depth value for sorting.</p>\n\
<div class=\'codeBlock\'><pre>local theStrokeThickness = 1\n\
</pre></div><p>We will set the Stroke to 1 to be able to better investigate the previous problems at the outlines of the Geosphere.</p>\n\
<div class=\'codeBlock\'><pre>gw.setTransform (matrix3 1) \n\
for o in Geometry where not o.isHiddenInVpt and classof o != TargetObject do\n\
(\n\
    local theStrokeColor = white\n\
    local theFillColor = o.wirecolor    \n\
    \n\
    local theMesh = snapshotAsMesh o\n\
    for f = 1 to theMesh.numfaces do\n\
    (\n\
        local theNormal = normalize (getfaceNormal theMesh f) \n\
        if (theNormal*theViewTM).z &gt; 0 do\n\
        (\n\
            local theFace = getFace theMesh f\n\
            local v1 = gw.transPoint (getVert theMesh theFace.x)\n\
            local v2 = gw.transPoint (getVert theMesh theFace.y)\n\
            local v3 = gw.transPoint (getVert theMesh theFace.z)\n\
            \n\
            v1.x /= theViewScale.x \n\
            v1.y /= theViewScale.y \n\
            v2.x /= theViewScale.x \n\
            v2.y /= theViewScale.y\n\
            v3.x /= theViewScale.x\n\
            v3.y /= theViewScale.y\n\
            local theFaceCenter = meshop.getFaceCenter theMesh f\n\
            local theZDepth = (theFaceCenter*theViewTM2).z \n\
</pre></div><p>We will sort by the distance of the Face Center to the viewer, so we need to get the Face Center position in the World Space first, then transform it into the View space.</p>\n\
<p>The Z coordinate will be a negative value that will be lower the farther the point is from the viewer.</p>\n\
<p>We will use this in our sorting function called by <span class=\'code\'>qsort()</span> .</p>\n\
<div class=\'codeBlock\'><pre>            append drawArray #(v1, v2, v3, (ColorToHex theStrokeColor), (ColorToHex theLitFillColor), theZDepth)\n\
</pre></div><p>Instead of outputting directly to the SVG file, we will collect each polygon in the drawArray variable, including the three vertices in screen space, the Hexadecimal colors of the polygon&#39;s Stroke and Fill, and the Z-Depth value calculated above.</p>\n\
<div class=\'codeBlock\'><pre>        )--end if normal positive\n\
    )--end f loop\n\
)--end o loop\n\
qsort drawArray compareFN\n\
</pre></div><p>Now, we can sort the drawArray according to the distance stored in the 6th element (the Z-Depth value).</p>\n\
<p>We want polygons with lower Z-Depth (larger negative numbers) to be drawn first, thus implementing the &quot;Painters Algorithm&quot; where the drawing is performed back to front relative to the camera.</p>\n\
<div class=\'codeBlock\'><pre>for d in drawArray do\n\
(\n\
    format &quot;\\t&lt;polygon points=&#39;%,%  %,%  %,%&#39; \\n&quot; d[1].x d[1].y d[2].x d[2].y d[3].x d[3].y to:theSVGfile\n\
    format &quot;\\tstyle=&#39;stroke:%; fill:%; stroke-width:%&#39;/&gt;\\n&quot; d[4] d[5] theStrokeThickness to:theSVGfile\n\
)\n\
</pre></div><p>This for loop will output the sorted polygon data to the SVG file.</p>\n\
<p>This is very similar to the previous version of the code, but we do this in a second loop and read the values from the sorted array.</p>\n\
<div class=\'codeBlock\'><pre>format &quot;&lt;/svg&gt;\\n&quot; to:theSVGfile\n\
close theSVGfile\n\
local theSVGMap = VectorMap vectorFile:theFileName alphasource:0\n\
local theBitmap = bitmap theViewSize.x theViewSize.y\n\
renderMap theSVGMap into:theBitmap filter:true\n\
display theBitmap\n\
format &quot;Render Time: % sec.\\n&quot; ((timestamp()-st)/1000.0)\n\
)\n\
</pre></div><div class=\'section\'><a id=\"using-the-script-to-render-geometry\"></a><h2 id=\"using-the-script-to-render-geometry\">Using The Script To Render Geometry</h2></div>\n\
<p>Let us test the changes to the script on the same examples as in Part 1 to see the difference.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-A9B56F7D-64FF-41EF-918D-B33EA577D7A2-low.png\' title=\'\'></div>\n\
<p>As you can see, the problems at the edges of the Geosphere have been solved by the new sorted drawing approach.</p>\n\
<p>It matches the results seen in the viewport using &quot;Consistent Colors + Edged Faces&quot; drawing mode pretty closely.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-87DC858E-7C33-40A2-85A5-00E916E855D8-low.png\' title=\'\'></div>\n\
<p>Let us increase the Stroke Thickness to 2 and render the Teapot primitive from the Part 1:</p>\n\
<p><img src=\'developer/images/GUID-88054D36-8DC3-4AF0-BDE9-512A1B158ED1-low.png\' title=\'\'> <img src=\'developer/images/GUID-38B10D6E-F302-4830-9457-9206EA0AA706-low.png\' title=\'\'></p>\n\
<p>Let us resize the viewport and look at the result:</p>\n\
<p><img src=\'developer/images/GUID-8B4102E6-3BAA-4A11-B0FD-CFF487356F90-low.png\' title=\'\'> <img src=\'developer/images/GUID-6FE1C4E7-3199-4168-908E-85C0CBE3007E-low.png\' title=\'\'></p>\n\
<p>Rendering the problematic setup from the first part also produces correct results now:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-74F04213-511B-4230-9128-4CDC677CA769-low.png\' title=\'\'></div>\n\
<p>Because we are culling the backfaces, it is possible to see the Sphere through the gap between the Teapot&#39;s Body and Lid.</p>\n\
<p>By remarking the backface culling line,</p>\n\
<div class=\'codeBlock\'><pre>-- if (theNormal*theViewTM).z &gt; 0 do\n\
</pre></div><p>we can render all polygons of all objects without any culling. The rendering will take approximately twice as long, but the sphere will be correctly occluded:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-28D3C5E3-F137-4F6E-8F35-39737EB3BC42-low.png\' title=\'\'></div>\n\
<p>In the <a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-An-SVG-Polygon/How-To-Develop-An-SVG-Polygon-3.html\' title=\'\'>third part of the tutorial</a>, we will add material color and lighting support to the script to produce faceted rendering with diffuse shading and Blinn specular highlights.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";