var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Develop An SVG Polygon Renderer - Part 3</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Develop An SVG Polygon Renderer - Part 3</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-develop-an-svg-polygon-renderer---part-3\"></a></div>\n\
<p>The following is <strong>part three</strong> of a three parts tutorials series demonstrating the use of MAXScript together with the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-textureMap.html\' title=\'\'>Vector_Map TextureMap</a>. MAXScript will be used to write an SVG XML file to disk containing polygon entities representing the faces of scene objects to be rendered. The SVG file can be loaded in any Web Browser or rendered to a bitmap via the <span class=\'code\'>renderMap()</span> function. For more information about the use of MAXScript to create SVG files, please see the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-TextureMap-and.html\' title=\'\'>Vector_Map TextureMap and MAXScript</a> topic.</p>\n\
<p>In <a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-An-SVG-Polygon/How-To-Develop-An-SVG-Polygon-1.html\' title=\'\'>the first part of the tutorial</a>, we output all camera-facing triangle faces of all geometry object.</p>\n\
<p>In <a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-An-SVG-Polygon/How-To-Develop-An-SVG-Polygon-2.html\' title=\'\'>the second part of the tutorial</a>, we sorted the polygons by depth to make sure the faces do not overlap incorrectly.</p>\n\
<p>In <strong>this third part of the tutorial</strong>, we will add support for material colors and implement lighting using Facets Shading and Blinn Specular Highlights.</p>\n\
<p><strong>Related topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-textureMap.html\' title=\'\'>Vector_Map TextureMap</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Types/Vector_Map-TextureMap/Vector_Map-TextureMap-and.html\' title=\'\'>Vector_Map TextureMap and MAXScript</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/Number-Values.htmlGUID-DF4741A6-F352-4E30-9EEF-35E4CDD45042\' title=\'\'>Number Values - bit methods</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/TextureMap-Material/TextureMap-Common-Properties.html\' title=\'\'>renderMap Method</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Get the Viewer&#39;s Position value from the View Transformation Matrix.</p>\n\
<p>Get the Diffuse Color, SpecularLevel and Glossiness of the material, if any. Otherwise use default values.</p>\n\
<p>Calculate the Diffuse and Specular components of the Blinn Shading model.</p>\n\
<p>Accumulate the influence of all scene lights in a variable</p>\n\
<p>Pass the new lighting variable to the array for sorting and drawing.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` ( fn ColorToHex col = ( local theComponents = #(bit.intAsHex col.r, bit.intAsHex col.g, bit.intAsHex col.b) local theValue = &quot;#&quot; for i in theComponents do theValue += (if i.count == 1 then &quot;0&quot; else &quot;&quot;) + i theValue )</p>\n\
<p>fn compareFN v1 v2= ( if v1[6] &lt; v2[6] then -1 else 1 )</p>\n\
<p>local st = timestamp() local theFileName = (getDir #userscripts + &quot;\\PolygonRendering8.svg&quot;) local theSVGfile = createFile theFileName format &quot;&lt;svg xmlns=&quot;http://www.w3.org/2000/svg&quot;\\n&quot; to:theSVGfile format &quot;\\t\\txmlns:xlink=&quot;http://www.w3.org/1999/xlink&quot;&gt;\\n&quot; to:theSVGfile</p>\n\
<p>local theViewTM = viewport.getTM() theViewTM.row4 = [0,0,0] local theViewTM2 = viewport.getTM() local theViewPos = (inverse (viewport.getTM())).row4 local theViewSize = getViewSize() local theViewScale = getViewSize() theViewScale.x /= 1024.0 theViewScale.y /= 1024.0</p>\n\
<p>local drawArray = #()</p>\n\
<p>local theStrokeThickness = 1</p>\n\
<p>gw.setTransform (matrix3 1) local theLights = for o in Lights where classof o != TargetObject collect o for o in Geometry where not o.isHiddenInVpt and classof o != TargetObject do ( local theStrokeColor = o.wirecolor if classof o.material == StandardMaterial then ( local theFillColor = o.material.diffusecolor local theSpecularPower = o.material.Glossiness local theSpecularLevel = o.material.SpecularLevel/100.0 ) else ( local theFillColor = o.wirecolor<br> local theSpecularPower = 50.0 local theSpecularLevel = 0.25 )</p>\n\
<div class=\'codeBlock\'><pre>  local theMesh = snapshotAsMesh o\n\
  for f = 1 to theMesh.numfaces do\n\
  (\n\
      local theNormal = normalize (getfaceNormal theMesh f) \n\
      if (theNormal*theViewTM).z &gt; 0 do\n\
      (\n\
          local theFace = getFace theMesh f\n\
          local v1 = gw.transPoint (getVert theMesh theFace.x)\n\
          local v2 = gw.transPoint (getVert theMesh theFace.y)\n\
          local v3 = gw.transPoint (getVert theMesh theFace.z)\n\
          \n\
          v1.x /= theViewScale.x \n\
          v1.y /= theViewScale.y \n\
          v2.x /= theViewScale.x \n\
          v2.y /= theViewScale.y\n\
          v3.x /= theViewScale.x\n\
          v3.y /= theViewScale.y\n\
          \n\
          local theFaceCenter = meshop.getFaceCenter theMesh f\n\
          local theZDepth = (theFaceCenter*theViewTM2).z\n\
          local theViewVector = normalize (theViewPos - theFaceCenter)\n\
          \n\
          local theLitFillColor = black\n\
          for aLight in theLights where classof aLight != TargetObject do\n\
          (\n\
              local theLightVector = normalize (aLight.pos - theFaceCenter)\n\
              local theHalfVector = normalize (theLightVector + theViewVector)\n\
              \n\
              theDiffuse = (dot theLightVector theNormal)\n\
              if theDiffuse &lt; 0 do theDiffuse = 0\n\
                  \n\
              theSpecular = (dot theNormal theHalfVector)\n\
              if theSpecular &lt; 0 do theSpecular = 0\n\
              theSpecular = (theSpecular^theSpecularPower)*theSpecularLevel\n\
          \n\
              theLitFillColor += theFillColor * aLight.color * theDiffuse + aLight.color * theSpecular\n\
          )\n\
          if theLitFillColor.r &gt; 255.0 do theLitFillColor.r = 255\n\
          if theLitFillColor.g &gt; 255.0 do theLitFillColor.g = 255\n\
          if theLitFillColor.b &gt; 255.0 do theLitFillColor.b = 255\n\
          \n\
          append drawArray #(v1, v2, v3, (ColorToHex theStrokeColor), (ColorToHex theLitFillColor), theZDepth)\n\
      )--end aLight loop\n\
  )--end f loop\n\
</pre></div><p>)--end o loop qsort drawArray compareFN</p>\n\
<p>for d in drawArray do ( format &quot;\\t<polygon points=\'%,%  %,%  %,%\' \\n\"=\"\" d[1].x=\"\" d[1].y=\"\" d[2].x=\"\" d[2].y=\"\" d[3].x=\"\" d[3].y=\"\" to:thesvgfile=\"\" format=\"\" \"\\tstyle=\'stroke:%; fill:%; stroke-width:%\'></polygon>\\n&quot; d[4] d[5] theStrokeThickness to:theSVGfile )</p>\n\
<p>format &quot;\\n&quot; to:theSVGfile close theSVGfile local theSVGMap = VectorMap vectorFile:theFileName alphasource:0 local theBitmap = bitmap theViewSize.x theViewSize.y renderMap theSVGMap into:theBitmap filter:true display theBitmap format &quot;Render Time: % sec.\\n&quot; ((timestamp()-st)/1000.0) ) ```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>(\n\
fn ColorToHex col =\n\
(\n\
    local theComponents = #(bit.intAsHex col.r, bit.intAsHex col.g, bit.intAsHex col.b)\n\
    local theValue = &quot;#&quot;\n\
    for i in theComponents do \n\
        theValue += (if i.count == 1 then &quot;0&quot; else &quot;&quot;) + i\n\
    theValue\n\
)\n\
\n\
fn compareFN v1 v2=\n\
(\n\
    if v1[6] &lt; v2[6] then -1 else 1\n\
)\n\
\n\
local st = timestamp()\n\
local theFileName = (getDir #userscripts + &quot;\\\\PolygonRendering8.svg&quot;)\n\
local theSVGfile = createFile theFileName\n\
format &quot;&lt;svg xmlns=\\&quot;http://www.w3.org/2000/svg\\&quot;\\n&quot; to:theSVGfile\n\
format &quot;\\t\\txmlns:xlink=\\&quot;http://www.w3.org/1999/xlink\\&quot;&gt;\\n&quot; to:theSVGfile\n\
\n\
local theViewTM =  viewport.getTM()\n\
theViewTM.row4 = [0,0,0]\n\
local theViewTM2 = viewport.getTM()\n\
local theViewPos = (inverse (viewport.getTM())).row4 \n\
</pre></div><p>In order to calculate the shading, we will need to compute the view ray connecting the eye (camera position) with the center of the face.</p>\n\
<p>Even when there is no explicit camera, the fourth row of the inverted view transformation matrix gives us the viewer&#39;s location.</p>\n\
<div class=\'codeBlock\'><pre>local theViewSize = getViewSize()\n\
local theViewScale = getViewSize()\n\
theViewScale.x /= 1024.0\n\
theViewScale.y /= 1024.0\n\
\n\
local drawArray = #()   \n\
    \n\
local theStrokeThickness = 1\n\
    \n\
gw.setTransform (matrix3 1) \n\
local theLights = for o in Lights where classof o != TargetObject collect o\n\
for o in Geometry where not o.isHiddenInVpt and classof o != TargetObject do\n\
(\n\
    local theStrokeColor = o.wirecolor\n\
    if classof o.material == StandardMaterial then \n\
    (\n\
        local theFillColor = o.material.diffusecolor \n\
        local theSpecularPower = o.material.Glossiness\n\
        local theSpecularLevel = o.material.SpecularLevel/100.0\n\
    )\n\
    else\n\
    (\n\
        local theFillColor = o.wirecolor    \n\
        local theSpecularPower = 50.0\n\
        local theSpecularLevel = 0.25\n\
    )\n\
</pre></div><p>We will now change the Stroke color to be taken from the object&#39;s wirecolor property.</p>\n\
<p>The Fill color will be set to the diffuse color of the material if a Standard Material is assigned to the object, otherwise the wirecolor will be used again.</p>\n\
<p>Additionally, we will try to get the SpecularPower (Glossiness) value and the SpecularLevel of the Standard Material to reflect correctly the shading parameters.</p>\n\
<p>Note that the 3ds Max UI exposes the Specular Level as 100 times stronger to make it easier to control, so we have to divide it by 100.0 to bring it in the right range.</p>\n\
<p>If there is no Material, we will set the specular settings to be very close to what the <strong>3ds Max</strong> viewports use in that case...</p>\n\
<div class=\'codeBlock\'><pre>local theMesh = snapshotAsMesh o\n\
    for f = 1 to theMesh.numfaces do\n\
    (\n\
        local theNormal = normalize (getfaceNormal theMesh f) \n\
        if (theNormal*theViewTM).z &gt; 0 do\n\
        (\n\
            local theFace = getFace theMesh f\n\
            local v1 = gw.transPoint (getVert theMesh theFace.x)\n\
            local v2 = gw.transPoint (getVert theMesh theFace.y)\n\
            local v3 = gw.transPoint (getVert theMesh theFace.z)\n\
            \n\
            v1.x /= theViewScale.x \n\
            v1.y /= theViewScale.y \n\
            v2.x /= theViewScale.x \n\
            v2.y /= theViewScale.y\n\
            v3.x /= theViewScale.x\n\
            v3.y /= theViewScale.y\n\
            \n\
            local theFaceCenter = meshop.getFaceCenter theMesh f\n\
            local theZDepth = (theFaceCenter*theViewTM2).z\n\
\n\
            local theViewVector = normalize (theViewPos - theFaceCenter)\n\
</pre></div><p>For the shading calculations, we will need the normalized view vector pointing from the center of the face at the viewer&#39;s position.</p>\n\
<div class=\'codeBlock\'><pre>local theLitFillColor = black\n\
</pre></div><p>We will initialize a new variable to black color.</p>\n\
<p>This will be the variable where we will accumulate the lighting information as we process the lights and shade the face.</p>\n\
<p>We could initialize this value to the Ambient color of the material if we want to support Ambient lighting.</p>\n\
<div class=\'codeBlock\'><pre>            for aLight in theLights where classof aLight != TargetObject do\n\
            (\n\
                local theLightVector = normalize (aLight.pos - theFaceCenter)\n\
                local theHalfVector = normalize (theLightVector + theViewVector)\n\
</pre></div><p>A for loop will visit all light sources in the scene.</p>\n\
<p>For each light, we will calculate the light vector (a normalized vector pointing from the center of the face at the light).</p>\n\
<p>We will also calculate the Half-Vector (according to the Blinn Shading approximation of the Phong Shading model) by adding the Light Vector and the View Vector.</p>\n\
<div class=\'codeBlock\'><pre>                theDiffuse = (dot theLightVector theNormal)\n\
                if theDiffuse &lt; 0 do theDiffuse = 0\n\
</pre></div><p>The Diffuse component is calculated as the dot product of the Light Vector and the Normal. It is view-independent (because the diffusion is Isotropic, the same in all directions).</p>\n\
<p>The amount of light diffused depends only on the cosine of the angle between the Light Vector and the Normal.</p>\n\
<p>Faces pointing away from the light get no light at all, so when the dot product is negative, we set the value to 0.</p>\n\
<div class=\'codeBlock\'><pre>                theSpecular = (dot theNormal theHalfVector)\n\
                if theSpecular &lt; 0 do theSpecular = 0\n\
                theSpecular = (theSpecular^theSpecularPower)*theSpecularLevel \n\
</pre></div><p>The Specular component on the other hand is view-dependent.</p>\n\
<p>We calculate the dot product of the Normal and the Half Vector which depends on the Light Vector and the View Vector.</p>\n\
<p>Again, we don&#39;t want any influence on faces that are facing in the opposite direction, so we zero out any values below 0.</p>\n\
<p>The actual specular value is then taken to the power of the Glossiness (a.k.a. SpecularPower), and multiplied by the Specular Level.</p>\n\
<div class=\'codeBlock\'><pre>                theLitFillColor += theFillColor * aLight.color * theDiffuse + aLight.color * theSpecular\n\
            )--end aLight loop\n\
</pre></div><p>The influence of the light will be accumulated into the variable we originally initialized to black.</p>\n\
<p>The value that is added is comprised of the fill color multiplied by the light color, multiplied by the Diffuse coefficient.</p>\n\
<p>To that we add the light color multiplied by the Specular coefficient.</p>\n\
<p>This is repeated for all lights, producing the combined illumination of the face.</p>\n\
<div class=\'codeBlock\'><pre>            if theLitFillColor.r &gt; 255.0 do theLitFillColor.r = 255\n\
            if theLitFillColor.g &gt; 255.0 do theLitFillColor.g = 255\n\
            if theLitFillColor.b &gt; 255.0 do theLitFillColor.b = 255\n\
</pre></div><p>Finally we want to clamp the color to 255 to avoid strange results because the Hexadecimal conversion does not support Hight Dynamic Range colors.</p>\n\
<div class=\'codeBlock\'><pre>            \n\
            append drawArray #(v1, v2, v3, (ColorToHex theStrokeColor), (ColorToHex theLitFillColor), theZDepth)\n\
</pre></div><p>We just have to change the name of the Fill Color variable to include the lighting in the array.</p>\n\
<div class=\'codeBlock\'><pre>                            )\n\
    )--end f loop\n\
)--end o loop\n\
qsort drawArray compareFN\n\
\n\
for d in drawArray do\n\
(\n\
    format &quot;\\t&lt;polygon points=&#39;%,%  %,%  %,%&#39; \\n&quot; d[1].x d[1].y d[2].x d[2].y d[3].x d[3].y to:theSVGfile\n\
    format &quot;\\tstyle=&#39;stroke:%; fill:%; stroke-width:%&#39;/&gt;\\n&quot; d[4] d[5] theStrokeThickness to:theSVGfile\n\
)\n\
\n\
format &quot;&lt;/svg&gt;\\n&quot; to:theSVGfile\n\
close theSVGfile\n\
local theSVGMap = VectorMap vectorFile:theFileName alphasource:0\n\
local theBitmap = bitmap theViewSize.x theViewSize.y\n\
renderMap theSVGMap into:theBitmap filter:true\n\
display theBitmap\n\
format &quot;Render Time: % sec.\\n&quot; ((timestamp()-st)/1000.0)\n\
)\n\
</pre></div><div class=\'section\'><a id=\"using-the-script-to-render-geometry-and-lights\"></a><h2 id=\"using-the-script-to-render-geometry-and-lights\">Using The Script To Render Geometry And Lights</h2></div>\n\
<p>Let&#39;s render once again the same Geosphere as before, but this time lit by two Omni lights - one white on the left, and one blue and with a lower Multiplier on the right.</p>\n\
<p>The left image is the screenshot of the viewport set to Facets + Edged Faces mode. The right image shows the render output of our SVG script:</p>\n\
<p><img src=\'developer/images/GUID-C84DFD5F-E226-4A55-9298-3945D08D27FA-low.png\' title=\'\'> <img src=\'developer/images/GUID-6AA98CD9-6EAD-4E8A-AD57-B11BFC432B31-low.png\' title=\'\'></p>\n\
<p>Let&#39;s see how this changes when we assign a default Standard Material to this object.</p>\n\
<p>The Fill color of the faces will now be taken from the Diffuse color of the material, while the Stroke color will be taken from the .wirecolor property:</p>\n\
<p><img src=\'developer/images/GUID-EAB89C30-A7F6-4658-BFD2-A1DB34B2DBF8-low.png\' title=\'\'> <img src=\'developer/images/GUID-727BE682-9D48-4DE2-8FA4-44D479712CB3-low.png\' title=\'\'></p>\n\
<p>The default Standard Material has a Specular Level of 0, so there is no Specular component in the above rendering.</p>\n\
<p>Let&#39;s increase the Specular Level to 100, and change the Glossiness to 20.</p>\n\
<p><img src=\'developer/images/GUID-370D4B31-063D-4AB2-91DB-352AF78BC506-low.png\' title=\'\'> <img src=\'developer/images/GUID-496B9530-7ED2-4C3B-9E05-C60E5D6A5649-low.png\' title=\'\'></p>\n\
<p>It is very easy to modify the script to render without edged faces - simply set the edge color to the lit fill color!</p>\n\
<div class=\'codeBlock\'><pre>append drawArray #(v1, v2, v3, (ColorToHex theLitFillColor), (ColorToHex theLitFillColor), theZDepth)\n\
</pre></div><p>As you can see, our script&#39;s output matches very closely the representation of the same object in the viewport:</p>\n\
<p><img src=\'developer/images/GUID-809E9482-71C0-4FE9-8AB2-E413AD1EE9DE-low.png\' title=\'\'> <img src=\'developer/images/GUID-F227DCF4-A40C-4E7A-B706-C6C146E8F8B1-low.png\' title=\'\'></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";