var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Copy The Last Rendered Image To The Windows Clipboard</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Copy The Last Rendered Image To The Windows Clipboard</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-copy-the-last-rendered-image-to-the-windows-clipboard\"></a></div>\n\
<p>The following tutorial demonstrates the use of the <strong>System.Windows.Forms.Clipboard</strong> DotNetClass to read and write bitmaps from and to the Windows Clipboard.</p>\n\
<p>The script can be saved into one of the Startup folders to be evaluated on startup. The custom function will be executed by a PostRender callback each time the renderer finishes, putting the last rendered image into the Windows Clipboard automatically.</p>\n\
<p><strong>Related topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript.html\' title=\'\'>DotNet In MAXScript</a></p>\n\
<p><a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/dotnetclass.html\' title=\'\'>dotNetClass</a></p>\n\
<p><a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/Selected-DotNet-Classes-and/dotNetClass-System-Windows-Forms.html\' title=\'\'>dotNetClass:System.Windows.Forms.Clipboard</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Define a global function to be called by a general callback after each rendering.</p>\n\
<p>Get the DotNet class exposing Windows Clipboard functionality</p>\n\
<p>Get the last rendered image via MAXScript</p>\n\
<p>Save the image to disk</p>\n\
<p>Convert the image to a DotNet Image</p>\n\
<p>Put the image into the Windows Clipboard</p>\n\
<p>Release any memory related to the image and delete the file from disk</p>\n\
<p>Returns true if the clipboard now contains an image</p>\n\
<p>Unregister any callbacks with the same ID</p>\n\
<p>Register a PostRender callback with a custom ID that calls the function</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` fn CopyRenderToClipboard = ( clipboardClass = dotNetClass &quot;System.Windows.Forms.Clipboard&quot; b = getLastRenderedImage() theFileName = GetDir #image +&quot;\\_renderToClipboard.bmp&quot; b.filename = theFileName save b close b theImage = dotNetClass &quot;System.Drawing.Image&quot; theBitmap = theImage.FromFile theFileName clipboardClass.setImage theBitmap theBitmap.Dispose() deleteFile theFileName clipboardClass.ContainsImage() )--end fn</p>\n\
<p>callbacks.removeScripts id:#CopyRenderToClipboard callbacks.addScript #PostRender &quot;CopyRenderToClipboard()&quot; id:#CopyRenderToClipboard</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>fn CopyRenderToClipboard = (\n\
</pre></div><p>Define a global function. We will place the script in a startup folder, so we want the function to be visible in the global scope.</p>\n\
<div class=\'codeBlock\'><pre>clipboardClass = dotNetClass &quot;System.Windows.Forms.Clipboard&quot;\n\
</pre></div><p>Get the Clipboard dotNetClass from System.Windows.Forms</p>\n\
<div class=\'codeBlock\'><pre>b = getLastRenderedImage()\n\
</pre></div><p>Get the last rendered image</p>\n\
<div class=\'codeBlock\'><pre>theFileName = GetDir #image + &quot;\\\\_renderToClipboard.bmp&quot;\n\
</pre></div><p>Define a temporary file name.</p>\n\
<div class=\'codeBlock\'><pre>b.filename = theFileName\n\
</pre></div><p>Set the bitmap&#39;s file name to the one defined in the previous step.</p>\n\
<div class=\'codeBlock\'><pre>save b\n\
</pre></div><p>Save the bitmap to disk under the assigned file name.</p>\n\
<div class=\'codeBlock\'><pre>close b\n\
</pre></div><p>Close the bitmap.</p>\n\
<div class=\'codeBlock\'><pre>theImage = dotNetClass &quot;System.Drawing.Image&quot;\n\
</pre></div><p>Get the Image dotNetClass from System.Drawing</p>\n\
<div class=\'codeBlock\'><pre>theBitmap = theImage.FromFile theFileName\n\
</pre></div><p>Get the saved image from file as bitmap</p>\n\
<div class=\'codeBlock\'><pre>clipboardClass.setImage theBitmap\n\
</pre></div><p>Copy the image to the clipboard by calling the <span class=\'code\'>setImage</span> method exposed by the clipboard class.</p>\n\
<div class=\'codeBlock\'><pre>theBitmap.Dispose()\n\
</pre></div><p>Release the bitmap - it is already in the Windows Clipboard!</p>\n\
<div class=\'codeBlock\'><pre>deleteFile theFileName\n\
</pre></div><p>Delete the temporary file from disk.</p>\n\
<div class=\'codeBlock\'><pre>clipboardClass.ContainsImage()\n\
</pre></div><p>Return true if the Windows Clipboard contains an image, which we can assume is our image.</p>\n\
<div class=\'codeBlock\'><pre>)--end fn\n\
</pre></div><p>This is the end of the global function.</p>\n\
<p>Now we will register a general callback to call the function whenever the renderer finishes.</p>\n\
<div class=\'codeBlock\'><pre>callbacks.removeScripts id:#CopyRenderToClipboard\n\
</pre></div><p>First we make sure we remove any callbacks with the same ID as the one we are about to register. This way, you can run the script multiple times (for example while further developing the function or making changes to the code in general).</p>\n\
<div class=\'codeBlock\'><pre>callbacks.addScript #PostRender &quot;CopyRenderToClipboard()&quot; id:#CopyRenderToClipboard\n\
</pre></div><p>Then we register a PostRender callback to run the function whenever the renderer finishes.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";