var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Generate Hash Checksums Using DotNet</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Generate Hash Checksums Using DotNet</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-generate-hash-checksums-using-dotnet\"></a></div>\n\
<p>The following tutorials demonstrates the use of the <strong><span class=\'code\'>.GetHashCode()</span></strong> method exposed by the <span class=\'code\'>&quot;System.String</span> &quot; dotNetObject for determining whether specific data collected in the form of a string has changed between two runs of the script.</p>\n\
<p><strong>Related topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript.html\' title=\'\'>DotNet In MAXScript</a></p>\n\
<p><a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/dotnetobject.html\' title=\'\'>dotNetObject</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Define a MAXScript function to calculate the Hash code of all scene objects.</p>\n\
<p>Collect the name, transformation matrix and parent of every object in a string.</p>\n\
<p>Get the HashCode of the string and return it.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` fn getHashCodeFromGeometry = ( local hashStr = stringstream &quot;&quot; for obj in objects do ( print obj.name to:hashStr print obj.transform to:hashStr if obj.parent != undefined then print obj.parent.name to:hashStr )--end for loop (dotNetObject &quot;System.String&quot; hashStr).GetHashCode() )--end function</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>fn getHashCodeFromGeometry = (\n\
</pre></div><p>Define a MAXScript function to be called by the Timer.</p>\n\
<div class=\'codeBlock\'><pre>local hashStr = stringstream &quot;&quot;\n\
</pre></div><p>Create an empty string stream to collect the data to convert to Hash Code.</p>\n\
<div class=\'codeBlock\'><pre>for obj in objects do (\n\
</pre></div><p>Loop through all scene objects...</p>\n\
<div class=\'codeBlock\'><pre>print obj.name to:hashStr print obj.transform to:hashStr\n\
</pre></div><p>And print the name and transform of the current object to the stream.</p>\n\
<div class=\'codeBlock\'><pre>if obj.parent != undefined then print obj.parent.name to:hashStr\n\
</pre></div><p>If the object has a parent, also print the parent&#39;s name to the stream.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
(dotNetObject &quot;System.String&quot; hashStr).GetHashCode()\n\
</pre></div><p>Finally, create an instance of the System.String class from the collected string stream and get its Hash Code.</p>\n\
<div class=\'codeBlock\'><pre>)--end function\n\
</pre></div><div class=\'section\'><a id=\"practical-use\"></a><h2 id=\"practical-use\">Practical Use</h2></div>\n\
<p>Let&#39;s see how this function could be useful in a real-world situation.</p>\n\
<p>Let&#39;s assume we are developing a script which has to perform complex time consuming calculations when the scene content has changed. For example, it would have to rebuild all its data when</p>\n\
<ul>\n\
<li><p>the object count in the scene has changed (objects were added or removed),</p></li>\n\
<li><p>one or more objects were renamed</p></li>\n\
<li><p>one or more objects were moved, rotated or scaled</p></li>\n\
<li><p>the hierarchy has changed (objects were linked or unlinked to/from parent objects)</p></li>\n\
</ul>\n\
<p>It would be useful to cache the last results and return the same value next time the script is executed if the scene has not changed since the previous run. If checking the scene for changes is significantly faster than actually processing the data again, this would lead to a nice speed up.</p>\n\
<p>One possible approach would be to store all this scene state data in some user variables - assign the objects.count value to a variable, collect the names, transformation matrices and parent names of all objects into arrays the first time the script is run and then, the next time the script has to determine whether it needs to recalculate its initial data, it could collect the same information once again and compare all values with the results from the previous run.</p>\n\
<p>Obviously, if the scene contains 10,000+ objects, the amount of data to store (and the time needed to collect and compare the two data sets) would be quite substantial.</p>\n\
<p>But since we are not interested in the actual data values but only want to know whether they have changed between runs, we can use the HashCode value which represents ALL the above conditions with a single long integer value. All we have to do is run the function once to get a HashCode number reflecting the count, names, transforms and parents of all scene objects, then if we want to know if any of these properties have changed since the last time we run our script, we can call the function again and compare the two values. If the numbers are the same, the scene has not changed. In that case we can skip any data rebuilding steps since we can be confident the scene is in the same state as before. If the hash values are different, we must reprocess the scene to collect the actual data.</p>\n\
<p>Of course, the above function is just one example of possible HashCode usage. It can be changed to reflect more or less properties of objects, or could be used to track the state of other values that can be represented as strings.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";