var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Develop a Bitmap Painting Tool - Basic Utility</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Develop a Bitmap Painting Tool - Basic Utility</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-develop-a-bitmap-painting-tool---basic-utility\"></a></div>\n\
<p>The original code of the complete advanced version was developed in less than an hour and showcases the flexibility of MAXScript for prototyping applications of any kind.</p>\n\
<p>Here is the very basic initial version:</p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>We will develop a simple MacroScript that creates a dialog from a rollout.</p>\n\
<p>The rollout will contain only a bitmap UI control</p>\n\
<p>The user will paint by pressing the left mouse button and dragging the mouse inside the bitmap.</p>\n\
<p>The brush will be a single black dot - if the mouse moves fast, the strokes will appear dotted.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` macroScript MicroPaint category:&quot;HowTo&quot; ( global MicroPaint_CanvasRollout try (destroyDialog MicroPaint_CanvasRollout) catch() local isDrawing = false local bitmapX = bitmapY = 512 local theCanvasBitmap = bitmap bitmapX bitmapY color:white</p>\n\
<p>rollout MicroPaint_CanvasRollout &quot;MicroPaint&quot; ( bitmap theCanvas pos:[0,0] width:bitmapX height:bitmapY bitmap:theCanvasBitmap fn paintBrush pos = ( setPixels theCanvasBitmap pos #(black) theCanvas.bitmap = theCanvasBitmap ) on MicroPaint_CanvasRollout lbuttondown pos do ( isDrawing = true paintBrush pos ) on MicroPaint_CanvasRollout lbuttonup pos do isDrawing = false on MicroPaint_CanvasRollout mousemove pos do if isDrawing do paintBrush pos ) createDialog MicroPaint_CanvasRollout bitmapX bitmapY )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>macroScript MicroPaint category:&quot;HowTo&quot; (\n\
</pre></div><p>We define a macroScript called MicroPaint which will appear in the &quot;HowTo&quot; category.</p>\n\
<div class=\'codeBlock\'><pre>global MicroPaint_CanvasRollout\n\
</pre></div><p>In order to be able to close any existing dialog from previous sessions, we define the variable of the rollout to be used as dialog as a global variable.</p>\n\
<p><a href=\'#!/url=./developer/Learning-MAXScript/Creating-Your-Own-Scripts/Local-and-Global-Variables.html\' title=\'\'>Local and Global Variables</a></p>\n\
<div class=\'codeBlock\'><pre>try(destroyDialog CanvasRollout)catch()\n\
</pre></div><p>Then we try to destroy any existing dialog from a previous session. If there is none, the try()catch() error trap will prevent any error messages.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/Try-Expression.html\' title=\'\'>Try Expression</a></p>\n\
<div class=\'codeBlock\'><pre>local isDrawing = false\n\
</pre></div><p>This local variable will be used as a flag for enabling drawing. When the variable is false, the mouse move event handler will not draw. When the left mouse button has been pressed, this variable will be set to true and allow drawing until the left mouse button is released.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/BooleanClass-Values.html\' title=\'\'>BooleanClass Values</a></p>\n\
<div class=\'codeBlock\'><pre>local bitmapX = bitmapY = 512\n\
</pre></div><p>These local variables will contain the size of the bitmap to be painted. Simply changing this value would resize the tool to paint on a different canvas size!</p>\n\
<div class=\'codeBlock\'><pre>local theCanvasBitmap = bitmap bitmapX bitmapY color:white\n\
</pre></div><p>This variable will contain the canvas to draw on. We initialize it to a white bitmap with a size of 400 by 400 pixels.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Bitmap-Values/Bitmap-Values-1.html\' title=\'\'>Bitmap Values</a></p>\n\
<div class=\'codeBlock\'><pre>rollout MicroPaint_CanvasRollout &quot;MicroPaint&quot; (\n\
</pre></div><p>This is the rollout which will define the dialog with the bitmap canvas.</p>\n\
<div class=\'codeBlock\'><pre>bitmap theCanvas pos:[0,0] width:bitmapX height:bitmapY bitmap:theCanvasBitmap \n\
</pre></div><p>This is the bitmap User Interface control. It is aligned to the upper left corner of the rollout and displays the 400 by 400 canvas bitmap.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-User-Interface-Controls/Rollout-User-Interface-Controls-3/Bitmap-UI-Control.html\' title=\'\'>Bitmap</a></p>\n\
<p>Note:</p>\n\
<p>that there are two different constructors with the name <strong>bitmap</strong> - the User Interface control used here and the bitmap value constructor used two lines higher! MAXScript knows which one you have in mind based on the context - if you are inside a rollout definition scope and type in</p>\n\
<div class=\'codeBlock\'><pre>bitmap my_bmp width:100 height:100\n\
\n\
</pre></div><p>MAXScript will create a User Interface control.</p>\n\
<p>If you are inside the same rollout and type in</p>\n\
<div class=\'codeBlock\'><pre>local my_bmp = bitmap 100 100\n\
\n\
</pre></div><p>a new local bitmap value will be created and NOT a User Interface control!</p>\n\
<div class=\'codeBlock\'><pre>fn paintBrush pos = (\n\
</pre></div><p>This function will be called to draw a point on the bitmap. The argument pos will contain the 2D coordinates to place the new point at.</p>\n\
<p><a href=\'#!/url=./developer/Learning-MAXScript/Creating-Your-Own-Scripts/Defining-Custom-Functions.html\' title=\'\'>Defining Custom Functions</a></p>\n\
<div class=\'codeBlock\'><pre>setPixels theCanvasBitmap pos #(black)\n\
</pre></div><p>setPixels is used to change the color of one or more pixels in a row. The pos defines the location in the bitmap (where 0,0 is the upper left corner) the paining should start at.The colors to be changes are provided in an array. In our case, the array contains a single element, the color black.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Bitmap-Values/Bitmap-Values-1.html\' title=\'\'>setpixels</a></p>\n\
<div class=\'codeBlock\'><pre>theCanvas.bitmap = theCanvasBitmap\n\
</pre></div><p>After the black point is drawn into the bitmap, we assign it to the user interface control to update the drawing.</p>\n\
<div class=\'codeBlock\'><pre>) onMicroPaint_CanvasRollout lbuttondown pos do (\n\
</pre></div><p>This dialog event handler is called whenever the left mouse button is pressed while the mouse is located over the rollout. The argument pos will contain the 2D position in rollout coordinates.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Dialogs/CreateDialog.html\' title=\'\'>CreateDialog</a></p>\n\
<div class=\'codeBlock\'><pre>isDrawing = true\n\
</pre></div><p>We raise the flag to notify the mousemove handler (see below) that the drawing can be started.</p>\n\
<div class=\'codeBlock\'><pre>paintBrush pos\n\
</pre></div><p>We also call the paintbrush function by passing the currently clicked point to it. This way, simply clicking without moving the mouse will cause a black point to be placed on the bitmap.</p>\n\
<div class=\'codeBlock\'><pre> ) on MicroPaint_CanvasRollout lbuttonup pos do isDrawing = false\n\
</pre></div><p>This dialog event handler is called whenever the left mouse button is released. We just lower the flag again so the drawing can be stopped.</p>\n\
<div class=\'codeBlock\'><pre>on MicroPaint_CanvasRollout mousemove pos do if isDrawing do paintBrush pos\n\
</pre></div><p>This dialog event handler is called whenever the mouse movies over the rollout, regardless of the button state. The argument pos contains the 2D position in pixels inside the rollout, coinciding with the position in pixels inside the bitmap (remember? Both have the same origin [0,0].</p>\n\
<p>We check to see whether the left mouse button has been pressed but not released yet by looking into the isDrawing variable. If it contains true, we call the drawing paintbrush function with the current position of the mouse inside the dialog.</p>\n\
<div class=\'codeBlock\'><pre>) createDialogMicroPaint_CanvasRollout bitmapX bitmapY\n\
</pre></div><p>Finally, we create a dialog using the rollout we just defined.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
</pre></div><div class=\'section\'><a id=\"result\"></a><h2 id=\"result\">Result</h2></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-BAEE8878-1007-4160-9615-56778B2DE216-low.gif\' title=\'\'></div>\n\
<p><strong>Next Tutorial:</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-a-Bitmap-Painting/How-To-Develop-a-Bitmap-Painting-2.html\' title=\'\'>How To ... Develop a Bitmap Painting Tool - Strokes Support</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";