var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Develop a Bitmap Painting Tool - Strokes Support</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Develop a Bitmap Painting Tool - Strokes Support</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-develop-a-bitmap-painting-tool---strokes-support\"></a></div>\n\
<p>In this step of the Bitmap Painting tool development, we will add some better stroke drawing code to avoid the dotted appearance.</p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>We will extend the existing MacroScript by adding a new function.</p>\n\
<p>The new function will be passed the old and the new position of the mouse and a line will be drawn between the two points to define a continuous stroke.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` macroScript MicroPaint category: &quot;HowTo&quot; ( global MicroPaint_CanvasRollout try (destroyDialog MicroPaint_CanvasRollout) catch() local isDrawing = false local bitmapX = bitmapY = 512 local theCanvasBitmap = bitmap bitmapX bitmapY color:white local currentPos = lastPos = [0,0]</p>\n\
<p>rollout MicroPaint_CanvasRollout &quot;MicroPaint&quot; ( bitmap theCanvas pos:[0,0] width:bitmapX height:bitmapY bitmap:theCanvasBitmap fn paintBrush pos = ( setPixels theCanvasBitmap pos #(color 0 0 0) ) fn drawStroke lastPos pos = ( currentPos = lastPos deltaX = pos.x - lastPos.x deltaY = pos.y - lastPos.y maxSteps = amax #(abs(deltaX),abs(deltaY)) deltaStepX = deltaX / maxSteps deltaStepY = deltaY / maxSteps for i = 0 to maxSteps do ( paintBrush currentPos currentPos += [deltaStepX, deltaStepY] ) theCanvas.bitmap = theCanvasBitmap ) on MicroPaint_CanvasRollout lbuttondown pos do ( lastPos = pos isDrawing = true drawStroke lastPos pos ) on MicroPaint_CanvasRollout lbuttonup pos do isDrawing = false on MicroPaint_CanvasRollout mousemove pos do ( if isDrawing do drawStroke lastPos pos lastPos = pos ) ) createDialog MicroPaint_CanvasRollout bitmapX bitmapY )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>--Code in italic has no changes since the previous version. macroScript MicroPaint category:&quot;HowTo&quot;\n\
(\n\
global MicroPaint_CanvasRollout\n\
try(destroyDialog CanvasRollout)catch()\n\
local isDrawing = false\n\
local bitmapX = bitmapY = 512\n\
local theCanvasBitmap = bitmap bitmapX bitmapY color:white local currentPos = lastPos = [0,0]\n\
</pre></div><p>The first change we will have to do is to define the current and the last known position variables that will be used to keep track of the current stroke. We initialize both to [0,0].</p>\n\
<div class=\'codeBlock\'><pre>rolloutMicroPaint_CanvasRollout &quot;MicroPaint&quot; ( bitmap theCanvas pos:[0,0] width:400 height:400 bitmap:theCanvasBitmap fn paintBrush pos = ( setPixels theCanvasBitmap pos #(black) )\n\
</pre></div><p>We will simplify the paintbrush function. It will only draw the point, but will not update the canvas. This is necessary because the stroke will contain a large number of brush points, but will have to be updated just once after the stroke to maintain interactivity.</p>\n\
<div class=\'codeBlock\'><pre>fn drawStroke lastPos pos =\n\
(\n\
</pre></div><p>This will be the stroke drawing function called by the mouse handlers. Two arguments are passed to it - the last mouse position (beginning of the stroke) and the current mouse position (the end of the stroke).</p>\n\
<div class=\'codeBlock\'><pre>currentPos = lastPos\n\
</pre></div><p>The current position variable is initialized to the beginning of the stroke. It will be used to draw the line from the start to the end point of the stroke.</p>\n\
<div class=\'codeBlock\'><pre>deltaX = pos.x - lastPos.x\n\
deltaY = pos.y - lastPos.y\n\
</pre></div><p>To draw a straight line from the last to the new position, we must know how far these two points are from each other along both X and Y.</p>\n\
<div class=\'codeBlock\'><pre>maxSteps = amax #(abs(deltaX),abs(deltaY))\n\
</pre></div><p>Then, we compare the absolute values along X and Y to see which one is larger. MaxSteps will be equal to either the number of pixels between the two along X or along Y.</p>\n\
<div class=\'codeBlock\'><pre>deltaStepX = deltaX / maxSteps\n\
deltaStepY = deltaY / maxSteps\n\
</pre></div><p>Now, we calculate the increment per step we will need for the X and Y axis. If maxSteps is equal to the distance along X, then deltaStepX will be +1 or -1, while deltaStepY will be a number less than 1.0. If maxSteps is equal to the distance along Y, then deltaStepY will be +1 or -1, and deltaStepX will be &lt; 1.0.</p>\n\
<div class=\'codeBlock\'><pre>for i = 0 to maxSteps do\n\
(\n\
</pre></div><p>Now, we loop from 0 to the number of steps,</p>\n\
<div class=\'codeBlock\'><pre>paintBrush currentPos\n\
</pre></div><p>paint a black dot at the current position by calling our custom paintbrush function,</p>\n\
<div class=\'codeBlock\'><pre>currentPos += [deltaStepX, deltaStepY]\n\
</pre></div><p>and then increment the current position with the deltaStep values until the current mouse position is reached.</p>\n\
<div class=\'codeBlock\'><pre>) \n\
theCanvas.bitmap = theCanvasBitmap\n\
</pre></div><p>Finally, when the stroke is done, we update the bitmap in the rollout.</p>\n\
<div class=\'codeBlock\'><pre>) on MicroPaint_CanvasRollout lbuttondown pos do\n\
(  \n\
lastPos = pos\n\
</pre></div><p>If the user pressed the mouse button, we will have to reset the stroke to the currently clicked point.</p>\n\
<div class=\'codeBlock\'><pre>isDrawing = true drawStroke lastPos pos\n\
</pre></div><p>Instead of calling the PaintBrush function, we call the drawStroke function and pass the last and the current position (which are equal at this point) to it. This will create a single dot at the clicked point (the stroke has length 0, both deltaX and deltaY are 0, thus maxSteps is 0, but since the for i loop starts counting at 0, we get at least one iteration to draw the point).</p>\n\
<div class=\'codeBlock\'><pre>) on MicroPaint_CanvasRollout mousemove pos do ( if isDrawing do drawStroke lastPos pos on MicroPaint_CanvasRollout lbuttonup pos do isDrawing = false\n\
</pre></div><p>Instead of calling the PaintBrush function, we call the drawStroke function again. At this point, the lastPos and the pos values are different and require a longer stroke to be drawn.</p>\n\
<div class=\'codeBlock\'><pre>lastPos = pos\n\
</pre></div><p>After the stroke is drawn, we record the current mouse position into the lastPos variable to be used as the starting point of the next stroke.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
)\n\
createDialog MicroPaint_CanvasRollout bitmapX bitmapY\n\
)\n\
</pre></div><div class=\'section\'><a id=\"result\"></a><h2 id=\"result\">Result</h2></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-7E7978E1-C49D-4644-85E8-0B26A37CE643-low.gif\' title=\'\'></div>\n\
<p><strong>Previous Tutorial:</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-a-Bitmap-Painting/How-To-Develop-a-Bitmap-Painting-1.html\' title=\'\'>How To ... Develop a Bitmap Painting Tool - Basic Utility</a></p>\n\
<p><strong>Next Tutorial:</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-a-Bitmap-Painting/How-To-Develop-a-Bitmap-Painting-3.html\' title=\'\'>How To ... Develop a Bitmap Painting Tool - Brush Size and Color</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";