var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Develop a Bitmap Painting Tool - Brush Size and Color</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Develop a Bitmap Painting Tool - Brush Size and Color</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-develop-a-bitmap-painting-tool---brush-size-and-color\"></a></div>\n\
<p>In this step of the Bitmap Painting tool development, we will add brush color and size controls.</p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>We will extend the existing MacroScript by adding new UI controls to the rollout to define the Ink color and the Brush Size.</p>\n\
<p>The paintbrush function will be changed to use the color defined by the UI color picker.</p>\n\
<p>The drawStroke function will be enhanced to draw a large rectangle based on the defined size.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` macroScript MicroPaint category:&quot;HowTo&quot; ( global MicroPaint_CanvasRollout try(destroyDialog MicroPaint_CanvasRollout)catch() local isDrawing = false local bitmapX = bitmapY = 512 local theCanvasBitmap = bitmap bitmapX bitmapY color:white local currentPos = lastPos = [0,0]</p>\n\
<p>rollout MicroPaint_CanvasRollout &quot;MicroPaint&quot; ( bitmap theCanvas pos:[0,0] width:bitmapX height:bitmapY bitmap:theCanvasBitmap colorpicker inkColor height:16 modal:false color:black across:2 spinner BrushSize&quot;Size&quot;range:[1,50,10] type:#integer fieldwidth:40</p>\n\
<div class=\'codeBlock\'><pre>fn paintBrush pos = (setPixels theCanvasBitmap pos #(inkColor.color))\n\
fn drawStroke lastPos pos =\n\
(\n\
  currentPos = lastPos\n\
  deltaX = pos.x - lastPos.x\n\
  deltaY = pos.y - lastPos.y\n\
  maxSteps = amax #(abs(deltaX),abs(deltaY))\n\
  deltaStepX = deltaX / maxSteps\n\
  deltaStepY = deltaY / maxSteps\n\
  for i = 0 to maxSteps do\n\
  (\n\
    for b = -BrushSize.value/2 to BrushSize.value/2 do\n\
      for c = -BrushSize.value/2 to BrushSize.value/2 do\n\
        paintBrush (currentPos + [c,b])\n\
    currentPos += [deltaStepX, deltaStepY]\n\
  ) \n\
  theCanvas.bitmap = theCanvasBitmap\n\
)\n\
on MicroPaint_CanvasRollout lbuttondown pos do\n\
(\n\
  lastPos = pos\n\
  isDrawing = true\n\
  drawStroke lastPos pos\n\
)\n\
on MicroPaint_CanvasRollout lbuttonup pos do isDrawing = false\n\
on MicroPaint_CanvasRollout mousemove pos do\n\
(\n\
  if isDrawing do drawStroke lastPos pos\n\
  lastPos = pos\n\
)\n\
</pre></div><p>) createDialog MicroPaint_CanvasRollout bitmapX (bitmapY+30) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>--Code in italic has no changes since the previous version. macroScript MicroPaint category:&quot;HowTo&quot;\n\
(\n\
global MicroPaint_CanvasRollout\n\
try(destroyDialog CanvasRollout)catch()\n\
local isDrawing = false\n\
local bitmapX = bitmapY = 512\n\
local theCanvasBitmap = bitmap bitmapX bitmapY color:white\n\
rollout MicroPaint_CanvasRollout &quot;MicroPaint&quot;\n\
(\n\
bitmap theCanvas pos:[0,0] width:bitmapX height:bitmapY bitmap:theCanvasBitmap colorpicker inkColor height:16 modal:false color:black across:2\n\
</pre></div><p>This is the color picker which will be used to define the color of the paintbrush.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-User-Interface-Controls/Rollout-User-Interface-Controls-3/Colorpicker-UI-Control.html\' title=\'\'>Colorpicker</a></p>\n\
<div class=\'codeBlock\'><pre>spinner BrushSize &quot;Size&quot; range:[1,50,10] type:#integer fieldwidth:40\n\
</pre></div><p>This spinner will define the size of the paintbrush.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-User-Interface-Controls/Rollout-User-Interface-Controls-3/Spinner-UI-Control.html\' title=\'\'>Spinner</a></p>\n\
<div class=\'codeBlock\'><pre>fn paintBrush pos = (setPixels theCanvasBitmap pos)\n\
fn drawAPoint lastPos pos =\n\
(\n\
currentPos = lastPos\n\
deltaX = pos.x - lastPos.x\n\
deltaY = pos.y - lastPos.y\n\
maxSteps = amax #(abs(deltaX),abs(deltaY))\n\
deltaStepX = deltaX / maxSteps\n\
deltaStepY = deltaY / maxSteps\n\
for i = 0 to maxSteps do\n\
( for b = -BrushSize.value/2 to BrushSize.value/2 do\n\
(\n\
</pre></div><p>This new loop will define the vertical size of the brush. It counts from minus half the size to plus half the size, full size altogether.</p>\n\
<div class=\'codeBlock\'><pre>for c = -BrushSize.value/2 to BrushSize.value/2 do\n\
</pre></div><p>This second loop defines the width of the paintbrush. It also loops from minus half the size to plus half the size, full size altogether.</p>\n\
<div class=\'codeBlock\'><pre>paintBrush (currentPos + [c,b])\n\
</pre></div><p>After each iteration of the c loop, we call our paint Brush function, passing the current position in the stroke plus the offset based on half the size of the brush and the b loop.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
currentPos += [deltaStepX, deltaStepY]\n\
) \n\
theCanvas.bitmap = theCanvasBitmap\n\
)\n\
on MicroPaint_CanvasRollout lbuttondown pos do\n\
(\n\
lastPos = pos\n\
isDrawing = true\n\
drawAPoint lastPos pos\n\
)\n\
on MicroPaint_CanvasRollout lbuttonup pos do isDrawing = false\n\
on MicroPaint_CanvasRollout mousemove pos do\n\
(\n\
if isDrawing do drawAPoint lastPos pos\n\
lastPos = pos\n\
) createDialog MicroPaint_CanvasRollout bitmapX (bitmapY+30)\n\
</pre></div><p>To accommodate the new User Interface controls for the color and brush size, we have to increase the vertical size of the dialog by 30 pixels.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
</pre></div><div class=\'section\'><a id=\"result\"></a><h2 id=\"result\">Result</h2></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-9824C739-088F-4B3A-B6C7-BBE2C7530F4F-low.gif\' title=\'\'></div>\n\
<p><strong>Previous Tutorial:</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-a-Bitmap-Painting/How-To-Develop-a-Bitmap-Painting-2.html\' title=\'\'>How To ... Develop a Bitmap Painting Tool - Strokes Support</a></p>\n\
<p><strong>Next Tutorial:</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-a-Bitmap-Painting/How-To-Develop-a-Bitmap-Painting-4.html\' title=\'\'>How To ... Develop a Bitmap Painting Tool - Airbrush and Shapes</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";