var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Develop a Bitmap Painting Tool - Airbrush and Shapes</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Develop a Bitmap Painting Tool - Airbrush and Shapes</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-develop-a-bitmap-painting-tool---airbrush-and-shapes\"></a></div>\n\
<p>In this step of the Bitmap Painting tool development, we will add an airbrush option to the tool and a brush shape option to draw both rectangular and circular brushes.</p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>The existing rollout will be enhanced by adding a dropdown list to define the Brush shape, a checkbutton to enable the AirBrush, and a spinner to control its strength.</p>\n\
<p>We will extend the existing code by drawing random points for the AirBrush option.</p>\n\
<p>The drawStroke function will be enhanced to draw a circle with the Size as the radius.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` macroScript MicroPaint category: &quot;HowTo&quot; ( global MicroPaint_CanvasRollout try (destroyDialog MicroPaint_CanvasRollout) catch() local isDrawing = false local bitmapX = bitmapY = 512 local theCanvasBitmap = bitmap bitmapX bitmapY color:white local currentPos = lastPos = [0,0]</p>\n\
<p>rollout MicroPaint_CanvasRollout &quot;MicroPaint&quot; ( bitmap theCanvas pos:[0,0] width:bitmapX height:bitmapY bitmap:theCanvasBitmap colorpicker inkColor height:16 modal:false color:black across:4 checkbutton airBrush &quot;AirBrush&quot; width:50 spinner AirBrushSpeed &quot;Speed&quot; range:[0.1,50,10] fieldwidth:40 spinner BrushSize &quot;Size&quot; range:[1,50,10] type:#integer fieldwidth:40 listbox BrushShape items:#(&quot;Circle&quot;,&quot;Box&quot;) pos:[bitmapX+5,0]width:90</p>\n\
<div class=\'codeBlock\'><pre>fn paintBrush pos =\n\
(\n\
  case BrushShape.selection of\n\
  (\n\
    1: (\n\
      if distance pos currentPos &lt;= BrushSize.value/2 do\n\
        setPixels theCanvasBitmap pos #(inkColor.color)\n\
    )\n\
    2:  setPixels theCanvasBitmap pos #(inkColor.color)\n\
   )\n\
)\n\
\n\
fn drawStroke lastPos pos =\n\
(\n\
  currentPos = lastPos\n\
  deltaX = pos.x - lastPos.x\n\
  deltaY = pos.y - lastPos.y\n\
  maxSteps = amax #(abs(deltaX),abs(deltaY))\n\
  deltaStepX = deltaX / maxSteps\n\
  deltaStepY = deltaY / maxSteps\n\
  for i = 0 to maxSteps do\n\
  (\n\
    if airBrush.checked then\n\
    (\n\
      for b = 1 to (BrushSize.value / AirBrushSpeed.value) do\n\
      paintBrush (currentPos + (random [-BrushSize.value/2,-BrushSize.value/2] [BrushSize.value/2,BrushSize.value/2] ))\n\
    )\n\
    else\n\
      for b = -BrushSize.value/2 to BrushSize.value/2 do\n\
        for c = -BrushSize.value/2 to BrushSize.value/2 do\n\
          paintBrush (currentPos + [c,b])\n\
    currentPos += [deltaStepX, deltaStepY]\n\
  ) \n\
  theCanvas.bitmap = theCanvasBitmap\n\
)\n\
\n\
on MicroPaint_CanvasRollout lbuttondown pos do\n\
(\n\
  lastPos = pos\n\
  isDrawing = true\n\
  drawStroke lastPos pos\n\
)\n\
on MicroPaint_CanvasRollout lbuttonup pos do isDrawing = false\n\
on MicroPaint_CanvasRollout mousemove pos do\n\
(\n\
  if isDrawing do drawStroke lastPos pos\n\
  lastPos = pos\n\
)\n\
</pre></div><p>) createDialog MicroPaint_CanvasRollout (bitmapx+100) (bitmapy+30) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>--Code in italic has no changes since the previous version. \n\
macroScript MicroPaint category:&quot;HowTo&quot;\n\
(\n\
global MicroPaint_CanvasRollout\n\
try(destroyDialog CanvasRollout)catch()\n\
local isDrawing = false\n\
local bitmapX = bitmapY = 512\n\
local theCanvasBitmap = bitmap bitmapX bitmapY color:white\n\
rollout MicroPaint_CanvasRollout &quot;MicroPaint&quot;\n\
(\n\
bitmap theCanvas pos:[0,0] width:bitmapX height:bitmapY bitmap:theCanvasBitmap colorpicker inkColor height:16 modal:false color:black across:4 \n\
</pre></div><p>To accommodate automatically all new controls in the bottom row, we will have to increase the across: parameter to 4.</p>\n\
<div class=\'codeBlock\'><pre>checkbutton airBrush &quot;AirBrush&quot; width:50\n\
</pre></div><p>When checked, this checkbutton will enable the Airbrush feature.</p>\n\
<div class=\'codeBlock\'><pre>spinner AirBrushSpeed &quot;Speed&quot; range:[0.1,50,10] fieldwidth:40\n\
</pre></div><p>This value will control the strength of the Airbrush feature.</p>\n\
<div class=\'codeBlock\'><pre>spinner BrushSize &quot;Size&quot; range:[1,50,10] type:#integer fieldwidth:40 listbox BrushShape items:#(&quot;Circle&quot;, &quot;Box&quot;) width:90 pos:[bitmapx+5,0]\n\
</pre></div><p>This listbox controls the shape of the brush. In the future versions, we will add additional tools to it.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-User-Interface-Controls/Rollout-User-Interface-Controls-3/Listbox-UI-Control.html\' title=\'\'>Listbox</a></p>\n\
<div class=\'codeBlock\'><pre>fn paintBrush pos = ( case BrushShape.selection of (\n\
</pre></div><p>Depending on the setting of the Brush Shape dropdown list, the pixels will be limited inside a circle, or will be drawn as before.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/Case-Expression.html\' title=\'\'>Case Expression</a></p>\n\
<div class=\'codeBlock\'><pre>1: (\n\
if distance pos currentPos &lt;= BrushSize.value/2 do\n\
setPixels theCanvasBitmap pos #(inkColor.color)\n\
)\n\
</pre></div><p>If the Circle shape is selected, the distance from the position to be drawn to the center of the brush will be compared to the radius value (the size divided by 2). Only if the point is at a distance less than the radius, it will be drawn. This defines a circular brush.</p>\n\
<div class=\'codeBlock\'><pre>2: setPixels theCanvasBitmap pos #(inkColor.color)\n\
</pre></div><p>This is the original function used in the previous step. It will be used when the dropdown list selection is 2 - &quot;Box&quot;.</p>\n\
<div class=\'codeBlock\'><pre>) ) \n\
fn drawStroke lastPos pos =\n\
(\n\
currentPos = lastPos\n\
deltaX = pos.x - lastPos.x\n\
deltaY = pos.y - lastPos.y\n\
maxSteps = amax #(abs(deltaX),abs(deltaY))\n\
deltaStepX = deltaX / maxSteps\n\
deltaStepY = deltaY / maxSteps\n\
for i = 0 to maxSteps do\n\
( if airBrush.checked then (\n\
</pre></div><p>When the Airbrush option is checked, the following code will be executed:</p>\n\
<div class=\'codeBlock\'><pre>for b = 1 to (BrushSize.value / AirBrushSpeed.value) do\n\
</pre></div><p>We will repeat a number of times. The actual number will be dependent on the size of the brush and the Airbrush speed value. The higher the Speed value, the lower the number of samples in the brush.</p>\n\
<div class=\'codeBlock\'><pre>paintBrush (currentPos + (random [-BrushSize.value/2,-BrushSize.value/2] [BrushSize.value/2,BrushSize.value/2] ))\n\
</pre></div><p>For every iteration, we will draw a random point between the lower left and upper right corners of the box brush. If circular brush is selected, some of the points will be filtered out by the new code in the paintbrush function above.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
else\n\
</pre></div><p>Otherwise, the original brush code below will be executed.</p>\n\
<div class=\'codeBlock\'><pre>for b = -BrushSize.value/2 to BrushSize.value/2 do\n\
for c = -BrushSize.value/2 to BrushSize.value/2 do\n\
paintBrush (currentPos + [c,b])\n\
currentPos += [deltaStepX, deltaStepY]\n\
) \n\
theCanvas.bitmap = theCanvasBitmap\n\
)\n\
on MicroPaint_CanvasRollout lbuttondown pos do\n\
(\n\
lastPos = pos\n\
isDrawing = true\n\
drawAPoint lastPos pos\n\
)\n\
on MicroPaint_CanvasRollout lbuttonup pos do isDrawing = false\n\
on MicroPaint_CanvasRollout mousemove pos do\n\
(\n\
if isDrawing do drawAPoint lastPos pos\n\
lastPos = pos\n\
) createDialog MicroPaint_CanvasRollout (bitmapX+100)(bitmapY+30)\n\
</pre></div><p>In order to accommodate the new User Interface controls for the color and brush size, we have to increase the horizontal size of the dialog by 100 pixels.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
</pre></div><p><strong>Result</strong></p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-8CF6215A-55E6-43C1-BDF7-E0DB958BCE8A-low.gif\' title=\'\'></div>\n\
<p><strong>Previous Tutorial:</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-a-Bitmap-Painting/How-To-Develop-a-Bitmap-Painting-3.html\' title=\'\'>How To ... Develop a Bitmap Painting Tool - Brush Size and Color</a></p>\n\
<p><strong>Next Tutorial:</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-a-Bitmap-Painting/How-To-Develop-a-Bitmap-Painting-5.html\' title=\'\'>How To ... Develop a Bitmap Painting Tool - Smooth Brushes</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";