var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Develop a Bitmap Painting Tool - Smooth Brushes</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Develop a Bitmap Painting Tool - Smooth Brushes</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-develop-a-bitmap-painting-tool---smooth-brushes\"></a></div>\n\
<p>In this step of the Bitmap Painting tool development, we will add optional smooth falloff to the brush.</p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>We will add a new item to the brushes listbox.</p>\n\
<p>We will extend the paintbrush function with a new case calculating the new color using the existing one and a falloff based on the pixel&#39;s distance to the center of the brush.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` macroScript MicroPaint category: &quot;HowTo&quot; ( global MicroPaint_CanvasRollout try (destroyDialog MicroPaint_CanvasRollout) catch() local isDrawing = false local bitmapX = bitmapY = 512 local theCanvasBitmap = bitmap bitmapX bitmapY color:white local currentPos = lastPos = [0,0]</p>\n\
<p>rollout MicroPaint_CanvasRollout &quot;MicroPaint&quot; ( bitmap theCanvas pos:[0,0] width:bitmapX height:bitmapY bitmap:theCanvasBitmap colorpicker inkColor height:16 modal:false color:black across:4 checkbutton airBrush &quot;AirBrush&quot;width:50 spinner AirBrushSpeed &quot;Speed&quot; range:[0.1,50,10] fieldwidth:30 spinner BrushSize &quot;Size&quot; range:[1,50,10] type:#integer fieldwidth:40 listbox BrushShape items:#(&quot;Circle&quot;,&quot;Box&quot;,&quot;Circle Smooth&quot;) pos:[bitmapX+5,0] width:90</p>\n\
<div class=\'codeBlock\'><pre>fn paintBrush pos =\n\
(\n\
  case BrushShape.selection of\n\
  (\n\
    1: (\n\
      if distance pos currentPos &lt;= BrushSize.value/2 do\n\
        setPixels theCanvasBitmap pos #(inkColor.color)\n\
    )\n\
    2: setPixels theCanvasBitmap pos #(inkColor.color)\n\
    3: (\n\
      theFactor = (distance pos currentPos) / (BrushSize.value/2.0)\n\
      if theFactor &lt;= 1.0 do\n\
      (\n\
        theFactor = sin ( 90.0 * theFactor)\n\
        thePixels = getPixels theCanvasBitmap pos 1\n\
        if thePixels[1] != undefined do\n\
        (\n\
          thePixels[1] = (thePixels[1] * theFactor) + (inkColor.color * (1.0 - theFactor))\n\
          setPixels theCanvasBitmap pos thePixels\n\
        )\n\
      )\n\
    )--end case 3\n\
  )--end case\n\
)--end fn\n\
\n\
fn drawStroke lastPos pos =\n\
(\n\
  currentPos = lastPos\n\
  deltaX = pos.x - lastPos.x\n\
  deltaY = pos.y - lastPos.y\n\
  maxSteps = amax #(abs(deltaX),abs(deltaY))\n\
  deltaStepX = deltaX / maxSteps\n\
  deltaStepY = deltaY / maxSteps\n\
  for i = 0 to maxSteps do\n\
  (\n\
    if airBrush.checked then\n\
    (\n\
      for b = 1 to (BrushSize.value / AirBrushSpeed.value) do\n\
      paintBrush (currentPos + (random [-BrushSize.value/2,-BrushSize.value/2] [BrushSize.value/2,BrushSize.value/2] ))\n\
    )\n\
    else\n\
      for b = -BrushSize.value/2 to BrushSize.value/2 do\n\
        for c = -BrushSize.value/2 to BrushSize.value/2 do\n\
          paintBrush (currentPos + [c,b])\n\
    currentPos += [deltaStepX, deltaStepY]\n\
  )\n\
  theCanvas.bitmap = theCanvasBitmap\n\
)\n\
\n\
on MicroPaint_CanvasRollout lbuttondown pos do\n\
(\n\
  lastPos = pos\n\
  isDrawing = true\n\
  drawStroke lastPos pos\n\
)\n\
on MicroPaint_CanvasRollout lbuttonup pos do isDrawing = false\n\
on MicroPaint_CanvasRollout mousemove pos do\n\
(\n\
  if isDrawing do drawStroke lastPos pos\n\
  lastPos = pos\n\
)\n\
</pre></div><p>) createDialog MicroPaint_CanvasRollout (bitmapx+100) (bitmapy+30) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>--Code in italic has no changes since the previous version. macroScript MicroPaint category:&quot;HowTo&quot;\n\
(\n\
global MicroPaint_CanvasRollout\n\
try(destroyDialog CanvasRollout)catch()\n\
local isDrawing = false\n\
local bitmapX = bitmapY = 512\n\
local theCanvasBitmap = bitmap bitmapX bitmapY color:white\n\
local currentPos = lastPos = [0,0]\n\
\n\
rollout MicroPaint_CanvasRollout &quot;MicroPaint&quot;\n\
(\n\
bitmap theCanvas pos:[0,0] width:bitmapX height:bitmapY bitmap:theCanvasBitmap\n\
colorpicker inkColor height:16 modal:false color:black across:4\n\
checkbutton airBrush &quot;AirBrush&quot; width:50\n\
spinner AirBrushSpeed &quot;Speed&quot; range:[0.1,50,10] fieldwidth:40\n\
spinner BrushSize &quot;Size&quot; range:[1,50,10] type:#integer fieldwidth:40\n\
 listbox BrushShape items:#(&quot;Circle&quot;, &quot;Box&quot;, &quot;Circle Smooth&quot;) pos:[bitmapX+5,0] width:90 \n\
</pre></div><p>We add a new brush to our &quot;toolbox&quot; - &quot;Circle Smooth&quot;.</p>\n\
<div class=\'codeBlock\'><pre>fn paintBrush pos =\n\
(\n\
case BrushShape.selection of\n\
(\n\
1: (\n\
if distance pos currentPos &lt;= BrushSize.value/2 do\n\
setPixels theCanvasBitmap pos #(inkColor.color)\n\
)\n\
2: setPixels theCanvasBitmap pos #(inkColor.color)\n\
 \n\
3: ( \n\
</pre></div><p>When the &quot;Circle Smooth&quot; brush is selected,</p>\n\
<div class=\'codeBlock\'><pre>theFactor =(distance pos currentPos)/ (BrushSize.value/2.0)\n\
</pre></div><p>we calculate the distance from the pixel to be drawn to the center of the brush and divide by the radius of the brush.</p>\n\
<div class=\'codeBlock\'><pre>if theFactor &lt;= 1.0 do\n\
(\n\
</pre></div><p>If the result is less than 1.0, the pixel lies inside the circle.</p>\n\
<div class=\'codeBlock\'><pre>theFactor = sin ( 90.0 * theFactor)\n\
</pre></div><p>In that case, we multiply the value by 90 and use the Sine function to calculate a nice falloff curve. Note that remarking this line gives you a linear falloff curve instead of the sine-based falloff curve.</p>\n\
<div class=\'codeBlock\'><pre>thePixels = getPixels theCanvasBitmap pos 1\n\
</pre></div><p>Next, we read a single pixel from the position we are about to write to.</p>\n\
<div class=\'codeBlock\'><pre>if thePixels[1] != undefined do\n\
(\n\
</pre></div><p>If the single pixel in the array is a valid color,</p>\n\
<div class=\'codeBlock\'><pre>thePixels[1] = (thePixels[1] * theFactor) + (inkColor.color * (1.0 - theFactor))\n\
</pre></div><p>we blend the color of the background with the brush color based on the distance factor. If the factor is 0.5, the two colors will be blended 50-50%. If the factor is 1 (at the edge of the circle, the background color will be used 100% and the ink will be 0%.</p>\n\
<div class=\'codeBlock\'><pre>setPixels theCanvasBitmap pos thePixels\n\
</pre></div><p>Finally, we write the color back into the bitmap.</p>\n\
<div class=\'codeBlock\'><pre>) \n\
)\n\
)  \n\
)\n\
)\n\
 \n\
\n\
fn drawStroke lastPos pos =\n\
(\n\
currentPos = lastPos\n\
deltaX = pos.x - lastPos.x\n\
deltaY = pos.y - lastPos.y\n\
maxSteps = amax #(abs(deltaX),abs(deltaY))\n\
deltaStepX = deltaX / maxSteps\n\
deltaStepY = deltaY / maxSteps\n\
for i = 0 to maxSteps do\n\
(\n\
if airBrush.checked then\n\
(\n\
for b = 1 to (BrushSize.value / AirBrushSpeed.value) do\n\
paintBrush (currentPos + (random [-BrushSize.value/2,-BrushSize.value/2] [BrushSize.value/2,BrushSize.value/2] ))\n\
)\n\
else\n\
for b = -BrushSize.value/2 to BrushSize.value/2 do\n\
for c = -BrushSize.value/2 to BrushSize.value/2 do\n\
paintBrush (currentPos + [c,b])\n\
currentPos += [deltaStepX, deltaStepY]\n\
) \n\
theCanvas.bitmap = theCanvasBitmap\n\
)\n\
\n\
on MicroPaint_CanvasRollout lbuttondown pos do\n\
(\n\
lastPos = pos\n\
isDrawing = true\n\
drawStroke lastPos pos\n\
)\n\
on MicroPaint_CanvasRollout lbuttonup pos do isDrawing = false\n\
on MicroPaint_CanvasRollout mousemove pos do\n\
(\n\
if isDrawing do drawStroke lastPos pos\n\
lastPos = pos\n\
)\n\
)\n\
createDialog MicroPaint_CanvasRollout (bitmapx+100) (bitmapy+30)\n\
) \n\
</pre></div><p><strong>Result</strong></p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-12EBE87A-1379-4F63-BD1F-2A497503DBD9-low.gif\' title=\'\'></div>\n\
<p><strong>Previous Tutorial:</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-a-Bitmap-Painting/How-To-Develop-a-Bitmap-Painting-4.html\' title=\'\'>How To ... Develop a Bitmap Painting Tool - Airbrush and Shapes</a></p>\n\
<p><strong>Next Tutorial:</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-a-Bitmap-Painting/How-To-Develop-a-Bitmap-Painting-6.html\' title=\'\'>How To ... Develop a Bitmap Painting Tool - Load and Save</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";