var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Develop a Bitmap Painting Tool - Erase Changes</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Develop a Bitmap Painting Tool - Erase Changes</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-develop-a-bitmap-painting-tool---erase-changes\"></a></div>\n\
<p>In this step of the Bitmap Painting tool development, we will add an eraser option to the existing brushes. When the user is drawing with the right mouse button pressed, the background image will be revealed.This mode will support all available brushes including the Airbrush mode, allowing the user to erase smoothly.</p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>We will add a new flag variable to control the Erase mode.</p>\n\
<p>We will change the paintbrush function to support reading of pixels from the background image.</p>\n\
<p>We will implement right mouse button handlers to enable erasing of the existing pixels with the original pixels from the background.</p>\n\
<p>We will add a commit change option to the Edit menu to copy the foreground painting canvas into the background and &quot;bake in&quot; all changes.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` macroScript MicroPaint category: &quot;HowTo&quot; ( global MicroPaint_CanvasRollout try (destroyDialog MicroPaint_CanvasRollout) catch() local isErasing =isDrawing = false local bitmapX = bitmapY = 512 local theCanvasBitmap = bitmap bitmapX bitmapY color:white local theBackgroundBitmap = bitmap bitmapX bitmapY color:white local currentPos = lastPos = [0,0]</p>\n\
<p>rcMenu CanvasMenu ( subMenu &quot;File&quot; ( menuItem new_menu &quot;New&quot; menuItem open_menu &quot;Open...&quot; menuItem save_as &quot;Save As...&quot; separator file_menu_1 menuItem quit_tool &quot;Quit&quot;<br> ) subMenu &quot;Edit&quot; ( menuItem commit_menu &quot;Commit Changes&quot; ) on commit_menu picked do copy theCanvasBitmap theBackgroundBitmap</p>\n\
<div class=\'codeBlock\'><pre>subMenu &quot;Help&quot;\n\
(\n\
  menuItem about_tool &quot;About MicroPaint...&quot; \n\
)\n\
\n\
on new_menu picked do\n\
(\n\
  theBackgroundBitmap = theCanvasBitmap = bitmap bitmapX bitmapY color:MicroPaint_CanvasRollout.paperColor.color\n\
  MicroPaint_CanvasRollout.theCanvas.bitmap = theCanvasBitmap\n\
)\n\
\n\
\n\
on open_menu picked do\n\
(\n\
  theOpenBitmap= selectBitmap()\n\
  if theOpenBitmap != undefined do\n\
  (\n\
    copy theOpenBitmap theCanvasBitmap\n\
    copy theOpenBitmap theBackgroundBitmap\n\
    close theOpenBitmap\n\
    MicroPaint_CanvasRollout.theCanvas.bitmap = theCanvasBitmap\n\
  )\n\
)\n\
\n\
on save_as picked do\n\
(\n\
  theSaveName = getSaveFileName types:&quot;BMP (*.bmp)|*.bmp|Targa (*.tga)|*.tga|JPEG (*.jpg)|*.jpg&quot;\n\
  if theSaveName != undefined do\n\
  (\n\
    theCanvasBitmap.filename = theSaveName\n\
    save theCanvasBitmap\n\
  )\n\
)\n\
on about_tool picked do messagebox &quot;MicroPaint\\nMAXScript Tutorial&quot; title:&quot;About...&quot;\n\
on quit_tool picked do destroyDialog MicroPaint_CanvasRollout\n\
</pre></div><p>)</p>\n\
<p>rollout MicroPaint_CanvasRollout &quot;MicroPaint&quot; ( bitmap theCanvas pos:[0,0] width:bitmapX height:bitmapY bitmap:theCanvasBitmap colorpicker inkColor height:16 modal:false color:black across:5 colorpicker paperColor height:16 modal:false color:white checkbutton airBrush &quot;AirBrush&quot; width:50 spinner AirBrushSpeed &quot;Speed&quot; range:[0.1,50,10] fieldwidth:30 spinner BrushSize &quot;Size&quot; range:[1,50,10] type:#integer fieldwidth:40 listbox BrushShape items:#(&quot;Circle&quot;,&quot;Box&quot;,&quot;Circle Smooth&quot;) pos:[bitmapX+5,0] width:90</p>\n\
<div class=\'codeBlock\'><pre>fn paintBrush pos =\n\
(\n\
  if isErasing then\n\
    thePaintColor = (getPixels theBackgroundBitmap pos 1)[1]\n\
  else\n\
    thePaintColor = inkColor.color\n\
  if thePaintColor == undefined do thePaintColor = white\n\
\n\
  case BrushShape.selection of\n\
  (\n\
    1: (\n\
      if distance pos currentPos &lt;= BrushSize.value/2 do\n\
        setPixels theCanvasBitmap pos #(thePaintColor)\n\
    )\n\
    2: setPixels theCanvasBitmap pos #(thePaintColor)\n\
    3: (\n\
      theFactor = (distance pos currentPos) / (BrushSize.value/2.0)\n\
      if theFactor &lt;= 1.0 do\n\
      (\n\
        theFactor = sin ( 90.0 * theFactor)\n\
        thePixels = getPixels theCanvasBitmap pos 1\n\
        if thePixels[1] != undefined do\n\
        (\n\
          thePixels[1] = (thePixels[1] * theFactor) + (thePaintColor * (1.0 - theFactor))\n\
            setPixels theCanvasBitmap pos thePixels\n\
        )\n\
      )\n\
    )--end case 3\n\
  )--end case\n\
)--end fn\n\
\n\
fn drawStroke lastPos pos =\n\
(\n\
  currentPos = lastPos\n\
  deltaX = pos.x - lastPos.x\n\
  deltaY = pos.y - lastPos.y\n\
  maxSteps = amax #(abs(deltaX),abs(deltaY))\n\
  deltaStepX = deltaX / maxSteps\n\
  deltaStepY = deltaY / maxSteps\n\
  for i = 0 to maxSteps do\n\
  (\n\
    if airBrush.checked then\n\
    (\n\
      for b = 1 to (BrushSize.value / AirBrushSpeed.value) do\n\
        paintBrush (currentPos + (random [-BrushSize.value/2,-BrushSize.value/2] [BrushSize.value/2,BrushSize.value/2] ))\n\
    )\n\
    else\n\
      for b = -BrushSize.value/2 to BrushSize.value/2 do\n\
        for c = -BrushSize.value/2 to BrushSize.value/2 do\n\
          paintBrush (currentPos + [c,b])\n\
    currentPos += [deltaStepX, deltaStepY]\n\
  )\n\
  theCanvas.bitmap = theCanvasBitmap\n\
)\n\
\n\
on MicroPaint_CanvasRollout lbuttondown pos do\n\
(\n\
  lastPos = pos\n\
  isDrawing = true\n\
  isErasing = false\n\
  drawStroke lastPos pos\n\
)\n\
on MicroPaint_CanvasRollout rbuttondown pos do\n\
(\n\
  lastPos = pos\n\
  isErasing = isDrawing = true\n\
  drawStroke lastPos pos\n\
)\n\
on MicroPaint_CanvasRollout lbuttonup pos do isErasing =isDrawing = false\n\
on MicroPaint_CanvasRollout rbuttonup pos do isErasing =isDrawing = false\n\
\n\
on MicroPaint_CanvasRollout mousemove pos do\n\
(\n\
  if isDrawing do drawStroke lastPos pos\n\
  lastPos = pos\n\
)\n\
</pre></div><p>) createDialog MicroPaint_CanvasRollout (bitmapx+100) (bitmapy+30) menu:CanvasMenu MicroPaint_CanvasRollout.theCanvas.bitmap = theBackgroundBitmap )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>--Code in green has no changes since the previous version. macroScript MicroPaint category:&quot;HowTo&quot;\n\
(\n\
global MicroPaint_CanvasRollout\n\
try(destroyDialog MicroPaint_CanvasRollout)catch() local isErasing = isDrawing = false\n\
</pre></div><p>We add a new variable isErasing that will be set to true when the right mouse button is pressed.</p>\n\
<div class=\'codeBlock\'><pre>local bitmapX = bitmapY = 512\n\
local theCanvasBitmap = bitmap bitmapX bitmapY color:white\n\
local theBackgroundBitmap = bitmap bitmapX bitmapY color:white\n\
local currentPos = lastPos = [0,0]\n\
\n\
rcMenu CanvasMenu\n\
(\n\
subMenu &quot;File&quot;\n\
(\n\
menuItem new_menu &quot;New&quot;\n\
menuItem open_menu &quot;Open...&quot;\n\
menuItem save_as &quot;Save As...&quot;\n\
separator file_menu_1\n\
menuItem quit_tool &quot;Quit&quot;\n\
)\n\
subMenu &quot;Edit&quot;\n\
( menuItem commit_menu &quot;Commit Changes&quot;\n\
</pre></div><p>We add a new menu item to the Edit dialog. It will be used to commit the editing changes and make them &quot;unerasable&quot;.</p>\n\
<div class=\'codeBlock\'><pre>) on commit_menu picked do copy theCanvasBitmap theBackgroundBitmap\n\
</pre></div><p>This is the event handler for the commit changes option. When selected, the foreground image we are painting on will be copied into the background image, thus &quot;baking&quot; all the changed pixels into it. Using the eraser from this point on will reveal the new pixels.</p>\n\
<div class=\'codeBlock\'><pre>subMenu &quot;Help&quot;\n\
(\n\
menuItem about_tool &quot;About MicroPaint...&quot; \n\
)\n\
\n\
on new_menu picked do\n\
(\n\
theBackgroundBitmap = theCanvasBitmap = bitmap bitmapX bitmapY color:MicroPaint_CanvasRollout.paperColor.color\n\
MicroPaint_CanvasRollout.theCanvas.bitmap = theCanvasBitmap\n\
)\n\
\n\
on open_menu picked do\n\
(\n\
theOpenBitmap= selectBitmap()\n\
if theOpenBitmap != undefined do\n\
(\n\
copy theOpenBitmap theCanvasBitmap\n\
copy theOpenBitmap theBackgroundBitmap\n\
close theOpenBitmap\n\
MicroPaint_CanvasRollout.theCanvas.bitmap = theCanvasBitmap\n\
)\n\
)\n\
\n\
on save_as picked do\n\
(\n\
theSaveName = getSaveFileName types:&quot;BMP (*.bmp)|*.bmp|Targa (*.tga)|*.tga|JPEG (*.jpg)|*.jpg&quot;\n\
if theSaveName != undefined do\n\
(\n\
theCanvasBitmap.filename = theSaveName\n\
save theCanvasBitmap\n\
)\n\
)\n\
\n\
on about_tool picked do messagebox &quot;MicroPaint\\nMAXScript Tutorial&quot; title:&quot;About...&quot;\n\
on quit_tool picked do destroyDialog MicroPaint_CanvasRollout\n\
)\n\
\n\
rollout MicroPaint_CanvasRollout &quot;MicroPaint&quot;\n\
(\n\
bitmap theCanvas pos:[0,0] width:bitmapX height:bitmapY bitmap:theCanvasBitmap\n\
colorpicker inkColor height:16modal:false color:black across:5\n\
colorpicker paperColor height:16 modal:false color:white\n\
checkbutton airBrush &quot;AirBrush&quot; width:50\n\
spinner AirBrushSpeed &quot;Speed&quot; range:[0.1,50,10] fieldwidth:30\n\
spinner BrushSize &quot;Size&quot; range:[1,50,10] type:#integer fieldwidth:40\n\
listbox BrushShape items:#(&quot;Circle&quot;, &quot;Box&quot;, &quot;Circle Smooth&quot;) pos:[bitmapX+5,0] width:90\n\
\n\
fn paintBrush pos =\n\
( if isErasing then\n\
</pre></div><p>If the eraser mode is active (that means, the user is holding down the right mouse button), then</p>\n\
<div class=\'codeBlock\'><pre>thePaintColor = (getPixels theBackgroundBitmap pos 1)[1]\n\
</pre></div><p>we get the color of the pixel from the background as the ink color.</p>\n\
<div class=\'codeBlock\'><pre>else\n\
thePaintColor = inkColor.color\n\
</pre></div><p>Otherwise, we use the ink color defined by the User Interface.</p>\n\
<div class=\'codeBlock\'><pre>if thePaintColor == undefined do thePaintColor = white\n\
</pre></div><p>If the pixel was outside the bitmap, it might contain undefined. To avoid errors, we reset it back to white.</p>\n\
<div class=\'codeBlock\'><pre>case BrushShape.selection of\n\
(\n\
1: (\n\
if distance pos currentPos &lt;= BrushSize.value/2 do setPixels theCanvasBitmap pos #(thePaintColor) ) 2: setPixels theCanvasBitmap pos #(thePaintColor)\n\
</pre></div><p>In both cases, we replace the explicit use of the InkColor.color with thepaintColor that contains the correct color to paint with.</p>\n\
<div class=\'codeBlock\'><pre>3: (\n\
theFactor = (distance pos currentPos) / (BrushSize.value/2.0)\n\
if theFactor &lt;= 1.0 do\n\
(\n\
theFactor = sin ( 90.0 * theFactor)\n\
thePixels = getPixels theCanvasBitmap pos 1\n\
if thePixels[1] != undefined do\n\
( thePixels[1] = (thePixels[1] * theFactor) + (thePaintColor * (1.0 - theFactor)) \n\
</pre></div><p>Again, we replace the explicit use of the InkColor.color with thePaintColor that contains the correct color to paint with.</p>\n\
<div class=\'codeBlock\'><pre>setPixels theCanvasBitmap pos thePixels\n\
)\n\
)\n\
)--end case 3\n\
)--end case\n\
)--end fn\n\
\n\
fn drawStroke lastPos pos =\n\
(\n\
currentPos = lastPos\n\
deltaX = pos.x - lastPos.x\n\
deltaY = pos.y - lastPos.y\n\
maxSteps = amax #(abs(deltaX),abs(deltaY))\n\
deltaStepX = deltaX / maxSteps\n\
deltaStepY = deltaY / maxSteps\n\
for i = 0 to maxSteps do\n\
(\n\
if airBrush.checked then\n\
(\n\
for b = 1 to (BrushSize.value / AirBrushSpeed.value) do\n\
paintBrush (currentPos + (random [-BrushSize.value/2,-BrushSize.value/2] [BrushSize.value/2,BrushSize.value/2] ))\n\
)\n\
else\n\
for b = -BrushSize.value/2 to BrushSize.value/2 do\n\
for c = -BrushSize.value/2 to BrushSize.value/2 do\n\
paintBrush (currentPos + [c,b])\n\
currentPos += [deltaStepX, deltaStepY]\n\
)\n\
theCanvas.bitmap = theCanvasBitmap\n\
)\n\
\n\
on MicroPaint_CanvasRollout lbuttondown pos do\n\
(\n\
lastPos = pos\n\
isDrawing = true isErasing = false\n\
</pre></div><p>The isErasing flag is set to false whenever the user presses the left mouse button.</p>\n\
<div class=\'codeBlock\'><pre>drawStroke lastPos pos\n\
) on MicroPaint_CanvasRollout rbuttondown pos do\n\
(\n\
lastPos = pos\n\
isErasing = isDrawing = true\n\
drawStroke lastPos pos\n\
)\n\
</pre></div><p>This new handler is called whenever the right mouse button is pressed. It is identical to the left mouse button handler except for the isErasing flag that is set to true this time.</p>\n\
<div class=\'codeBlock\'><pre>on MicroPaint_CanvasRollout lbuttonup pos do isErasing = isDrawing = false\n\
on MicroPaint_CanvasRollout rbuttonup pos do isErasing = isDrawing = false\n\
</pre></div><p>The lbuttonup and the new rbuttonup handlers will stop drawing and erasing by setting both the flags to false.</p>\n\
<div class=\'codeBlock\'><pre>on MicroPaint_CanvasRollout mousemove pos do\n\
(\n\
if isDrawing do drawStroke lastPos pos\n\
lastPos = pos\n\
)\n\
)\n\
createDialog MicroPaint_CanvasRollout (bitmapx+100) (bitmapy+30) menu:CanvasMenu\n\
MicroPaint_CanvasRollout.theCanvas.bitmap = theBackgroundBitmap\n\
) \n\
</pre></div><p><strong>Previous Tutorial:</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-a-Bitmap-Painting/How-To-Develop-a-Bitmap-Painting-6.html\' title=\'\'>How To ... Develop a Bitmap Painting Tool - Load and Save</a></p>\n\
<p><strong>NextTutorial:</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-a-Bitmap-Painting/How-To-Develop-a-Bitmap-Painting-8.html\' title=\'\'>How To ... Develop a Bitmap Painting Tool - Unwrap UV Coordinates</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";