var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Develop a Scene Browser using TreeView ActiveX Control - Part One</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Develop a Scene Browser using TreeView ActiveX Control - Part One</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-develop-a-scene-browser-using-treeview-activex-control---part-one\"></a></div>\n\
<p>This tutorial demonstrates how to create a Scene Browser showing the object hierarchy in a TreeView ActiveX Control.</p>\n\
<p>Note:</p>\n\
<p><img src=\'developer/images/GUID-58798F8D-5DC2-454D-A1A2-9DF57E5A2077-low.gif\' title=\'\'> ActiveX Controls have been deprecated by Microsoft in the latest versions of the Windows operating system in favor of the <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript.html\' title=\'\'>DotNet</a> framework and its controls.</p>\n\
<p>While MAXScript still supports ActiveX controls, these have to be installed and registered on the system to be accessible to MAXScript.</p>\n\
<p>As a replacement of ActiveX controls, MAXScript supports <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript.html\' title=\'\'>DotNet controls</a> in <strong>3ds Max 9 and higher</strong>.</p>\n\
<p>Please see the topic <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/Converting-ActiveX-Controls-To/Converting-ActiveX-TreeView.html\' title=\'\'>Converting ActiveX TreeView Control to DotNet TreeView Control</a></p>\n\
<p><strong>Related topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/ActiveX-Controls-in-MAXScript/ActiveX-Controls-in-MAXScript-1.html\' title=\'\'>ActiveX Controls in MAXScript Rollouts</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/ActiveX-Controls-in-MAXScript/Typical-ActiveX-Controls/TreeView-ActiveX-Control.html\' title=\'\'>TreeView ActiveX Control</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Create a simple macroScript.</p>\n\
<p>Define a rollout which will be used to create a floating dialog.</p>\n\
<p>The only UI controls in the rollout will be a TreeView ActiveX Control and a spinner to control the Indentation</p>\n\
<p>Create a function to recursively traverse all children and add children nodes to the TreeView.</p>\n\
<p>Create a function to define the layout and appearance of the TreeView.</p>\n\
<p>Create a function to fill in the nodes into the TreeView by calling the recursive function.</p>\n\
<p>The two functions will be called by the on open event handler whenever the dialog is created (and thus the rollout is opened).</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` macroScript SceneTreeView category:&quot;HowTo&quot; ( rollout treeview_rollout &quot;TreeView Scene Browser&quot; ( fn initTreeView tv = ( tv.Indentation = 28*15 tv.LineStyle = #tvwRootLines ) fn addChildren tv theNode theChildren = ( for c in theChildren do ( newNode = tv.Nodes.add theNode.index 4 &quot;&quot; c.name 0 addChildren tv newNode c.children ) ) fn fillInTreeView tv = ( theRoot = tv.Nodes.add() theRoot.text =&quot;WORLD ROOT&quot; rootNodes =for o in objects where o.parent == undefined collect o addChildren tv theRoot rootNodes ) activeXControl tv &quot;MSComctlLib.TreeCtrl&quot; width:190 height:290 align:#center spinner spn_indent &quot;Indentation&quot; range:[0,100,28] type:#integer fieldwidth:40</p>\n\
<p>on tv nodeClick theNode do try(select (getNodeByName theNode.text))catch() on spn_indent changed val do tv.indentation = val*15 on treeview_rollout open do ( initTreeView tv fillInTreeView tv ) ) try(destroyDialog treeview_rollout)catch() createDialog treeview_rollout 200 320 )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>RESULT:</strong></p>\n\
</blockquote>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-1C8E6BD7-99EF-4AF3-8B89-7441A40C6634-low.gif\' title=\'\'></div>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>macroScript SceneTreeView category:&quot;HowTo&quot; (\n\
</pre></div><p>We start by defining a simple MacroScript with the name SceneTreeView which will appear in the category &quot;HowTo&quot;. Simple (old-style) macroScripts do not have <span class=\'code\'>on execute do</span> or <span class=\'code\'>on isEnabled</span> event handlers. The code inside the MacroScript definition is executed immediately when the ActionItem (button, menu item or keyboard shortcut) representing the MacroScript is activated.</p>\n\
<div class=\'codeBlock\'><pre>rollout treeview_rollout &quot;TreeView Scene Browser&quot; (\n\
</pre></div><p>This is the rollout to be created when the MacroScript is executed. It will display the title &quot;TreeView Scene Browser&quot;. The variable treeview_rollout will be local to the macroScript and will be used later on to create a dialog out of the rollout definition.</p>\n\
<div class=\'codeBlock\'><pre>fn initTreeView tv = (\n\
</pre></div><p>This is the function which will perform the initialization of the TreeView ActiveX control we will create. The control itself will be passed as argument to the function.</p>\n\
<div class=\'codeBlock\'><pre>tv.Indentation = 28*15\n\
</pre></div><p>The .indentation property expects a value in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/ActiveX-Controls-in-MAXScript/Point2-Values-as-Twips-in.html\' title=\'\'>Twips</a> and defines the amount of twips to indent children relatively to their parent. Since a pixel is roughly 15 twips, this line tells the hierarchy to use 28 pixels indentation.</p>\n\
<div class=\'codeBlock\'><pre>tv.LineStyle = #tvwRootLines\n\
</pre></div><p>TheLineStyle propery controls the appearance of the lines connecting the nodes in the hierarchy. We want the root to have its own plus/minus box and be connected to the scene nodes.</p>\n\
<div class=\'codeBlock\'><pre>) fn addChildren tv theNode theChildren = (\n\
</pre></div><p>This function will be called recursively to create children of the node passed as argument using <span class=\'code\'>theChildren</span> argument containing an array of <strong>3ds Max</strong> scene nodes. The argument <span class=\'code\'>tv</span> will contain the TreeView to add to.</p>\n\
<div class=\'codeBlock\'><pre>for c in theChildren do (\n\
</pre></div><p>For each <strong>3ds Max</strong> scene node in <span class=\'code\'>theChildren</span> array...</p>\n\
<div class=\'codeBlock\'><pre>newNode = tv.Nodes.add theNode.index 4 &quot;&quot; c.name 0\n\
</pre></div><p>...we add a new child to the supplied node. We pass a couple of parameters to the <strong><span class=\'code\'>add()</span></strong> method - the index of the parent, the relationship flag (4), the key (empty string), the text of the new child (the name of the scene node), and the index of the image to be displayed as icon (0 for no image)</p>\n\
<div class=\'codeBlock\'><pre>addChildren tv newNode c.children\n\
</pre></div><p>Once the child is created, the function calls itself recursively, passing the newly created node and the array of children of the current scene object as parameter. This way, the complete scene hierarchy will be recreated by the TreeView!</p>\n\
<div class=\'codeBlock\'><pre>)\n\
</pre></div><p>The c loop ends here.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
</pre></div><p>The recursive function ends here.</p>\n\
<div class=\'codeBlock\'><pre>fn fillInTreeView tv = (\n\
</pre></div><p>This function will define the content of the TreeView.</p>\n\
<div class=\'codeBlock\'><pre>theRoot = tv.Nodes.add()\n\
</pre></div><p>We add a single new node to represent the Root.</p>\n\
<div class=\'codeBlock\'><pre>theRoot.text = &quot;WORLD ROOT&quot;\n\
</pre></div><p>We set its label to &quot;WORLD ROOT&quot;</p>\n\
<div class=\'codeBlock\'><pre>rootNodes = for o in objects where o.parent == undefined collect o\n\
</pre></div><p>Then we collect all objects in the scene that have no parent. These are the top-level nodes that will be the &quot;children of the world&quot;.</p>\n\
<div class=\'codeBlock\'><pre>addChildren tv theRoot rootNodes\n\
</pre></div><p>Finally, we call the recursive function, passing the TreeView, the Root node and the array of top-level scene objects as arguments.</p>\n\
<div class=\'codeBlock\'><pre>) \n\
\n\
activeXControl tv &quot;MSComctlLib.TreeCtrl&quot; width:190 height:290 align:#center\n\
</pre></div><p>Now we can create a TreeView ActiveX control in the rollout.</p>\n\
<div class=\'codeBlock\'><pre>spinner spn_indent &quot;Indentation&quot; range:[0,100,28] type:#integer fieldwidth:40\n\
</pre></div><p>This spinner will allow us to test interactively the <span class=\'code\'>.indentation</span> property of the TreeView. Simply changing the spinner&#39;s value will dynamically update the indentation of the complete hierarchy!</p>\n\
<div class=\'codeBlock\'><pre>on tv nodeClick theNode do try(select (getNodeByName theNode.text))catch()\n\
</pre></div><p>If the user clicked a node, we will try to convert its name back to a <strong>3ds Max</strong> scene node and select it in the scene. This demonstrates the usage of TreeView event handlers...</p>\n\
<div class=\'codeBlock\'><pre>on spn_indent changed val do tv.indentation = val*15\n\
</pre></div><p>If the user changed the spinner, we want the <span class=\'code\'>.indentation</span> to be set to the respective amount of <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/ActiveX-Controls-in-MAXScript/Point2-Values-as-Twips-in.html\' title=\'\'>Twips</a>.</p>\n\
<div class=\'codeBlock\'><pre>on treeview_rollout open do (\n\
</pre></div><p>When the rollout is opening (this is when the <span class=\'code\'>CreateDialog</span> function is called)...</p>\n\
<div class=\'codeBlock\'><pre>initTreeView tv fillInTreeView tv\n\
</pre></div><p>...the initialization function and the data collecting function will be called to define the style and populate the TreeView control with the names of the <strong>3ds Max</strong> scene objects.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
</pre></div><p>The rollout open event ends here.</p>\n\
<div class=\'codeBlock\'><pre>) try(destroyDialog treeview_rollout)catch()\n\
</pre></div><p>Before creating a new dialog, we want to make sure any previously opened dialog with the same name is closed...</p>\n\
<div class=\'codeBlock\'><pre>createDialog treeview_rollout 200 320\n\
</pre></div><p>Finally, we create a new Dialog using the rollout definition.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
</pre></div><div class=\'section\'><a id=\"whats-next\"></a><h2 id=\"whats-next\">What&#39;s Next?</h2></div>\n\
<p>This is a very basic version of the script. To see how it can be further improved and customized, see Part Two of the tutorial - <a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-a-Scene-Browser/How-To-Develop-a-Scene-Browser-2.html\' title=\'\'>How To ... Develop a Scene Browser using TreeView ActiveX Control - Part Two</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";