var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Develop a Selected Objects Inspector using ListView ActiveX Control - Part One</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Develop a Selected Objects Inspector using ListView ActiveX Control - Part One</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-develop-a-selected-objects-inspector-using-listview-activex-control---part-one\"></a></div>\n\
<p>This tutorial will demonstrate how to set up an ActiveX Control in a MAXScript rollout to display details about selected scene objects.</p>\n\
<p>Note:</p>\n\
<p><img src=\'developer/images/GUID-58798F8D-5DC2-454D-A1A2-9DF57E5A2077-low.gif\' title=\'\'> ActiveX Controls have been deprecated by Microsoft in the latest versions of the Windows operating system in favor of the <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript.html\' title=\'\'>DotNet</a> framework and its controls.</p>\n\
<p>While MAXScript still supports ActiveX controls, these have to be installed and registered on the system to be accessible to MAXScript.</p>\n\
<p>As a replacement of ActiveX controls, MAXScript supports <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript.html\' title=\'\'>DotNet controls</a> in <strong>3ds Max 9 and higher</strong>.</p>\n\
<p>Please see the topic <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/Converting-ActiveX-Controls-To/Converting-ActiveX-ListView.html\' title=\'\'>Converting ActiveX ListView Control to DotNet ListView Control</a></p>\n\
<p><strong>Related topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/ActiveX-Controls-in-MAXScript/ActiveX-Controls-in-MAXScript-1.html\' title=\'\'>ActiveX Controls in MAXScript Rollouts</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/ActiveX-Controls-in-MAXScript/Typical-ActiveX-Controls/ListView-ActiveX-Control.html\' title=\'\'>ListView ActiveX Control</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/ActiveX-Controls-in-MAXScript/Typical-ActiveX-Controls/ListView-ActiveX-Control/Listview-ActiveX-functions.html\' title=\'\'>Listview ActiveX functions</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/ActiveX-Controls-in-MAXScript/Typical-ActiveX-Controls/ListView-ActiveX-Control/ListView-ActiveX-Control-Example.html\' title=\'\'>ListView ActiveX Control Example</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Create a simple macroScript.</p>\n\
<p>Define a rollout which will be used to create a floating dialog.</p>\n\
<p>The only UI control in the rollout will be a Listview ActiveX Control.</p>\n\
<p>Create a function to define the layout and appearance of the Listview.</p>\n\
<p>Create another function to fill in the data of selected objects into the list</p>\n\
<p>The two functions will be called by the on open event handler whenever the dialog is created (and thus the rollout is opened).</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` macroScript SceneListView category:&quot;HowTo&quot; ( rollout listview_rollout &quot;ListView Selected&quot; ( fn initListView lv = ( lv.gridLines = true<br> lv.View = #lvwReport<br> lv.fullRowSelect = true</p>\n\
<p>layout_def = #(&quot;Object Name&quot;,&quot;Object Class&quot;,&quot;Verts&quot;,&quot;Faces&quot;,&quot;Material&quot;)</p>\n\
<p>for i in layout_def do ( column = lv.ColumnHeaders.add() column.text = I ) )</p>\n\
<p>fn fillInSpreadSheet lv = ( for o in selection do ( li = lv.ListItems.add() li.text = o.name sub_li = li.ListSubItems.add() sub_li.text = (classof o) as string sub_li = li.ListSubItems.add() sub_li.text =try((o.mesh.numverts) as string)catch(&quot;--&quot;) sub_li = li.ListSubItems.add() sub_li.text =try((o.mesh.numfaces) as string)catch(&quot;--&quot;) sub_li = li.ListSubItems.add() sub_li.text = (o.material)as string ) )</p>\n\
<p>activeXControl lv_objects &quot;MSComctlLib.ListViewCtrl&quot; width:490 height:190 align:#center on listview_rollout open do ( initListView lv_objects fillInSpreadSheet lv_objects ) ) createDialog listview_rollout500 200 )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>RESULT:</strong></p>\n\
</blockquote>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-A15CE4AA-D1DE-4220-8E01-7308DCA73F7B-low.gif\' title=\'\'></div>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>macroScript SceneListView category:&quot;HowTo&quot; (\n\
</pre></div><p>We start by defining a simple MacroScript with the name SceneListview which will appear in the category &quot;HowTo&quot;. Simple (old-style) macroScripts do not have on execute do or on isEnabled event handlers. The code inside the MacroScript definition is executed immediately when the ActionItem (button, menu item or keyboard shortcut) representing the MacroScript is activated.</p>\n\
<div class=\'codeBlock\'><pre>rollout listview_rollout &quot;ListView Selected&quot; (\n\
</pre></div><p>This is the rollout to be created when the MacroScript is executed. It will display the title &quot;ListView Selected&quot;. The variable listview_rollout will be local to the macroScript and will be used later on to create a dialog out of the rollout definition.</p>\n\
<div class=\'codeBlock\'><pre>fn initListView lv = (\n\
</pre></div><p>This is the function which will perform the initialization of the ListView ActiveX control we will create. The control itself will be passed as argument to the function.</p>\n\
<div class=\'codeBlock\'><pre>lv.gridLines = true\n\
</pre></div><p>We want the ListViewControl to display grid lines.</p>\n\
<div class=\'codeBlock\'><pre>lv.View = #lvwReport\n\
</pre></div><p>We also want to see the column headers, so we define the view type as lvwReport.</p>\n\
<div class=\'codeBlock\'><pre>lv.fullRowSelect = true \n\
</pre></div><p>By setting this property to true, we ensure that selecting a row will select across all columns.</p>\n\
<div class=\'codeBlock\'><pre>layout_def = #(&quot;Object Name&quot;,&quot;Object Class&quot;,&quot;Verts&quot;,&quot;Faces&quot;,&quot;Material&quot;)\n\
</pre></div><p>This user variable is assigned an array containing the names of the columns to be created.</p>\n\
<div class=\'codeBlock\'><pre>for i in layout_def do (\n\
</pre></div><p>The i loop will go through all elements of the array defined above. Inside the loop, a new column will be created for each entry in the array.</p>\n\
<div class=\'codeBlock\'><pre>column = lv.ColumnHeaders.add()\n\
</pre></div><p>By calling the function add() in the ColumnHeaders property of the listview, we add a new column to the list. A reference to the column is returned and written in the user variable &quot;column&quot;, so we can now access properties of the column.</p>\n\
<div class=\'codeBlock\'><pre>column.text =i \n\
</pre></div><p>For example, we can set the text in the column header to the string stored in the array we are looping through.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
</pre></div><p>This is the end of the i loop..</p>\n\
<div class=\'codeBlock\'><pre>)\n\
</pre></div><p>This is the end of the function.</p>\n\
<div class=\'codeBlock\'><pre>fn fillInSpreadSheet lv =\n\
(\n\
</pre></div><p>This is the function which will fill in the data of the selected scene objects into the Listview ActiveX control. The control itself will be passed as argument to the function.</p>\n\
<div class=\'codeBlock\'><pre>for o in selection do\n\
(\n\
</pre></div><p>This loop will iterate through all objects currently selected in the scene. The variable o will contain one object at a time, the loop will repeat as ofter as there are objects in the selection set.</p>\n\
<div class=\'codeBlock\'><pre>li = lv.ListItems.add()\n\
</pre></div><p>We add a new row to the Listview.</p>\n\
<div class=\'codeBlock\'><pre>li.text = o.name\n\
</pre></div><p>Then we set the text displayed in the first column of the list to the name of the object.</p>\n\
<div class=\'codeBlock\'><pre>sub_li = li.ListSubItems.add()\n\
</pre></div><p>Now we add a new sub-item (which is basically the following column) by calling the <span class=\'code\'>.add()</span> method in the ListSubItems property of the current listItem (which represents the first column). The result is written into the user variable sub_li</p>\n\
<div class=\'codeBlock\'><pre>sub_li.text = (classof o) as string\n\
</pre></div><p>We can now set the .text property of the new column to the class of the current object. Since the result of <span class=\'code\'>classof()</span> is not a string, we have to explicitly convert it to string before assigning it to the <span class=\'code\'>.text</span> property.</p>\n\
<div class=\'codeBlock\'><pre>sub_li = li.ListSubItems.add()\n\
sub_li.text = try((o.mesh.numverts) as string)catch(&quot;--&quot;)\n\
</pre></div><p>We create a third column the same way as above and assign the number of vertices in the mesh of the current object to the .text property of the new column. Since the number of vertices is returned as an integer, we have to convert it to a string before assigning it to the <span class=\'code\'>.text</span> property.</p>\n\
<p>Some of the selected objects might not have a <span class=\'code\'>.mesh</span> property (for example lights, helpers, cameras, targetObjects etc.) In these cases, trying to access <span class=\'code\'>o.mesh.numverts</span> would cause an error. For these cases, we put the <span class=\'code\'>try()catch()</span> error trap. If the attempt to read the vertex count fails, we assign the string &quot;--&quot; to the <span class=\'code\'>.text</span> property of the sub-list item instead.</p>\n\
<div class=\'codeBlock\'><pre>sub_li = li.ListSubItems.add()\n\
sub_li.text = try((o.mesh.numfaces) as string)catch(&quot;--&quot;)\n\
</pre></div><p>We create another column the same way as above and assign the number of f aces in the mesh of the current object to the <span class=\'code\'>.text</span> property of the new column. Since the number of faces is returned as an integer, we have to convert it to a string before assigning it to the <span class=\'code\'>.text</span> property.</p>\n\
<p>Some of the selected objects might not have a .mesh property (for example lights, helpers, cameras, targetObjects etc.) In these cases, trying to access <span class=\'code\'>o.mesh.numfaces</span> would cause an error. For these cases, we put the <span class=\'code\'>try()catch()</span> error trap. If the attempt to read the face count fails, we assign the string &quot;--&quot; to the <span class=\'code\'>.text</span> property of the sub-list item instead.</p>\n\
<div class=\'codeBlock\'><pre>sub_li = li.ListSubItems.add()\n\
sub_li.text = (o.material) as string\n\
</pre></div><p>Finally, we create another column the same way as above and assign the material of the current object to the <span class=\'code\'>.text</span> property of the new column. Objects without a material will display &quot;undefined&quot; in the column.</p>\n\
<div class=\'codeBlock\'><pre>) \n\
)\n\
 \n\
activeXControl lv_objects &quot;MSComctlLib.ListViewCtrl&quot; width:490 height:190 align:#center\n\
</pre></div><p>This is it - the ActiveX control we have been processing in the above functions! It is the only user interface element in the rollout. It is centered to the rollout and slightly smaller than the dialog dimensions.</p>\n\
<div class=\'codeBlock\'><pre>on listview_rollout open do\n\
(\n\
</pre></div><p>When the rollout is opened for display as a dialog, this event handler will be called.</p>\n\
<div class=\'codeBlock\'><pre>initListView lv_objects\n\
fillInSpreadSheet lv_objects\n\
</pre></div><p>We can use the event to both initialize and fill in the listview with the currently selected objects&#39; data.</p>\n\
<div class=\'codeBlock\'><pre>) \n\
</pre></div><p>This is the end of the on open event handler.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
</pre></div><p>This is the end of the rollout definition.</p>\n\
<div class=\'codeBlock\'><pre>try(destroyDialog listview_rollout)catch()\n\
</pre></div><p>Before creating the dialog, we try to close it. Since the variable <span class=\'code\'>listview_rollout</span> is local to the MacroScript, calling the MacroScript multiple times will always access the same variable and will be able to close a previously opened dialog before creating a new one.</p>\n\
<div class=\'codeBlock\'><pre>createDialog listview_rollout 500 200\n\
</pre></div><p>At the end, we create the dialog using the rollout we defined above.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
</pre></div><div class=\'section\'><a id=\"using-the-script\"></a><h2 id=\"using-the-script\">Using the Script</h2></div>\n\
<p>After evaluating the script, you will find a new ActionItem in the &quot;HowTo&quot; category of the Customize User Interface dialog. Assign it to a toolbar, menu, QuadMenu or keyboard shortcut to be able to access it quickly.</p>\n\
<p>Select some scene objects and press the button/select the menu item or press the keyboard shortcut - a new dialog with a listView ActiveX control displaying the name, class, vertex and face count and assigned material should appear.</p>\n\
<p>Select some other object and call the script again - the old dialog will be closed, a new one will be opened and will display the data of the new selection.</p>\n\
<div class=\'section\'><a id=\"whats-next\"></a><h2 id=\"whats-next\">What&#39;s Next?</h2></div>\n\
<p>This is a very basic version of the script. To see how it can be further improved and customized, see <a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-a-Selected/How-To-Develop-a-Selected-2.html\' title=\'\'>How To ... Develop a Selected Objects Inspector using ListView ActiveX Control - Part Two</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";