var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Develop a Vertex Renderer</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Develop a Vertex Renderer</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-develop-a-vertex-renderer\"></a></div>\n\
<p>The tutorial will demonstrate the basics of rendering - transforming objects from 3D space into 2D images.To make it simple and fast (realtime!), the script will draw only vertices. The image will be redrawn every time the viewport is updated - changing the view, panning, zooming and orbiting will be reflected by the vertex renderer instantly!</p>\n\
<p><strong>Related topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Viewports/Accessing-Active-Viewport-Info.html\' title=\'\'>Accessing Active Viewport Info, Type, and Transforms</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Create a macroScript.</p>\n\
<p>Define a flag variable to remember whether the renderer is enabled or disabled</p>\n\
<p>Define local variables to hold the render size and the front and back buffer images</p>\n\
<p>Define a function to be called when the viewport redraws.</p>\n\
<p>In the function,</p>\n\
<ul>\n\
<li><p>Copy the back buffer into the front buffer</p></li>\n\
<li><p>Go through all geometry objects and get their mesh</p></li>\n\
<li><p>Get every vertex of the mesh, transform into image coordinates using the current view transformation matrix</p></li>\n\
<li><p>Draw a pixel for the vertex in the front buffer</p></li>\n\
<li><p>When done, display the image</p></li>\n\
</ul>\n\
<p>Return the flag from the on isChecked handler.</p>\n\
<p>When executed,</p>\n\
<ul>\n\
<li><p>Invert the flag</p></li>\n\
<li><p>Redefine the render size variables and the bitmaps</p></li>\n\
<li><p>Register the viewport redraw callback function if the flag is true, unregister if false.</p></li>\n\
</ul>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` macroScript VertexRender category:&quot;HowTo&quot; ( local VertexRendererEnabled = false local screen_width, screen_height, back_vfb, front_vfb fn VertexRendererFunction = ( st = timestamp() copy back_vfb front_vfb for o in geometry where classof o != TargetObject do ( theMesh = snapshotAsMesh o dot_color = #(o.wirecolor) theVertCount = theMesh.numverts for v = 1 to theVertCount do ( thePos = (getVert theMesh v)* viewport.getTM() screen_origin = mapScreenToView [0,0] (thePos.z) [screen_width,screen_height] end_screen = mapScreenToView [screen_width,screen_height] (thePos.z) [screen_width,screen_height] world_size = screen_origin-end_screen x_aspect = screen_width/(abs world_size.x) y_aspect = screen_height/(abs world_size.y) screen_coords = point2 (x_aspect<em>(thePos.x-screen_origin.x)) (-(y_aspect</em>(thePos.y-screen_origin.y))) setPixels front_vfb screen_coords dot_color )--end v loop )--end o loop display front_vfb et = timestamp() pushPrompt (&quot;VertRender &quot;+(1000.0/(et-st)) as string +&quot; fps&quot;) )--end fn</p>\n\
<p>on isChecked return VertexRendererEnabled</p>\n\
<p>on execute do ( VertexRendererEnabled =not VertexRendererEnabled</p>\n\
<p>if VertexRendererEnabled then ( screen_width=RenderWidth screen_height=RenderHeight back_vfb = bitmap screen_width screen_height front_vfb = bitmap screen_width screen_height registerRedrawViewsCallback VertexRendererFunction RedrawViews() ) else ( unRegisterRedrawViewsCallback VertexRendererFunction close front_vfb ) )--end on execute )--end script</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-B22E1D14-6E5C-4D81-ADD9-E528B2F2E784-low.gif\' title=\'\'></div>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>macroScript VertexRender category:&quot;HowTo&quot;\n\
(\n\
</pre></div><p>We start by defining a MacroScript with the name VertexRender which will appear in the category &quot;HowTo&quot;. This will be an advanced macroScripts which will have <span class=\'code\'>on execute do</span> or <span class=\'code\'>on is Checked do</span> event handlers.</p>\n\
<div class=\'codeBlock\'><pre>localVertexRendererEnabled= false\n\
</pre></div><p>We define a local variable to hold a flag determining whether the renderer is active or not. In the beginning, the variable will be set to false.</p>\n\
<div class=\'codeBlock\'><pre>local screen_width,screen_height, back_vfb,front_vfb\n\
</pre></div><p>We define a couple more local variables to hold the width and height of the image and the two bitmaps - the back buffer and the front buffer (see below for more info).</p>\n\
<div class=\'codeBlock\'><pre>fn VertexRendererFunction =\n\
(\n\
</pre></div><p>This is the function that will be executed when the renderer is enabled and the viewport is being updated.</p>\n\
<div class=\'codeBlock\'><pre>st = timestamp()\n\
</pre></div><p>To be able to output info on the rendering speed, we will use the timestamp function to get the current system time.</p>\n\
<div class=\'codeBlock\'><pre>copy back_vfb front_vfb\n\
</pre></div><p>Then we will copy the back buffer into the front buffer, basically clearing the previous image. The back buffer could be changed to hold a background image, and the function would draw on top of it... For now, the back buffer image is set to black.</p>\n\
<div class=\'codeBlock\'><pre>for o in geometry where classof o != TargetObject do\n\
(\n\
</pre></div><p>We loop through all scene geometry objects that are not target objects of lights, cameras etc. Note that we are not checking for hidden objects - you could add this to the code as an exercise! Right now, all objects will be drawn, even the hidden ones!</p>\n\
<div class=\'codeBlock\'><pre>theMesh = snapshotAsMesh o\n\
</pre></div><p>Then we snapshot the objects as mesh into memory. This includes all modifiers AND space warps applied to the object.</p>\n\
<div class=\'codeBlock\'><pre>dot_color = #(o.wirecolor)\n\
</pre></div><p>We define an array to be used for painting the vertices and use the wireframe color to draw.</p>\n\
<div class=\'codeBlock\'><pre>theVertCount = theMesh.numverts\n\
</pre></div><p>To speed things up, we read the number of vertices in the mesh once. We will use this value below to limit the vertex loop:</p>\n\
<div class=\'codeBlock\'><pre>for v = 1 to theVertCount do\n\
( \n\
</pre></div><p>The v variable will count from 1 to the number of vertices.</p>\n\
<div class=\'codeBlock\'><pre>thePos = (getVert theMesh v)* viewport.getTM()\n\
</pre></div><p>The position of the v-th vertex has to be multiplied by the transformation matrix of the viewport. (If the viewport is a Camera, the viewport.getTM() returns the inverse of the camera&#39;s transformation matrix. If the viewport is a Perspective or Ortho view, the matrix is already inverted). By multiplying the vertex position by this matrix, we transform the 3D space coordinates into camera space!</p>\n\
<div class=\'codeBlock\'><pre>screen_origin = mapScreenToView [0,0] (thePos.z) [screen_width,screen_height]\n\
</pre></div><p>Now we need to know the size of the projection plane with pixel size equal to the rendering image when placed at the depth of the current vertex. To calculate this, we will need the two extremes (upper left and lower right) points of the plane as 3D points in camera space.</p>\n\
<p>Since thePos is already in camera coordinates, the.Z coordinate is the Z-depth of the point!The return value of <span class=\'code\'>mapScreenToView</span> is a 3D point in camera space corresponding to the upper left corner of the projection plane.</p>\n\
<div class=\'codeBlock\'><pre>end_screen = mapScreenToView [screen_width,screen_height] (thePos.z) [screen_width,screen_height]\n\
</pre></div><p>We do the same for the lower right corner of the projection plane.</p>\n\
<p>Here is what we just did and why:</p>\n\
<p>As you know, the camera has a cone (frustrum) with the top at the position of the camera. If the projection plane would &quot;travel&quot; along the Z axis of the camera, the farther it gets from the &quot;eye&quot;, the larger it becomes in world units, but the number of pixels in the final image remains the same.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-F18B8243-7BF3-4894-8D32-45DE2884F9CA-low.gif\' title=\'\'></div>\n\
<p>On the screenshot, you can see a camera and two projection planes (shown as red X). You can also see that the size of the projection plane is increasing as it gets farther from the camera.</p>\n\
<p>The farther projection plane is exactly at the depth of the teapot&#39;s position in camera space.</p>\n\
<p>The red sphere in the upper left corner of the projection plane corresponds to the <span class=\'code\'>screen_origin</span> coordinate calculated above. To create the image, the <span class=\'code\'>screen_origin</span> value was calculated, then the MAXScript line of code</p>\n\
<div class=\'codeBlock\'><pre>sphere pos:(screen_origin*$Camera01.transform)\n\
</pre></div><p>was called to create a sphere in world coordinates representing that point. ( <span class=\'code\'>screen_origin</span> was originally in camera space, multiplying it by the camera&#39;s transformation matrix transforms it back into world coordinates!)</p>\n\
<p>Same with the blue sphere - it represents the <span class=\'code\'>end_screen</span> coordinate.</p>\n\
<p>Here is what the camera sees when rendering the view - notice the red and blue spheres appearing exactly where expected:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-2553A757-0412-469C-973C-FB5806851F12-low.gif\' title=\'\'></div>\n\
<div class=\'codeBlock\'><pre>world_size = screen_origin-end_screen\n\
</pre></div><p>Now we know the two extremes of the projection plane and can calculate the width and height of the projection plane in world units. We also know the size of the plane in pixels, so we can determine the relationship between pixels and world units!</p>\n\
<div class=\'codeBlock\'><pre>x_aspect = screen_width/(abs world_size.x)\n\
y_aspect = screen_height/(abs world_size.y)\n\
</pre></div><p>Using the size of the plane, we can calculate the aspect values - basically the number of pixels corresponding to one world unit along X and Y.</p>\n\
<div class=\'codeBlock\'><pre>screen_coords= point2 (x_aspect*(thePos.x-screen_origin.x)) (-(y_aspect*(thePos.y-screen_origin.y)))\n\
</pre></div><p>Using the aspect values, we can convert the X and Y values of the vertex position into actual pixel positions. Note that the Y coordinate is inverted, and the X position has to be offset by the screen_origin because the camera axis (the center of the image) is located at coordinates [0,0], while the actual origin of the image in MAXScript is in the upper left corner...</p>\n\
<div class=\'codeBlock\'><pre>setPixels front_vfbscreen_coordsdot_color\n\
</pre></div><p>Now we can draw a pixel in the front buffer at the location of the current vertex using the color array defined above using the wireframe color.</p>\n\
<div class=\'codeBlock\'><pre>)--end v loop\n\
)--end o loop\n\
display front_vfb \n\
</pre></div><p>When all vertices of all objects have been processed, we can update the display.</p>\n\
<div class=\'codeBlock\'><pre>et = timestamp()\n\
</pre></div><p>Then we can stop the time again to see how long it took to draw once.</p>\n\
<div class=\'codeBlock\'><pre>pushPrompt (&quot;VertRender &quot; +(1000.0/(et-st)) as string + &quot; fps&quot;)\n\
</pre></div><p>The result will be output to the status bar.</p>\n\
<div class=\'codeBlock\'><pre>)--end fn\n\
on isChecked returnVertexRendererEnabled\n\
</pre></div><p>When the macroScript is placed on a toolbar, menu or QuadMenu, its checked status will be determined by the boolean value stored in the local variable we defined in the beginning...</p>\n\
<div class=\'codeBlock\'><pre>on execute do (\n\
</pre></div><p>When the user presses the button / selects the menu item...</p>\n\
<div class=\'codeBlock\'><pre>VertexRendererEnabled = not VertexRendererEnabled\n\
</pre></div><p>...we flip the state of the variable - if it was true it becomes false and vice-versa.</p>\n\
<div class=\'codeBlock\'><pre>if VertexRendererEnabled then\n\
(\n\
</pre></div><p>If the script was just enabled, then</p>\n\
<div class=\'codeBlock\'><pre>screen_width=RenderWidth\n\
screen_height=RenderHeight\n\
</pre></div><p>we read the current size values of the Render Scene dialog. You could replace these values with your fixed values, for example 320 and 240 to have a fixed size regardless of the renderer settings...</p>\n\
<div class=\'codeBlock\'><pre>back_vfb = bitmap screen_width screen_height\n\
front_vfb = bitmap screen_width screen_height\n\
</pre></div><p>Then we use these size values to define two bitmaps. The first is the back buffer used to clear the image before drawing. Once again, you could use an openBitmap call here to load a background image from disk to draw on top of it!</p>\n\
<div class=\'codeBlock\'><pre>registerRedrawViewsCallback VertexRendererFunction\n\
</pre></div><p>Here we register the function we defined above as a viewport redraw callback. Each time the <strong>3ds Max</strong> viewport is redrawn, the function will be called and update the rendered image!</p>\n\
<div class=\'codeBlock\'><pre>VertexRendererFunction() \n\
</pre></div><p>To initialize the display, we call the function once.</p>\n\
<div class=\'codeBlock\'><pre>) \n\
else\n\
(\n\
unRegisterRedrawViewsCallback VertexRendererFunction \n\
</pre></div><p>If the renderer was already open, it has to close now. We unregister the callback function to avoid further updates,</p>\n\
<div class=\'codeBlock\'><pre>close front_vfb \n\
</pre></div><p>and close the image to undisplay it.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
)--end on execute\n\
)--end script\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";