var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Develop A Face Area XView Checker - Part 1</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Develop A Face Area XView Checker - Part 1</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-develop-a-face-area-xview-checker---part-1\"></a></div>\n\
<p>The following tutorial demonstrates the creation of a <strong>custom xView Checker</strong> using MAXScript functions.</p>\n\
<p>The xView Checker is available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<p><strong>Related topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Geometry-Checker/xView-Geometry-Checker-Access.html\' title=\'\'>xViewChecker Access</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/U-V-W-X-Y-Z/Interface-xViewChecker.html\' title=\'\'>Interface:xViewChecker</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Create a global struct with properties and functions</p>\n\
<p>Define an xView geometry checker function</p>\n\
<p>Define a supported function</p>\n\
<p>Register xView Checker.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` ( global FaceAreaChecker struct FaceAreaCheckerStruct ( FaceAreaThresholdMin = 1, FaceAreaThresholdMax = 10, faceAreaDialog = undefined,</p>\n\
<p>fn geomCheck theTime theNode theResults = ( local theCount = case classof theNode of ( Editable_Poly: getNumFaces theNode Editable_Mesh: theNode.numfaces ) local theAreaMethod = case classof theNode of ( Editable_Poly: polyOp.getFaceArea Editable_Mesh: meshOp.getFaceArea )</p>\n\
<div class=\'codeBlock\'><pre>for f = 1 to theCount do\n\
(\n\
  local theArea = theAreaMethod theNode f\n\
  if theArea &gt;= FaceAreaChecker.FaceAreaThresholdMin and theArea &lt;= FaceAreaChecker.FaceAreaThresholdMax do append theResults f\n\
) \n\
</pre></div><p>3 ),</p>\n\
<p>fn supportedCheck theNode = ( classof theNode == Editable_Mesh or classof theNode == Editable_Poly ),</p>\n\
<p>fn configDlg = ( try(destroyDialog FaceAreaChecker.faceAreaDialog)catch() rollout faceAreaDialog &quot;Face Area Checker&quot; ( spinner spn_FaceAreaThresholdMin &quot;Min. Threshold:&quot; range:[0,1000000,FaceAreaChecker.FaceAreaThresholdMin] offset:[7,-3] type:#worldUnits spinner spn_FaceAreaThresholdMax &quot;Max. Threshold:&quot; range:[0,1000000,FaceAreaChecker.FaceAreaThresholdMax] offset:[7,-3] type:#worldUnits</p>\n\
<div class=\'codeBlock\'><pre>  fn updateDisplay =\n\
  (\n\
    XViewChecker.runCheck CurrentTime\n\
    max views redraw\n\
  )\n\
  on spn_FaceAreaThresholdMin changed val do\n\
  (\n\
    FaceAreaChecker.FaceAreaThresholdMin = val\n\
    updateDisplay()\n\
  ) \n\
  on spn_FaceAreaThresholdMax changed val do\n\
  (\n\
    FaceAreaChecker.FaceAreaThresholdMax = val\n\
    updateDisplay()\n\
  )   \n\
)--end rollout\n\
\n\
createDialog faceAreaDialog\n\
setDialogPos faceAreaDialog mouse.screenpos\n\
FaceAreaChecker.faceAreaDialog = faceAreaDialog\n\
</pre></div><p>) )--end struct</p>\n\
<p>try(destroyDialog FaceAreaChecker.faceAreaDialog)catch() FaceAreaChecker = FaceAreaCheckerStruct()</p>\n\
<p>XViewChecker.unRegisterChecker &quot;Face Area Checker&quot; XViewChecker.registerChecker FaceAreaChecker.geomCheck FaceAreaChecker.supportedCheck #Faces &quot;Face Area Checker&quot; FaceAreaChecker.configDlg undefined undefined )--end script</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>(\n\
</pre></div><p>The complete script is in a local scope.</p>\n\
<div class=\'codeBlock\'><pre>global FaceAreaChecker\n\
</pre></div><p>Only the instance of the struct containing the xView Checker properties and functions will be exposed to the global scope.</p>\n\
<div class=\'codeBlock\'><pre>struct FaceAreaCheckerStruct (\n\
</pre></div><p>We start a struct to encapsulate all properties and functions. It will be local to the current scope.</p>\n\
<div class=\'codeBlock\'><pre>FaceAreaThresholdMin = 1,\n\
</pre></div><p>This property will contain the minimum face area to check for.</p>\n\
<div class=\'codeBlock\'><pre>FaceAreaThresholdMax = 10,\n\
</pre></div><p>This property will contain the maximum face area to check for.</p>\n\
<div class=\'codeBlock\'><pre>faceAreaDialog = undefined,\n\
</pre></div><p>Our xView Checker will include a settings dialog. To be able to close it between sessions, we will store the rollout of the dialog in this property. This will give us global access to the dialog without directly storing it in a global variable.</p>\n\
<div class=\'codeBlock\'><pre>fn geomCheck theTime theNode theResults =\n\
(\n\
</pre></div><p>This is the main xViewChecker function.</p>\n\
<p>An xView Checker function must expect three arguments which are passed to it by the system - the time at which the check is performed, the node being checked, and an array to put the results from the check into.</p>\n\
<div class=\'codeBlock\'><pre>local theCount = case classof theNode of\n\
(\n\
Editable_Poly: getNumFaces theNode\n\
Editable_Mesh: theNode.numfaces\n\
)\n\
</pre></div><p>Since we want to be able to check both Editable Poly objects and Editable Meshes, we check the class of the node passed to the function and get the face or polygon count using the correct method or property.</p>\n\
<div class=\'codeBlock\'><pre>local theAreaMethod = case classof theNode of\n\
(\n\
Editable_Poly: polyOp.getFaceArea\n\
Editable_Mesh: meshOp.getFaceArea\n\
)\n\
</pre></div><p>Again, based on the class of the node, we store the method to get the polygon or face area in a user variable. This will both speed up the access to the method and allow us to use the same expression to get the face area in the following loop.</p>\n\
<div class=\'codeBlock\'><pre>for f = 1 to theCount do\n\
(\n\
</pre></div><p>We loop through all the faces or polygons of the node</p>\n\
<div class=\'codeBlock\'><pre>local theArea = theAreaMethod theNode f\n\
</pre></div><p>We call the cached method for polygon resp. face area and pass the node and the face index to it.</p>\n\
<div class=\'codeBlock\'><pre>if theArea &gt;= FaceAreaChecker.FaceAreaThresholdMin and theArea &lt;= FaceAreaChecker.FaceAreaThresholdMax do append theResults f\n\
</pre></div><p>Then we can compare the value to the min. and max. threshold and if the area is between the two thresholds, we append the face index to the results array.</p>\n\
<div class=\'codeBlock\'><pre>) \n\
3\n\
</pre></div><p>The xViewCheck function must return an integer specifying the result type.</p>\n\
<p>We return 3 because we stored the indices of the faces in the results array.</p>\n\
<p>The other options are 2 for edges, 1 for vertices and 0 if the check failed.</p>\n\
<p>This will help the rest of the xView Checker system figure out how to use the data in the results array to display in the viewport or convert the results to a sub-object selection.</p>\n\
<div class=\'codeBlock\'><pre>),\n\
\n\
fn supportedCheck theNode =\n\
(\n\
classof theNode == Editable_Mesh or classof theNode == Editable_Poly\n\
),\n\
</pre></div><p>The supported check function is called by the xView Checker system to determine whether a node supports the Checker or not. In our case, we want to allow the checking of Editable Meshes and Editable Poly objects, so we check the class of the node and compare to these classes. Any other objects will be skipped.</p>\n\
<div class=\'codeBlock\'><pre>fn configDlg =\n\
(\n\
</pre></div><p>This function will be called by the xView Checker system whenever the user clicks on the &quot;Click Here To Configure&quot; button in the Viewport. If this function was not registered with the checker (but passed as undefined value instead), that viewport button would not be displayed and the system would assume the Checker does not support a configuration dialog.</p>\n\
<div class=\'codeBlock\'><pre>try (destroyDialog FaceAreaChecker.faceAreaDialog)catch()\n\
</pre></div><p>We attempt to close any dialog that might have been opened previously. We use the property of the struct instance where we will assign the rollout used by the dialog.</p>\n\
<p>If the dialog is not open, nothing will happen.</p>\n\
<div class=\'codeBlock\'><pre>rollout faceAreaDialog &quot;Face Area Checker&quot;\n\
(\n\
</pre></div><p>Now we define a rollout to display as a configuration dialog.</p>\n\
<div class=\'codeBlock\'><pre>spinner spn_FaceAreaThresholdMin &quot;Min. Threshold:&quot; range:[0,1000000,FaceAreaChecker.FaceAreaThresholdMin] offset:[7,-3] type:#worldUnits\n\
spinner spn_FaceAreaThresholdMax &quot;Max. Threshold:&quot; range:[0,1000000,FaceAreaChecker.FaceAreaThresholdMax] offset:[7,-3] type:#worldUnits \n\
</pre></div><p>We define two spinners to control the min. and max. threshold values used by the test. Both spinners are set to default to the current properties of the struct instance and display world units. Of course, we will be checking for SQUARE units, but the spinners will show just regular linear units. So if the spinner shows 10&quot;, we will interpret the value as 10 square inches.</p>\n\
<div class=\'codeBlock\'><pre>fn updateDisplay =\n\
(\n\
XViewChecker.runCheck CurrentTime\n\
max views redraw\n\
)\n\
</pre></div><p>This function will be called when User Interface elements (the spinners) change their values. The function calls the method to run the current xView check at the current time, resulting in updated checker data. To force the display of the new data, we have to do a full redraw of all viewports.</p>\n\
<div class=\'codeBlock\'><pre>on spn_FaceAreaThresholdMin changed val do\n\
(\n\
FaceAreaChecker.FaceAreaThresholdMin = val\n\
updateDisplay()\n\
) \n\
</pre></div><p>Whenever the min. threshold spinner is changed, we store the new value in the struct instance&#39;s property and call the update function to refresh the viewports.</p>\n\
<div class=\'codeBlock\'><pre>on spn_FaceAreaThresholdMax changed val do\n\
(\n\
FaceAreaChecker.FaceAreaThresholdMax = val\n\
updateDisplay()\n\
)   \n\
</pre></div><p>We do the same with the max. threshold spinner.</p>\n\
<div class=\'codeBlock\'><pre>)--end rollout \n\
\n\
createDialog faceAreaDialog\n\
</pre></div><p>At this point, we can create a dialog from the rollout. The size of the dialog will be set automatically based on the size of the controls in the rollout.</p>\n\
<div class=\'codeBlock\'><pre>setDialogPos faceAreaDialog mouse.screenpos\n\
</pre></div><p>Then we reposition the dialog to the mouse position, so when the user clicks the &quot;Click Here To Configure&quot; button in the viewport, the dialog will appear next to the mouse pointer.</p>\n\
<div class=\'codeBlock\'><pre>FaceAreaChecker.faceAreaDialog = faceAreaDialog\n\
</pre></div><p>Finally, we store the rollout definition in the property of the struct instance. This way, the attempt to close the dialog before the rollout definition will access the correct value.</p>\n\
<div class=\'codeBlock\'><pre>) )--end struct\n\
\n\
try (destroyDialog FaceAreaChecker.faceAreaDialog)catch()\n\
</pre></div><p>This attempt to close the dialog is useful when developing the script and re-evaluating the source again and again - each time the script is run, a previous open dialog will be closed. Otherwise, orphaned dialogs could accumulate during testing.</p>\n\
<div class=\'codeBlock\'><pre>FaceAreaChecker = FaceAreaCheckerStruct()\n\
</pre></div><p>Here we create the instance of the local struct and assign to the global variable. This way, any other script or the Listener can access the properties and functions inside the struct instance, which simplifies both development and debugging.</p>\n\
<div class=\'codeBlock\'><pre>XViewChecker.unRegisterChecker &quot;Face Area Checker&quot;\n\
</pre></div><p>We unregister the XView Checker by name. If the same code is run multiple times, we ensure the previous version is removed before registering it again.</p>\n\
<div class=\'codeBlock\'><pre>XViewChecker.registerChecker FaceAreaChecker.geomCheck FaceAreaChecker.supportedCheck #Faces &quot;Face Area Checker&quot; FaceAreaChecker.configDlg undefined undefined\n\
</pre></div><p>Finally, we register our Checker with the xViewChecker system.</p>\n\
<p>The first argument is the function to call to check scene objects.</p>\n\
<p>The second argument is the function to call to determine if a scene object can be checked.</p>\n\
<p>The third argument defines the type of the checker - whether it operates on Faces, Edges or Vertices. This is necessary for the Selection conversion to interpret the content of the results array as the right type of Sub-Object indices.</p>\n\
<p>The fourth argument is the name of the checker. It is used both to display the checker in the list and the viewport and to access the checker by name when unregistering it.</p>\n\
<p>The fifth argument is the function to call when the &quot;Click Here To Configure&quot; button is clicked. It can be passed as undefined if no dialog is necessary.</p>\n\
<p>The sixth argument is the function to call to override the text in the viewport next to the Checker&#39;s name. We pass undefined since we don&#39;t want a text override at this point. We will implement such a function in the next part of the tutorial.</p>\n\
<p>The last argument is the function to call to override the default display functionality. We pass again undefined because we want to use the default display feature at this point. We will implement such a function in the next part of the tutorial.</p>\n\
<div class=\'codeBlock\'><pre>)--end script\n\
</pre></div><div class=\'section\'><a id=\"using-the-xview-checker\"></a><h2 id=\"using-the-xview-checker\">Using the xView Checker</h2></div>\n\
<p>At this point, we can evaluate the code by pressing <strong>Ctrl+E</strong> and use the xView checker, but it will not be visible in the Viewport Menus yet.</p>\n\
<p>To see the new checker, enable any other xView checker like for example <strong>Face Orientation</strong>, then click on the [Face Orientation] label at the bottom of the viewport to display the list of registered checkers. The <strong>Face Area Checker</strong> should appear there.</p>\n\
<p>Select it from the list to enable it.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-6149F943-BBB7-4D34-9BF2-8CE841F2F2B0-low.gif\' title=\'\'></div>\n\
<p>The label <strong>[ Face Area Checker ]</strong> will be displayed at the bottom of the screen and if a valid object (Editable Mesh or Editable Poly) is selected, the faces/polygons will be tested and shaded in the viewport.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-0CB1EB81-A26C-4625-8702-A628E4BF8B71-low.gif\' title=\'\'></div>\n\
<p>To configure the Min. and Max. Thresholds, click on the <strong>[ Click Here To Configure ]</strong> label.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-5D751E6C-E60B-4490-B68D-8AB67F2536A2-low.gif\' title=\'\'></div>\n\
<p>To make the checker available in future <strong>3ds Max</strong> sessions without the need to evaluate the script manually, copy the script to the \\Startup folder or any folder registered as a plugin path OR its sub-folders.</p>\n\
<p>We will take a look at how to add a custom xView Checker to the Viewport Menus in <a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-an-XView-Geometry/How-To-Develop-A-Face-Area-XView-3.html\' title=\'\'>Part 4 of this tutorial</a>.</p>\n\
<p><strong>Next</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Develop-an-XView-Geometry/How-To-Develop-A-Face-Area-XView-1.html\' title=\'\'>How To ... Develop A Face Area XView Checker - Part 2</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";