var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Draw a Freehand Spline</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Draw a Freehand Spline</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-draw-a-freehand-spline\"></a></div>\n\
<p><strong>3ds Max</strong> does not provide a built-in function for drawing splines freely with the mouse. Surprisingly enough, the old Autodesk 3D Studio DOS had such a feature.</p>\n\
<p>Using the power of MAXScript, we can implement this feature as a simple MacroScript. It will let us draw a spline in the ground plane using the mouse.</p>\n\
<p><strong>Related Topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Defining MacroScripts</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/SplineShape-Shape.html\' title=\'\'>SplineShape : Shape</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Subclasses/Shape-Node/Shapes-Splines/Spline-Shape-Common-Properties.html\' title=\'\'>Spline Shape Common Properties, Operators, and Methods</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Viewports/Picking-Points-in-the-Viewports.html\' title=\'\'>Picking Points in the Viewports</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/MAXScript-Message-and-Query/MAXScript-Message-and-Query-1.html\' title=\'\'>MAXScript Message and Query Dialogs</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Package the code as macroScript to be able to use as a button, menu item or shortcut.</p>\n\
<p>Define a function to measure the distance between the last and current mouse position and add a new knot to the spline when a threshold is exceeded.</p>\n\
<p>Define a drawing function to capture the mouse movement using the built-in pickPoint function.</p>\n\
<p>Put the complete creation code in an undo context to be able to undo the drawing.</p>\n\
<p>Create a new splineShape object.</p>\n\
<p>Let the user click in the viewport to define the start of the spline.</p>\n\
<p>If the user right-clicked, cancel the operation</p>\n\
<p>If the user left-clicked, add a knot to the spline and call the draw function.</p>\n\
<p>As long as the user moves the mouse, the pickPoint callback will keep on measuring the segment lengths and adding new knots when needed.</p>\n\
<p>If the user clicked again, ask about closing the spline.</p>\n\
<p>If answer is yes, close the spline, select it and exit the script</p>\n\
<p>If answer is no, just select the spline and exit the script.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>MAXSCRIPT</strong></p>\n\
<p>``` macroscript FreeSpline category:&quot;HowTo&quot; tooltip:&quot;FreeSpline&quot; ( local old_pos local new_spline local second_knot_set</p>\n\
<p>fn get_mouse_pos pen_pos old_pen_pos = ( if old_pos == undefined then old_pos = old_pen_pos if distance pen_pos old_pos &gt; 10 then ( if second_knot_set then addKnot new_spline 1 #smooth #curve pen_pos else ( setKnotPoint new_spline 1 2 pen_pos second_knot_set = true ) old_pos = pen_pos updateShape new_spline )-- end if )-- end fn fn draw_new_line old_pen_pos = ( pickPoint mouseMoveCallback:#(get_mouse_pos,old_pen_pos) )</p>\n\
<p>undo&quot;Free Spline&quot;on ( new_spline = splineShape () old_pen_pos = pickPoint () if old_pen_pos == #RightClick then ( delete new_spline ) else ( select new_spline new_spline.pos = old_pen_pos addNewSpline new_spline addKnot new_spline 1 #smooth #curve old_pen_pos addKnot new_spline 1 #smooth #curve old_pen_pos second_knot_set = false draw_new_line old_pen_pos q = querybox &quot;Close Spline?&quot; title:&quot;Free Spline&quot; if q then ( close new_spline 1 updateshape new_spline ) select new_spline )--end else )--end undo )--end script</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h3 id=\"step-by-step\">Step-By-Step</h3></div>\n\
<div class=\'codeBlock\'><pre>macroscript FreeSpline category:&quot;HowTo&quot; tooltip:&quot;FreeSpline&quot;\n\
(\n\
</pre></div><p>The macroScript will be called <span class=\'code\'>FreeSpline</span> . To use the script, you can go to Customize... and drag the script from the category &quot;HowTo&quot; to a toolbar, a menu, a quad menu or assign to a keyboard shortcut.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Defining Macro Scripts</a></p>\n\
<div class=\'codeBlock\'><pre>local old_pos\n\
local new_spline\n\
local second_knot_set\n\
</pre></div><p>We will need some local variables to store the last knot position and the new object created by the script. The third variable will be used as a flag to tell us whether we just started creation of the spline.</p>\n\
<p>These variables will exist only inside the macroScript’s context as we declare them as local.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Scope-of-Variables.html\' title=\'\'>Scope of Variables</a></p>\n\
<div class=\'codeBlock\'><pre>fn get_mouse_pos pen_pos old_pen_pos =\n\
(\n\
</pre></div><p>We create our own function to handle the drawing of new knots in the splineShape. This function receives two parameters – the current position of the mouse, and the result of the first click captured by the pickPoint function (see below).</p>\n\
<p><a href=\'#!/url=./developer/Learning-MAXScript/Creating-Your-Own-Scripts/Defining-Custom-Functions.html\' title=\'\'>Defining Custom Functions</a></p>\n\
<div class=\'codeBlock\'><pre>if old_pos == undefined then old_pos = old_pen_pos\n\
</pre></div><p>If we don’t know of an existing Knot (creation just started!), we set the value of the old_pos local variable to the first clicked point provided by the old_pen_pos parameter.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/If-Expression.html\' title=\'\'>If Expression</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Special-Data-Values/Undefined-Value.html\' title=\'\'>Undefined Value</a></p>\n\
<div class=\'codeBlock\'><pre>if distance pen_pos old_pos &gt; 10 then\n\
(\n\
</pre></div><p>Next we check the distance between the last known knot’s position and the current mouse position. If the distance is longer than 10 units...</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/If-Expression.html\' title=\'\'>If Expression</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/Point3-Values.html\' title=\'\'>Distance_Point3</a></p>\n\
<div class=\'codeBlock\'><pre>if second_knot_set then\n\
</pre></div><p>The flag variable we defined will contrain either true or false. When the variable contains false, spline creation has just started. Because a spline must have at least two knots (vertices), we will create the first knot twice and then set this flag to false. When the next knot position is to be set, instead of creating a new one, we will reposition the existing second knot to the new coordinates and then set the flag to true.</p>\n\
<p>When the flag is set to true, we will just create the next new knot - see next line...</p>\n\
<div class=\'codeBlock\'><pre>addKnot new_spline 1 #smooth #curve pen_pos\n\
</pre></div><p>...we go on and place a new knot, thus adding a new segment to the spline shape. The addKnot function requires a splineShape object, the index of the spline (we have just 1), the type of the knot (we use #smooth in our case), and the position to put the knot at.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/SplineShape-Shape.html\' title=\'\'>SplineShape : Shape</a></p>\n\
<div class=\'codeBlock\'><pre>else\n\
(\n\
setKnotPoint new_spline 1 2 pen_pos\n\
</pre></div><p>When the flag is set to false, we have to move the existing second knot instead of creating a new one...</p>\n\
<div class=\'codeBlock\'><pre>second_knot_set = true\n\
</pre></div><p>Then we set the flag to true. Next time, a new knot will be created instead...</p>\n\
<div class=\'codeBlock\'><pre>)\n\
old_pos = pen_pos\n\
</pre></div><p>Then we remember the new knot’s position to use by the next mouse movement check.</p>\n\
<div class=\'codeBlock\'><pre>updateShape new_spline\n\
</pre></div><p>To see the changes made to the spline, we update the splineShape object.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/SplineShape-Shape.html\' title=\'\'>SplineShape : Shape</a></p>\n\
<div class=\'codeBlock\'><pre>) -- end if\n\
) -- end fn\n\
fn draw_new_line old_pen_pos =\n\
(\n\
</pre></div><p>We create another function to handle the capturing of the mouse motion.</p>\n\
<p><a href=\'#!/url=./developer/Learning-MAXScript/Creating-Your-Own-Scripts/Defining-Custom-Functions.html\' title=\'\'>Defining Custom Functions</a></p>\n\
<div class=\'codeBlock\'><pre>pickPoint mouseMoveCallback:#(get_mouse_pos,old_pen_pos)\n\
</pre></div><p>Our function calls only the built-in pickPoint function which provides an optional callback which calls the function we just defined (get_mouse_point) and passes the current mouse position and any user parameters supplied (in our case, old_pen_pos).</p>\n\
<p>As long as the mouse is moving and no clicks are encountered, the pickPoint’s mouseMoveCallback will constantly call our function and thus create new knots at distance of 10 units...</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Viewports/Picking-Points-in-the-Viewports.html\' title=\'\'>Picking Points in the Viewports</a></p>\n\
<div class=\'codeBlock\'><pre>)\n\
undo &quot;Free Spline&quot; on\n\
(\n\
</pre></div><p>We will put the complete code in an undo context to be able to undo the whole drawing result.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/undo.html\' title=\'\'>undo</a></p>\n\
<div class=\'codeBlock\'><pre>new_spline = splineShape ()\n\
</pre></div><p>When starting the script, we first construct an empty splineShape object.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/SplineShape-Shape.html\' title=\'\'>SplineShape : Shape</a></p>\n\
<div class=\'codeBlock\'><pre>old_pen_pos = pickpoint ()\n\
</pre></div><p>Then we go into pickPoint mode (but this time without a mouse callback). The function will wait for a click in the viewport and return the position of the picked point, or #RightClick if the Right Mouse Button has been pressed.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Viewports/Picking-Points-in-the-Viewports.html\' title=\'\'>Picking Points in the Viewports</a></p>\n\
<div class=\'codeBlock\'><pre>if old_pen_pos == #RightClick then\n\
(\n\
delete new_spline\n\
)\n\
</pre></div><p>If the Right Mouse Button has been actually pressed, we just delete the newly created splineShape and finish the script.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/If-Expression.html\' title=\'\'>If Expression</a></p>\n\
<div class=\'codeBlock\'><pre>else\n\
(\n\
select new_spline\n\
</pre></div><p>If the pickButton has returned a position value and not #RightClick, we can select the splineShape...</p>\n\
<div class=\'codeBlock\'><pre>new_spline.pos = old_pen_pos\n\
</pre></div><p>Set the position of the splineShape to the clicked point...</p>\n\
<div class=\'codeBlock\'><pre>addNewSpline new_spline\n\
</pre></div><p>...add a new spline to the empty splineShape...</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/SplineShape-Shape.html\' title=\'\'>SplineShape : Shape</a></p>\n\
<div class=\'codeBlock\'><pre>addKnot new_spline 1 #smooth #curve old_pen_pos\n\
addKnot new_spline 1 #smooth #curve old_pen_pos\n\
</pre></div><p>...and add two new knots to the newly create spline in the splineShape. As mentioned above, a spline should have at least two knots, so we create the first two with the same position and will then move the second knot instead of creating a new one.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/SplineShape-Shape.html\' title=\'\'>SplineShape : Shape</a></p>\n\
<div class=\'codeBlock\'><pre>second_knot_set = false\n\
</pre></div><p>We &quot;lower the flag&quot; by setting it to false. This way, the script will know that we just created the first two knots and the second one has to be set to the next mouse position captured by the script. When this is done in the <span class=\'code\'>get_mouse_pos</span> function, we will &quot;raise the flag&quot; again by setting it to true and thus know that the initial spline creation steps are over...</p>\n\
<div class=\'codeBlock\'><pre>draw_new_line old_pen_pos\n\
</pre></div><p>Now we can call our <span class=\'code\'>draw_new_line</span> function and pass the first clicked point as parameter. That function will start monitoring the mouse movements until a new click occurs.</p>\n\
<p><a href=\'#!/url=./developer/Learning-MAXScript/Creating-Your-Own-Scripts/Defining-Custom-Functions.html\' title=\'\'>Defining Custom Functions</a></p>\n\
<div class=\'codeBlock\'><pre>q = querybox &quot;Close Spline?&quot; title:&quot;Free Spline&quot;\n\
</pre></div><p>If a new click has been captured by the <span class=\'code\'>pickPoint</span> function, the <span class=\'code\'>draw_new_line</span> function will return to this point. Now we can ask the user whether he wants to close the newly drawn spline.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/MAXScript-Message-and-Query/MAXScript-Message-and-Query-1.html\' title=\'\'>MAXScript Message and Query Dialogs</a></p>\n\
<div class=\'codeBlock\'><pre>if q then\n\
(\n\
close new_spline 1\n\
updateshape new_spline\n\
</pre></div><p>If the answer to the query is Yes, we close the first and only spline in the splineShape and update the internal data structures to reflect the changes.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/If-Expression.html\' title=\'\'>If Expression</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/SplineShape-Shape.html\' title=\'\'>SplineShape : Shape</a></p>\n\
<div class=\'codeBlock\'><pre>) \n\
select new_spline\n\
</pre></div><p>Finally, we select the newly-created splineShape in the scene before exiting.</p>\n\
<div class=\'codeBlock\'><pre>)--end else\n\
)--end undo\n\
)--end script\n\
</pre></div><div class=\'section\'><a id=\"using-the-script\"></a><h3 id=\"using-the-script\">Using the Script</h3></div>\n\
<p>Evaluate the script. To use it, you can use Customize... to drag the script from the category &quot;HowTo&quot; to a toolbar, a menu, a quad menu or to assign to a keyboard shortcut.</p>\n\
<p>Execute the FreeSpline script and left-click in the top or perspective viewport. Drag the mouse freely to draw a spline. Left-click again to finish drawing. Answer the prompt with Yes to close or No to leave the spline open.</p>\n\
<div class=\'section\'><a id=\"where-to-go-from-here\"></a><h3 id=\"where-to-go-from-here\">Where to go from here</h3></div>\n\
<p>This is just some basic code. You could try to add a UI with controls for segment length threshold, spline segment and knot types (linear, smooth, bezier etc.)</p>\n\
<p><strong>Back to</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Introduction-to-the.html\' title=\'\'>&quot;How To&quot; Tutorials Index Page</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";