var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Flatten a SplineShape</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Flatten a SplineShape</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-flatten-a-splineshape\"></a></div>\n\
<p>The following tutorial shows how to access and modify the splines and their knots (vertices) and tangents in a SplineShape. The resulting macroScript will move all knots to the Z height defined by the shape’s Z position, thus aligning them to a plane parallel to the ground XY world construction plane.</p>\n\
<p><strong>Related Topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Defining MacroScripts</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/SplineShape-Shape.html\' title=\'\'>SplineShape : Shape</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Subclasses/Shape-Node/Shapes-Splines/Spline-Shape-Common-Properties.html\' title=\'\'>Spline Shape Common Properties, Operators, and Methods</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Package the code as macroScript to be able to use as a button, menu item or shortcut.</p>\n\
<p>Enable the script only when a single Editable Spline without modifiers has been selected.</p>\n\
<p>When executed, go through all splines in the shape</p>\n\
<p>For each spline, go through all knots (vertices)</p>\n\
<p>For each knot, set the Z coordinate of the In and Out tangent to the shape’s Z position</p>\n\
<p>For each knot, set knot’s Z coordinate to the shape’s Z position</p>\n\
<p>When ready with all splines and knots, update the shape.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>MAXSCRIPT</strong></p>\n\
<p>``` macroscript FlattenSpline category:&quot;HowTo&quot; tooltip:&quot;Flatten Spline&quot; ( on isEnabled return ( selection.count == 1 and<br> (classof selection[1] == SplineShape or<br> classof selection[1] == Line)<br> and selection[1].modifiers.count == 0 ) on execute do ( new_z = $.pos.z for s = 1 to (numSplines $) do ( for k = 1 to (numKnots $ s) do ( knt = getKnotPoint $ s k in_vec = getInVec $ s k out_vec = getOutVec $ s k knt.z = in_vec.z = out_vec.z = new_z setInVec $ s k in_vec setOutVec $ s k out_vec setKnotPoint $ s k knt )--end k loop )--end s loop updateshape $ )--end execute )--end script</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>macroscript FlattenSpline category:&quot;HowTo&quot; tooltip:&quot;Flatten Spline&quot; (\n\
</pre></div><p>The macroScript will be called <span class=\'code\'>FlattenSpline</span> . To use the script, you can go to Customize... and drag the script from the category &quot;HowTo&quot; to a toolbar, a menu, a quad menu or assign to a keyboard shortcut.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Defining Macro Scripts</a></p>\n\
<div class=\'codeBlock\'><pre>on isEnabled return\n\
(\n\
selection.count == 1 and \\\n\
(classof selection[1] == SplineShape or \\\n\
classof selection[1] == Line) \\\n\
and selection[1].modifiers.count == 0\n\
)\n\
</pre></div><p>The macroScript ActionItem (button, menu item, shortcut) will only be enabled when the scene selection contains a single object AND this one object is either a SplineShape class (in other words an EditableSpline) without any modifiers as MAXScript cannot modify a spline with modifiers on top. The result of the expression after the return statement evaluates to true or false. When true, the script becomes enabled.</p>\n\
<p>In these lines we compare the count of the current scene selection with 1, then the class of the first selected object to the class SplineShape. Then once again we compare the class of the first selected object with the class Line as a newly drawn line would be an exception – we can modify it, but the class is not SplineShape until collapsed to EditableSpline. Lastly, we check the number of modifiers and compare to 0.</p>\n\
<p>If the first AND either the second OR the third, AND the fourth condition are true, the selected object is valid and can be modified by the script!</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Macroscript_Body_Event_Handlers</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/Node-Common-Methods.html\' title=\'\'>ClassOf</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/ModifierArray-Values.html\' title=\'\'>ModifierArray Values</a></p>\n\
<div class=\'codeBlock\'><pre>on execute do\n\
(\n\
</pre></div><p>The <span class=\'code\'>on execute</span> handler contains the actual code. It will be executed whenever the script is started by clicking the button, selecting the item from a menu, using the keyboard shortcut etc.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Macroscript_Body_Event_Handlers</a></p>\n\
<div class=\'codeBlock\'><pre>new_z = $.pos.z\n\
</pre></div><p>We will need the Z coordinate of the splineShape in order to move all Knots and Tangents to that position. We store the Z component of the position of the scene selection in the user variable new_z. Because we already checked in the isEnabled handler that there is only one object selected, we don’t need to use selected[1] to access the first selected object – we are completely sure the $ representing the current selection is actually a single object!</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/Node-Transform-Properties.html\' title=\'\'>Node Transform Properties</a></p>\n\
<div class=\'codeBlock\'><pre>for s = 1 to (numSplines $) do\n\
(\n\
</pre></div><p>A splineShape can contain any number of splines (a Donut shape for example contains two circles!). To change every single spline, we will create a for loop which counts from 1 to the number of splines in the selected object.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/For-Loop.html\' title=\'\'>For Loop</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/SplineShape-Shape.html\' title=\'\'>SplineShape : Shape</a></p>\n\
<div class=\'codeBlock\'><pre>for k = 1 to (numKnots $ s) do\n\
(\n\
</pre></div><p>Each spline in the shape can contain any number of knots. To change every single knot, we will create another for loop which counts from 1 to the number of knots in the s-th spline – the index of the spline is controlled by the outer for loop. Note that the for k... loop will be executed again and again for each repetition of the for s loop. So these are nested loops!</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/For-Loop.html\' title=\'\'>For Loop</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/SplineShape-Shape.html\' title=\'\'>SplineShape : Shape</a></p>\n\
<div class=\'codeBlock\'><pre>knt = getKnotPoint $ s k\n\
</pre></div><p>Using getKnotPoint, we read the K-th knot in the S-th spline in the selected splineShape. We store its Point3 world coordinates in the user variable knt.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/SplineShape-Shape.html\' title=\'\'>SplineShape : Shape</a></p>\n\
<div class=\'codeBlock\'><pre>in_vec = getInVec $ s k\n\
</pre></div><p>Then we read the in vector of the K-th knot in the S-th spline in the selected splineShape. We store its Point3 world coordinates in the user variable in_vec.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/SplineShape-Shape.html\' title=\'\'>SplineShape : Shape</a></p>\n\
<div class=\'codeBlock\'><pre>out_vec = getOutVec $ s k\n\
</pre></div><p>We read the out vector of the K-th knot in the S-th spline in the selected splineShape. We store its Point3 world coordinates in the user variable out_vec.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/SplineShape-Shape.html\' title=\'\'>SplineShape : Shape</a></p>\n\
<div class=\'codeBlock\'><pre>knt.z = in_vec.z = out_vec.z = new_z\n\
</pre></div><p>Now we can set the Z coordinate of both vectors and the knot to the new value stored in the new_z variable. Note we can assign the same value to multiple variables as MAXScript processes the expression by evaluating the right-hand side of the assignment first then assigning the result to the left-hand side and so on.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Variable-Assignment.html\' title=\'\'>Variable Assignment</a></p>\n\
<div class=\'codeBlock\'><pre>setInVec $ s k in_vec\n\
setOutVec $ s k out_vec\n\
</pre></div><p>Now we can assign the new in and out vectors back to the respective knot and spline.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/SplineShape-Shape.html\' title=\'\'>SplineShape : Shape</a></p>\n\
<div class=\'codeBlock\'><pre>setKnotPoint $ s k knt\n\
</pre></div><p>Then we assign the new knot position back to the respective knot and spline.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/SplineShape-Shape.html\' title=\'\'>SplineShape : Shape</a></p>\n\
<div class=\'codeBlock\'><pre>)--end k loop\n\
)--end s loop\n\
updateshape $\n\
)--end execute\n\
</pre></div><p>Finally, it is very important to update the splineShape. This makes all changes visible by updating the internal data structures. Failing to do so could cause instabilities in <strong>3ds Max</strong>.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/SplineShape/SplineShape-Shape.html\' title=\'\'>SplineShape : Shape</a></p>\n\
<div class=\'codeBlock\'><pre>)--end script\n\
</pre></div><div class=\'section\'><a id=\"using-the-script\"></a><h2 id=\"using-the-script\">Using the Script</h2></div>\n\
<p>Evaluate the script. To use it, you can use Customize... to drag the script from the category &quot;HowTo&quot; to a toolbar, a menu, a quad menu or to assign to a keyboard shortcut.</p>\n\
<p>Select a single spline in the scene and execute the script. All knots should move to become aligned to the XY plane in the height of the spline’s pivot.</p>\n\
<div class=\'section\'><a id=\"where-to-go-from-here\"></a><h2 id=\"where-to-go-from-here\">Where to go from here</h2></div>\n\
<p>You could add an UI with options to align to other construction planes or to move the knots to the ground plane (by just using 0.0 instead of new_Z)</p>\n\
<p><strong>Back to</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Introduction-to-the.html\' title=\'\'>&quot;How To&quot; Tutorials Index Page</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";