var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Move Objects to a Surface</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Move Objects to a Surface</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-move-objects-to-a-surface\"></a></div>\n\
<p>You can move objects along their Z axis to fit a specified surface using the following. You can use this script to automatically plant trees, poles, and others on the ground.</p>\n\
<p><strong>Related Topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Defining MacroScripts</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/Node-Common-Methods/Node-Utility-Methods.html\' title=\'\'>IntersectRay</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Package the code as macroScript to be able to use as a button, menu item, or shortcut.</p>\n\
<p>Define a custom function for moving objects to a surface down the Z axis.</p>\n\
<p>Find the intersection along -Z starting from the position of the object to be moved to the target object.</p>\n\
<p>If no intersection can be found, project the position of the object up the Z and intersect again down the –Z axis.</p>\n\
<p>Return the intersection as result of the function.</p>\n\
<p>Enable the macroScript only when objects are selected.</p>\n\
<p>When the macroScript is executed, let the user pick a target object.</p>\n\
<p>Filter the pick to allow only Geometry objects to be picked.</p>\n\
<p>In case a valid object has been picked, enable an undo context.</p>\n\
<p>Go through all objects and call the intersection function for each one.</p>\n\
<p>As long as the intersection is not undefined, move the object to the intersection.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>MAXSCRIPT</strong></p>\n\
<p>``` macroscript MoveToSurface category: &quot;HowTo&quot; ( fn g_filter o = superclassof o == Geometryclass fn find_intersection z_node node_to_z = ( local testRay = ray node_to_z.pos [0,0,-1] local nodeMaxZ = z_node.max.z testRay.pos.z = nodeMaxZ + 0.0001 * abs nodeMaxZ intersectRay z_node testRay ) on isEnabled return selection.count &gt; 0 on Execute do ( target_mesh = pickObject message:&quot;Pick Target Surface:&quot; filter:g_filter if isValidNode target_mesh then ( undo &quot;MoveToSurface&quot; on ( for i in selection do ( int_point = find_intersection target_mesh i if int_point != undefined then i.pos = int_point.pos )--end i loop )--end undo )--end if )--end execute )--end script</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h3 id=\"step-by-step\">Step-By-Step</h3></div>\n\
<div class=\'codeBlock\'><pre>macroscript MoveToSurface category:&quot;HowTo&quot;\n\
(\n\
</pre></div><p>The macroScript will be called <span class=\'code\'>MoveToSurface</span> . To use the script, you can go to Customize and drag the script from the category &quot;HowTo&quot; to a toolbar, a menu, a quad menu, or assign to a keyboard shortcut.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Defining Macro Scripts</a></p>\n\
<div class=\'codeBlock\'><pre>fn g_filter o = superclassof o == Geometryclass\n\
</pre></div><p>This custom function will be used as filter for geometry objects. It will accept an object as parameter and will return true when the object is of Geometry Superclass and false otherwise.</p>\n\
<div class=\'codeBlock\'><pre>fn find_intersection z_node node_to_z =\n\
(\n\
</pre></div><p>This custom function will do the actual ray intersection. It will accept two parameters – the target object and the object to be moved to the target object’s surface.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Creating-Functions/Creating-Functions-1.html\' title=\'\'>Creating Functions</a></p>\n\
<div class=\'codeBlock\'><pre>local testRay = ray node_to_z.pos [0,0,-1]\n\
</pre></div><p>Here, we define a custom Ray value with a starting position at the position of the object to be moved and direction along the -Z axis.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/Ray-Values.html\' title=\'\'>Ray Values</a></p>\n\
<div class=\'codeBlock\'><pre>local nodeMaxZ = z_node.max.z\n\
</pre></div><p>We also get the max. Z coordinate of the surface to intersect with.</p>\n\
<div class=\'codeBlock\'><pre>testRay.pos.z = nodeMaxZ + 0.0001 * abs nodeMaxZ\n\
</pre></div><p>Then, we move the Z position of the ray slightly above the highest Z point of the surface to intersect with. This way we can be sure that the ray will have a chance to hit the surface along the -Z axis.</p>\n\
<div class=\'codeBlock\'><pre>intersectRay z_node test_ray\n\
</pre></div><p>This built-in intersectRay function is given a node and a ray (spatial vector with a start point and direction) and returns the point in space where the ray hits the surface of the node, or undefined if there is no intersection. The result of this intersection will be also the return value of the function as it is the last value calculated.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/Node-Common-Methods/Node-Utility-Methods.html\' title=\'\'>IntersectRay</a></p>\n\
<div class=\'codeBlock\'><pre>)\n\
on isEnabled return selection.count &gt; 0\n\
</pre></div><p>The script can only do meaningful job when at least one object is selected. If there are no selected objects in the scene, the script will be disabled. The &#39;on isEnabled&#39; handler controls the enabled state by evaluating the expression after the &#39;return&#39; statement. When the result is <span class=\'code\'>false</span> , the script’s button resp. Menu item is greyed out and cannot be activated.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Macroscript_Body_Event_Handlers</a></p>\n\
<div class=\'codeBlock\'><pre>on Execute do (\n\
</pre></div><p>The body of the script is contained in the &#39;on Execute&#39; handler. It is executed when the script is started by pressing its button, selecting its menu item or pressing assigned shortcut keys.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Macroscript_Body_Event_Handlers</a></p>\n\
<div class=\'codeBlock\'><pre>target_mesh = pickObject message:&quot;Pick Target Surface:&quot; filter:g_filter\n\
</pre></div><p>The pickObject function lets the user pick objects in the scene. The filter function we provided allows the picking of Geometry objects only – the mouse will not register any other objects like Lights, Helpers, and so on when moving over them. The result will be written to the user variable target_mesh. It can be either the picked node or undefined in case the picking has been canceled.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Picking-Scene-Nodes/Picking-Scene-Nodes-By-Hit.html\' title=\'\'>Picking Scene Nodes By Hit</a></p>\n\
<div class=\'codeBlock\'><pre>if isValidNode target_mesh then\n\
(\n\
</pre></div><p>If the picked object is a valid object (which means the user actually picked an object and did not press Escape or right-clicked the mouse to cancel),</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/If-Expression.html\' title=\'\'>If Expression</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/Node-Common-Methods.html\' title=\'\'>isValidNode</a></p>\n\
<div class=\'codeBlock\'><pre>undo &quot;MoveToSurface&quot; on\n\
(\n\
</pre></div><p>then we define an undo context to be able to reset all objects back to their original state if necessary,</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/undo.html\' title=\'\'>undo</a></p>\n\
<div class=\'codeBlock\'><pre>for i in selection do\n\
(\n\
</pre></div><p>and create a loop that will go through all objects in the current selection. In each iteration of the loop, the variable i will contain another object from the selection.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/For-Loop.html\' title=\'\'>For Loop</a></p>\n\
<div class=\'codeBlock\'><pre>int_point = find_intersection target_mesh i\n\
</pre></div><p>Here, we call the user function we defined and pass the target_mesh object picked by the user and the current objects from the loop through the selection. The result will be either undefined or the point of intersection – the projection of the object’s position onto the surface of the target object along –Z.</p>\n\
<div class=\'codeBlock\'><pre>if int_point != undefined then i.pos = int_point.pos\n\
</pre></div><p>If the intersection really exists, we simply set the position of the current object to that point. If it does not (the intersection is undefined), we skip this step.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/If-Expression.html\' title=\'\'>If Expression</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Special-Data-Values/Undefined-Value.html\' title=\'\'>Undefined Value</a></p>\n\
<div class=\'codeBlock\'><pre>)--end i loop\n\
)--end undo\n\
)--end if\n\
)--end execute\n\
)--end script\n\
</pre></div><div class=\'section\'><a id=\"using-the-script\"></a><h3 id=\"using-the-script\">Using the Script</h3></div>\n\
<p>Evaluate the script. To use it, you can use Customize to drag the script from the category &quot;HowTo&quot; to a toolbar, a menu, a quad menu, or to assign to a keyboard shortcut.</p>\n\
<p>Select any number of objects you wish to move to a surface. Start the script and pick the object to move to.</p>\n\
<div class=\'section\'><a id=\"where-to-go-from-here\"></a><h3 id=\"where-to-go-from-here\">Where to go from here</h3></div>\n\
<p>Using this script as the starting point, you can add axes controls to allow alignment in any world or local direction.</p>\n\
<p><strong>Back to</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Introduction-to-the.html\' title=\'\'>&quot;How To&quot; Tutorials Index Page</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";