var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Output Object Data To File</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Output Object Data To File</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-output-object-data-to-file\"></a></div>\n\
<p>MAXScript lets you create text files on disk and output custom data. The following example will create a macroScript that will output the speed of the current object selection on each frame and its average speed to a text file.</p>\n\
<p><strong>Related Topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Defining Macroscripts</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/External-Files-Access/Standard-Open-and-Save-File.html\' title=\'\'>Save File Dialog</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/StringStream-Values.html\' title=\'\'>Text Files Creation and Output</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Package the code as macroScript to be able to use as a button, menu item, or shortcut.</p>\n\
<p>Let the user specify an output filename to save the information.</p>\n\
<p>Write out the list of all selected objects as the file header.</p>\n\
<p>Go through all frames in the current animation segment, get the selection’s position on the current frame and the frame before, and calculate the units per frame speed.</p>\n\
<p>Write out the result for each frame.</p>\n\
<p>Collect all frame speed values and divide by the length of the animation segment to get the average speed.</p>\n\
<p>Write out the average speed result.</p>\n\
<p>Show the user the result by opening the file in an Editor.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>MAXSCRIPT</strong></p>\n\
<p>``` macroScript SpeedSheet category:&quot;HowTo&quot; ( if selection.count &gt; 0 then ( output_name = getSaveFileName caption:&quot;SpeedSheet File&quot; types:&quot;SpeedSheet (<em>.ssh)|</em>.ssh|All Files (<em>.</em>)|<em>.</em>|&quot; if output_name != undefined then ( output_file = createfile output_name at time animationrange.start format &quot;Object(s): %\\n&quot; (selection as array) to:output_file average_speed = 0 for t = animationrange.start to animationrange.end do ( at time t current_pos = selection.center at time(t-1f) last_pos = selection.center frame_speed = (distance current_pos last_pos)*FrameRate average_speed += frame_speed format &quot;Frame %: %\\n&quot; t frame_speed to:output_file ) average_speed /= (animationrange.end-animationrange.start) format &quot;Average Speed: %\\n&quot; average_speed to:output_file close output_file edit output_name )--end if )--end if )--end macroScript</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step:</h2></div>\n\
<div class=\'codeBlock\'><pre>MacroScript SpeedSheet category:&quot;HowTo&quot;\n\
(\n\
</pre></div><p>We create a new macroScript called SpeedSheet that will appear in the &quot;HowTo&quot; category.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Defining Macro Scripts</a></p>\n\
<div class=\'codeBlock\'><pre>if selection.count &gt; 0 then\n\
(\n\
</pre></div><p>The script will function only if there is at least one object selected. We check the number of objects in the current scene selection and execute the code only if the number is higher than 0.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/ObjectSet-Values.html\' title=\'\'>ObjectSet Values</a></p>\n\
<div class=\'codeBlock\'><pre>output_name = getSaveFileName caption:&quot;SpeedSheet File&quot; types:&quot;SpeedSheet (*.ssh)|*.ssh|All Files (*.*)|*.*|&quot;\n\
</pre></div><p>Then, we present the user with a standard windows File Saving dialog box. The dialog title bar will show the custom caption string &quot;SpeedSheet File&quot;. We specify the default file type as .SSH (SpeedSheet) file. If the user types in a file name, the extension specified in the dialog is being added automatically.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/External-Files-Access/Standard-Open-and-Save-File.html\' title=\'\'>Standard Open and Save File Dialogs</a></p>\n\
<div class=\'codeBlock\'><pre>if output_name != undefined then\n\
(\n\
</pre></div><p>If the user canceled the file selection in the Save File Name dialog, the output_name variable will contain undefined. In such a case, we will have to skip the whole output code. If the file name is valid, we can go on.</p>\n\
<div class=\'codeBlock\'><pre>output_file = createfile output_name\n\
</pre></div><p>Then, we create a new file for output using the specified file name. If the file already exists, it will be overwritten.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/FileStream-Values.html\' title=\'\'>FileStream Values</a></p>\n\
<div class=\'codeBlock\'><pre>at time animationrange.start format &quot;Object(s): %\\n&quot; (selection as array) to:output_file\n\
</pre></div><p>Right after creating the file, we write out the names of the selected objects. The <span class=\'code\'>at time</span> context ensures that position data of the objects is printed out for the first frame in the animation. The <span class=\'code\'>format</span> method uses a formatting string where variables are denoted with <strong>%</strong>. <span class=\'code\'>&quot;\\\\n&quot;</span> forces a new line.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/at-time.html\' title=\'\'>at time</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Reserved-Keywords-Symbols/3ds-Max-System-Globals.html\' title=\'\'>3ds MaxSystem Globals</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/FileStream-Values.html\' title=\'\'>FileStream Values</a></p>\n\
<div class=\'codeBlock\'><pre>average_speed = 0\n\
</pre></div><p>To calculate the average speed, we initialize a variable to store all speed values for all frames.</p>\n\
<div class=\'codeBlock\'><pre>for t = animationrange.start to animationrange.end do\n\
(\n\
</pre></div><p>Now, we go through all frames in the current animation segment. The variable <span class=\'code\'>t</span> will contain a frame value which will change from the first to the last frame of the scene animation range.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/For-Loop.html\' title=\'\'>For Loop</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Time-Control/Time-Configuration-Dialog.html\' title=\'\'>AnimationRange_Time_Configuration</a></p>\n\
<div class=\'codeBlock\'><pre>at time t current_pos = selection.center\n\
</pre></div><p>Using the current time from the <span class=\'code\'>for</span> loop variable <span class=\'code\'>t</span> , we read the position of the center of the object selection.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/at-time.html\' title=\'\'>at time</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/ObjectSet-Values.html\' title=\'\'>ObjectSet Values</a></p>\n\
<div class=\'codeBlock\'><pre>at time (t-1f) last_pos = selection.center\n\
</pre></div><p>Then, we read the position of the selection center one frame before the current frame.</p>\n\
<div class=\'codeBlock\'><pre>frame_speed = (distance current_pos last_pos)*FrameRate\n\
</pre></div><p>The frame speed on the current frame is equal to the distance traveled by the selection center since the last frame, multiplied by the frame number in a second. This gives us a speed in Generic Units per second.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/Point3-Values.html\' title=\'\'>Distance_Point3</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Time-Control/Time-Configuration-Dialog.html\' title=\'\'>Mid Topic ID: FrameRate_Time_Configuration</a></p>\n\
<div class=\'codeBlock\'><pre>average_speed += frame_speed\n\
</pre></div><p>The average speed variable collects all frame speed values. Note that the same can be expressed in the full form as <span class=\'code\'>average_speed = average_speed + frame_speed</span> .</p>\n\
<div class=\'codeBlock\'><pre>Format &quot;Frame %: %\\n&quot; t frame_speed to:output_file\n\
</pre></div><p>The frame speed is written together with the frame number to the output file.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/FileStream-Values.html\' title=\'\'>FileStream Values</a></p>\n\
<div class=\'codeBlock\'><pre>)\n\
average_speed /= (animationrange.end - animationrange.start)\n\
</pre></div><p>After the loop is over, the average speed can be calculated by dividing the sum of all frame speed values through the number of frames. The same can be written as <span class=\'code\'>average_speed = average_speed / (animationrange.end-animationrange.start)</span> .</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Time-Control/Time-Configuration-Dialog.html\' title=\'\'>AnimationRange_Time_Configuration</a></p>\n\
<div class=\'codeBlock\'><pre>format &quot;Average Speed: %\\n&quot; average_speed to:output_file\n\
</pre></div><p>The result is printed out to the output file.</p>\n\
<div class=\'codeBlock\'><pre>Close output_file\n\
</pre></div><p>The file is ready. We must close it before we can open it for reading.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/FileStream-Values.html\' title=\'\'>close_fileStream</a></p>\n\
<div class=\'codeBlock\'><pre>edit output_name\n\
</pre></div><p>Using the <span class=\'code\'>edit</span> method, we open the file in a MAXScript editor window.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Introduction/The-MAXScript-Editor/MAXScript-Legacy-Editor-Windows/The-MAXScript-Legacy-Editor.html\' title=\'\'>edit_MAXScript_Editor</a></p>\n\
<div class=\'codeBlock\'><pre>)--end if\n\
)--end if\n\
)--end macroScript\n\
</pre></div><div class=\'section\'><a id=\"using-the-script\"></a><h2 id=\"using-the-script\">Using the Script</h2></div>\n\
<p>Evaluate the script and customize a toolbar by dragging the SpeedSheet button from the &quot;HowTo&quot; category. You can create any number of objects and animate their position. While the objects are selected, press the SpeedSheet button, specify the name of the output file and the result appears in a second.</p>\n\
<div class=\'section\'><a id=\"where-to-go-from-here\"></a><h2 id=\"where-to-go-from-here\">Where to go from here</h2></div>\n\
<p>If you want to see the content of the text file in an external editor, for example in Windows Notepad, you can replace the line,</p>\n\
<div class=\'codeBlock\'><pre>edit output_name\n\
</pre></div><p>with the line,</p>\n\
<div class=\'codeBlock\'><pre>shellLaunch &quot;notepad.exe&quot; output_name\n\
</pre></div><p>which will launch the external application notepad.exe with the file name of the file as parameter.</p>\n\
<p>You might want to improve the script by calculating real-world units (inches, feet, meters, and so on) instead of generic units.</p>\n\
<p><strong>Back to</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Introduction-to-the.html\' title=\'\'>&quot;How To&quot; Tutorials Index Page</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";