var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Affect Particle Flow Particles by Mass</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Affect Particle Flow Particles by Mass</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-affect-particle-flow-particles-by-mass\"></a></div>\n\
<p>Particle Flow allows the user to control the influence of certain Force-related Operators using MAXScript-generated particle channels. This is called Particle Wiring and is a hidden option in the Particle Flow User Interface.</p>\n\
<p>The following tutorial shows how to calculate a mass value for each particle and control the influence of a Wind force to get a more realistic behavior where light particles are blown away while heavy ones stay almost unaffected.</p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE - SETUP</strong></p>\n\
<p>Generate Particles on a surface without any speed or rotation, just position.</p>\n\
<p>Add a Scale Operator to vary the size of the particles.</p>\n\
<p>Add a Script Operator which will read the size of the particles generated by the Scale Operator.</p>\n\
<p>Add a Force Operator.</p>\n\
<p>Create a Wind Space Warp, add to the Force Operator.</p>\n\
<p>Enable Script Wiring (see below).</p>\n\
<p>Edit the script of the Script Operator to calculate the influence value for the Force Operator.</p>\n\
<p><strong>NATURAL LANGUAGE - SCRIPT</strong></p>\n\
<p>Enable the Scale and Force channels.</p>\n\
<p>For each particle, get the Scale value (the size of the particle).</p>\n\
<p>Calculate the influence value.</p>\n\
<p>Assign to the Force channel.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>PARTICLE VIEW SETUP</strong> <strong>:</strong></p>\n\
<p>The Particle View setup features a Scale operator that defines variable sizes for the particles.</p>\n\
<p>To get the <strong>Script Wiring</strong>, you have to do the following:</p>\n\
<ul>\n\
<li><p><strong>A:</strong> Add a Script Operator <strong>before</strong> the Force Operator to generate the Particle Float channel values needed to control the Force Influence.</p></li>\n\
<li><p><strong>B:</strong> Right-click the Force Operator and check the &quot;Use Script Wiring&quot; option.</p></li>\n\
<li><p><strong>C:</strong> This enables a new additional rollout in the Force Operator that lets you enable the Influence Control through the Float channel.</p></li>\n\
</ul>\n\
</blockquote>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-EE212018-61C6-4731-986B-30396E5B34D9-low.gif\' title=\'\'></div>\n\
<blockquote>\n\
<p><strong>SCRIPT OPERATOR CODE:</strong></p>\n\
<p>``` on ChannelsUsed pCont do ( pCont.useScale = true pCont.useFloat = true ) on Init pCont do () on Proceed pCont do ( count = pCont.NumParticles() for i in 1 to count do ( pCont.particleIndex = i pCont.particleFloat = 1.0/(pCont.particleScale^3) ) ) on Release pCont do ( )</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
</blockquote>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-83FCC767-E850-4732-AFF3-638A1C61C571-low.gif\' title=\'\'></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-B0295D2A-F96A-4EEA-8681-C203413D075D-low.gif\' title=\'\'></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-7D36634C-7298-4327-95DF-5D09719EE2AB-low.gif\' title=\'\'></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-3DC70E05-4EB5-4D6A-82AC-1F12262B9B53-low.gif\' title=\'\'></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-C6551527-EDAB-4F9A-9A8A-B6B3EAC8E484-low.gif\' title=\'\'></div>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>on ChannelsUsed pCont do\n\
(\n\
</pre></div><p>The <span class=\'code\'>ChannelsUsed</span> handler defines the channels to be used by the Script Operator. You cannot get or set particle related values from the particle container without specifying which properties you need access to. This way, Particle Flow does not have to provide the Script Operator with all possible channels (and there can be an arbitrary number of channels in Particle Flow), but only with those that are actually needed. This conserves memory.</p>\n\
<p>The parameter pCont contains the Particle Container.</p>\n\
<div class=\'codeBlock\'><pre>pCont.useScale = true\n\
</pre></div><p>As we want to read the size of the particles to calculate the mass, we will need access to the Scale channel.</p>\n\
<div class=\'codeBlock\'><pre>pCont.useFloat = true\n\
</pre></div><p>We will also need the Float channel, which is an all-purpose data channel used to store floating point values.</p>\n\
<div class=\'codeBlock\'><pre> )\n\
\n\
on Init pCont do\n\
(\n\
</pre></div><p>The <strong>Init</strong> handler is used to initialize the Script Operator. Usually, you define variables and acquire initial values or create objects to be used by the <strong>Proceed</strong> handler. In our case, we will not use this handler. The parameter <strong>pCont</strong> contains the Particle Container.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
\n\
on Proceed pCont do\n\
(\n\
</pre></div><p>The <strong>Proceed</strong> handler is called every time the Script Operator is evaluated by Particle Flow. It contains the actual body of the script. The parameter <strong>pCont</strong> contains the Particle Container that contains all particles the Operator is applied to.</p>\n\
<div class=\'codeBlock\'><pre>count = pCont.NumParticles()\n\
</pre></div><p>Here, we read the current number of particles in the particle container. We will access every one of them in the following loop. The reason we assign the value to a variable is that in the for loop that follows, the to limit is evaluated after each cycle of the loop to decide whether the i variable is greater than the limit. Using the pCont.NumParticles() method call inside the for loop calls the method n times, where n is the number of particles. With the current code, the method will be called just once and this will make the script faster.</p>\n\
<div class=\'codeBlock\'><pre>for i in 1 to count do\n\
(\n\
</pre></div><p>Now, we repeat the following code block for every single particle by using a for loop that counts from 1 to the number of particles. The variable i will contain the current particle index.</p>\n\
<div class=\'codeBlock\'><pre>pCont.particleIndex = i\n\
</pre></div><p>To work with multiple particles, we have to specify the current particle to access. Setting the .particleIndex property of the Particle Container to the i variable will make the i-th particle the current one. Any subsequent particle property access calls will be directed to that particle.</p>\n\
<div class=\'codeBlock\'><pre>pCont.particleFloat = 1.0/(pCont.particleScale^3)\n\
</pre></div><p>This is the actual code line that calculates an influence value, which is reverse-proportional to the mass of the particle. The result is assigned to the particleFloat channel of the current particle and will be accessed by the Force Operator that has its Script Wiring enabled to accept the Float values from the particleFloat channel.</p>\n\
<blockquote>\n\
<p><strong>THIS LINE REQUIRES SOME MORE EXPLANATION:</strong></p>\n\
<p>In general, the mass of an object depends on its volume and its density. As we assume that all particles in this system are made of the same material, we do not need the density. We will use just the Bounding Sphere of the particles. The volume of a sphere can be calculated using the following expression:</p>\n\
<p>4/3*Pi*R^3</p>\n\
<p>Where, R is the radius of the sphere. As 4, 3, and Pi are constants, we do not need them. They just scale the final value a bit and make the calculation slower. What we have now is Radius to the power of 3. The influence must decrease as the volume (and mass) increases, so we divide 1.0 by R^3.</p>\n\
<p>This is not completely realistic. When using Wind, the influence of the Wind is also proportional on the cross-section of the blown object. The smaller the object, the lower the cross-section and thus lower the influence. As the cross-section of a sphere is a circle (Pi*R^2), we can reduce R<sup>3/R</sup>2 to just R (which is the particleScale in our case).</p>\n\
<p><strong>SO, WE CAN ACTUALLY USE THE LINE:</strong></p>\n\
<p><span class=\'code\'>pCont.particleFloat = 1.0/pCont.particleScale</span></p>\n\
<p>to be more realistic. Both functions provide a nice effect. You can use whatever suits your needs better.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>)\n\
)\n\
</pre></div><p>These are the end of the i loop and the end of the on Proceed... handler.</p>\n\
<div class=\'codeBlock\'><pre> on Release pCont do ( ) \n\
</pre></div><p>The Release handler is usually needed to do cleanup work, but we do not need it this time.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";