var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Transfer ParticleFlow Particle Motion To Scene Objects</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Transfer ParticleFlow Particle Motion To Scene Objects</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-transfer-particleflow-particle-motion-to-scene-objects\"></a></div>\n\
<p>This simple tutorial explains the basics of moving scene objects using Particle Flow. The objects can be anything from lights through helpers to mesh objects.</p>\n\
<p>In this example, we will move a large number of Atmospheric Gizmos with a Fire Effect assigned to simulate a steaming Teapot.</p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE - SETUP</strong></p>\n\
<p>Go to Create tab &gt; Helpers &gt; Atmospheric Apparatus &gt; Sphere Gizmo.</p>\n\
<p>Create a single object called SphereGizmo01 with any radius.</p>\n\
<p>Shift-Move the object and enter 29 to create 30 copies of the Sphere Gizmo (not Instances).</p>\n\
<p>Create a Particle Flow with Birth operator generating particles from start to end frame at the rate of 20.0.</p>\n\
<p>Use Speed operator to accelerate the particles up. Use some variation to get a more random look.</p>\n\
<p>Set the Display to Geometry.</p>\n\
<p>Add an AgeTest to kill the particles after 50 frames. Wire to a Delete operator in a separate event.</p>\n\
<p>Add a Force and some Wind if you want more motion.</p>\n\
<p>To get the scene working completely, assign a Fire Effect in the Environment dialog and assign ALL 30 SphereGizmos to it. Play with the color settings, density, and others to get the look you want.</p>\n\
<p>Create a Teapot and place the Particle Flow at the spout to get the steam coming out of the right place.</p>\n\
</blockquote>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-7EF7CE6D-741A-4FB2-A658-C665E80D2341-low.gif\' title=\'\'></div>\n\
<blockquote>\n\
<p><strong>SCRIPT OPERATOR CODE:</strong></p>\n\
<p>``` on ChannelsUsed pCont do ( pCont.useTM = true pCont.useAge = true )</p>\n\
<p>on Init pCont do ( global My_Atmospheric_Gizmos_01 = $SphereGizmo* My_Atmospheric_Gizmos_01.pos = [0,0,-100000] )</p>\n\
<p>on Proceed pCont do ( partcount = pCont.NumParticles() count = amin #(partcount, My_Atmospheric_Gizmos_01.count) for i in 1 to count do ( pCont.particleIndex = i My_Atmospheric_Gizmos_01[i].transform = pCont.ParticleTM My_Atmospheric_Gizmos_01[i].radius = 10 + pCont.ParticleAge*2 ) )</p>\n\
<p>on Release pCont do ( )</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
</blockquote>\n\
<p><img src=\'developer/images/GUID-81476EF5-B960-4367-A84A-BAD588E2F3A2-low.gif\' title=\'\'> <img src=\'developer/images/GUID-7DAA6E18-5717-42E0-9F7C-52112F3B4F15-low.gif\' title=\'\'></p>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>on ChannelsUsed pCont do\n\
(\n\
</pre></div><p>The <span class=\'code\'>ChannelsUsed</span> handler defines the channels to be used by the Script Operator. You cannot get or set particle related values from the particle container without specifying which properties you need access to. This way, Particle Flow does not have to provide the Script Operator with all possible channels (and there can be an arbitrary number of channels in Particle Flow), but only with those that are actually needed. This conserves memory.</p>\n\
<p>The parameter <strong>pCont</strong> contains the Particle Container.</p>\n\
<div class=\'codeBlock\'><pre>pCont.useTM = true\n\
</pre></div><p>We want to copy the complete transformation of the particle to the scene object, so we will need access to that channel.</p>\n\
<div class=\'codeBlock\'><pre>pCont.useAge = true\n\
</pre></div><p>To get an even nicer effect, we will want to read the age of the particle and assign it to the gizmos&#39; radius property to make them grow over time.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
\n\
on Init pCont do\n\
(\n\
</pre></div><p>The <strong>Init</strong> handler is used to initialize the Script Operator. The parameter <strong>pCont</strong> contains the Particle Container.</p>\n\
<div class=\'codeBlock\'><pre>global My_Atmospheric_Gizmos_01 = $SphereGizmo*\n\
</pre></div><p>We define a global variable that will contain an array of the scene objects to be driven by the particles. In this case, we collect all SphereGizmos from the scene using their common base name.</p>\n\
<div class=\'codeBlock\'><pre>My_Atmospheric_Gizmos_01.pos = [0,0,-100000]\n\
</pre></div><p>To remove the gizmos from the scene in the first frames of the animation, we move them away from the camera field of view, in this case way down.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
\n\
on Proceed pCont do\n\
(\n\
</pre></div><p>The Proceed handler is called each time the Script Operator is evaluated by Particle Flow. It contains the actual body of the script. The parameter <strong>pCont</strong> contains the Particle Container that contains all particles the Operator is applied to.</p>\n\
<div class=\'codeBlock\'><pre>partcount = pCont.NumParticles()\n\
</pre></div><p>First, we read the number of particles in the current Event. There can be zero or millions of particles in the event.</p>\n\
<div class=\'codeBlock\'><pre>count = amin #(partcount, My_Atmospheric_Gizmos_01.count)\n\
</pre></div><p>Then, we compare the number of particles to the number of collected gizmos. The function <strong><span class=\'code\'>amin()</span></strong> returns the smallest value in the array.</p>\n\
<blockquote>\n\
<p><strong>THE SAME CAN BE EXPRESSED AS</strong></p>\n\
<p>``` if partcount &lt; My_Atmospheric_Gizmos_01.count then count = partcount else count = My_Atmospheric_Gizmos_01.count</p>\n\
<p>```</p>\n\
<p>As you see, the first version is much shorter. Also, it works with more than two values if necessary, always picking the smallest value.</p>\n\
<p><strong>WHY DO WE NEED THIS?</strong></p>\n\
<p>Because we have a limited number of particles in the beginning of the animation, less than the number of gizmos. After a while, the number of particles will be higher than the available gizmos. In both cases, we want to build &quot;pairs&quot; of gizmo+particle, and some of the particles or gizmos might have no corresponding partner at certain parts of the animation. Knowing the lowest count of the two sets of objects gives us the number of possible pairs that we can process.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre> for i in 1 to count do\n\
(\n\
</pre></div><p>Now, we will repeat the following code as many times as there are possible particle+gizmo pairs in the scene.</p>\n\
<div class=\'codeBlock\'><pre>pCont.particleIndex = i\n\
</pre></div><p>To read data from a particle, we must make it the current one. To do so, we assign the index i to the particleIndex property of the particleContainer of the current event. After this, any particle-related queries or assignments will be performed on the i-th particle only.</p>\n\
<div class=\'codeBlock\'><pre>My_Atmospheric_Gizmos_01[i].transform = pCont.ParticleTM\n\
</pre></div><p>Now, we can assign the transformation matrix of the current i-th particle to the i-th gizmo in the array. Note that because of our smart amin test above, i is guaranteed smaller or equal to both the available particle and gizmo counts.</p>\n\
<div class=\'codeBlock\'><pre>My_Atmospheric_Gizmos_01[i].radius = 10 + pCont.ParticleAge*2\n\
</pre></div><p>Finally, we change the radius of the i-th gizmo to 10 units plus twice the age of the i-th particle. 10 is the minimum size of a gizmo (when particleAge is 0), at age of 10 the gizmo&#39;s radius will be 30 units or so. You can use different values to get different cloud behaviors.</p>\n\
<div class=\'codeBlock\'><pre>)\n\
)\n\
\n\
on Release pCont do ()\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";