var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>How To ... Select Non-Quad Polygons</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>How To ... Select Non-Quad Polygons</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"how-to-...-select-non-quad-polygons\"></a></div>\n\
<p>MAXScript lets you access Editable Poly object data and explore relationships between polygons, vertices and edges. When using polygon modeling it is usually desirable that all polygons are kept as quads. The following script will select all polygons that have less or more than 4 edges.</p>\n\
<p><strong>Related Topics:</strong></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Defining and Enabling Macroscripts</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Poly/Editable_Poly-GeometryClass.html\' title=\'\'>Accessing Editable Polygon Data</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Command-Panels/Modify-Panel.html\' title=\'\'>Accessing the Modify Panel</a></p>\n\
<blockquote>\n\
<p><strong>NATURAL LANGUAGE</strong></p>\n\
<p>Package the code as macroScript to be able to use as a button, menu item or shortcut.</p>\n\
<p>Enable only if a single object with an Editable Poly base object is selected.</p>\n\
<p>When executed, get the base object of the selected object.</p>\n\
<p>Go though all polygons of the base object and ask about their edges.</p>\n\
<p>Count the edges and if they are not exactly 4, remember the index of the polygon.</p>\n\
<p>Select all the non-quad polygons.</p>\n\
<p>Go to Polygon Sub-Object Level in the Modify Tab.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>MAXSCRIPT</strong></p>\n\
<p>``` macroscript SelectNonQuadPolys category: &quot;HowTo&quot; ( on isEnabled return ( selection.count == 1 and classOf selection[1].baseobject == Editable_Poly ) on execute do ( local face_selection = #{} local base_obj = $.baseobject local num_faces = polyop.getNumFaces base_obj for f = 1 to num_faces do ( local num_face_verts = polyop.getFaceDeg base_obj f if num_face_verts != 4 do face_selection[f] = true )--end f loop polyop.setFaceSelection base_obj face_selection max modify mode modPanel.setCurrentObject base_obj subobjectlevel = 4 )--end on execute )--end script</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"step-by-step\"></a><h2 id=\"step-by-step\">Step-By-Step</h2></div>\n\
<div class=\'codeBlock\'><pre>Macroscript SelectNonQuadPolys category:&quot;HowTo&quot;\n\
(\n\
</pre></div><p>The macroScript will be called <span class=\'code\'>SelectNonQuadPolys</span> . To use the script, you can use Customize... to drag the script from the category &quot;HowTo&quot; to a toolbar, a menu, a quad menu or to assign to a keyboard shortcut.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Defining Macro Scripts</a></p>\n\
<div class=\'codeBlock\'><pre>on isEnabled return\n\
(\n\
selection.count == 1 and classOf selection[1].baseobject == Editable_Poly\n\
)\n\
</pre></div><p>The <span class=\'code\'>isEnabled</span> handler should return <span class=\'code\'>true</span> or <span class=\'code\'>false</span> and determines the enabled state of the button / menu item. When <span class=\'code\'>true</span> , the button will be available. When <span class=\'code\'>false</span> , it will be grayed out. In the return expression, we check whether only one object is selected in the scene and whether its base object class is Editable Poly. The script will only work on objects that meet both conditions.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/General-Node-Properties.html\' title=\'\'>ClassOf</a></p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-Common-Properties-Operators/General-Node-Properties.html\' title=\'\'>General Node Properties</a></p>\n\
<div class=\'codeBlock\'><pre>on execute do (\n\
</pre></div><p>The <span class=\'code\'>on Execute</span> handler will be executed each time the macroScript is executed (by pressing the button, selecting from the menu, pressing the shortcut etc.). The handler contains the &quot;body&quot; of the script.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts.html\' title=\'\'>Macroscript_Body_Event_Handlers</a></p>\n\
<div class=\'codeBlock\'><pre>local face_selection = #{}\n\
</pre></div><p>We will need a user variable to store the polygons to be selected. We initialize the variable to an empty <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/BitArray-Values.html\' title=\'\'>BitArray</a></p>\n\
<div class=\'codeBlock\'><pre>local base_obj = $.baseobject\n\
</pre></div><p>Our script will work on the base object only. This means that the object may have modifiers on top of the base object – they will not be taken into account as polygon modeling usually happens at the base level anyway. Because we already made sure in the isEnabled handler that there is only a single object selected, we can access the selection using $ without worrying that it might contain multiple objects!</p>\n\
<div class=\'codeBlock\'><pre>local num_faces = polyop.getNumFaces base_obj\n\
</pre></div><p>We will need the number of faces in the object in order to iterate through them.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Poly/Editable_Poly-Methods.html\' title=\'\'>Editable_Poly Methods</a></p>\n\
<div class=\'codeBlock\'><pre>for f = 1 to num_faces do\n\
(\n\
</pre></div><p>We will loop through all polygons in the base object – f will contain the index of the current polygon to be checked.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/For-Loop.html\' title=\'\'>For Loop</a></p>\n\
<div class=\'codeBlock\'><pre>local num_face_verts = polyop.getFaceDeg base_obj f\n\
</pre></div><p>Next we get a the number of vertices in the current polygon.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Poly/Editable_Poly-Methods.html\' title=\'\'>Editable_Poly Methods</a></p>\n\
<div class=\'codeBlock\'><pre>if num_face_verts != 4 do face_selection[f] = true\n\
</pre></div><p>If the number of vertices is not 4, we should select the polygon so we set the respective bit in the bitArray corresponding to the current face to true.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/Array-Values.html\' title=\'\'>Array Values</a></p>\n\
<div class=\'codeBlock\'><pre>)--end f loop\n\
polyop.setFaceSelection base_obj face_selection\n\
</pre></div><p>After checking all polygons, we can simply select all collected polygons.</p>\n\
<p><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Poly/Editable_Poly-Methods.html\' title=\'\'>Editable_Poly Methods</a></p>\n\
<div class=\'codeBlock\'><pre>max modify mode\n\
</pre></div><p>In order to show the results of the selection to the user, we will first switch the command panel to modify mode...</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/3ds-MAX-Commands.html\' title=\'\'>MAX Commands</a></p>\n\
<div class=\'codeBlock\'><pre>modPanel.setCurrentObject base_obj\n\
</pre></div><p>...then set the current object in Stack View to the base object we checked...</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Command-Panels/Modify-Panel.html\' title=\'\'>Modify Panel</a></p>\n\
<div class=\'codeBlock\'><pre>subobjectlevel = 4\n\
</pre></div><p>...and finally switch to Polygon sub-object level to show the selected polygons.</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Command-Panels/Modify-Panel.html\' title=\'\'>subObjectLevel</a></p>\n\
<div class=\'codeBlock\'><pre>)--end on execute\n\
)--end script \n\
</pre></div><div class=\'section\'><a id=\"using-the-script\"></a><h2 id=\"using-the-script\">Using the Script</h2></div>\n\
<p>To use the script, you can use Customize... to drag the script from the category &quot;HowTo&quot; to a toolbar, a menu, a quad menu or to assign to a keyboard shortcut. Select a single object with an Editable Poly base object and the script will be enabled. Execute and the non-quad polygons will become selected.</p>\n\
<p><strong>Back to</strong></p>\n\
<p><a href=\'#!/url=./developer/How-To-Practical-Examples/How-To-Introduction-to-the.html\' title=\'\'>&quot;How To&quot; Tutorials Index Page</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";