var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Registry Structure</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Registry Structure</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"registry-structure\"></a></div>\n\
<p>The <strong>Registry struct</strong> provides methods to access the Windows registry keys.</p>\n\
<p>These methods are available in <strong>3ds Max 2008 and higher</strong>.</p>\n\
<p>They were previously available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<blockquote>\n\
<p>Warning: Editing the Windows Registry can destabilize your operating system. This task must be performed only by professionals who know what they are doing.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>registry.closeKey &lt;HKey&gt;   \n\
</pre></div><p>Closes the open HKey. Returns true if successful, false if an error occurs. Use <span class=\'code\'>registry.getLastError()</span> to get the error message.</p>\n\
<p>A HKey must not be used after it has been closed because it will no longer be valid.</p>\n\
<p>HKeys must not be left open any longer than necessary.</p>\n\
<p>The closeKey method does not necessarily write information to the registry before returning; it can take as much as several seconds for the cache to be flushed to the hard disk.</p>\n\
<p>If an application must explicitly write registry information to the hard disk, it can use <span class=\'code\'>registry.flushKey()</span> . However, this method uses many system resources and must be called only when necessary.</p>\n\
<div class=\'codeBlock\'><pre>registry.flushKey &lt;HKey&gt; \n\
</pre></div><p>Writes all the attributes of the open HKey into the registry. Returns true if successful, false if an error occurs. Use <span class=\'code\'>registry.getLastError()</span> to get the error message.</p>\n\
<p>It is <strong>not</strong> necessary to call <span class=\'code\'>registry.flushKey()</span> method to change a key. Registry changes are flushed to the disk by the registry using its lazy flusher. Lazy flushing occurs automatically and regularly after a system-specified interval of time. Registry changes are also flushed to disk at system shutdown. Unlike <span class=\'code\'>registry.closeKey()</span> , <span class=\'code\'>registry.flushKey()</span> returns only when all the data has been written to the registry. <span class=\'code\'>registry.flushKey()</span> might also write out parts or all of the other keys.</p>\n\
<p>Calling this function excessively can have a negative effect on an application&#39;s performance. An application must only call <span class=\'code\'>registry.flushKey()</span> if it requires absolute certainty that registry changes are on the disk.</p>\n\
<p>In general , <span class=\'code\'>registry.flushKey()</span> is rarely used.</p>\n\
<div class=\'codeBlock\'><pre>registry.deleteSubKey &lt;HKey&gt; &lt;string subKeyName&gt; recurse:&lt;boolean&gt; \n\
</pre></div><p>Deletes the specified subkey of the open HKey. The entire key, including all of its values is removed. Returns true if successful, false if an error occurs. Use <span class=\'code\'>registry.getLastError()</span> to get the error message.</p>\n\
<p>If recurse is false or not specified, the subkey to be deleted must not have subkeys. If recurse is true, the subkey and all its descendants are deleted.</p>\n\
<div class=\'codeBlock\'><pre>registry.deleteKey &lt;HKey&gt; recurse:&lt;boolean&gt; \n\
</pre></div><p>Deletes the HKey. The parent HKey of the specified HKey must be open. The entire key including all of its values is removed. Returns true if successful, false if an error occurs. Use <span class=\'code\'>registry.getLastError()</span> to get the error message.</p>\n\
<p>If recurse is false or not specified, the HKey to be deleted must not have subkeys. If recurse is true, the HKey and all its descendants are deleted.</p>\n\
<div class=\'codeBlock\'><pre>registry.createKey &lt;HKey&gt; &lt;string subKeyName&gt; accessRights:&lt;{#readOnly|#writeOnly|#all| &lt;int&gt;}&gt; newKeyCreated:&lt;&amp;boolean&gt;Key:&lt;&amp;HKey&gt;volatile:&lt;boolean&gt; \n\
</pre></div><p>Creates a new HKey as a subkey of the specified open HKey. If the subkey already exists, the function opens it.</p>\n\
<p>Returns true if successful, false if an error occurs. Use <span class=\'code\'>registry.getLastError()</span> to get the error message.</p>\n\
<p>See &quot;HKey Values&quot; for a description of the <span class=\'code\'>&lt;int&gt;</span> values for accessRights. The default accessRights is <span class=\'code\'>#all</span> .</p>\n\
<p>If a new key is created, a true value will be written to the <span class=\'code\'>newKeyCreated:</span> keyword variable.</p>\n\
<p>If a new key is created or an existing key is opened, the HKey value will be written to the <span class=\'code\'>Key:</span> keyword variable.</p>\n\
<p>If <span class=\'code\'>volatile:</span> is <span class=\'code\'>false</span> or not specified, the key information will be written to the registry file. If <span class=\'code\'>true</span> , the information is stored only in memory and is not preserved when the corresponding registry hive is unloaded.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` registry.createKey HKEY_CLASSES_ROOT &quot;.123&quot; accessRights:#all newKeyCreated:&amp;newKeyCreated key:&amp;key1</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>registry.openKey &lt;HKey&gt; &lt;string subKeyName&gt; accessRights:&lt;{#readOnly |#writeOnly|#all| &lt;int&gt;}&gt; key:&lt;&amp;HKey&gt; \n\
</pre></div><p>Opens an existing HKey.</p>\n\
<p>Returns <span class=\'code\'>true</span> if successful, <span class=\'code\'>false</span> if an error occurs. Use <span class=\'code\'>registry.getLastError()</span> to get the error message.</p>\n\
<p><span class=\'code\'>registry.openKey</span> does not create the specified key if the key does not exist in the registry.</p>\n\
<p>See &quot;HKey Values&quot; for a description of the <span class=\'code\'>&lt;int&gt;</span> values for <span class=\'code\'>accessRights</span> . The default accessRights is <span class=\'code\'>#readOnly</span> .</p>\n\
<p>If a HKey is successfully opened, the HKey value will be written to the <span class=\'code\'>Key</span> keyword variable.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` registry.openKey HKEY_CLASSES_ROOT &quot;.123&quot; accessRights:#all key:&amp;key1</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>registry.deleteValue &lt;HKey&gt; &lt;string valueName&gt; \n\
</pre></div><p>Deletes the specified value of the open HKey.</p>\n\
<p>Returns <span class=\'code\'>true</span> if successful, false if an error occurs.</p>\n\
<p>Use <span class=\'code\'>registry.getLastError()</span> to get the error message.</p>\n\
<p>If valueName is an empty string (&quot;&quot;), the default value on the HKey is deleted.</p>\n\
<div class=\'codeBlock\'><pre>registry.setValue &lt;HKey&gt; &lt;string valueName&gt; &lt;name valueType&gt; &lt;value data&gt; \n\
</pre></div><p>Sets the data type and value of the specified value of the open HKey.</p>\n\
<p>Returns <span class=\'code\'>true</span> if successful, <span class=\'code\'>false</span> if an error occurs.</p>\n\
<p>Use <span class=\'code\'>registry.getLastError()</span> to get the error message.</p>\n\
<p>If valueName is an empty string (&quot;&quot;), the default value on the HKey is set.</p>\n\
<p>The valid valueType values for setValue, and the corresponding MXS data type are:</p>\n\
<p><span class=\'code\'>#REG_DWORD</span> - integer</p>\n\
<p><span class=\'code\'>#REG_SZ</span> - string</p>\n\
<p><span class=\'code\'>#REG_EXPAND_SZ</span> - string that contains unexpanded references to environment variables</p>\n\
<p><span class=\'code\'>#REG_MULTI_SZ</span> - array of strings</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` registry.setvalue key1 &quot;&quot; #multiSZ #(&quot;zz&quot;,&quot;ww&quot;)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>registry.queryValue &lt;HKey&gt; &lt;string valueName&gt; type:&lt;&amp;name&gt; value:&lt;&amp;value&gt; expand:&lt;boolean&gt; \n\
</pre></div><p>Gets the data type and value of the open HKey.</p>\n\
<p>Returns <span class=\'code\'>true</span> if successful, <span class=\'code\'>false</span> if an error occurs.</p>\n\
<p>Use <span class=\'code\'>registry.getLastError()</span> to get the error message.</p>\n\
<p>If the query is successful, the data type will be written to the type keyword variable.</p>\n\
<p>If the query is successful and the data type is one of the following supported data types, the data value will be written to the value keyword variable.</p>\n\
<p><span class=\'code\'>#REG_DWORD</span> -integer</p>\n\
<p><span class=\'code\'>#REG_SZ</span> - string</p>\n\
<p><span class=\'code\'>#REG_EXPAND_SZ</span> - string that contains unexpanded references to environment variables</p>\n\
<p><strong>#REG_MULTI_SZ</strong> - array of strings</p>\n\
<p>If the data type is REG_EXPAND_SZ and expand is true, the environment variables are expanded in the returned data value.</p>\n\
<p>Other data types that might be returned, but are not currently supported are:</p>\n\
<p><span class=\'code\'>#REG_BINARY</span></p>\n\
<p><span class=\'code\'>#REG_DWORD_LITTLE_ENDIAN</span></p>\n\
<p><span class=\'code\'>#REG_DWORD_BIG_ENDIAN</span></p>\n\
<p><span class=\'code\'>#REG_LINK</span></p>\n\
<p><span class=\'code\'>#REG_NONE</span></p>\n\
<p><span class=\'code\'>#REG_QWORD</span></p>\n\
<p><span class=\'code\'>#REG_QWORD</span></p>\n\
<p><span class=\'code\'>#REG_RESOURCE_LIST</span></p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` registry.queryValue key2 &quot;Notepad.exe&quot; type:&amp;type value:&amp;val</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>registry.queryInfoKey &lt;HKey&gt; numSubKeys:&lt;&amp;int&gt; numValues:&lt;&amp;int&gt; \n\
</pre></div><p>Gets the number of subkeys and values of the open HKey.</p>\n\
<p>Returns <span class=\'code\'>true</span> if successful, <span class=\'code\'>false</span> if an error occurs.</p>\n\
<p>Use <span class=\'code\'>registry.getLastError()</span> to get the error message.</p>\n\
<p>If the query is successful, the number of subKeys and values will be written to the <span class=\'code\'>numSubKeys:</span> and <span class=\'code\'>numValues:</span> keyword variable, respectively.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` registry.queryInfoKey key2 numSubKeys:&amp;numSubKeys numValues:&amp;numValues</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>registry.isKeyOpen &lt;HKey&gt; \n\
</pre></div><p>Returns true if the specified HKey is open.</p>\n\
<div class=\'codeBlock\'><pre>registry.isParentKeyOpen &lt;HKey&gt; \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the parent HKey of the specified HKey is open.</p>\n\
<div class=\'codeBlock\'><pre>registry.isKeyConstant &lt;HKey&gt; \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the HKey is a constant (root) HKey.</p>\n\
<div class=\'codeBlock\'><pre>registry.getParentKey &lt;HKey&gt; \n\
</pre></div><p>Returns the parent HKey of the specified HKey.</p>\n\
<div class=\'codeBlock\'><pre>registry.getSubKeyName &lt;HKey&gt; &lt;index&gt; name:&lt;&amp;name&gt; \n\
</pre></div><p>Gets a subkey name of the open HKey by index. Returns <span class=\'code\'>true</span> if successful, false if an error occurs. Uses <span class=\'code\'>registry.getLastError()</span> to get the error message.</p>\n\
<p>If successful, the name will be written to the <span class=\'code\'>name:</span> keyword variable.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` registry.getSubKeyName key2 i name:&amp;vname</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>registry.getSubKeyNames &lt;HKey&gt; names:&lt;&amp;array&gt; \n\
</pre></div><p>Gets an array of subkey names of the open HKey by index. Returns <span class=\'code\'>true</span> if successful, <span class=\'code\'>false</span> if an error occurs. Use the <span class=\'code\'>registry.getLastError()</span> to get the error message.</p>\n\
<p>If successful, an array of the subkey names as strings name will be written to the <span class=\'code\'>names:</span> keyword variable.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` registry.getSubKeyNames key2 names:&amp;vnames</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>registry.getValueName &lt;HKey&gt; &lt;index&gt; name:&lt;&amp;name&gt; \n\
</pre></div><p>Gets a value name of the open HKey by index. Returns <span class=\'code\'>true</span> if successful, <span class=\'code\'>false</span> if an error occurs. Use <span class=\'code\'>registry.getLastError()</span> to get the error message.</p>\n\
<p>If successful, the name will be written to the <span class=\'code\'>name:</span> keyword variable.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` registry.getValueName key2 i name:&amp;vname</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>registry.getValueNames &lt;HKey&gt; names:&lt;&amp;array&gt; \n\
</pre></div><p>Get an array of value names of the open HKey by index. Returns <span class=\'code\'>true</span> if successful, <span class=\'code\'>false</span> if an error occurs. Use <span class=\'code\'>registry.getLastError()</span> to get the error message.</p>\n\
<p>If successful, an array of value names as strings name will be written to the <span class=\'code\'>names:</span> keyword variable.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` registry.getSubKeyNames key2 names:&amp;vnames</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>registry.getLastError() \n\
</pre></div><p>Returns a string describing the last registry error that occurred.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` registry.openKey HKEY_CLASSES_ROOT&quot;*&quot;accessRights:#readOnly key:&amp;key2</p>\n\
<p>registry.queryInfoKey key2 numSubKeys:&amp;numSubKeys numValues:&amp;numValues;numSubKeys;numValues for i = 1 to 2 do (registry.getSubKeyName key2 i name:&amp;vname;print vname)</p>\n\
<p>registry.isKeyOpen key2</p>\n\
<p>registry.setvalue key2 &quot;&quot; #REG_SZ &quot;123123&quot; -- fails because opened with #readOnly access registry.getLastError()</p>\n\
<p>registry.getSubKeyNames key2 names:&amp;names;names registry.getvalueNames key2 names:&amp;names;names registry.queryValue key2 &quot;InfoTip&quot; type:&amp;type value:&amp;val;type;val</p>\n\
<p>registry.createKey HKEY_CLASSES_ROOT &quot;.123x&quot; accessRights:#all key:&amp;key1 registry.setvalue key1 &quot;&quot; #REG_MULTI_SZ #(&quot;zz&quot;,&quot;ww&quot;) registry.queryValue key1 &quot;&quot; type:&amp;type value:&amp;val;type;val registry.setvalue key1 &quot;&quot; #REG_SZ&quot;123123&quot; registry.queryValue key1 &quot;&quot; type:&amp;type value:&amp;val;type;val registry.deleteKey key1</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"registry-related-global-variables\"></a><h2 id=\"registry-related-global-variables\">Registry-related global variables:</h2></div>\n\
<div class=\'codeBlock\'><pre>HKEY_CLASSES_ROOT HKEY_CURRENT_CONFIG HKEY_CURRENT_USER HKEY_LOCAL_MACHINE HKEY_USERS HKEY_PERFORMANCE_DATA\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";