var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>System Information</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>System Information</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"system-information\"></a></div>\n\
<p>The <strong>sysinfo struct</strong> provides several variables and methods related to accessing system information like system directories, system name, user, desktop size, and color depth as well as hardware-related data like CPU count and memory usage.</p>\n\
<p>{{toc}}</p>\n\
<div class=\'section\'><a id=\"system-directories\"></a><h2 id=\"system-directories\">System Directories</h2></div>\n\
<div class=\'codeBlock\'><pre>sysInfo.windowsdir \n\
</pre></div><p>A <strong>read only</strong> variable containing the Windows directory as a <span class=\'code\'>&lt;string&gt;</span> value.</p>\n\
<div class=\'codeBlock\'><pre>sysInfo.systemdir \n\
</pre></div><p>A <strong>read only</strong> variable containing the Windows System directory as a <span class=\'code\'>&lt;string&gt;</span> value.</p>\n\
<div class=\'codeBlock\'><pre>sysInfo.tempdir \n\
</pre></div><p>A <strong>read only</strong> variable containing the Temp directory as a <span class=\'code\'>&lt;string&gt;</span> value.</p>\n\
<div class=\'codeBlock\'><pre>sysInfo.currentdir \n\
</pre></div><p>A variable to <strong>get/set</strong> the current directory as a <span class=\'code\'>&lt;string&gt;</span> value.</p>\n\
<p>The current directory is the directory MAXScript will look for files if no explicit path is specified, for example, in <span class=\'code\'>fileIn()</span> calls. If a relative path is specified in such a call, it will be resolved relatively to the directory in <span class=\'code\'>sysInfo.currentdir</span> .</p>\n\
<p>As this variable can be read and written to, it effectively allows you to specify the current directory at any time before using relative paths or no explicit paths at all.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` sysinfo.currentdir --&gt;&quot;C:\\Documents and Settings\\username\\My Documents\\3dsmax\\Scripts&quot;</p>\n\
<p>sysinfo.currentdir = &quot;C:\\Temp&quot; --&gt;&quot;C:\\Temp&quot;</p>\n\
<p>fileIn &quot;test.ms&quot; --this willloadthe scriptfromC:\\Temp\n\
  --&gt;OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"user-and-computer-names\"></a><h2 id=\"user-and-computer-names\">User and Computer Names:</h2></div>\n\
<div class=\'codeBlock\'><pre>sysInfo.username \n\
</pre></div><p>A <strong>read only</strong> variable containing the user name as a <span class=\'code\'>&lt;string&gt;</span> value.</p>\n\
<div class=\'codeBlock\'><pre>sysInfo.computername \n\
</pre></div><p>A <strong>read only</strong> variable containing the computer name as a <span class=\'code\'>&lt;string&gt;</span> value.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` currentUser = sysinfo.username + &quot;@&quot; + sysinfo.computername &quot;SonGoku@FlyingNimbus&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"cpu-and-desktop-info\"></a><h2 id=\"cpu-and-desktop-info\">CPU and Desktop Info:</h2></div>\n\
<div class=\'codeBlock\'><pre>sysInfo.cpucount \n\
</pre></div><p>A <strong>read only</strong> variable containing the number of CPUs as an <span class=\'code\'>&lt;integer&gt;</span> value.</p>\n\
<div class=\'codeBlock\'><pre>sysInfo.desktopSize \n\
</pre></div><p>A <strong>read only</strong> system global variable that returns the Windows Desktop size in pixels as a Point2 value. Note that on dual monitor systems with the desktop set to stretch on both monitors, the desktop size returned will include the second monitor.</p>\n\
<div class=\'codeBlock\'><pre>sysInfo.DesktopSizeUnscaled \n\
</pre></div><p>A read only system global variable that contains the unscaled Windows Desktop size in pixels as a Point2 value. Note that on dual monitor systems with the desktop set to stretch on both monitors, the desktop size returned will include the second monitor. Available in <strong>in 3ds Max 2017 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>sysInfo.desktopBPP \n\
</pre></div><p>A <strong>read only</strong> system global variable. Returns the Windows Desktop color depth as an integer value in Bits Per Pixel. For example, if the graphics driver is set to 32 bit True Color, the value returned will be 32.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES</strong></p>\n\
<p>``` format &quot;Your system has % CPUs (Cores)\\n&quot; sysinfo.cpucount &quot;Your system has 8 CPUs (Cores)&quot; format &quot;Desktop: Scaled % / Unscaled % @ % bits per pixel\\n&quot; sysinfo.desktopSize sysinfo.DesktopSizeUnscaled sysinfo.desktopBPP &quot;Desktop: Scaled [1920,1080] / Unscaled [1920,1080] @ 32 bits per pixel&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"ds-max-process-priority-and-affinity\"></a><h2 id=\"ds-max-process-priority-and-affinity\">3ds Max Process Priority and Affinity:</h2></div>\n\
<div class=\'codeBlock\'><pre>sysInfo.MAXPriority \n\
</pre></div><p><strong>Gets/sets</strong> the <strong>3ds Max</strong> process priority as a <span class=\'code\'>&lt;name&gt;</span> value. Valid priority name values are <strong>#realtime</strong>, <strong>#high</strong>, <strong>#abovenormal</strong>, <strong>#normal</strong>, <strong>#belownormal</strong>, and <strong>#low</strong>.</p>\n\
<p>Note: You need admin privileges to set <strong>#realtime</strong>. If you are not admin, setting <strong>#realtime</strong> will result in a setting of <strong>#high</strong>. Setting <strong>#realtime</strong> is not generally recommended, and is only appropriate for applications that talk directly to hardware.</p>\n\
<p>There are also write-only priorities: <strong>#backgroundBegin</strong> and <strong>#backgroundEnd</strong>. In Windows 10, setting <strong>#backgroundBegin</strong> results in a reported priority of #low, and <strong>#backgroundEnd</strong> returns the process to its original priority, unless you were in <strong>#realTime</strong>, in which case the process remains in <strong>#low</strong>. In Windows 7, setting <strong>#backgroundBegin</strong> does not change the reported priority.</p>\n\
<p>Available in <strong>3ds Max 2017.1 Update and higher</strong>: <strong>#abovenormal</strong>, <strong>#belownormal</strong>, <strong>#backgroundBegin</strong>, <strong>#backgroundEnd</strong>, and <strong>#realtime</strong>.</p>\n\
<p>For information about the corresponding system process priority levels, see the MSDN topic <a href=\'https://docs.microsoft.com/en-ca/windows/win32/api/processthreadsapi/nf-processthreadsapi-setpriorityclass\' title=\'\' target=\'_blank\'>SetPriorityClass function</a>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` ( current_priority = sysinfo.MAXpriority priorities = #(#low,#belowNormal,#normal,#aboveNormal,#high,#realtime) for p1 in priorities do ( sysinfo.MAXpriority = #normal sysinfo.MAXpriority = p1 format &quot;% : %\\t&quot; p1 sysinfo.MAXpriority for p2 in priorities do ( sysinfo.MAXpriority = p2 format &quot;\\t%&quot; sysinfo.MAXpriority sysinfo.MAXpriority = p1 ) format &quot;\\n&quot; ) print &quot;Priority Modifiers&quot; priority_modifiers = #(#backgroundBegin,#backgroundEnd) for p1 in priorities do ( sysinfo.MAXpriority = #normal sysinfo.MAXpriority = p1 format &quot;% : %\\t&quot; p1 sysinfo.MAXpriority for p2 in priority_modifiers do ( sysinfo.MAXpriority = p2 format &quot;\\t%&quot; sysinfo.MAXpriority ) format &quot;\\n&quot; ) sysinfo.MAXpriority = current_priority ok )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>sysinfo.processAffinity \n\
</pre></div><p><strong>Gets/sets</strong> the process affinity (the processors the process can use) as a pointer value. Each bit in the pointer value corresponds to a processor. If the bit is set, the process can use that processor.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>sysinfo.systemAffinity \n\
</pre></div><p>A <strong>read-only</strong> property containing the system affinity (the processors present in the system) as a pointer. Each bit in the pointer corresponds to a processor. If the bit is set, the processor exists.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>The following example shows how to get an array of existing processor or a bitarray with a bit set for each existing processor (core). In this example, the system has four cores.</p>\n\
<p>``` --getting system affinity as a Pointer: sysinfo.systemAffinity --&gt;15P</p>\n\
<p>--getting system affinity as an array: (for i = 1 to 32 where bit.get sysinfo.systemAffinity i collect i) --&gt;#(1,2,3,4)</p>\n\
<p>--getting system affinity as a bitarray: (for i = 1 to 32 where bit.get sysinfo.systemAffinity i collect i)as bitarray --&gt;#{1..4}</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"system-language-and-locale\"></a><h2 id=\"system-language-and-locale\">System Language and Locale:</h2></div>\n\
<div class=\'codeBlock\'><pre>sysinfo.getLanguage [user:&lt;boolean&gt;] \n\
</pre></div><p>This method returns the Windows OS Language as an array with three elements:</p>\n\
<p>The first two elements are integer values that correspond to the Primary Language and SubLanguage IDs. See the Windows SDK Help file for documentation of these IDs.</p>\n\
<p>The third element is a description script for the current language. Starting with <strong>3ds Max 2010</strong>, if the language cannot be retrieved, the third element will contain an error string.</p>\n\
<p>If the optional keyword <span class=\'code\'>user</span> : is <span class=\'code\'>true</span> (the default), the current user&#39;s language is returned. If <span class=\'code\'>false</span> , the system&#39;s language is returned.</p>\n\
<p>Available in <strong>3ds Max 6 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>sysinfo.getMaxLanguage() \n\
</pre></div><p>This method available in <strong>3ds Max 2010 and higher</strong> returns the <strong>3ds Max</strong> Language as an array such as <span class=\'code\'>#(9, 1, &quot;ENU&quot;, &quot;English (United States)&quot;, &quot;en-US&quot;)</span>. <strong>Starting in 3ds Max 2013</strong> and higher, this method returns an array with five elements. Previous versions returned a four element array.</p>\n\
<p>The first two elements are integer values that correspond to the Primary Language and SubLanguage IDs. See the Windows SDK Help file for documentation of these IDs.</p>\n\
<p>The third element is the three letter code for the current language, for example &quot;ENU&quot; for US English.</p>\n\
<p>The fourth element is the description string for the current 3ds Max language. If the description string cannot be retrieved, this element contains the value <span class=\'code\'>undefined</span>.</p>\n\
<p>The fifth element is the 3ds Max two letter localization code and country name code, in the form <span class=\'code\'>&lt;language&gt;-&lt;country&gt;</span>, for example &quot;en-US&quot;.</p>\n\
<div class=\'codeBlock\'><pre>sysInfo.getDecimalChars()\n\
</pre></div><p>Available in <strong>3ds Max 2020.2 Update and higher:</strong> Returns and array containing the user locale decimal separator characters from the following locations:</p>\n\
<ol>\n\
<li>The OS user locale</li>\n\
<li>the C runtime locale</li>\n\
<li>The C++ runtime global locale</li>\n\
<li>The .NET runtime global locale</li>\n\
</ol>\n\
<p>For example:</p>\n\
<div class=\'codeBlock\'><pre>res = sysInfo.getDecimalChars()\n\
--&gt; #(&quot;.&quot;, &quot;.&quot;, &quot;.&quot;, &quot;.&quot;)\n\
</pre></div><p>Note: 3ds Max only reads the once locale on startup. Changing the locale or specifying a custom decimal separator while 3ds Max is running will cause this method to return the new character, but does not change the character 3ds Max uses until it re-starts.</p>\n\
<div class=\'section\'><a id=\"memory-usage-and-max-process-info\"></a><h2 id=\"memory-usage-and-max-process-info\">Memory Usage and Max Process Info:</h2></div>\n\
<div class=\'codeBlock\'><pre>sysinfo.getSystemMemoryInfo() \n\
</pre></div><p>A method which returns a seven element array containing the system memory status data. The array elements contain the following respectively:</p>\n\
<ul>\n\
<li><p>percent of memory in use</p></li>\n\
<li><p>bytes of physical memory</p></li>\n\
<li><p>free physical memory bytes</p></li>\n\
<li><p>bytes of paging file</p></li>\n\
<li><p>free bytes of paging file</p></li>\n\
<li><p>user bytes of address space</p></li>\n\
<li><p>free user bytes</p></li>\n\
</ul>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` ( r=sysinfo.getSystemMemoryInfo() for i=2 to 7 do r[i] /= (1024*1024.) format &quot;percent of memory in use:\\t%\\n&quot; r[1] format &quot;total physical memory:\\t% MB\\n&quot; r[2] format &quot;free physical memory:\\t% MB\\n&quot; r[3] format &quot;used physical memory:\\t% MB\\n&quot; (r[2]-r[3]) format &quot;total paging file size:\\t% MB\\n&quot; r[4] format &quot;free paging file size:\\t% MB\\n&quot; r[5] format &quot;used paging file size:\\t% MB\\n&quot; (r[4]-r[5]) format &quot;total virtual memory:\\t% MB\\n&quot; r[6] format &quot;free virtual memory:\\t\\t% MB\\n&quot; r[7] format &quot;used virtual memory:\\t\\t% MB\\n&quot; (r[6]-r[7]) ok )</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT</strong></p>\n\
<p>``` percent of memory in use: 0 total physical memory: 255.359 MB free physical memory: 16.5156 MB used physical memory: 238.844 MB total paging file size: 1016.3 MB free paging file size: 757.898 MB used paging file size: 258.398 MB total virtual memory: 2047.88 MB free virtual memory: 1846.55 MB used virtual memory: 201.328 MB OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>sysinfo.getMAXMemoryInfo() \n\
</pre></div><p>Returns a nine element array containing the <strong>3ds Max</strong> memory status data. The array elements contain the following respectively:</p>\n\
<ul>\n\
<li><p>Page Fault Count</p></li>\n\
<li><p>Peak Working Set Size</p></li>\n\
<li><p>Working Set Size</p></li>\n\
<li><p>Quota Peak Paged Pool Usage</p></li>\n\
<li><p>Quota Paged Pool Usage</p></li>\n\
<li><p>Quota Peak NonPaged Pool Usage</p></li>\n\
<li><p>Quota NonPaged Pool Usage</p></li>\n\
<li><p>Pagefile Usage</p></li>\n\
<li><p>Peak Pagefile Usage</p></li>\n\
</ul>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` ( r=sysinfo.getMAXMemoryInfo() for i=2 to 9 do r[i] /= (1024*1024.) format &quot;Page Fault Count:\\t\\t\\t%\\n&quot; r[1] format &quot;Peak Working Set Size:\\t\\t% MB\\n&quot; r[2] format &quot;Working Set Size:\\t\\t\\t% MB\\n&quot; r[3] format &quot;Quota Peak Paged Pool Usage:\\t% MB\\n&quot; r[4] format &quot;Quota Paged Pool Usage:\\t\\t% MB\\n&quot; r[5] format &quot;Quota Peak NonPaged Pool Usage:\\t% MB\\n&quot; r[6] format &quot;Quota NonPaged Pool Usage:\\t\\t% MB\\n&quot; r[7] format &quot;Pagefile Usage:\\t\\t\\t% MB\\n&quot; r[8] format &quot;Peak Pagefile Usage:\\t\\t\\t% MB\\n&quot; r[9] ok )</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT</strong></p>\n\
<p>``` Page Fault Count: 32948 Peak Working Set Size: 70.3594 MB Working Set Size: 70.3594 MB Quota Peak Paged Pool Usage: 0.166186 MB Quota Paged Pool Usage: 0.161236 MB Quota Peak NonPaged Pool Usage: 0.0213509 MB Quota NonPaged Pool Usage: 0.0213509 MB Pagefile Usage: 58.9023 MB Peak Pagefile Usage: 58.9219 MB</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;int&gt;sysinfo.getMAXHandleCount()\n\
&lt;int&gt;sysinfo.getMAXUserObjectCount()\n\
&lt;int&gt;sysinfo.getMAXGDIObjectCount()\n\
</pre></div><p>These functions return the number of handles, user objects, and GDI objects held by the 3ds Max process. Available in <strong>3ds Max 2019.3 Update and higher</strong>. This is the same information displayed in the Windows Task Manager on the Details tab.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer64&gt;sysInfo.getMAXHeapUsed()\n\
</pre></div><p>Returns the 3ds Max heap memory used, as an Integer64 value. <strong>Available in 3ds Max 2021 and higher.</strong> ## 3ds Max Command Line Info</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;sysinfo.getCommandLine()\n\
</pre></div><p>Returns the entire command line (including arguments) as a string. Available in <strong>3ds Max 2019.2 Update and higher</strong>.</p>\n\
<p>For example:</p>\n\
<p><span class=\'code\'>&quot;&quot;C:\\\\Program Files\\\\Autodesk\\\\3ds Max 2019\\\\3dsmax.exe&quot; -d -dfc -g -q&quot;</span></p>\n\
<div class=\'codeBlock\'><pre>&lt;array&gt;sysinfo.getCommandLineArgs() \n\
</pre></div><p>Returns an array of strings where each element is a command line argument. Available in <strong>3ds Max 2019.2 Update and higher</strong>.</p>\n\
<p>For example:</p>\n\
<p><span class=\'code\'>#(&quot;-d&quot;, &quot;-dfc&quot;, &quot;-g&quot;, &quot;-q&quot;)</span></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";