var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>System Tools</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>System Tools</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"system-tools\"></a></div>\n\
<p>This group of functions lets you gather various pieces of information about the system <strong>3ds Max</strong> is running on.</p>\n\
<div class=\'codeBlock\'><pre>systemTools.NumberOfProcessors()   \n\
</pre></div><p>Returns the number of processors (cores) available according to the operating system.</p>\n\
<div class=\'codeBlock\'><pre>systemTools.GetScreenWidth [ removeUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Returns the screen width including multiple monitors the desktop might be extended to.</p>\n\
<p>The optional <span class=\'code\'>removeUIScaling</span> parameter indicates whether to remove scaling on high-DPI displays.</p>\n\
<div class=\'codeBlock\'><pre>systemTools.GetScreenHeight [ removeUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Returns the screen height including multiple monitors the desktop might be extended to.</p>\n\
<p>The optional <span class=\'code\'>removeUIScaling</span> parameter indicates whether to remove scaling on high-DPI displays.</p>\n\
<div class=\'codeBlock\'><pre>systemTools.IsWindows98or2000() \n\
</pre></div><p>In versions <strong>prior to 3ds Max 2017</strong>, returned True if the Operating System is Windows98, Windows2000, Windows XP, Windows Vista or Windows 7.</p>\n\
<div class=\'codeBlock\'><pre>systemTools.IsWindows9x() \n\
</pre></div><p>In versions <strong>prior to 3ds Max 2017</strong>, returned True if the OS is a Win9x flavor.</p>\n\
<div class=\'codeBlock\'><pre>systemTools.GetOSVersion() \n\
</pre></div><p>Returns the OS version as a three part array representing the major version, the minor version, and the build number. This function works for all versions of Windows that 3ds Max supports.</p>\n\
<p>Available <strong>in 3ds Max 2019.1 Update and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt; systemTools.IsDebugging() \n\
</pre></div><p>Returns True if running in a Debugger.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt; systemTools.GetBuildNumber() \n\
</pre></div><p>Returns string in the form &quot;#.#.#.#&quot; where the numbers are the major version, the update version, the hot fix number, and the build number. This is the same string displayed as Product Version for 3dsmax.exe in <strong>File Properties</strong> and at the top of the <strong>About 3ds Max</strong> dialog.</p>\n\
<p>Available in <strong>3ds Max 2018 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>systemTools.DebugPrint &lt;string&gt; \n\
</pre></div><p>Prints the specified string to the debug output window of Visual Studio.</p>\n\
<p>Available in <strong>3ds Max 2011 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>systemTools.sceneIODebugEnabled &lt;boolean&gt; \n\
</pre></div><p>Specifies whether scene IO debugging is enabled. If true, information on scene load is sent to the log system.</p>\n\
<p>Available in <strong>3ds Max 2018 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt; systemTools.isDebugBuild \n\
</pre></div><p>Returns true if this is a debug build of 3ds Max, false otherwise.</p>\n\
<p>Available in <strong>in 3ds Max 2019.2 Update and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>systemTools.getEnvVariable &lt;string&gt; \n\
</pre></div><p>Returns the contents of specified environment variable. If the specified environment variable does not exist, returns a value of undefined.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` systemTools.getEnvVariable &quot;PATH&quot; &quot;C:\\WINDOWS\\system32;C:\\WINDOWS;C:\\WINDOWS\\System32\\Wbem;C:\\Program Files\\Common Files\\Autodesk Shared;C:\\Program Files\\backburner 2;&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;systemTools.setEnvVariable &lt;string&gt; { &lt;string&gt; | undefined } \n\
</pre></div><p>Sets the contents of specified environment variable.</p>\n\
<p>Returns True if the set occurred, False if not.</p>\n\
<p>If the second argument is the value undefined, the environment variable is deleted.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>systemTools.GetRegistryKeyBase()\n\
</pre></div><p>Returns the base product registry key in the form: &quot;SOFTWARE\\<company name=\"\">\\<product name=\"\">\\<version>&quot;. The application uses this key as the base for storing registry settings.<p>\n\
<p>Available in <strong>3ds Max 2018 and higher</strong>.</p>\n\
<p>For example:</p>\n\
<div class=\'codeBlock\'><pre>systemTools.GetRegistryKeyBase()\n\
--&gt; &quot;SOFTWARE\\Autodesk\\3dsMax\\21.0&quot;\n\
&lt;int&gt;systemTools.getmaxstdio()\n\
</pre></div><p>Returns the number of simultaneously open files permitted at the stdio level (i.e. via fopen).</p>\n\
<p>Available in <strong>3ds Max 2014 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;int&gt;systemTools.setmaxstdio &lt;int newmax&gt;\n\
</pre></div><p>Sets the maximum number of simultaneously open files at the stdio level (i.e. via fopen).</p>\n\
<p>The valid range for the <span class=\'code\'>newmax</span> argument is between 512 and 2048.</p>\n\
<p>Returns the new maximum value if successful.</p>\n\
<p>Currently, only increasing the value is allowed.</p>\n\
<p>Returns -1 if attempting to reduce the maximum count.</p>\n\
<p>This could be used for example to allow more Point Cache files to be read in parallel at the same time.</p>\n\
<p>Available in <strong>3ds Max 2014 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;int&gt;systemTools.getSystemMetrics &lt;int&gt;\n\
</pre></div><p>Calls the win32 <span class=\'code\'>GetSystemMetrics()</span> function, passing in the specified value. The return value is the return value from <span class=\'code\'>GetSystemMetrics()</span>. See the Win32 documentation for <span class=\'code\'>getSystemMetrics</span> for parameter values. Available in <strong>in 3ds Max 2017 and higher</strong>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` -- get client window width systemTools.getSystemMetrics 16 --&gt;1920</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;systemTools.isAeroEnabled()\n\
</pre></div><p>Returns True if the Windows Aero theme is enabled, False if using the Windows Classic theme on Windows 7. Available in <strong>in 3ds Max 2017 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;systemTools.IsGpuPresent()\n\
</pre></div><p>Returns true if at least one GPU is present on the current system, false otherwise.</p>\n\
<p>Available in <strong>in 3ds Max 2018 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;array&gt;systemTools.EnumDisplayDevices [ removeUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Returns an array of arrays, where each element in the outer array corresponds to a display device. For each display device, the array contains the device ID, the device name, the device string, the device state flags, and the device key. If the device is attached to the desktop, the array also contains the device&#39;s top left x and y pixel coordinates and its width and height. The pixel coordinates are 0-based. Available in <strong>in 3ds Max 2017 and higher</strong>.</p>\n\
<p>See MSDN documentation of <span class=\'code\'>EnumDisplayDevices</span> for more information on display devices.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` devices= systemTools.EnumDisplayDevices removeUIScaling:true for d in devices do print d #nomap #(&quot;\\.\\DISPLAY1&quot;, &quot;NVIDIA Quadro FX 4800&quot;, 5, &quot;PCI\\VEN_10DE&amp;DEV_05FE&amp;SUBSYS_059410DE&amp;REV_A1&quot;, &quot;\\Registry\\Machine\\System\\CurrentControlSet\\Control\\Video{8A328D59-1288-485D-821D-7DA906E41335}\\0000&quot;, 0, 0, 1920, 1080) #(&quot;\\.\\DISPLAY2&quot;, &quot;NVIDIA Quadro FX 4800&quot;, 1, &quot;PCI\\VEN_10DE&amp;DEV_05FE&amp;SUBSYS_059410DE&amp;REV_A1&quot;, &quot;\\Registry\\Machine\\System\\CurrentControlSet\\Control\\Video{8A328D59-1288-485D-821D-7DA906E41335}\\0001&quot;, 1920, 0, 1920, 1080) #(&quot;\\.\\DISPLAYV1&quot;, &quot;RDPDD Chained DD&quot;, 2097160, &quot;&quot;, &quot;\\Registry\\Machine\\System\\CurrentControlSet\\Control\\Video{DEB039CC-B704-4F53-B43E-9DD4432FA2E9}\\0000&quot;) #(&quot;\\.\\DISPLAYV2&quot;, &quot;RDP Encoder Mirror Driver&quot;, 2097160, &quot;&quot;, &quot;\\Registry\\Machine\\System\\CurrentControlSet\\Control\\Video{42cf9257-1d96-4c9d-87f3-0d8e74595f78}\\0000&quot;) #(&quot;\\.\\DISPLAYV3&quot;, &quot;RDP Reflector Display Driver&quot;, 2097160, &quot;&quot;, &quot;\\Registry\\Machine\\System\\CurrentControlSet\\Control\\Video{b043b95c-5670-4f10-b934-8ed0c8eb59a8}\\0000&quot;) OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt; GenerateMiniDumpAndContinue sendDump:&lt;false&gt; \n\
</pre></div><p>Available <strong>in 3ds Max 2018.2 Update and higher</strong>: Generate a MiniDump file and continue executing. If <strong>sendDump</strong> is true, the minidump file is sent to Autodesk.</p>\n\
<p>Note: This method, and in particular the <strong>sendDump</strong> argument is primarily for testing of minidump generation, and should not generally be used.</p>\n\
<p>The MiniDump file generated is located at C:\\Users\\<username>\\AppData\\Local\\temp\\3dsmax_minidump.dmp.<p>\n\
<p>If a big MiniDump file is generated, it is located at C:\\Users\\<username>\\AppData\\Local\\temp\\3dsmax_minidump_big.dmp.<p>\n\
<p>See also: &quot;Using 3ds Max Generated Minidump Files&quot; in the 3ds Max Developer Guide.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt; SetMiniDumpContents {#default | #basic | #medium | #full | &lt;int&gt;}\n\
</pre></div><p>Available <strong>in 3ds Max 2018.2 Update and higher</strong>: Sets the contents of generated minidumps. The <span class=\'code\'>#default</span> and <span class=\'code\'>#medium</span> flags are equivalent.</p>\n\
<p>The MiniDump flags set for each level are as follows (see link below for description of the MiniDump flag values) :</p>\n\
<ul>\n\
<li><span class=\'code\'>#basic</span> - MiniDumpNormal</li>\n\
<li><span class=\'code\'>#medium</span> - MiniDumpNormal | MiniDumpWithIndirectlyReferencedMemory</li>\n\
<li><span class=\'code\'>#full</span> - MiniDumpNormal | MiniDumpWithDataSegs | MiniDumpWithFullMemory | MiniDumpWithHandleData | MiniDumpWithUnloadedModules | MiniDumpWithIndirectlyReferencedMemory | MiniDumpWithProcessThreadData | MiniDumpWithPrivateReadWriteMemory | MiniDumpIgnoreInaccessibleMemory</li>\n\
</ul>\n\
<p>If <span class=\'code\'>&lt;int&gt;</span> is specified, the bits set correspond to the MiniDump flag values.</p>\n\
<p>See also: &quot;Using 3ds Max Generated Minidump Files&quot; in the 3ds Max Developer Guide.</p>\n\
<div class=\'codeBlock\'><pre>systemTools.SetBigMiniDumpContents {#default | #basic | #medium | #full | #off | &lt;int&gt;\n\
</pre></div><p>Available <strong>in 3ds Max 2018.2 Update and higher</strong>: Sets the contents of generated big minidumps. Normally this is set to <span class=\'code\'>#off</span>.</p>\n\
<p>Note: Big minidump files at <span class=\'code\'>#full</span> setting can be quite large, sometimes more than 2GB. Use with caution.</p>\n\
<p>See also: &quot;Using 3ds Max Generated Minidump Files&quot; in the 3ds Max Developer Guide.</p>\n\
<p><strong>For internal use only:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;systemTools.PB2_AllNoRefSafePointersTestingDisable &lt;boolean&gt;disable\n\
</pre></div><p>For internal use only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;systemTools.PB2_AllNoRefSafePointersTestingDisables()\n\
</pre></div><p>For internal use only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;systemTools.allocateMemory()\n\
</pre></div><p>For internal use only.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;systemTools.releaseMemory()\n\
</pre></div><p>For internal use only.</p>\n\
</username></username></version></product></company>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";