var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Windows Structure</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Windows Structure</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"windows-structure\"></a></div>\n\
<p>The <strong>Windows struct</strong> provides methods to access the Windows OS&#39; User Interface elements.</p>\n\
<p>Unless noted otherwise, these methods are available in <strong>3ds Max 2008</strong> and higher.</p>\n\
<p>They were previously available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a> .</p>\n\
<div class=\'codeBlock\'><pre>windows.getMAXHWND()\n\
</pre></div><p>This method returns the HWND of the main <strong>3ds Max</strong> window as an integer (Pointer value).</p>\n\
<div class=\'codeBlock\'><pre>windows.getDesktopHWND()\n\
</pre></div><p>This method returns the HWND of the MS Window&#39;s desktop as an integer (Pointer value).</p>\n\
<div class=\'codeBlock\'><pre>windows.sendMessage &lt;int HWND&gt; &lt;int message&gt; &lt;int messageParameter1&gt; &lt;int messageParameter2&gt;\n\
</pre></div><p>Sends a Win32 message to the HWND specified in the first argument.</p>\n\
<p>The second argument is the message ID, usually specified as hexadecimal number.</p>\n\
<p>The third and fourth arguments are the message parameters. When no parameters are expected, pass 0 as a placeholder.</p>\n\
<div class=\'codeBlock\'><pre>windows.postMessage &lt;int HWND&gt; &lt;int message&gt; &lt;int messageParameter1&gt; &lt;int messageParameter2&gt; \n\
</pre></div><p>Calls the Window&#39;s PostMessage function passing the argument values.</p>\n\
<p>Available in <strong>3ds Max 2011 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>windows.processPostedMessages()\n\
</pre></div><p>Runs a message pump that retrieves any pending Window&#39;s messages and dispatches them to <strong>3ds Max</strong>.</p>\n\
<p>Calling this method will process all pending messages. It can be used inside a MAXScript loop which would otherwise cause a &quot;white screen&quot; in Windows 7 due to <strong>3ds Max</strong> being unresponsive while performing long calculations.</p>\n\
<p>Available in <strong>3ds Max 2011 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>windows.getChildrenHWND {&lt;int HWND&gt;|#max} parent:{&lt;int HWND&gt;| #max}\n\
</pre></div><p>This method returns an array of the children windows of the specified HWND, recursively.</p>\n\
<p>If the specified HWND is 0, only the top level desktop windows are returned (not recursively).</p>\n\
<p>If the parent HWND is specified, only windows whose immediate parent is the specified window are returned.</p>\n\
<p>If <span class=\'code\'>#max</span> is specified as the HWND, the HWND associated with the <strong>3ds Max</strong> main window is used.</p>\n\
<p>If the specified HWND does not exist, the value <span class=\'code\'>undefined</span> is returned.</p>\n\
<p>Otherwise, an array is returned.</p>\n\
<p>Each element of the array corresponds to a window, and contains an 8 elements array (originally, only the first 5 elements were returned in <strong>3ds Max 2008</strong>)</p>\n\
<p><strong>The elements of these arrays represent the window&#39;s:</strong></p>\n\
<p>1: HWND</p>\n\
<p>2: the parent HWND. This does not include the owner (GetAncestor(hWnd,GA_PARENT))</p>\n\
<p>3: the parent or owner HWND. If the window is a child window, the return value is a handle to the parent window. If the window is a top-level window, the return value is a handle to the owner window. (GetParent(hWnd))</p>\n\
<p>4: class name as a string (GetClassName(hWnd, className, bufSize)) - limit of 255 characters</p>\n\
<p>5: window text as a string (GetWindowText(hWnd, windowText, bufSize)) - limit of 255 characters</p>\n\
<p>6: the owner&#39;s HWND (GetWindow(hWnd,GW_OWNER))</p>\n\
<p>7: root window HWND. The root window as determined by walking the chain of parent windows (GetAncestor(hWnd,GA_ROOT))</p>\n\
<p>8: owned root window HWND. The owned root window as determined by walking the chain of parent and owner windows returned by GetParent (GetAncestor(hWnd,GA_ROOTOWNER))</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE, A PARTIAL RESULT FROM THE CALL</strong></p>\n\
<p>``` print (windows.getChildrenHWND #max)</p>\n\
<p>```</p>\n\
<p>looks like</p>\n\
<p>``` ... #(16990604P, 25827408P, 25827408P, &quot;#32770&quot;, &quot;Main Toolbar&quot;, 25827408P, 25827408P, 25827408P) #(2048768P, 16990604P, 16990604P, &quot;CustToolbar&quot;, &quot;&quot;, 0P, 25827408P, 25827408P) #(8794706P, 2048768P, 2048768P, &quot;CustSeparator&quot;, &quot;&quot;, 0P, 25827408P, 25827408P) #(33762226P, 2048768P, 2048768P, &quot;CustButton&quot;, &quot;&quot;, 0P, 25827408P, 25827408P) #(34615562P, 2048768P, 2048768P, &quot;CustButton&quot;, &quot;&quot;, 0P, 25827408P, 25827408P) #(999632P, 2048768P, 2048768P, &quot;CustButton&quot;, &quot;&quot;, 0P, 25827408P, 25827408P) #(5908980P, 2048768P, 2048768P, &quot;CustSeparator&quot;, &quot;&quot;, 0P, 25827408P, 25827408P) #(19083138P, 2048768P, 2048768P, &quot;ComboBox&quot;, &quot;All&quot;, 0P, 25827408P, 25827408P) ...</p>\n\
<p>```</p>\n\
<p>In this case, the Main Toolbar of <strong>3ds Max</strong> is a docked window which has a HWND of 16990604, the <strong>3ds Max</strong> main window&#39;s HWND is 25827408, the class name of the Main Toolbar is &quot;#32770&quot; and the window text of the toolbar is &quot;Main Toolbar&quot;. It is owned by and rooted at the <strong>3ds Max</strong> window with HWND 25827408, which explains elements 6,7 and 8.</p>\n\
<p>The next element is the toolbar window itself which has a HWND of 2048768 and is parented to the Main Toolbar window with HWND 16990604. The class of the toolbar is &quot;CustToolbar&quot; and it does not display any text. It is not owned by a window (so the HWND is 0), but it is rooted at the <strong>3ds Max</strong> window with HWND 25827408.</p>\n\
<p>The next element is the first separator in the toolbar. It has a HWND of 8794706 and is parented to the custom toolbar with HWND of 2048768. Its class is &quot;CustSeparator&quot; and has no text associated with it. It has no owner and is rooted at the 3ds Max window.</p>\n\
<p>After that we get the first icon in the Main Toolbar with HWND 33762226. It is also parented to the custom toolbar with HWND of 2048768 and has the class &quot;CustButton&quot; and no text. It has no owner and is rooted at the 3ds Max window.</p>\n\
<p>After that come more buttons and separators. The one with HWND 19083138P is the Selection Filter ComboBox which displays &quot;All&quot; by default.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>windows.getChildHWND {&lt;int HWND&gt;| #max} &lt;string&gt; parent:{&lt;int HWND&gt;|#max}\n\
</pre></div><p>The mehod returns the child window of the specified HWND with the given child window&#39;s text. Child windows are recursively searched.</p>\n\
<p>If the specified HWND is 0, only the top level desktop windows are searched (not recursively).</p>\n\
<p>If the parent HWND is specified, only windows whose immediate parent is the specified window are searched.</p>\n\
<p>If <span class=\'code\'>#max</span> is specified as the HWND, the HWND associated with <strong>3ds Max</strong> main window is used.</p>\n\
<p>If the specified HWND does not exist, the value <span class=\'code\'>undefined</span> is returned.</p>\n\
<p>If a child window with the specified text is not found, <span class=\'code\'>undefined</span> is returned.</p>\n\
<p>The text comparison is <strong>case insensitive</strong>.</p>\n\
<p>If a match is found, an 8 element array is returned. See the documentation of the <strong><span class=\'code\'>windows.getChildrenHWND()</span></strong> method above for details on their meaning.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE, A PARTIAL RESULT FROM THE CALL</strong></p>\n\
<p>``` max file xref object -- open xref object dialog xro_hwnd = windows.getChildHWND 0 &quot;XRef Objects&quot; parent:#max -- find xref object dialog if xro_hwnd != undefined do windows.sendMessage xro_hwnd[1] 0x0010 0 0 -- if found, send close message max file xref scene -- open xref sceen dialog xrs_hwnd = windows.getChildHWND 0 &quot;XRef Scenes&quot; parent:#max -- find xref scene dialog if xrs_hwnd != undefined do windows.sendMessage xrs_hwnd[1] 0x0010 0 0 -- if found, send close message</p>\n\
<p>```</p>\n\
<p><strong>LISTENER OUTPUT:</strong></p>\n\
<p>``` OK #(25961156P, 65552P, 25827408P, &quot;#32770&quot;, &quot;XRef Objects&quot;, 25827408P, 25961156P, 25827408P) 1 OK #(26813124P, 65552P, 25827408P, &quot;#32770&quot;, &quot;XRef Scenes&quot;, 25827408P, 26813124P, 25827408P) 1</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>windows.getHWNDData {&lt;int HWND&gt;|#max}\n\
</pre></div><p>Returns data associated with the specified HWND.</p>\n\
<p>If <span class=\'code\'>#max</span> is specified as the HWND, the HWND associated with the <strong>3ds Max</strong> main window is used.</p>\n\
<p>If the specified HWND does not exist, the value undefined is returned.</p>\n\
<p>If a match is found, a 8 element array is returned. See the documentation of the <strong><span class=\'code\'>windows.getChildrenHWND()</span></strong> method above for details on their meaning.</p>\n\
<p>Available in <strong>3ds Max 2011 and higher</strong>.</p>\n\
<p>Note that in <strong>3ds Max 2011 and higher</strong>, rollouts and rollout controls expose a read-only <span class=\'code\'>.hwnd</span> property.</p>\n\
<p>In the case of a rollout, the property contains the Window&#39;s HWND associated with the rollout, or 0 if the rollout is not open.</p>\n\
<p>In the case of a rollout User Interface control, the property contains an array of the Window&#39;s HWND of the rollout containing the rollout, or an empty array of the rollout is not open.</p>\n\
<div class=\'codeBlock\'><pre>windows.setWindowPos &lt;int HWND&gt; &lt;int x&gt; &lt;int y&gt; &lt;int width&gt; &lt;int height&gt; &lt;bool repaint&gt; [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>]</p>\n\
<p>Set the position of the window specified by the HWND to the X and Y coordinates specified by the second and third arguments.</p>\n\
<p>Also set the Width and Height of the window to the values passed as fourth and fifth arguments.</p>\n\
<p>When the sixth argument is set to True, the window will also be repainted.</p>\n\
<p>The <span class=\'code\'>applyUIScaling</span> parameter indicates whether to apply scaling required on high DPI displays.</p>\n\
<p>Available in <strong>3ds Max 2014 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>windows.setWindowPos &lt;int HWND&gt; &lt;Box2 rect&gt; &lt;bool repaint&gt; [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Set the position of the window specified by the HWND to the coordinates and size given by the second Box2 argument.</p>\n\
<p>When the third argument is set to True, the window will also be repainted.</p>\n\
<p>The <span class=\'code\'>applyUIScaling</span> parameter, when set to true, applies any scaling required on HDPI displays.</p>\n\
<p>Available in <strong>3ds Max 2014 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Box2 rect&gt;windows.getWindowPos &lt;int HWND&gt; [ removeUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Returns the position of the upper left corner and the width and height of the window specified by the HWND argument.</p>\n\
<p>The position is expressed in screen coordinates relative to the upper-left corner of the screen.</p>\n\
<p>The <span class=\'code\'>removeUIScaling</span> parameter, when true, removes any scaling applied on HDPI displays.</p>\n\
<p>Available in <strong>3ds Max 2014 and higher</strong>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` rollout test1 &quot;Test&quot; ( button btn &quot;PRESS ME&quot; ) --a test rollout createDialog test1 200 50 120 140 --rollout, width, height, x, y windows.getWindowPos test1.hwnd --get the resulting position and size</p>\n\
<p>```</p>\n\
<p><strong>LISTENER OUTPUT:</strong></p>\n\
<p>``` Rollout:test1 true (Box2 120 140 206 75) --Note that the width and height include the borders and the title bar --and can vary depending on the Windows Theme used.</p>\n\
<p>```</p>\n\
<p><strong>NOW LET&#39;S MOVE AND RESIZE IT:</strong></p>\n\
<p><span class=\'code\'>windows.setWindowPos test1.hwnd 220 240 206 55 true</span></p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;Point2&gt;windows.clientToScreen &lt;int HWND&gt; &lt;int x&gt; &lt;int y&gt; [ applyUIScaling:&lt;true&gt; ]\n\
&lt;Point2&gt;windows.clientToScreen &lt;int HWND&gt; &lt;Point2 clientCoord&gt; [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Converts the coordinates from the Client space of the window specified by the first argument to coordinates relative to the upper left corner of the Screen.</p>\n\
<p>The <span class=\'code\'>applyUIScaling</span> parameter, when set to true, applies any scaling required on HDPI displays.</p>\n\
<p>Available in <strong>3ds Max 2014 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Point2&gt;windows.screenToClient &lt;int HWND&gt; &lt;int x&gt; &lt;int y&gt; [ applyUIScaling:&lt;true&gt; ]\n\
&lt;Point2&gt;windows.screenToClient &lt;int HWND&gt; &lt;Point2 screenCoord&gt; [ applyUIScaling:&lt;true&gt;] \n\
</pre></div><p>Converts the coordinates from Screen space relative to the upper left corner into Client space of the window specified by the first argument.</p>\n\
<p>The <span class=\'code\'>applyUIScaling</span> parameter, when set to true, applies any scaling required on HDPI displays.</p>\n\
<p>Available in <strong>3ds Max 2014 and higher</strong>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` tv = trackviews.getTrackView 1 --&gt;<mixininterface:trackview><p>\n\
<p>windows.getWindowPos tv.ui.hwnd --&gt;(Box2 244 242 1200 400)</p>\n\
<p>screenPos = windows.clientToScreen tv.ui.hwnd 10 20 --&gt;[262,312]</p>\n\
<p>windows.screenToClient tv.ui.hwnd screenPos.x screenPos.y --&gt;[10,20]</p>\n\
<p>windows.getWindowPos tv.ui.hwnd --&gt;(Box2 244 242 1200 400)</p>\n\
<p>windows.setWindowPos tv.ui.hwnd 0 0 1200 400 --&gt;true</p>\n\
<p>```</p>\n\
</mixininterface:trackview></blockquote>\n\
<div class=\'codeBlock\'><pre>windows.snapshot {&lt;int_HWND&gt;|#max} captureAlpha:&lt;boolean&gt; gammaCorrect:&lt;boolean&gt; captureScreenPixels:&lt;boolean&gt; \n\
</pre></div><p>Creates a Bitmap snapshot of the specified HWND.</p>\n\
<p>If the specified HWND is 0, a snapshot of the Windows Desktop will be taken.</p>\n\
<p>If the argument is set to <span class=\'code\'>#max</span> , the HWND associated with the 3ds Max main window will be used.</p>\n\
<p>If the <span class=\'code\'>captureAlpha:</span> optional keyword argument is specified and set to True, the viewport Alpha will also be captured. If not specified or set to False, the returned image will contain no Alpha and only the RGB channels.</p>\n\
<p>If the <span class=\'code\'>gammaCorrect:</span> optional keyword argument is not specified or set to True, gamma correction will be performed on the returned Bitmap value. If set to False, no gamma correction will be performed.</p>\n\
<p>If the <span class=\'code\'>captureScreenPixels:</span> optional keyword argument is set to True, the window desktop pixels will be captured within the region of the specified window.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` --Get a snapshot of the Windows Desktop: ssBitmap1 = windows.snapshot 0 display ssBitmap1 caption:&quot;Desktop Snapshot&quot;</p>\n\
<p>--Get a snapshot of the 3ds Max Main Window without gamma correction: ssBitmap2 = windows.snapshot #max gammaCorrect:False display ssBitmap2 caption:&quot;3ds Max Main Window&quot;</p>\n\
<p>--Get a snapshot of the active viewport: ssBitmap3 = windows.snapshot (viewport.getHWnd()) display ssBitmap3 caption:&quot;Active Viewport&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>See also <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Viewports/Accessing-Active-Viewport-Info.html\' title=\'\'>Viewport.GetViewportDib()</a> and <a href=\'#!/url=./developer/Interaction-With-The-Operating/GUID-1B088FF0-6A36-420E-9F37-F0DBE9FB2676.html#dib--device-independent-bitmap--methods\' title=\'\'>gw.getViewportDib()</a>.</p>\n\
<div class=\'codeBlock\'><pre>windows.addChild &lt;int_HWND&gt; &lt;int_HWND&gt;\n\
</pre></div><p>Makes an ActiveX control whose HWND is passed as first argument the child of the window with HWND passed as second argument.</p>\n\
<p>The first argument cannot be a MAXScript control or rollout, it must be an ActiveX control.</p>\n\
<p>Given that ActiveX controls are considered obsolete since <strong>3ds Max 9</strong>, this method can also be considered <strong>obsolete</strong>.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";