var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>DotNet Objects and Classes Life Time Control</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>DotNet Objects and Classes Life Time Control</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"dotnet-objects-and-classes-life-time-control\"></a></div>\n\
<p>In versions prior to <strong>3ds Max 2010</strong>, performing MAXScript garbage collection can delete the DotNet event handlers too early.</p>\n\
<p>With this method available in <strong>3ds Max 2010 and higher</strong>, this can be avoided by setting the life time control of the corresponding objects to be handled by DotNet instead of MAXScript.</p>\n\
<div class=\'codeBlock\'><pre>dotNet.setLifetimeControl {&lt;dotNetObject&gt; | &lt;dotNetClass&gt;} {#mxs | #dotnet}\n\
</pre></div><p>Controls whether the MAXScript value wrapping the DotNet object or DotNetclass can be garbage collected when there are no MAXScript references to the value ( <span class=\'code\'>#mxs</span> ), or whether the DotNet object is destroyed before the MAXScript value can be garbage collected ( <span class=\'code\'>#dotnet</span> ).</p>\n\
<p>By default, a dotNetObject value holds a <strong>strong reference</strong> to the DotNet object, and the DotNet object is deleted only when the dotNetObject value is deleted. This is equivalent to specifying <span class=\'code\'>#mxs</span> as second argument in the above method.</p>\n\
<p>If you specify <span class=\'code\'>#dotnet</span> as the second argument, the dotNetObject cannot be collected until the DotNet object is deleted. The dotNetObject value holds a weak reference to the DotNet object and the DotNet object is deleted when no other DotNet objects hold a reference to it and a DotNet garbage collection occurs.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE 1 - HANDLERS DELETED</strong></p>\n\
<p>``` ( function whenButtonIsPressed = ( print &quot;Pressed from a .NET button&quot; ) function formIsClosed = ( print &quot;form closed&quot; ) local mButton = dotNetObject &quot;System.windows.forms.button&quot; mButton.text = &quot;.NET Button&quot; mButton.size = dotNetObject &quot;System.Drawing.Size&quot; 100 100 mButton.location = dotNetObject &quot;System.Drawing.Point&quot; 50 50 local hForm = dotNetObject &quot;System.Windows.Forms.Form&quot; hForm.controls.add mButton dotNet.addEventHandler mButton &quot;click&quot; whenButtonIsPressed dotNet.addEventHandler hForm &quot;Closed&quot; formIsClosed hForm.show() ok ) gc()</p>\n\
<p>```</p>\n\
<p>Evaluating the above code creates a DotNet Form with a DotNet button and two event handlers - one to print a message to the Listener when the button is pressed and one to print a message when the Form is closed.</p>\n\
<p>Because of the MAXScript Garbage Collection performed after the creation of the Form, both handlers are deleted immediately and nothing is printed when pressing the button or closing the form.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>EXAMPLE2 - HANDLERS PRESERVED</strong></p>\n\
<p>By switching the life time control of the button and the form to DotNet, it is ensured that the event handlers of both buttons are preserved after a MAXScript Garbage Collection:</p>\n\
<p>``` ( function whenButtonIsPressed = ( print &quot;Pressed from a .NET button&quot; ) function formIsClosed = ( print &quot;form closed&quot; ) local mButton = dotNetObject &quot;System.windows.forms.button&quot; mButton.text = &quot;.NET Button&quot; mButton.size = dotNetObject &quot;System.Drawing.Size&quot; 100 100 mButton.location = dotNetObject &quot;System.Drawing.Point&quot;50 50 local hForm = dotNetObject &quot;System.Windows.Forms.Form&quot; hForm.controls.add mButton dotNet.addEventHandler mButton &quot;click&quot; whenButtonIsPressed dotNet.addEventHandler hForm &quot;Closed&quot; formIsClosed dotNet.setLifetimeControl mButton #dotnet dotNet.setLifetimeControl hForm #dotnet hForm.show() ok ) gc()</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";