var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>MAXScript / DotNet Value Conversions</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>MAXScript / DotNet Value Conversions</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"maxscript-dotnet-value-conversions\"></a></div>\n\
<p>MAXScript will automatically convert its native values to DotNet values and DotNet values to MAXScript values.</p>\n\
<p>In addition, value conversion can be performed explicitly using a dedicated function in <strong>3ds Max 2010 and higher</strong>.</p>\n\
<div class=\'section\'><a id=\"automatic-conversion\"></a><h3 id=\"automatic-conversion\">Automatic Conversion</h3></div>\n\
<p>The following table shows the native MAXScript value types and the converted DotNet value types in <strong>3ds Max 9 and higher</strong>.</p>\n\
<p>|MAXScript type|DotNet type| |--- |--- | |Integer, Integer64, IntegerPtr, Float, Double, MSTime|Byte, SByte, Decimal, Int16, UInt16, Int32, UInt32, IntPtr, UIntPtr, Int64, UInt64, Single, Double| |Boolean|Boolean| |String|String, Char array|</p>\n\
<p>The following table shows the DotNet value types and the converted native MAXScript value types.</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">DotNet type</th>\n\
<th align=\"left\">MAXScript type</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">Byte, SByte, Decimal,</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">Int16, UInt16, Int32, UInt32</td>\n\
<td align=\"left\">Integer</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">Int64, UInt64</td>\n\
<td align=\"left\">Integer64</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">IntPtr, UIntPtr</td>\n\
<td align=\"left\">IntegerPtr</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">Single</td>\n\
<td align=\"left\">Float</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">Double</td>\n\
<td align=\"left\">Double</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">Boolean</td>\n\
<td align=\"left\">Boolean</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">String, Char array</td>\n\
<td align=\"left\">String</td>\n\
</tr>\n\
</table>\n\
<div class=\'section\'><a id=\"explicit-conversion\"></a><h3 id=\"explicit-conversion\">Explicit Conversion</h3></div>\n\
<p>The following method performs a conversion of a MAXScript value to a DotNet value.</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>dotNet.ValueToDotNetObject &lt;value&gt; { &lt;dotNetClass&gt; | &lt;dotNetObject&gt; }\n\
</pre></div><p>Returns a dotNetObject value where the MAXScript value passed as first argument is converted to a DotNet object of the type specified by the second argument.</p>\n\
<p>Available in <strong>3ds Max 2018.2 Update and higher</strong>: Some native MAXScript types are converted into .NET arrays, as some .NET libraries do not support these types natively. <strong>Point2</strong>, <strong>Point3</strong>, <strong>Point4</strong>, <strong>Quat</strong>, <strong>EulerAngles</strong>, and <strong>Matrix3</strong> types are all converted into <span class=\'code\'>float\\[\\]</span> or <span class=\'code\'>double\\[\\]</span> arrays.</p>\n\
<p>Note: EulerAngles are displayed in degrees, but are stored internally as radians, so the converted .NET values are in radians.</p>\n\
<p>This allows for the easy creation of DotNet arrays from MAXScript arrays:</p>\n\
<div class=\'codeBlock\'><pre>&lt;value&gt; dotnet.DotNetArrayToValue &lt;dotNetObject&gt; &lt;Matrix3 | Point2 | Point3 | Point4 | Quat | EulerAngles&gt;\n\
</pre></div><p>Available in <strong>3ds Max 2018.2 Update and higher</strong>: Converts the .net array to a value of the specified mxs value type. The .net arrays must be of type float or double. For Matrix3, the .net array must be of size [4,4] , for Point2 it must be of size [2] , for Point3 and EulerAngles it must be of size [3] , and for Point4 and Quat it must be of size [4] .</p>\n\
<div class=\'codeBlock\'><pre>&lt;value&gt; dotnet.DotNetObjectToValue &lt;dotNetObject&gt;\n\
</pre></div><p>Available in <strong>3ds Max 2018.2 Update and higher</strong>: Converts the .NET object to a MAXScript value.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES</strong></p>\n\
<p>``` type = dotNetClass &quot;System.Int32[]&quot; --&gt; dotNetClass:System.Int32[] res = dotnet.ValueToDotNetObject #(11,12,23) type --&gt; dotNetObject:System.Int32[] res.length --&gt; 3 res.getvalue 2 --DotNet arrays are zero-based. --&gt; 23</p>\n\
<p>```</p>\n\
<p><span class=\'code\'>typef = dotnetclass &quot;System.Single[]&quot; --&gt; dotNetClass:System.Single[]   vf = dotnet.ValueToDotNetObject x_axis typef --&gt; dotNetObject:System.Single[]   vf.get 0 --&gt; 1.0   typed = dotnetclass &quot;System.Double[]&quot; --&gt; dotNetClass:System.Double[]   vd = dotnet.ValueToDotNetObject x_axis typed --&gt; dotNetObject:System.Double[]   vd.get 0 --&gt; 1.0d0   typefa = dotnetclass &quot;System.Single[][]&quot; --&gt; dotNetClass:System.Single[][]   vfa = dotnet.ValueToDotNetObject #([1,2],        [1,2,3],        [1,2,3,4],       (quat 0.854433 0.00437304 0.0050751 0.519518),        (eulerAngles -117.399 -0.757267 0.126046)        )  typefa  --&gt; dotNetObject:System.Single[]   vfa0 = vfa.get 0 --&gt; #(1.0, 2.0)   vfa1 = vfa.get 1 --&gt; #(1.0, 2.0, 3.0)   vfa2 = vfa.get 2 --&gt; #(1.0, 2.0, 3.0, 4.0)   vfa3 = vfa.get 3 --&gt; #(0.854433, 0.00437304, 0.0050751, 0.519518)   vfa4 = vfa.get 4 --&gt; #(-2.049, -0.0132168, 0.00219992)</span></p>\n\
<p>``` typef2 = dotnetclass &quot;System.Single[]&quot; vfa2 = dotnet.ValueToDotNetObject (matrix3 [0.99991,0.0127462,0.00412892] [0.00219972,-0.460163,0.887832] [0.0132164,-0.887743,-0.46015] [90,0,-45]) typef2 --&gt; dotNetClass:System.Single[,] vfa2.get 0 0 --&gt; 0.99991</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";