var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>dotNet Generics</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>dotNet Generics</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"dotnet-generics\"></a></div>\n\
<p>.NET generic classes and methods can be specialized to specific types in MAXScript by using <span class=\'code\'>Type.MakeGenericType</span> and <span class=\'code\'>MethodInfo.MakeGenericMethod()</span>. These .NET methods create a type-specific version of a type or method. For example, if you run:</p>\n\
<div class=\'codeBlock\'><pre>callSiteOps = (dotNetClass &quot;System.Runtime.CompilerServices.CallSiteOps&quot;)\n\
showmethods callSiteOps\n\
</pre></div><p>You will get:</p>\n\
<div class=\'codeBlock\'><pre>.[static]AddRule &lt;CallSite`1&gt;site &lt;T&gt;rule\n\
.[static]&lt;T&gt;Bind &lt;System.Runtime.CompilerServices.CallSiteBinder&gt;binder &lt;CallSite`1&gt;site &lt;System.Object[]&gt;args\n\
.[static]ClearMatch &lt;System.Runtime.CompilerServices.CallSite&gt;site\n\
.[static]&lt;System.Runtime.CompilerServices.CallSite`1[T]&gt;CreateMatchmaker &lt;CallSite`1&gt;site\n\
.[static]&lt;System.Boolean&gt;Equals &lt;System.Object&gt;objA &lt;System.Object&gt;objB\n\
.[static]&lt;T[]&gt;GetCachedRules &lt;RuleCache`1&gt;cache\n\
.[static]&lt;System.Boolean&gt;GetMatch &lt;System.Runtime.CompilerServices.CallSite&gt;site\n\
.[static]&lt;System.Runtime.CompilerServices.RuleCache`1[T]&gt;GetRuleCache &lt;CallSite`1&gt;site\n\
.[static]&lt;T[]&gt;GetRules &lt;CallSite`1&gt;site\n\
.[static]MoveRule &lt;RuleCache`1&gt;cache &lt;T&gt;rule &lt;System.Int32&gt;i\n\
.[static]&lt;System.Boolean&gt;ReferenceEquals &lt;System.Object&gt;objA &lt;System.Object&gt;objB\n\
.[static]&lt;System.Boolean&gt;SetNotMatched &lt;System.Runtime.CompilerServices.CallSite&gt;site\n\
.[static]UpdateRules &lt;CallSite`1&gt;this &lt;System.Int32&gt;matched\n\
true\n\
</pre></div><p>As you can see from the output, the line <span class=\'code\'>\\[static\\]AddRule &lt;CallSite`1&gt;site &lt;T&gt;rule</span> indicates that the AddRule(<span class=\'code\'>&lt;T&gt;</span>) method is a generic method. If you wanted a MAXScript version of this method that works with System.String, you would first get the method as a dotNetObject, and then specialize it so that <span class=\'code\'>&lt;T&gt;</span> is System.String:</p>\n\
<div class=\'codeBlock\'><pre>addRuleGeneric = getproperty callSiteOps &quot;AddRule&quot; asdotnetobject:true\n\
addRuleStringType = addRuleGeneric.MakeGenericMethod #(dotNetClass &quot;System.String&quot;)\n\
</pre></div><p>The AddRule() method takes 2 arguments, an instance of a templated class &#39;CallSite&#39; and an instance of the specialized class . Looking at the <a href=\'https://docs.microsoft.com/en-us/dotnet/api/system.runtime.compilerservices.callsiteops?view=netframework-4.8\' title=\'\' target=\'_blank\'>CallSite documentation</a>, you will see the method is documented as</p>\n\
<p><span class=\'code\'>AddRule&lt;T&gt;(CallSite&lt;T&gt;, T)</span></p>\n\
<p>Adds a rule to the cache maintained on the dynamic call site.</p>\n\
<p>In the MAXScript showmethods output, note the first arg is listed as <span class=\'code\'>&lt;CallSite`1&gt;site</span>. This means that the argument is an instance of a generic class that is templated with a single Type (indicated by the `1 in the class name). Therefore in the documentation it is shown as <span class=\'code\'>CallSite&lt;T&gt;</span>.</p>\n\
<p>If the generic class was templated with two Types, it would be &#39;2. An example of a class templated with two Types is:</p>\n\
<p><span class=\'code\'>System.Collections.Generic.Dictionary&lt;TKey,TValue&gt;</span></p>\n\
<p>Which in MAXScript looks like:</p>\n\
<div class=\'codeBlock\'><pre>d = dotnetclass &quot;System.Collections.Generic.Dictionary`2&quot;\n\
dotnet.showConstructors d\n\
</pre></div><p>The showConstructors yields:</p>\n\
<div class=\'codeBlock\'><pre>System.Collections.Generic.Dictionary`2()\n\
System.Collections.Generic.Dictionary`2 &lt;IDictionary`2&gt;dictionary\n\
System.Collections.Generic.Dictionary`2 &lt;IEqualityComparer`1&gt;comparer\n\
System.Collections.Generic.Dictionary`2 &lt;System.Int32&gt;capacity\n\
System.Collections.Generic.Dictionary`2 &lt;System.Int32&gt;capacity &lt;IEqualityComparer`1&gt;comparer\n\
System.Collections.Generic.Dictionary`2 &lt;IDictionary`2&gt;dictionary &lt;IEqualityComparer`1&gt;comparer\n\
</pre></div><p>By using the following code, you create a instance of a dictionary where <span class=\'code\'>TKey</span> is System.String and <span class=\'code\'>TValue</span> is System.Int32:</p>\n\
<div class=\'codeBlock\'><pre>genericType = dotnet.GetType &quot;System.Collections.Generic.Dictionary`2&quot;\n\
innerType1 = dotnet.GetType &quot;System.String&quot;\n\
innerType2 = dotnet.GetType &quot;int&quot;\n\
specificType = genericType.MakeGenericType #(innerType1, innerType2)\n\
theDict = (dotnetclass &quot;System.Activator&quot;).CreateInstance specificType\n\
</pre></div><p>This calls constructor:</p>\n\
<p><span class=\'code\'>System.Collections.Generic.Dictionary`2()</span></p>\n\
<p>This code:</p>\n\
<p><span class=\'code\'>theDict = (dotnetclass &quot;System.Activator&quot;).CreateInstance specificType #(32)</span></p>\n\
<p>Calls the constructor:</p>\n\
<p><span class=\'code\'>System.Collections.Generic.Dictionary`2 &lt;System.Int32&gt;capacity</span></p>\n\
<p>If the constructor took more than one argument, the additional arguments would be specified as additional elements in the array.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";