var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>dotNet Struct Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>dotNet Struct Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"dotnet-struct-methods\"></a></div>\n\
<p>The dotNet <strong>Struct</strong> provides additional MAXScript methods for managing dotNet objects, classes, assemblies, event handlers, and others.</p>\n\
<p>Available in <strong>3ds Max 9</strong> and higher.</p>\n\
<div class=\'section\'><a id=\"assembly-loading\"></a><h3 id=\"assembly-loading\">Assembly Loading:</h3></div>\n\
<div class=\'codeBlock\'><pre>&lt;dotNetObject&gt;dotNet.loadAssembly &lt;assembly&gt; [returnPassFail:bool]\n\
</pre></div><p>This method loads the specified assembly. The assembly can be specified as an assembly name or the filename of the dll containing the assembly.</p>\n\
<p>The method first attempts to load an assembly from the application directory or from the global assembly cache using the assembly name. If that fails, a dll with the assembly name is searched in the directory containing the primary .net assemblies.</p>\n\
<p>If <strong>returnPassFail</strong> is false (the default), the assembly is found and successfully loaded, a dotNetObject value wrapping the .net assembly value is returned, otherwise a value of undefined is returned. If <strong>returnPassFail</strong> is true, this method returns true if the assembly is loaded, false if not.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` dotnet.loadAssembly &quot;system.xml&quot; dotnet.loadAssembly &quot;system.xml.dll&quot; dotnet.loadAssembly &quot;C:\\WINDOWS\\Microsoft.NET\\Framework\\v2.0.50727\\system.xml.dll&quot; dotnet.loadAssembly &quot;C:\\WINDOWS\\Microsoft.NET\\Framework\\v2.0.50727\\system.xml&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note:</p>\n\
<p>You can do the same by using the existing dotNet classes:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` assembly = dotNetClass &quot;System.Reflection.Assembly&quot; r = assembly.loadfrom &quot;F:\\FlashTrackBar\\bin\\Debug\\FlashTrackBar.dll&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"icon-loading\"></a><h3 id=\"icon-loading\">Icon Loading:</h3></div>\n\
<div class=\'codeBlock\'><pre>dotNet.LoadIcon &lt;iconName&gt; iconSize:&lt;point2&gt; enabled:&lt;boolean&gt; on:&lt;boolean&gt; applyUIScaling:&lt;boolean&gt;\n\
</pre></div><p>Returns a <span class=\'code\'>System::Drawing::Icon</span> if the icon is found, undefined if not. Available in <strong>in 3ds Max 2017 and higher</strong>.</p>\n\
<p>The <span class=\'code\'>iconName</span> is the path to an icon file, or previously loaded icon resource.</p>\n\
<p>The <span class=\'code\'>iconSize</span> is the size of the icon at 100% DPI scaling. The default is [24,24] if not specified.</p>\n\
<p>The <span class=\'code\'>enabled</span> parameter specifies which version (enabled or disabled) of the icon to load.</p>\n\
<p>The <span class=\'code\'>on</span> parameter specifies which version (on or off) of the icon to load.</p>\n\
<p>The <span class=\'code\'>applyUIScaling</span> specifies whether to apply scaling to the icon on High DPI displays. The default is true.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` hForm = dotNetObject &quot;System.Windows.Forms.Form&quot; dotNetIcon = dotnet.loadIcon(&quot;PolyTools\\TransformTools\\PB_CW&quot;) hForm.Icon = dotNetIcon --set the title bar icon of the form hForm.show() --Result: an empty form with a clockwise rotation arrow as icon</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"event-handlers\"></a><h3 id=\"event-handlers\">Event Handlers:</h3></div>\n\
<div class=\'codeBlock\'><pre>dotNet.addEventHandler &lt;dotNetControl&gt; &lt;EventNameString&gt; &lt;function&gt;\n\
</pre></div><p>This method adds an event handler to the dotNetControl passed as the first argument.</p>\n\
<p>The second argument specifies the event name as string. The list of all available events for a given dotNetControl can be acquired by calling showEvents() on the dotNetControl value.</p>\n\
<p>The third argument is the custom MAXScript function to be called when the event is triggered.</p>\n\
<p>If the custom MAXScript function called by the handler expects two arguments, the first argument must contain the sender and the second the eventArg.</p>\n\
<p>If the event handler function specifies only one argument, then only the eventArg is passed.</p>\n\
<p>If the event handler function does not specify any arguments, none are passed.</p>\n\
<p>See the example further on this page for details.</p>\n\
<p>Note: You can register multiple functions with differing number of arguments for the same event using <span class=\'code\'>dotNet.addEventHandler()</span> .</p>\n\
<p>Note: You can only add functions that are registered in the global scope as event handlers. If you need to register a function that is hidden from the global scop (for example, contained in a struct), you need to define a global function to point to the hidden function.</p>\n\
<blockquote>\n\
<p><strong>Example</strong></p>\n\
<p>``` struct dotNetStruct ( myForm = dotNetObject &quot;system.windows.forms.form&quot;, myButton = dotNetObject &quot;system.windows.forms.button&quot; )</p>\n\
<p>ui = dotNetStruct()</p>\n\
<p>ui.myForm.width = 100 ui.myForm.height = 100 ui.myButton.text = &quot;Say Something&quot; ui.myForm.controls.add ui.myButton</p>\n\
<p>-- A function &quot;hidden&quot; in a global struct struct functionStruct ( fn printSomething a b = ( print &quot;something&quot; ) )</p>\n\
<p>myFunctionStruct = functionStruct()</p>\n\
<p>--- Create a new function in global scope to point to our &quot;hidden&quot; function fn theFunctionPrint a b = myFunctionStruct.printSomething a b</p>\n\
<p>DotNet.AddEventHandler ui.mybutton &quot;click&quot; theFunctionPrint</p>\n\
<p>ui.myForm.show() ```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>dotNet.removeAllEventHandlers &lt;dotNetControl&gt;\n\
</pre></div><p>Removes all event handlers from the specified dotNetControl.</p>\n\
<div class=\'codeBlock\'><pre>dotNet.removeEventHandler &lt;dotNetControl&gt; &lt;EventNameString&gt; &lt;function&gt;\n\
</pre></div><p>Removes the specified event handler function from the given dotNetControl and event.</p>\n\
<p>The arguments list is the same as the <span class=\'code\'>dotNet.addEventHandler()</span> .</p>\n\
<p>The callback function is specified as the third argument because there can be multiple functions registered with the same event (see note above).</p>\n\
<p>To remove all functions registered with a given event, see the following method:</p>\n\
<div class=\'codeBlock\'><pre>dotNet.removeEventHandlers &lt;dotNetControl&gt; &lt;EventNameString&gt;\n\
</pre></div><p>Removes all functions registered with the specified event of the dotNetControl.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` ( fn buttonPressed1 a1 a2 = ( print &quot;1. Button Pressed - Two Arguments&quot; print a1 print a2 ) fn buttonPressed2 a1 = ( print &quot;2. Button Pressed - One Argument&quot; print a1 ) fn buttonPressed3 = ( print &quot;3. Button Pressed - No Arguments&quot; ) fn mouseEnter4 = ( print &quot;4. Mouse Entered The Button!&quot; ) fn mouseLeave5 = ( print &quot;5. Mouse Left The Button!&quot; ) local mButton = dotNetObject &quot;System.windows.forms.button&quot; mButton.text = &quot;Press Me&quot; mButton.size = dotNetObject &quot;System.Drawing.Size&quot; 100 100 mButton.location = dotNetObject &quot;System.Drawing.Point&quot; 10 10 local hForm = dotNetObject &quot;System.Windows.Forms.Form&quot; hForm.size = dotNetObject &quot;System.Drawing.Size&quot; 120 140 hForm.controls.add mButton dotNet.addEventHandler mButton &quot;click&quot; buttonPressed1 dotNet.addEventHandler mButton &quot;click&quot; buttonPressed2 dotNet.addEventHandler mButton &quot;click&quot; buttonPressed3 dotNet.addEventHandler mButton &quot;MouseEnter&quot; mouseEnter4 dotNet.addEventHandler mButton &quot;MouseLeave&quot; mouseLeave5 hForm.show() ok )</p>\n\
<p>```</p>\n\
<p>If you evaluate the above script, move the mouse over the button, click it, move the mouse away from the button, and then back in and out, the Listener output appears as follows:</p>\n\
<p>``` OK &quot;4. Mouse Entered The Button!&quot; &quot;1. Button Pressed - Two Arguments&quot; dotNetObject:System.Windows.Forms.Button dotNetObject:System.Windows.Forms.MouseEventArgs &quot;2. Button Pressed - One Argument&quot; dotNetObject:System.Windows.Forms.MouseEventArgs &quot;3. Button Pressed - No Arguments&quot; &quot;5. Mouse Left The Button!&quot; &quot;4. Mouse Entered The Button!&quot; &quot;5. Mouse Left The Button!&quot;</p>\n\
<p>```</p>\n\
<p>Adding the following line to the first (buttonPressed1) function causes the first on Click event handler to be removed after the first click on the button. Clicking a second time prints only the second and third functions to the Listener.</p>\n\
<p>Within the function, the a1 argument contains the &quot;sender&quot;, or the dotNetControl whose event was triggered.</p>\n\
<p>``` dotNet.removeEventHandlers a1 &quot;click&quot; buttonPressed1</p>\n\
<p>```</p>\n\
<p>``` OK &quot;4. Mouse Entered The Button!&quot; &quot;1. Button Pressed - Two Arguments&quot; dotNetObject:System.Windows.Forms.Button dotNetObject:System.Windows.Forms.MouseEventArgs &quot;3. Button Pressed - No Arguments&quot; &quot;2. Button Pressed - One Argument&quot; dotNetObject:System.Windows.Forms.MouseEventArgs &quot;3. Button Pressed - No Arguments&quot; &quot;2. Button Pressed - One Argument&quot; dotNetObject:System.Windows.Forms.MouseEventArgs &quot;3. Button Pressed - No Arguments&quot; &quot;5. Mouse Left The Button!&quot; --additional clicks result in no output from function 1 --but all others work</p>\n\
<p>```</p>\n\
<p>Adding the following line to the first (buttonPressed1) function causes all on Click event handlers to be removed after the first click on the button.</p>\n\
<p>Clicking a second time does not print anything to the Listener, but when the mouse moves in and out, the other two functions are printed.</p>\n\
<p>``` dotNet.removeEventHandlers a1 &quot;click&quot;</p>\n\
<p>```</p>\n\
<p>``` OK &quot;4. Mouse Entered The Button!&quot; &quot;1. Button Pressed - Two Arguments&quot; dotNetObject:System.Windows.Forms.Button dotNetObject:System.Windows.Forms.MouseEventArgs &quot;2. Button Pressed - One Argument&quot; dotNetObject:System.Windows.Forms.MouseEventArgs &quot;3. Button Pressed - No Arguments&quot; &quot;5. Mouse Left The Button!&quot; &quot;4. Mouse Entered The Button!&quot; &quot;5. Mouse Left The Button!&quot; --additional clicks result in no output --but moving the mouse prints to the Listener</p>\n\
<p>```</p>\n\
<p>Adding the following line to the first (buttonPressed1) function causes all event handlers to be removed after the first click on the button including the on Click, on MouseEnter, and on MouseLeave events.</p>\n\
<p>``` dotNet.removeAllEventHandlers a1</p>\n\
<p>```</p>\n\
<p>``` OK &quot;4. Mouse Entered The Button!&quot; &quot;1. Button Pressed - Two Arguments&quot; dotNetObject:System.Windows.Forms.Button dotNetObject:System.Windows.Forms.MouseEventArgs &quot;2. Button Pressed - One Argument&quot; dotNetObject:System.Windows.Forms.MouseEventArgs &quot;3. Button Pressed - No Arguments&quot; --additional clicks result in no output</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"additional-inspector-functions\"></a><h3 id=\"additional-inspector-functions\">Additional Inspector Functions:</h3></div>\n\
<div class=\'codeBlock\'><pre>dotNet.showConstructors [&lt;dotNetClass&gt; | &lt;dotNetObject&gt; | &lt;dotNetControl&gt;] [to:&lt;stream&gt;]\n\
</pre></div><p>Displays the constructors exposed by the specified DotNetClass, DotNetObject, or DotNetControl.</p>\n\
<p>If <span class=\'code\'>to</span> is not specified, the output goes to Listerner, otherwise the output goes to the specified stream.</p>\n\
<div class=\'codeBlock\'><pre>dotNet.getType&lt;type_string&gt;\n\
</pre></div><p>Returns a dotNetObject value that wraps the System:Type specified by the type string.</p>\n\
<div class=\'section\'><a id=\"enums\"></a><h3 id=\"enums\">Enums:</h3></div>\n\
<div class=\'codeBlock\'><pre>dotnet.combineEnums {&lt;dotNetObject&gt; | &lt;number&gt;}+\n\
</pre></div><p>Combines System::Enum-derived objects that are to be treated as bit fields (these have a FlagsAttribute). The System::Enum-derived objects must all be of the same type. The return value is of that type. If a number is specified, at least one System::Enum-derived object must also be specified (to provide the type).</p>\n\
<div class=\'codeBlock\'><pre>dotnet.CompareEnums{&lt;dotNetObject&gt; | &lt;number&gt;} {&lt;dotNetObject&gt; | &lt;number&gt;}\n\
</pre></div><p>Performs bit-wise comparison of the two value. Returns true if at least one corresponding bit is set in each value.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` BindingFlags= dotNetClass &quot;System.Reflection.BindingFlags&quot; --&gt; dotNetClass:System.Reflection.BindingFlags BindingFlags.Static.value__ --&gt; 8 BindingFlags.Public.value<strong> --&gt; 16 BindingFlags.FlattenHierarchy.value</strong> --&gt; 64 res = dotNet.combineEnums BindingFlags.Static BindingFlags.Public 2 --&gt; dotNetObject:System.Reflection.BindingFlags res.value__ --&gt; 26 dotNet.compareEnums res 1 --&gt; false dotNet.compareEnums res BindingFlags.Static --&gt; true dotNet.compareEnums res BindingFlags.Public --&gt; true dotNet.compareEnums res BindingFlags.FlattenHierarchy --&gt; false</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"value-conversion\"></a><h3 id=\"value-conversion\">Value Conversion:</h3></div>\n\
<div class=\'codeBlock\'><pre>dotNet.ValueToDotNetObject &lt;value&gt; { &lt;dotNetClass&gt; | &lt;dotNetObject&gt; }\n\
</pre></div><p>See <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/MAXScript-DotNet-Value.html\' title=\'\'>MAXScript / DotNet Value Conversions</a> for details.</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<div class=\'section\'><a id=\"life-time-control\"></a><h3 id=\"life-time-control\">Life Time Control:</h3></div>\n\
<div class=\'codeBlock\'><pre>dotNet.setLifetimeControl {&lt;dotNetObject&gt; | &lt;dotNetClass&gt;} {#mxs | #dotnet}\n\
</pre></div><p>See <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/DotNet-Objects-and-Classes-Life.html\' title=\'\'>DotNet Objects and Classes Life Time Control</a> details.</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";