var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>dotnetclass</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>dotnetclass</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"dotnetclass\"></a></div>\n\
<p>In <strong>3ds Max 9</strong> and higher, the <span class=\'code\'>dotNetClass</span> wraps a DotNet <span class=\'code\'>System::Type</span> and exposes the static properties, methods, and events associated with the class via reflection.</p>\n\
<p>Property access uses MAXScript number data types (widened as necessary), String, Boolean, dotNetControl, dotNetObject, and dotNetClass values. Properties are accessed via the normal property access specification [control.property] and <span class=\'code\'>getProperty()</span> / <span class=\'code\'>setProperty()</span> methods.</p>\n\
<p>Accessing a class method will create a <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/dotNetMethod.html\' title=\'\'>dotNetMethod</a> instance, or optionally a <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/dotnetobject.html\' title=\'\'>dotNetObject</a> wrapping the RuntimeMethodInfo instance.</p>\n\
<p>New methods are used to add and manage event handlers. These methods register and unregister callback functions to be called when the event is fired. The arguments passed back to the functions will include the class, the event name, and the arguments passed by the event handler. See <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/dotNet-Struct-Methods.html\' title=\'\'>dotNet Struct Methods</a> for details.</p>\n\
<p>Note:</p>\n\
<p>There is a difference between a dotNetClass and a <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/dotnetobject.html\' title=\'\'>dotNetObject</a> that wraps the same type.</p>\n\
<p>Accessing the dotNetClass accesses the System::Type while accessing the dotNetObject access the object type described by the System::Type.</p>\n\
<p>So, for example, if you called showProperties() on a dotNetObject you will get the properties of the System::Type the dotNetObject wraps, but on a dotNetClass that wraps the same type you will get the properties of System::Type itself.</p>\n\
<p><strong>Constructor:</strong></p>\n\
<div class=\'codeBlock\'><pre>dotNetClass {&lt;dotNetObject&gt; | &lt;dotNetControl&gt; | &lt;class_type_string&gt; | &lt;c_sharp_type_string&gt; }\n\
</pre></div><p>Constructs a dotNetClass object. If the argument is a dotNetObject or dotNetControl object, the dotNetClass will wrap the System::Type of that object. If the argument is a string, MXS will attempt to resolve the string as a System::Type name.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` theClass = dotNetClass &quot;System.Drawing.Size&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>This resolution is done using the following steps:</strong></p>\n\
<p>1. Attempt to resolve as a fully qualified name. A fully qualified name includes both the class name and the assembly name.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` dotNetClass &quot;System.Windows.Forms.MonthCalendar, System.Windows.Forms, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>2. Attempt to resolve as a class name by looking for the name in each assembly loaded into the current AppDomain.</p>\n\
<p>3. If no match is found, the name is prepended with &quot;System.&quot; and another attempt will be made.</p>\n\
<p>4. If no match is found, the name is prepended with &quot;System.Windows.Forms.&quot; and another attempt will be made.</p>\n\
<p>5. Finally, an attempt is made to match against built-in C# data type names to the matching .NET system type. The mappings are:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">C# Built-in Type Name</th>\n\
<th align=\"left\">.NET Framework Type</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>bool</span></td>\n\
<td align=\"left\"><span class=\'code\'>System.Boolean</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>byte</span></td>\n\
<td align=\"left\"><span class=\'code\'>System.Byte</span></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>sbyte</span></td>\n\
<td align=\"left\"><span class=\'code\'>System.SByte</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>char</span></td>\n\
<td align=\"left\"><span class=\'code\'>System.Char</span></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>decimal</span></td>\n\
<td align=\"left\"><span class=\'code\'>System.Decimal</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>float</span></td>\n\
<td align=\"left\"><span class=\'code\'>System.Single</span></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>int</span></td>\n\
<td align=\"left\"><span class=\'code\'>System.Int32</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>uint</span></td>\n\
<td align=\"left\"><span class=\'code\'>System.UInt32</span></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>long</span></td>\n\
<td align=\"left\"><span class=\'code\'>System.Int64</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>ulong</span></td>\n\
<td align=\"left\"><span class=\'code\'>System.UInt64</span></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>object</span></td>\n\
<td align=\"left\"><span class=\'code\'>System.Object</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>short</span></td>\n\
<td align=\"left\"><span class=\'code\'>System.Int16</span></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>ushort</span></td>\n\
<td align=\"left\"><span class=\'code\'>System.UInt16</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>string</span></td>\n\
<td align=\"left\"><span class=\'code\'>System.String</span></td>\n\
</tr>\n\
</table>\n\
<div class=\'section\'><a id=\"example\"></a><h3 id=\"example\">Example</h3></div>\n\
<div class=\'codeBlock\'><pre>type = dotnetclass &quot;bool[]&quot; --&gt; dotNetClass:System.Boolean[]\n\
v = dotnet.ValueToDotNetObject #(false,true) type --&gt; dotNetObject:System.Boolean[]\n\
v.get 0 --&gt; false\n\
type = dotnetclass &quot;byte[]&quot; --&gt; dotNetClass:System.Byte[]\n\
v = dotnet.ValueToDotNetObject #(1,2) type --&gt; dotNetObject:System.Byte[]\n\
v.get 0 --&gt; 1\n\
type = dotnetclass &quot;char[]&quot; --&gt; dotNetClass:System.Char[]\n\
v = dotnet.ValueToDotNetObject #(&quot;A&quot;,&quot;B&quot;) type --&gt; dotNetObject:System.Char[]\n\
v.get 0 --&gt; &quot;A&quot;\n\
</pre></div><p>Note: C# built-in type string matching was introduced in <strong>3ds Max 2018.2 Update</strong>.</p>\n\
<p>Assemblies can be loaded to the Current AppDomain. See the <span class=\'code\'>dotNet.LoadAssembly()</span> method in <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/dotNet-Struct-Methods.html\' title=\'\'>dotNet Struct Methods</a></p>\n\
<p>An example of adding an assembly to the current AppDomain via methods exposed by the dotNetClass itself:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` assembly = dotNetClass &quot;System.Reflection.Assembly&quot; r = assembly.loadfrom &quot;F:\\FlashTrackBar\\bin\\Debug\\FlashTrackBar.dll&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note:</p>\n\
<p>Assemblies can not be unloaded once loaded.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>getProperty &lt;dotNetClass&gt; &lt;prop name&gt; [asDotNetObject:&lt;boolean&gt;]\n\
</pre></div><p>Returns the value of the specified property.</p>\n\
<p>If asDotNetObject is false (the default) the value will converted to a native MAXScript value if possible; if true, the value will always be returned as a dotNetControl or dotNetObject value.</p>\n\
<p>Note: You can use the .NET <span class=\'code\'>Type.MakeGenericType()</span> method to access static generic methods on classes. See the <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/dotNet-Generics.html\' title=\'\'>dotNet Generics</a> topic for an example of how to do so.</p>\n\
<p>Note: Prior to <strong>3ds Max 2020.3 Update</strong>, this returned a dotNetMethod if the specified property was a method, even if <span class=\'code\'>asDotNetObject</span> was true.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` o = dotNetClass &quot;System.String&quot; -- o has only one property, .Empty: prop = getProperty o &quot;Empty&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>setProperty &lt;dotNetClass&gt; &lt;prop name&gt; &lt;value&gt;\n\
</pre></div><p>Sets the value of the specified property.</p>\n\
<p>If the value specified is a native MAXScript value, it will be converted to the proper DotNet value if possible.</p>\n\
<div class=\'codeBlock\'><pre>getPropNames &lt;dotNetClass&gt; [showStaticOnly:&lt;boolean&gt;] [declaredOnTypeOnly:&lt;boolean&gt;]\n\
</pre></div><p>Returns an array of property names exposed by the class.</p>\n\
<p>If <span class=\'code\'>showStaticOnly:</span> is true (the default), only static properties are shown; if false both static and instance properties are shown.</p>\n\
<p>If <span class=\'code\'>declaredOnTypeOnly:</span> is true, only properties declared on the specified class are shown; if false (the default) properties on the class and the classes it derives from are shown.</p>\n\
<p>The results of this method are sorted by name. The properties returned actually contain two different things in terms of DotNet - properties and fields. The properties are shown first in sorted order, then the fields are shown in sorted order.</p>\n\
<div class=\'codeBlock\'><pre>showProperties &lt;dotNetClass&gt; [&quot;prop_pat&quot;] [to:&lt;stream&gt;] [showStaticOnly:&lt;boolean&gt;] [showMethods:&lt;boolean&gt;] [showAttributes:&lt;boolean&gt;] [declaredOnTypeOnly:&lt;boolean&gt;]\n\
</pre></div><p>Displays the properties exposed by the class whose name matches the property pattern.</p>\n\
<p>If <span class=\'code\'>to</span> is not specified, the output goes to Listener, otherwise the output goes to the specified stream.</p>\n\
<p>If <span class=\'code\'>showStaticOnly:</span> is true (the default), only static properties are shown; if false both static and instance properties are shown.</p>\n\
<p>If <span class=\'code\'>showMethods:</span> is true, the signature of the get and set methods (if any) are shown; defaults to false.</p>\n\
<p>If <span class=\'code\'>showAttributes:</span> is true, the attributes associated with the property are shown; defaults to false.</p>\n\
<p>If <span class=\'code\'>declaredOnTypeOnly:</span> is true, only properties declared on the specified class are shown; if false (the default) properties on the class and the classes it derives from are shown.</p>\n\
<p>The results of this method are sorted by name. The properties returned actually contain two different things in terms of DotNet - properties and fields. The properties are shown first in sorted order, then the fields are shown in sorted order.</p>\n\
<div class=\'codeBlock\'><pre>showMethods &lt;dotNetClass&gt; [&quot;prop_pat&quot;] [to:&lt;stream&gt;] [showStaticOnly:&lt;boolean&gt;] [showSpecial:&lt;boolean&gt;] [showAttributes:&lt;boolean&gt;] [declaredOnTypeOnly:&lt;boolean&gt;]\n\
</pre></div><p>Displays the methods exposed by the class whose name matches the property pattern.</p>\n\
<p>The <span class=\'code\'>prop_pat</span> is a pattern string. See <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/GUID-879ECFAD-7928-44B3-BCD7-276D53C89B52.html#pattern-strings\' title=\'\'>Pattern Strings</a> for more information about special characters this string can contain.</p>\n\
<p>If <span class=\'code\'>to</span> is not specified, the output goes to Listener, otherwise the output goes to the specified stream.</p>\n\
<p>If <span class=\'code\'>showStaticOnly:</span> is true (the default), only static properties are shown; if false both static and instance properties are shown.</p>\n\
<p>If <span class=\'code\'>showSpecial:</span> is true, methods that are not normally called by the user (such as a method to set a property value or to invoke an event handler) are shown; defaults to false.</p>\n\
<p>If <span class=\'code\'>showAttributes:</span> is true, the attributes associated with the property are shown; defaults to false.</p>\n\
<p>If <span class=\'code\'>declaredOnTypeOnly:</span> is true, only properties declared on the specified class are shown; if false (the default) properties on the class and the classes it derives from are shown.</p>\n\
<p>The results are sorted by name. Secondary sort is performed based on the number of parameters.</p>\n\
<div class=\'codeBlock\'><pre>showEvents&lt;dotNetClass&gt; [&quot;prop_pat&quot;] [to:&lt;stream&gt;] [showStaticOnly:&lt;boolean&gt;] [declaredOnTypeOnly:&lt;boolean&gt;]\n\
</pre></div><p>Displays the events exposed by the class whose name matches the property pattern.</p>\n\
<p>The <span class=\'code\'>prop_pat</span> is a pattern string. See <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/GUID-879ECFAD-7928-44B3-BCD7-276D53C89B52.html#pattern-strings\' title=\'\'>Pattern Strings</a> for more information about special characters this string can contain.</p>\n\
<p>If <span class=\'code\'>to</span> is not specified, the output goes to Listener, otherwise the output goes to the specified stream.</p>\n\
<p>If <span class=\'code\'>showStaticOnly:</span> is true (the default), only static properties are shown; if false both static and instance properties are shown.</p>\n\
<p>If <span class=\'code\'>declaredOnTypeOnly:</span> is true, only properties declared on the specified class are shown; if false (the default) properties on the class and the classes it derives from are shown.</p>\n\
<p>The results are sorted by name.</p>\n\
<div class=\'codeBlock\'><pre>dotNet.showConstructors &lt;dotNetClass&gt; [to:&lt;stream&gt;]\n\
</pre></div><p>Displays the constructors exposed by the class.</p>\n\
<p>If <span class=\'code\'>to</span> is not specified, the output goes to Listener, otherwise the output goes to the specified stream.</p>\n\
<p>The results are sorted by name. Secondary sort is performed based on the number of parameters.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";