var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>dotnetcontrol</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>dotnetcontrol</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"dotnetcontrol\"></a></div>\n\
<p>In <strong>3ds Max 9</strong> and higher, the <span class=\'code\'>dotNetControl</span> class exposes the properties, methods, and events associated with the control via reflection.</p>\n\
<p>Property access will take/get MAXScript number data types (widened as necessary), string, Boolean, dotNetControl, dotNetObject, and dotNetClass values. Property access will be via the normal property access specification [control.property] and get/setProperty.</p>\n\
<p>Accessing a control method will create a <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/dotNetMethod.html\' title=\'\'>dotNetMethod</a> instance.</p>\n\
<p>The event handlers for dotNetControl are handled in the same way as all UI controls use event handlers - the user defines a named scripted event handler in the rollout definition that is called when the event with the same name is fired on the control.</p>\n\
<p>New methods are used to add and manage event handlers. These methods register and unregister callback functions to be called when the event is fired. The arguments passed back to the functions include the object, the event name, and the arguments passed by the event handler. See <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/dotNet-Struct-Methods.html\' title=\'\'>dotNet Struct Methods</a> for details.</p>\n\
<p><strong>Constructor:</strong></p>\n\
<div class=\'codeBlock\'><pre>dotNetControl &lt;name&gt; &lt;class_type_string&gt; [{&lt;property_name&gt;:&lt;value&gt;}]     \n\
</pre></div><p>keyword arguments are applied to the control after the control is created and event handlers have been assigned, but before the control is added to the rollout.</p>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>.focus \n\
</pre></div><p>When set to true, the control will have focus. When set to false (default), the control will not have focus.</p>\n\
<div class=\'codeBlock\'><pre>.enable \n\
</pre></div><p>When set to false, the control will be disabled. When set to true (default), the control will be available.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>getProperty &lt;dotNetControl&gt; &lt;prop name&gt; [asDotNetObject:&lt;boolean&gt;] \n\
</pre></div><p>Returns the value of the specified property.</p>\n\
<p>If <span class=\'code\'>asDotNetObject</span> is false (the default) the value will converted to a native MAXScript value if possible; if true, the value will always be returned as a dotNetControl or dotNetObject value.</p>\n\
<div class=\'codeBlock\'><pre>setProperty &lt;dotNetControl&gt; &lt;prop name&gt; &lt;value&gt; \n\
</pre></div><p>Sets the value of the specified property. If the value specified is a native MAXScript value, it will be converted to the proper DotNet value if possible.</p>\n\
<div class=\'codeBlock\'><pre>getPropNames &lt;dotNetControl&gt; [showStaticOnly:&lt;boolean&gt;] [declaredOnTypeOnly:&lt;boolean&gt;] \n\
</pre></div><p>Returns an array of property names exposed by the control.</p>\n\
<p>If <span class=\'code\'>showStaticOnly</span> is true (the default), only static properties are shown; if false both static and instance properties are shown.</p>\n\
<p>If <span class=\'code\'>declaredOnTypeOnly</span> is true, only properties declared on the specified control are shown; if false (the default) properties on the control and the classes it derives from are shown.</p>\n\
<p>The results of this method are sorted by name. The properties returned actually contain two different things in terms of DotNet- properties and fields. The properties are shown first in sorted order, then the fields are shown in sorted order.</p>\n\
<div class=\'codeBlock\'><pre>showProperties &lt;dotNetControl&gt; [&quot;prop_pat&quot;] [to:&lt;stream&gt;] [showStaticOnly:&lt;boolean&gt;] [showMethods:&lt;boolean&gt;] [showAttributes:&lt;boolean&gt;] [declaredOnTypeOnly:&lt;boolean&gt;] \n\
</pre></div><p>Displays the properties exposed by the control whose name matches the property pattern.</p>\n\
<p>If <span class=\'code\'>to</span> is not specified, the output goes to Listerner, otherwise the output goes to the specified stream.</p>\n\
<p>If <span class=\'code\'>showStaticOnly</span> is true (the default), only static properties are shown; if false both static and instance properties are shown.</p>\n\
<p>If <span class=\'code\'>showMethods</span> is true, the signature of the get and set methods (if any) are shown; defaults to false.</p>\n\
<p>If <span class=\'code\'>showAttributes</span> is true, the attributes associated with the property are shown; defaults to false.</p>\n\
<p>If <span class=\'code\'>declaredOnTypeOnly</span> is true, only properties declared on the specified control are shown; if false (the default) properties on the control and the classes it derives from are shown.</p>\n\
<p>The results of this method are sorted by name. The properties returned actually contain two different things in terms of DotNet - properties and fields. The properties are shown first in sorted order, then the fields are shown in sorted order.</p>\n\
<div class=\'codeBlock\'><pre>showMethods &lt;dotNetControl&gt; [&quot;prop_pat&quot;] [to:&lt;stream&gt;] [showStaticOnly:&lt;boolean&gt;] [showSpecial:&lt;boolean&gt;] [showAttributes:&lt;boolean&gt;] [declaredOnTypeOnly:&lt;boolean&gt;] \n\
</pre></div><p>Displays the methods exposed by the control whose name matches the property pattern.</p>\n\
<p>If <span class=\'code\'>to</span> is not specified, the output goes to Listerner, otherwise the output goes to the specified stream.</p>\n\
<p>If <span class=\'code\'>showStaticOnly</span> is true (the default), only static properties are shown; if false both static and instance properties are shown.</p>\n\
<p>If <span class=\'code\'>showSpecial</span> is true, methods that are not normally called by the user (such as a method to set a property value or to invoke an event handler) are shown; defaults to false.</p>\n\
<p>If <span class=\'code\'>showAttributes</span> is true, the attributes associated with the property are shown; defaults to false.</p>\n\
<p>If <span class=\'code\'>declaredOnTypeOnly</span> is true, only properties declared on the specified control are shown; if false (the default) properties on the control and the classes it derives from are shown.</p>\n\
<p>The results are sorted by name. Secondary sort is performed based on the number of parameters.</p>\n\
<div class=\'codeBlock\'><pre>showEvents &lt;dotNetControl&gt; [&quot;prop_pat&quot;] [to:&lt;stream&gt;] [showStaticOnly:&lt;boolean&gt;] [declaredOnTypeOnly:&lt;boolean&gt;] \n\
</pre></div><p>Displays the events exposed by the control whose name matches the property pattern.</p>\n\
<p>If <span class=\'code\'>to</span> is not specified, the output goes to Listerner, otherwise the output goes to the specified stream.</p>\n\
<p>If <span class=\'code\'>showStaticOnly</span> is true (the default), only static properties are shown; if false both static and instance properties are shown.</p>\n\
<p>If <span class=\'code\'>declaredOnTypeOnly</span> is true, only properties declared on the specified control are shown; if false (the default) properties on the control and the classes it derives from are shown.</p>\n\
<p>The results are sorted by name.</p>\n\
<div class=\'codeBlock\'><pre>dotNet.showConstructors&lt;dotNetClass&gt; [to:&lt;stream&gt;] \n\
</pre></div><p>Displays the constructors exposed by the control.</p>\n\
<p>If <span class=\'code\'>to</span> is not specified, the output goes to Listerner, otherwise the output goes to the specified stream.</p>\n\
<p>DotNet controls can be created by the class name of the control.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` dotNetControl f1 &quot;System.Windows.Forms.MonthCalendar&quot; align:#left height:180</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>To create a class instance, DotNet needs more than just this information, it also needs the assembly info in the constructor string. The following shows the full string needed, and will also be valid:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` dotNetControl f1 &quot;System.Windows.Forms.MonthCalendar, System.Windows.Forms, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089&quot; align:#left height:180</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In most cases, the user doesn&#39;t care about the assembly version, and just wants to specify the class name. The MAXScript UI control wrapper will try to create the control using the specified class name, and if the control cannot be created it will append the &quot;System.Windows.Forms&quot; assembly info to the class name and try again.</p>\n\
<p>If the class name specified still cannot be resolved, the class name will be prepended with &quot;System.&quot; and another attempt will be made. Thus, this will be valid:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` dotNetControl f1 &quot;Windows.Forms.MonthCalendar&quot; align:#left height:180</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>If the class name still cannot be resolved, the class name will be prepended with &quot;System.Windows.Forms.&quot; and another attempt will be made. Thus, this will be valid:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` dotNetControl f1 &quot;MonthCalendar&quot; align:#left height:180</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";