var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>dotnetobject</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>dotnetobject</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"dotnetobject\"></a></div>\n\
<p>In <strong>3ds Max 9</strong> and higher, the <span class=\'code\'>dotNetObject</span> value class wraps instances of DotNet objects. It is the MAXScript wrapper class around a DotNet <span class=\'code\'>System::Object</span> object.</p>\n\
<p>The dotNetObject class exposes the properties, methods, and events associated with the object via reflection.</p>\n\
<p>Property access uses MAXScript number data types (widened as necessary), String, Boolean, dotNetControl, dotNetObject, and dotNetClass values.</p>\n\
<p>Properties of dotNetObject can be accessed via the normal property access specification [object.property] and the <span class=\'code\'>getProperty()</span> / <span class=\'code\'>setProperty()</span> methods.</p>\n\
<p>Accessing an object method will create a <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/dotNetMethod.html\' title=\'\'>dotNetMethod</a> instance, or optionally a dotNetObject wrapping the RuntimeMethodInfo instance.</p>\n\
<p>New methods are used to add and manage event handlers. These methods register and unregister callback functions to be called when the event is fired. The arguments passed back to the functions include the object, the event name, and the arguments passed by the event handler. See <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/dotNet-Struct-Methods.html\' title=\'\'>dotNet Struct Methods</a> for details.</p>\n\
<p>Note:</p>\n\
<p>There is a difference between a <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/dotnetclass.html\' title=\'\'>dotNetClass</a> and a dotNetObject that wraps the same type.</p>\n\
<p>Accessing the dotNetClass accesses the System::Type while accessing the dotNetObject accesses the object type described by the System::Type.</p>\n\
<p>So, for example, if you called showProperties() on a dotNetObject you will get the properties of the System::Type the dotNetObject wraps, but on a dotNetClass that wraps the same type you will get the properties of System::Type itself.</p>\n\
<p><strong>Constructor:</strong></p>\n\
<div class=\'codeBlock\'><pre>dotNetObject { &lt;dotNetClass&gt; | &lt;class_type_string&gt; } ... additional args as needed ...   \n\
</pre></div><p>Constructs a dotNetObject object.</p>\n\
<p>A dotNetObject can be created either using the class type string or from a dotNetClass:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` o1 = dotNetObject &quot;System.Drawing.Size&quot; 10 20 -- existing object o2 = dotNetClass &quot;System.Drawing.Size&quot; o3 = dotNetObject o2 10 20 -- newobject from class</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Operators:</strong></p>\n\
<div class=\'codeBlock\'><pre>== != \n\
</pre></div><p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>getProperty &lt;dotNetObject&gt; &lt;prop name&gt; [  asDotNetObject:&lt;boolean&gt;] \n\
</pre></div><p>Returns the value of the specified property or method.</p>\n\
<p>If <span class=\'code\'>asDotNetObject</span> is false (the default) the value will converted to a native MAXScript value if possible; if true, the value will always be returned as a dotNetControl or dotNetObject value.</p>\n\
<p>Note: Previous to <strong>3ds Max 2020.3 Update</strong>, this returned a dotNetMethod if the specified property was a method, even if asDotNetObject was true.</p>\n\
<p>See <a href=\'#!/url=./developer/Interaction-with-Other/DotNet-In-MAXScript/dotNet-Generics.html\' title=\'\'>dotNet Generics</a> for an example of how to create a type-specific version of a generic method.</p>\n\
<div class=\'codeBlock\'><pre>setProperty &lt;dotNetObject&gt; &lt;prop name&gt; &lt;value&gt; \n\
</pre></div><p>Sets the value of the specified property. If the value specified is a native MAXScript value, it will be converted to the proper DotNet value if possible.</p>\n\
<div class=\'codeBlock\'><pre>getPropNames &lt;dotNetObject&gt; [showStaticOnly:&lt;boolean&gt;] [declaredOnTypeOnly:&lt;boolean&gt;] \n\
</pre></div><p>Returns an array of property names exposed by the object.</p>\n\
<p>If <span class=\'code\'>showStaticOnly</span> is true (the default), only static properties are shown; if false both static and instance properties are shown.</p>\n\
<p>If <span class=\'code\'>declaredOnTypeOnly</span> is true, only properties declared on the specified object are shown; if false (the default) properties on the object and the classes it derives from are shown.</p>\n\
<p>The results of this method are sorted by name. The properties returned actually contain two different things in terms of DotNet - properties and fields. The properties are shown first in sorted order, then the fields are shown in sorted order.</p>\n\
<div class=\'codeBlock\'><pre>showProperties &lt;dotNetObject&gt; [&quot;prop_pat&quot;] [to:&lt;stream&gt;] [showStaticOnly:&lt;boolean&gt;] [showMethods:&lt;boolean&gt;] [showAttributes:&lt;boolean&gt;] [declaredOnTypeOnly:&lt;boolean&gt;] \n\
</pre></div><p>Displays the properties exposed by the object whose name matches the property pattern.</p>\n\
<p>If <span class=\'code\'>to</span> is not specified, the output goes to Listerner, otherwise the output goes to the specified stream.</p>\n\
<p>If <span class=\'code\'>showStaticOnly</span> is true (the default), only static properties are shown; if false both static and instance properties are shown.</p>\n\
<p>If <span class=\'code\'>showMethods</span> is true, the signature of the get and set methods (if any) are shown; defaults to false.</p>\n\
<p>If <span class=\'code\'>showAttributes</span> is true, the attributes associated with the property are shown; defaults to false.</p>\n\
<p>If <span class=\'code\'>declaredOnTypeOnly</span> is true, only properties declared on the specified object are shown; if false (the default) properties on the object and the classes it derives from are shown.</p>\n\
<p>The results of this method are sorted by name. The properties returned actually contain two different things in terms of DotNet- properties and fields. The properties are shown first in sorted order, then the fields are shown in sorted order.</p>\n\
<div class=\'codeBlock\'><pre>showMethods &lt;dotNetObject&gt; [&quot;prop_pat&quot;] [to:&lt;stream&gt;] [showStaticOnly:&lt;boolean&gt;] [showSpecial:&lt;boolean&gt;] [showAttributes:&lt;boolean&gt;] [declaredOnTypeOnly:&lt;boolean&gt;] \n\
</pre></div><p>Displays the methods exposed by the object whose name matches the property pattern.</p>\n\
<p>If <span class=\'code\'>to</span> is not specified, the output goes to Listerner, otherwise the output goes to the specified stream.</p>\n\
<p>If <span class=\'code\'>showStaticOnly</span> is true (the default), only static properties are shown; if false both static and instance properties are shown.</p>\n\
<p>If <span class=\'code\'>showSpecial</span> is true, methods that are not normally called by the user (such as a method to set a property value or to invoke an event handler) are shown; defaults to false.</p>\n\
<p>If <span class=\'code\'>showAttributes</span> is true, the attributes associated with the property are shown; defaults to false.</p>\n\
<p>If <span class=\'code\'>declaredOnTypeOnly</span> is true, only properties declared on the specified object are shown; if false (the default) properties on the object and the classes it derives from are shown.</p>\n\
<p>The results are sorted by name. Secondary sort is performed based on the number of parameters.</p>\n\
<div class=\'codeBlock\'><pre>showEvents &lt;dotNetObject&gt; [&quot;prop_pat&quot;] [to:&lt;stream&gt;] [showStaticOnly:&lt;boolean&gt;] [declaredOnTypeOnly:&lt;boolean&gt;] \n\
</pre></div><p>Displays the events exposed by the object whose name matches the property pattern.</p>\n\
<p>If <span class=\'code\'>to</span> is not specified, the output goes to Listerner, otherwise the output goes to the specified stream.</p>\n\
<p>If <span class=\'code\'>showStaticOnly</span> is true (the default), only static properties are shown; if false both static and instance properties are shown.</p>\n\
<p>If <span class=\'code\'>declaredOnTypeOnly</span> is true, only properties declared on the specified object are shown; if false (the default) properties on the object and the classes it derives from are shown.</p>\n\
<p>The results are sorted by name.</p>\n\
<div class=\'codeBlock\'><pre>dotNet.showConstructors &lt;dotNetClass&gt; [to:&lt;stream&gt;] \n\
</pre></div><p>Displays the constructors exposed by the object.</p>\n\
<p>If <span class=\'code\'>to</span> is not specified, the output goes to Listerner, otherwise the output goes to the specified stream.</p>\n\
<p>The results are sorted by name. Secondary sort is performed based on the number of parameters.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";