var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>OLE Automation</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>OLE Automation</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"ole-automation\"></a></div>\n\
<p>The OLE Automation capability in MAXScript allows <strong>3ds Max</strong> to act as an OLE Automation server for applications such as, Visual Basic, Excel, Paradox, and others. With it, you can publish MAXScript functions that can be called from OLE Automation clients like VB and Excel to generate models or animations, return data from the current scene, and so on. There is an example provided in the script samples that defines a set of simple business graphing MAXScript functions and an Excel spreadsheet with some Excel VB-scripted menus, which pass a selection of cells across to these MAXScript functions to generate an animated bar chart.</p>\n\
<p>This facility has the following features and limitations:</p>\n\
<ul>\n\
<li><p>It exposes a <strong>single</strong> server object to which you can attach a list of MAXScript functions that appear as the methods of that object to an OLE Automation client.</p></li>\n\
<li><p>It is registered as a separate process, local server supporting multiple use of its exposed object.</p></li>\n\
<li><p>It does not support in-place activation or object linking and embedding, and provides no containers for other OLE objects.</p></li>\n\
<li><p>It supports only the IDispatch form of interface with no accessible type information. Clients need to declare their reference to the <strong>3ds Max</strong> server object as an untyped generic object.</p></li>\n\
<li><p>It supports the following method argument and result data types:</p>\n\
<ul>\n\
<li>integers</li>\n\
<li>reals (floats)</li>\n\
<li>currency (floats)</li>\n\
<li>string</li>\n\
<li>boolean</li>\n\
<li>empty (for example, an empty spreadsheet cell)</li>\n\
</ul></li>\n\
</ul>\n\
<p>The equivalent MAXScript value for empty is <span class=\'code\'>undefined</span> .</p>\n\
<div class=\'codeBlock\'><pre>OLE Objects (interfaces)\n\
\n\
<ul>\n\
<li></li></ul></pre></div><p>You need to have <strong>3ds Max</strong> running and MAXScript activated before OLE Clients can access <strong>3ds Max</strong>. MAXScript is activated (and the <span class=\'code\'>startup.ms</span> script run) when you first access its Utility panel rollout. Alternatively, you can use launch script facilities described in <a href=\'#!/url=./developer/MAXScript-Introduction/General-MAXScript-Topics/Running-Scripts-from-the-Command.html\' title=\'\'>Running Scripts from the Command Line</a> to establish an OLE server interface as soon as <strong>3ds Max</strong> runs.</p>\n\
<li><p>You must register <strong>3ds Max</strong> with Windows as an OLE server using the registration script supplied with this release. See the instructions in <a href=\'#!/url=./developer/Interaction-with-Other/OLE-Automation/Setting-Up-MAXScript-OLE.html\' title=\'\'>Setting Up MAXScript OLE Automation</a> for details.</p></li>\n\
\n\
<div class=\'section\'><a id=\"ole-client\"></a><h2 id=\"ole-client\">OLE Client</h2></div>\n\
<p>With the MAXScript OLE Automation Client system, you can use MAXScript to create OLE Automation (now called Active-X) objects within <strong>3ds Max</strong> and control the associated OLE Automation Servers with MAXScript such as, making an Excel spreadsheet and inserting <strong>3ds Max</strong> object information directly into cells there.</p>\n\
<p>The function,</p>\n\
<div class=\'codeBlock\'><pre>   createOLEObject()\n\
</pre></div><p>is used for establishing a connection to OLE Auto Servers. The return value of <span class=\'code\'>createOLEObject()</span> is an instance of the <span class=\'code\'>OLEObject</span> class.</p>\n\
<p><strong>For example,</strong></p>\n\
<div class=\'codeBlock\'><pre>xl = createOLEObject &quot;Excel.Sheet&quot;\n\
\n\
</pre></div><p>opens a connection to Excel and creates a sheet object and puts it in the variable xl. The single argument to this function is an OLE progID string. You can then access properties and call methods on the new OLE object.</p>\n\
<p><strong>For example,</strong></p>\n\
<div class=\'codeBlock\'><pre>xl.application.name\n\
\n\
</pre></div><p>will return</p>\n\
<div class=\'codeBlock\'><pre>&quot;Microsoft Excel&quot;\n\
\n\
xl.application.visible = true\n\
\n\
</pre></div><p>will make Excel visible on the desktop. You get properties on OLE objects with the dot &#39;.&#39; notation, just as you do in MAXScript. You also refer to OLE object methods as properties of the OLE object. For example, the Sheet has a method &#39;cells&#39; that takes a cell coordinate and returns a Cell OLE object.</p>\n\
<div class=\'codeBlock\'><pre>xlc = xl.application.cells 1 1\n\
\n\
</pre></div><p>puts the top-left-hand cell into xlc. Set its value like this:</p>\n\
<div class=\'codeBlock\'><pre>xlc.value = 123.45\n\
\n\
</pre></div><p>The server application that was attached with <span class=\'code\'>createOLEObject()</span> is released and terminated when the created MAXScript OLE object is eventually garbage-collected. You can explicitly disconnect from an OLE server application with the <span class=\'code\'>releaseOLEObject()</span> function.</p>\n\
<p>The form is:</p>\n\
<div class=\'codeBlock\'><pre>releaseOLEObject &lt;ole_object&gt;\n\
\n\
</pre></div><p>The OLE object becomes disabled once <span class=\'code\'>releaseOLEObject()</span> has been called on it and further attempts to use it results in a descriptive error message.</p>\n\
<p>You can explicitly disconnect from all active OLE server applications with the <span class=\'code\'>releaseAllOLEObjects()</span> function.</p>\n\
<p>Its form is:</p>\n\
<div class=\'codeBlock\'><pre> () \n\
                   releaseAllOLEObjects\n\
</pre></div><p>After calling this function, all existing OLE objects become disabled and any attempt to use them further will generate a runtime error.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";