var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>SafeArrayWrapper Class</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>SafeArrayWrapper Class</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"safearraywrapper-class\"></a></div>\n\
<p>Instances of <strong>SafeArrayWrapper</strong> are creatable by the user and are returned by OLE methods that return SAFEARRAY values. Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<p><strong>Constructor:</strong></p>\n\
<div class=\'codeBlock\'><pre>SafeArrayWrapper ()\n\
SafeArrayWrapper &lt;data array&gt;\n\
SafeArrayWrapper &lt;data array&gt; &lt;lBounds array&gt;\n\
</pre></div><p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;SafeArrayWrapper&gt;.dataArray\n\
</pre></div><p>Data array. Might be &#39;undefined&#39;. The dataArray is a set of nested arrays. The dataArray must be &quot;square&quot; (the number of elements in the dataArray at any given dimension is constant). For example,</p>\n\
<p>dataArray[i].count is constant for i = 1 to dataArray.count, dataArray[i][j].count is constant for j = 1 to dataArray[2].count.</p>\n\
<p>A runtime error will be thrown if dataArray is set to a non-square array. The depth of the array is its dimension. A dimension 2 array is where dataArray[i][j] is a non-array data value. Setting dataArray will change the number of elements in lBoundsArray to match with added elements having the value 0.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SafeArrayWrapper&gt;.lBoundsArray\n\
</pre></div><p>Lower bounds array. Might be &#39;undefined&#39;. Array of size dimensions, where each element contains the lower bound of one dimension of the array. This array is used for creating the OLE SAFEARRAY value from the SafeArrayWrapper. When setting lBoundsArray, its size must be &#39;dimensions&#39; or a runtime error will be thrown.</p>\n\
<div class=\'codeBlock\'><pre>&lt;SafeArrayWrapper&gt;.dimensions\n\
</pre></div><p>Number of dimensions in the data and bounds array. Read only.</p>\n\
<p><strong>Methods</strong>:</p>\n\
<div class=\'codeBlock\'><pre>copy &lt;SafeArrayWrapper&gt;\n\
</pre></div><p>Returns a new SafeArrayWrapper, a deep copy is performed on the data and bounds array.</p>\n\
<p><strong>Notes:</strong></p>\n\
<ul>\n\
<li><p>SafeArrayWrapper values can be passed to OLE methods as arguments and can passed to/from ActiveX control methods. Arrays passed to OLE or ActiveX methods are automatically converted to intermediate SafeArrayWrapper values.</p></li>\n\
<li><p>The following additional variant types for values returned by OLE objects can be converted to MAXScriptvalues: VT_UI2, VT_UI4, VT_INT, VT_NULL, and VT_VOID.</p></li>\n\
<li><p>Color values are converted to VT_I4 variant values when passed to OLE objects.</p></li>\n\
</ul>\n\
<p><strong>Examples:</strong></p>\n\
<p>Example tests which show in part retrieving data from an SQL database using the GetRows method:</p>\n\
<div class=\'codeBlock\'><pre>-- open sql database and get rows\n\
DogConn = createOLEObject &quot;ADODB.Connection&quot;\n\
DogConn.Open &quot;driver={SQL Server}; server=dsqedb01.autodesk.com; database=MXSTest&quot;\n\
recordSet = createOLEObject &quot;ADODB.Recordset&quot;\n\
recordSet.Open &quot;SELECT * from TestTable&quot; DogConn\n\
a = recordSet.GetRows()\n\
-- display data properties\n\
a.dataArray\n\
a.lBoundsArray\n\
a.dimensions\n\
\n\
-- create a new SafeArrayWrapper using data array and lbounds array\n\
b = SafeArrayWrapper #(#(1, 1.2345, &quot;One point two three four five&quot;, undefined, undefined, undefined), #(2, undefined, &quot;Float is null&quot;, undefined, undefined, undefined), #(3, 0.0, &quot; &quot;, undefined, undefined, undefined), #(4, 123.4, undefined, undefined, undefined, undefined)) #(0, 0)\n\
b.dataArray\n\
b.lBoundsArray\n\
b.dimensions\n\
\n\
-- create a new SafeArrayWrapper using data array\n\
d = SafeArrayWrapper a.dataArray\n\
d.dataArray\n\
d.lBoundsArray\n\
d.dimensions\n\
\n\
-- create a new SafeArrayWrapper via copy, show it is a deep copy\n\
f = copy a\n\
f.dataArray\n\
f.lBoundsArray\n\
f.dimensions\n\
f.dataArray[1][1] = 999999\n\
f.dataArray\n\
a.dataArray\n\
\n\
</pre></div><p>Example of updating an SQL database, where the update method is passed an array or SafeArrayWrapper values:</p>\n\
<div class=\'codeBlock\'><pre>DogConn=createOLEObject &quot;ADODB.Connection&quot;\n\
DogConn.Open &quot;driver={SQL Server}; server=dsqedb01.autodesk.com; database=MXSTest&quot;\n\
recordSet = createOLEObject &quot;ADODB.Recordset&quot;\n\
recordSet.Open &quot;SELECT * from TestTable&quot; DogConn 1 3 -- adOpenKeyset adLockOptimistic\n\
fields=recordSet.Fields -- print out column names\n\
count = fields.count\n\
for i = 1 to count do (local item = fields.item (i-1); print item.name)\n\
recordSet.GetRows() -- display current contents\n\
recordSet.AddNew #(&quot;arbitraryFloat&quot;, &quot;arbitraryChar&quot;, &quot;boolean&quot;, &quot;arbitraryInt&quot;) #(pi,&quot;Hello World&quot;,true,42) -- add via array\n\
recordSet.AddNew (SafeArrayWrapper #(&quot;arbitraryFloat&quot;, &quot;arbitraryChar&quot;, &quot;arbitraryInt&quot;)) (SafeArrayWrapper #(e/pi,&quot;Merry xmas!&quot;, 54321)) -- add via SafeArrayWrapper\n\
recordSet.close()\n\
recordSet.Open &quot;SELECT * from TestTable&quot; DogConn\n\
recordSet.GetRows() -- display current contents\n\
\n\
</pre></div><p>Example of getting/setting an ActiveX control property with SafeArrayWrapper:</p>\n\
<div class=\'codeBlock\'><pre>rollout controlR86 &quot;Microsoft Chart Control 6.0 (SP4) (OLEDB)&quot;\n\
(\n\
activeXControl ax &quot;{3A2B370C-BA0A-11D1-B137-0000F8753F5D}&quot; height:200 width:300 align:#left setupEvents:false\n\
)\n\
createdialog ControlR86 height:250 width:350\n\
data = ControlR86.ax.chartdata -- returns SafeArrayWrapper\n\
ControlR86.ax.chartdata = SafeArrayWrapper #(#(undefined, &quot;R1&quot;, &quot;R2&quot;, &quot;R3&quot;, &quot;R4&quot;, &quot;R5&quot;), #(&quot;C1&quot;, 1, 2, 3, 4, 5), #(&quot;C2&quot;, 1, 2, 3, 4, 5), #(&quot;C3&quot;, 5, 4, 3, 2, 1), #(&quot;C4&quot;, -1, 2, 3, 2, 1))\n\
\n\
</pre></div><div class=\'section\'><a id=\"conversion-between-maxscript-values-and-ole-variant-values\"></a><h3 id=\"conversion-between-maxscript-values-and-ole-variant-values\">Conversion between MAXScript values and OLE variant values:</h3></div>\n\
<p><strong>OLE -&gt; MAXScript:</strong></p>\n\
<table class=\'ruled\'>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>VT_EMPTY VT_NULL</span></td>\n\
<td align=\"left\"><span class=\'code\'>undefined</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>VT_VOID</span></td>\n\
<td align=\"left\"><span class=\'code\'>OK</span></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>VT_UI1 VT_UI2 VT_UI4 VT_I2 VT_I4 VT_INT</span></td>\n\
<td align=\"left\"><span class=\'code\'>Integer</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>VT_R4 VT_R8 VT_CY</span></td>\n\
<td align=\"left\"><span class=\'code\'>Float</span></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>VT_BSTR</span></td>\n\
<td align=\"left\"><span class=\'code\'>String</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>VT_BOOL</span></td>\n\
<td align=\"left\"><span class=\'code\'>Boolean</span></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>VT_DISPATCH</span></td>\n\
<td align=\"left\"><span class=\'code\'>OLEObject</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>VT_ARRAY | VT_VARIANT</span></td>\n\
<td align=\"left\"><span class=\'code\'>SafeArrayWrapper</span></td>\n\
</tr>\n\
</table>\n\
<p><strong>MAXScript -&gt; OLE:</strong></p>\n\
<table class=\'ruled\'>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>SafeArrayWrapper</span> <span class=\'code\'>Array</span></td>\n\
<td align=\"left\"><span class=\'code\'>VT_ARRAY</span> | <span class=\'code\'>VT_VARIANT</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>Integer</span></td>\n\
<td align=\"left\"><span class=\'code\'>VT_I4</span></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>Float</span></td>\n\
<td align=\"left\"><span class=\'code\'>VT_R4</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>Boolean</span></td>\n\
<td align=\"left\"><span class=\'code\'>VT_BOOL</span></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>Color</span></td>\n\
<td align=\"left\"><span class=\'code\'>VT_I4</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>String</span></td>\n\
<td align=\"left\"><span class=\'code\'>VT_BSTR</span></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>Undefined</span></td>\n\
<td align=\"left\"><span class=\'code\'>VT_EMPTY</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>OLEObject</span></td>\n\
<td align=\"left\"><span class=\'code\'>VT_DISPATCH</span></td>\n\
</tr>\n\
</table>\n\
<p>The following information is taken from the document &quot;Accessing Data with ADO&quot; from MSDN (<strong>ms-help://MS.MSDNQTR.2003OCT.1033/iisref/htm/AccessingDatawithADO.htm</strong>).</p>\n\
<p><strong>The following table lists OLE DB connection strings for several common data sources:</strong></p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">Data Source</th>\n\
<th align=\"left\">OLE DB Connection String</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">Microsoft Access</td>\n\
<td align=\"left\">Provider=Microsoft.Jet.OLEDB.4.0;Data Source=<strong>physical path to .mdb file</strong></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">Microsoft SQL Server</td>\n\
<td align=\"left\">Provider=SQLOLEDB.1;Data Source=<strong>path to database on server</strong></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">Oracle</td>\n\
<td align=\"left\">Provider=MSDAORA.1;Data Source=<strong>path to database on server</strong></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">Microsoft Indexing Service</td>\n\
<td align=\"left\">Provider=MSIDXS.1;Data Source=<strong>path to file</strong></td>\n\
</tr>\n\
</table>\n\
<p>To provide for backward compatibility, the OLE DB Provider for ODBC supports ODBC connection string syntax. The following table lists commonly used ODBC connection strings:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">Data Source Driver</th>\n\
<th align=\"left\">ODBC Connection String</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">Microsoft Access</td>\n\
<td align=\"left\">Driver={Microsoft Access Driver (<em>.mdb)};DBQ=<strong>physical path to .mdb file</strong>| |SQL Server|DRIVER={SQL Server};SERVER=<strong>path to server</strong>| |Oracle|DRIVER={Microsoft ODBC for Oracle};SERVER=<strong>path to server</strong>| |Microsoft Excel|Driver={Microsoft Excel Driver (</em>.xls)};DBQ=<strong>physical path to .xls file</strong>; DriverID=278</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">Microsoft Excel 97</td>\n\
<td align=\"left\">Driver={Microsoft Excel Driver (<em>.xls)};DBQ=<strong>physical path to .xls file</strong>;DriverID=790| |Paradox|Driver={Microsoft Paradox Driver (</em>.db)};DBQ=<strong>physical path to .db file</strong>;DriverID=26</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">Text</td>\n\
<td align=\"left\">Driver={Microsoft Text Driver (<em>.txt;</em>.csv)};DBQ=<strong>physical path to .txt file</strong></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">Microsoft Visual FoxPro (with a database container)</td>\n\
<td align=\"left\">Driver= {MicrosoftVisualFoxProDriver};SourceType=DBC;SourceDb=<strong>physical path to .dbc file</strong></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">Microsoft Visual FoxPro (without a database container)</td>\n\
<td align=\"left\">Driver= {MicrosoftVisualFoxProDriver};SourceType=DBF;SourceDb=<strong>physical path to .dbf file</strong></td>\n\
</tr>\n\
</table>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";