var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Controlling Program Flow in Scripts</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Controlling Program Flow in Scripts</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"controlling-program-flow-in-scripts\"></a></div>\n\
<p>MAXScript provides commands that allow you to control the path that the software follows it evaluates your script. The two most useful groups of commands are the conditional statements and loop statements.</p>\n\
<p>Before you go on, let&#39;s make sure you have the correct base scene.</p>\n\
<p>In the new MAXScript Editor you opened in the previous step,</p>\n\
<blockquote>\n\
<p><strong>ENTER:</strong></p>\n\
<p><span class=\'code\'>resetMaxFile #noprompt   mybox = box length:10 width:10 height:10 wirecolor:blue</span></p>\n\
</blockquote>\n\
<p>Then press <strong>Ctrl+E</strong> to evaluate the script. This will reset the current scene without the &quot;Are You Sure&quot; prompt and will create a new blue box with dimensions 10x10x10 at the origin.</p>\n\
<div class=\'section\'><a id=\"conditional-statements\"></a><h2 id=\"conditional-statements\">Conditional Statements</h2></div>\n\
<p>Conditional statements simply tell MAXScript to perform a specified command if a certain condition is met.</p>\n\
<p>Enter the following in the Listener (and not in the newly opened Script Editor):</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p><span class=\'code\'>if mybox.height == 10 then mybox.width = 20</span></p>\n\
</blockquote>\n\
<p>This changes the width of the box we just created to 20 if its height is equal to 10 (which happens to be the case).</p>\n\
<p>You may have taken note of the double equal sign used in the statement above. This is discussed at the end of this topic and denotes the logical operation &quot;Is Equal To&quot;.</p>\n\
<p>This &quot;if…then…&quot; statement can be expanded to include an &quot;else&quot; statement,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p><span class=\'code\'>if mybox.height == 10 then mybox.width = 20 else mybox.width = 10</span></p>\n\
</blockquote>\n\
<p>This statement tells MAXScript to change the width of your box to 20 if its height is 10, otherwise change the width to 10.</p>\n\
<p>The &quot;if&quot;, &quot;then&quot; and &quot;else&quot; portions of the statement can all be on separate lines,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p><span class=\'code\'>if mybox.height == 10   then mybox.width = 20   else mybox.width = 10</span></p>\n\
</blockquote>\n\
<p>What is even more fascinating about MAXScript is that since the if...then...else uses three expressions (one condition and two alternative expressions depending on whether the condition is true or false), the above could be written much shorter as</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p><span class=\'code\'>mybox.width = if mybox.height == 10 then 20 else 10</span></p>\n\
</blockquote>\n\
<p>In this case, the right-hand side of the assignment is an IF expression which evaluates the condition whether the height of the box is 10 or not and returns a value of 20 if it is and of 10 if it is not. Then the resulting value is assigned to the left-hand side of the assignment expression.</p>\n\
<p>This can be made clearer with some additional parentheses which are optional and simply improve readability:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p><span class=\'code\'>mybox.width = (if mybox.height == 10 then 20 else 10)</span></p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"if...then-conditions-in-the-listener\"></a><h3 id=\"if...then-conditions-in-the-listener\">If...Then Conditions In the Listener</h3></div>\n\
<p>If you are entering these commands into the Listener window, you may notice that the commands are not executed line by line, as is typical of the Listener. This is because the Listener recognizes that the &quot;if&quot; statement requires a &quot;then&quot; statement to be complete. In fact, the Listener does not execute the statement after the &quot;then&quot; statement, because it does not know if you intend to include an &quot;else&quot; statement. For this reason, the Listener does not execute an &quot;if...then...&quot; statement until you have either entered a &quot;then&quot; statement or <em>after</em> the next line you type, following the &quot;if...then...&quot; statement.</p>\n\
<p>To avoid the waiting for an &quot;else&quot; statement when typing in the Listener, you can use &quot;if...do...&quot; instead. You cannot use &quot;else&quot; with &quot;if...do...&quot;, so the Listener will not wait and will execute the expression after &quot;do&quot; as long as the condition expression after the &quot;if&quot; is true.</p>\n\
<div class=\'section\'><a id=\"comparison-operators\"></a><h3 id=\"comparison-operators\">Comparison Operators</h3></div>\n\
<p>The double equal sign in the last statement, &quot;==&quot; tells MAXScript to compare two values. The single &quot;=&quot; sign always signifies value assignment.</p>\n\
<p>This is common in many standard programming languages, such as C++.</p>\n\
<p>There are several different conditional operators used in MAXScript. They are listed here:</p>\n\
<ul>\n\
<li><p>== equal to</p></li>\n\
<li><p>!= not equal to</p></li>\n\
<li><p>&gt; greater than</p></li>\n\
<li><blockquote>\n\
<p>= greater than or equal to</p>\n\
</blockquote></li>\n\
<li><p>&lt; less than</p></li>\n\
<li><p>&lt;= less than or equal to</p></li>\n\
</ul>\n\
<p>Note:</p>\n\
<p>Any time MAXScript evaluates a conditional expression, the result is either true or false. MAXScript temporarily stores the value of this result. In an &quot;if…then&quot; statement, MAXScript uses this result to determine the path to follow in the statement. If the result of the &quot;if&quot; statement is true, MAXScript will evaluate the &quot;then&quot; expression. If the result is false, MAXScript will evaluate the &quot;else&quot; expression, assuming one is specified; otherwise, it will cease evaluating the conditional statement.</p>\n\
<p>In some scripts, you might see the words <span class=\'code\'>on</span> and <span class=\'code\'>off</span> used in place of <span class=\'code\'>true</span> and <span class=\'code\'>false</span>, respectively. These words are interchangeable and they mean the same thing to MAXScript.</p>\n\
<div class=\'section\'><a id=\"loops\"></a><h2 id=\"loops\">Loops</h2></div>\n\
<p>Loops are repetitive operations that tell MAXScript to repeat the execution of a collection of commands.</p>\n\
<p>Loops are useful for working with large groups of objects, as you can make changes to many objects with one set of commands.</p>\n\
<p>For example, if you wanted to make 50 boxes, you could use a loop to execute the create command 50 times, rather than creating the boxes with 50 separate commands. Loops are also useful for changing the properties of multiple objects.</p>\n\
<p>There are several different types of loop. The first to be considered are for and while loops.</p>\n\
<div class=\'section\'><a id=\"for-loops\"></a><h3 id=\"for-loops\">For Loops</h3></div>\n\
<p>The for loop iterates through a range of numbers, time values, or a sequenced collection of values, such as an array or object set.</p>\n\
<p>You can use a for loop to copy the box you created.</p>\n\
<p>Let&#39;s expand the script we started in the beginning of this lesson:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE SCRIPT</strong></p>\n\
<p>``` resetMaxFile #noprompt --reset the scene mybox = box length:10 width:10 height:10 wirecolor:blue --new box for i = 1 to 5 do --repeat five times, for each iteration do: ( box_copy = copy mybox --create a copy of the original box box_copy.pos = [i*20, 0, 0] --place it i*20 units along x box_copy.wirecolor = [i<em>25,i</em>50,(5-i)*50] --blue-green gradient )--end of the for loop</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-F4FA540A-2020-443C-AFFB-5B49F4210483-low.gif\' title=\'\'></div>\n\
<p>Everything inside of the parentheses makes up a &quot;block&quot;. All loop statements must be created as a block. This statement executes five times. Each time, a new box copy is created, placed to a new position and its color is changed.</p>\n\
<ul>\n\
<li><p>A for statement starts with the word &#39;for&#39;.</p></li>\n\
<li><p>Next, you must define how many times the statement will repeat. In this case, we have used the variable &quot;i&quot; to control the loop. The line, &quot;<span class=\'code\'>for i = 1 to 5</span>&quot; tells MAXScript to set the variable &quot;i&quot; to the value 1, execute the contents of the loop body, then set the variable &quot;i&quot; to 2, execute the loop body, and so on.</p></li>\n\
<li><p>The variable &quot;i&quot; is called the <em>index</em> for the loop. Each time the loop executes, the index is incremented by 1 automatically, without requiring any user input. Each repetition of the loop is called an iteration.</p></li>\n\
<li><p>To make MAXScript increment the index by a value other than 1, insert &#39;by x&#39; after the index statement, where x is the amount to increment the index by.</p></li>\n\
</ul>\n\
<p>The following statement will set the index to 1, then 3, then 5,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` resetMaxFile #noprompt --reset the scene mybox = box length:10 width:10 height:10 wirecolor:blue --new box for i = 1 to 5 by 2 do --repeat with step of 2: ( box_copy = copy mybox --create a copy of the original box box_copy.pos = [i*20, 0, 0] --place it i*20 units along x box_copy.wirecolor = [i<em>25,i</em>50,(5-i)*50] --blue-green gradient )--end of the for loop</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-C33149D7-7EA4-4AE7-B286-1DCD29D648F3-low.gif\' title=\'\'></div>\n\
<ul>\n\
<li><p>The &quot;do&quot; keyword tells MAXScript to execute the following block or statement each time the loop repeats. Note that in some loops you might see the word &quot;in&quot; in place of the equal sign, &quot;=&quot;. These both mean the same thing in for loops, and can be used interchangeably.</p></li>\n\
<li><p>Note how the index was used within the loop statement to set the position of each new box by multiplying by an offset value. This is a useful way to work with multiple object creation. The same approach was used for the color, changing the R, G and B components based on the index.</p></li>\n\
</ul>\n\
<p>For loops can also be used to build arrays and/or access values within an array. In the following example, you use a for loop to build an array called &#39;arr&#39;:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-5784B80E-8DE1-4255-8BE4-C7FDC62F3299-low.gif\' title=\'\'></div>\n\
<p>Remember that because MAXScript is an expression-based language, you are able to use expressions in variable assignment, as seen above in the assignment of the for loop expression to the variable, <span class=\'code\'>arr</span>.</p>\n\
<p>Note the &#39;collect&#39; statement in the for loop above. This tells MAXScript to collect the results of each iteration in an array, rather than just calculate them. In this case, you only asked MAXScript to collect the value of the index; however, you can collect iterations of any expression.</p>\n\
<p>Finally, for loops can also perform iterations with the contents of an array. In the following example, you use a for loop to access the values of the array you created in the previous example:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-76BD54C0-D1BB-41FF-8635-1D962B77587C-low.gif\' title=\'\'></div>\n\
<p>The &#39;print&#39; command is a MAXScript function that displays the specified variable in the Listener window. In this example you used &#39;in&#39; instead of an equal sign; however, they are still both acceptable, even when accessing values within an array.</p>\n\
<p>Note:</p>\n\
<p>You can also access the number of elements in an array with the <span class=\'code\'>.count</span> property.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>the previous example could have been written as:</p>\n\
<p><span class=\'code\'>for i = 1 to arr.count do print arr[i]</span></p>\n\
<p>This will return the same result.</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"while-and-do-loops\"></a><h3 id=\"while-and-do-loops\">While and Do Loops</h3></div>\n\
<p>While and Do loops are used to repeatedly execute an expression until a test expression evaluates as false. The while and do loop are simple variants of one another.</p>\n\
<p>The syntax is:</p>\n\
<div class=\'codeBlock\'><pre>do &lt;expr&gt; while &lt;expr&gt; -- do loop\n\
while &lt;expr&gt; do &lt;expr&gt; -- while loop\n\
</pre></div><p>The following example will return the value of a variable, incrementing the variable by -1 with each iteration.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p><span class=\'code\'>x=10   while x&gt;0 do print (x-=1)</span></p>\n\
<p><strong>RETURNS</strong></p>\n\
<p><span class=\'code\'>9   8   7   6   5   4   3   2   1   0   0</span></p>\n\
</blockquote>\n\
<p>MAXScript automatically returns the final value of the loop to the Listener. In this example, MAXScript is also instructed to return the value at each iteration of the loop; therefore, the final value is returned twice.</p>\n\
<p>Both loops repeat the <span class=\'code\'>do &lt;expr&gt;</span> as long as the <span class=\'code\'>while &lt;expr&gt;</span> evaluates to the value <span class=\'code\'>true</span>. The do form evaluates the <span class=\'code\'>do &lt;expr&gt;</span> at least at least once, before evaluating the text expression at the end of the loop. The while form evaluates the test expression at the start of the loop, and might not loop at all.</p>\n\
<p>Both forms return as their value the result of the <span class=\'code\'>do &lt;expr&gt;</span> from the last successful loop iteration. The while form returns the value undefined if the test expression immediately returns <span class=\'code\'>false</span>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p><span class=\'code\'>x=10   do print (x-=1) while x&gt;10</span></p>\n\
<p><strong>RETURNS</strong></p>\n\
<p><span class=\'code\'>9   undefined</span></p>\n\
<p><strong>HOWEVER</strong></p>\n\
<p><span class=\'code\'>x=10   while x&gt;10 do print (x-=1)</span></p>\n\
<p><strong>RETURNS</strong></p>\n\
<p><span class=\'code\'>undefined</span></p>\n\
</blockquote>\n\
<p><strong>Next Topic</strong></p>\n\
<p><a href=\'#!/url=./developer/Learning-MAXScript/Creating-Your-Own-Scripts/Local-and-Global-Variables.html\' title=\'\'>Local and Global Variables</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";