var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Defining Custom Functions</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Defining Custom Functions</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"defining-custom-functions\"></a></div>\n\
<p>MAXScript’s built-in functions are very powerful. They provide access to objects, allowing you to read and set their properties. However, scripting in <strong>3ds Max</strong> normally entails going beyond simple object creation. Fortunately, MAXScript allows you to make your own functions, giving you the ability to streamline and customize your work.</p>\n\
<p>In MAXScript, you can use functions to perform almost any of the software’s operations. Start with a simple function definition that subtracts two variables:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-A149D177-B559-4C7B-A2F0-FA288180DEF2-low.gif\' title=\'\'></div>\n\
<p>MAXScript returns <span class=\'code\'>subtract()</span> to let you know that it has defined the function, subtract.</p>\n\
<p>The definition contains the keyword <span class=\'code\'>function</span> (you can also use the word <span class=\'code\'>fn</span> in place of <span class=\'code\'>function</span>), followed by the name of the function (<span class=\'code\'>subtract</span>), followed by the list of variables (<span class=\'code\'>x</span> and <span class=\'code\'>y</span>). The equal sign signifies the start of the body of the function. The body is the series of statements that the function executes. Even if there is only one statement, the body of the function must be in parentheses.</p>\n\
<p>Note:</p>\n\
<p>Any variables created in the body of a function are local variables unless otherwise specified.</p>\n\
<p>Once a function has been defined, it can be used anywhere throughout the script. Therefore, it is useful to place function definitions at the beginning of your scripts.</p>\n\
<p>In order to use a function, you simply enter the function name and the values for its variables:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-39E0D9F5-1013-41E8-B395-31236C69BC6F-low.gif\' title=\'\'></div>\n\
<p>This example uses what are known as <em>positional arguments</em>. When you call the function, you must supply both arguments, and you must supply them in the proper order for the function to execute properly.</p>\n\
<p>The second type of arguments you can use are <em>keyword</em> arguments. This is what is used for all of the object constructors in MAXScript. The function definition is the same, with the exception of declaring the keyword arguments, or default values for the variables in a function.</p>\n\
<p>The following example determines whether a number is positive, negative, or equal to zero.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` function sign val:0 = ( if val == 0 then messagebox (&quot;Equal to 0&quot;) else if val &gt; 0 then messagebox (&quot;Greater than 0&quot;) else messagebox (&quot;Less than 0&quot;) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The <span class=\'code\'>messagebox</span> command causes a message box to pop up on the screen, displaying the argument in the parentheses that follow the command.</p>\n\
<p>In this example, a parameter called <span class=\'code\'>val</span> has been declared in the function definition. The value after the colon is the parameter’s default value. When the function definition contains parameters like this, they are optional in the function call. If you enter <span class=\'code\'>sign()</span>, without specifying any parameters in the function call, MAXScript uses the default value:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-957CAB61-2B26-433D-84C1-61562FCA80FB-low.gif\' title=\'\'></div>\n\
<p>The &quot;Equal to 0&quot; message box appears, since the default value for <span class=\'code\'>val</span> (0) will be used. However, if you do define <span class=\'code\'>val</span>:</p>\n\
<div class=\'codeBlock\'><pre>sign val:-5\n\
\n\
<div class=\'figure\'><img src=\'developer/images/GUID-CC7F11DE-8A08-433A-B477-62332E4B411F-low.gif\' title=\'\'></div>\n\
</pre></div><p>the &quot;Less than 0&quot; message appears. You can include as many keyword arguments in a function as you need, and they can be entered in any order when calling the function. This is useful when you consider functions such as object-creation functions, where the new object might have 20 or 30 parameters associated with it. If you wanted to use positional argument functions to create the same objects, you would have to provide all of these parameters, in the right order, each time you wanted to call the function.</p>\n\
<p>It is also possible to use both positional and keyword arguments in the same function call. In this case, you must use positional arguments first, followed by the keyword arguments,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` function mycube side position:[0, 0, 0] = ( box length:side width:side height:side pos:position )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>This function requires you to enter the size of the cube, but the position is optional.</p>\n\
<p><strong>Next Topic</strong></p>\n\
<p><a href=\'#!/url=./developer/Learning-MAXScript/Creating-Your-Own-Scripts/Structure-Definitions.html\' title=\'\'>Structure Definitions</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";