var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Local and Global Variables</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Local and Global Variables</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"local-and-global-variables\"></a></div>\n\
<p>In MAXScript, there are two classes of variables that you can create: &quot;local&quot; and &quot;global&quot; variables. When a variable is global, it means that the variable can be used anywhere in the program. The only place you cannot use a global variable is before you have defined it.</p>\n\
<blockquote>\n\
<p><strong>For example, the following lines will produce an error:</strong></p>\n\
<p><span class=\'code\'>sphere radius:rad   global rad = 10</span></p>\n\
</blockquote>\n\
<p>The variable &quot;<span class=\'code\'>rad</span>&quot; does not exist until it has been defined.</p>\n\
<blockquote>\n\
<p><strong>The following is an acceptable form of the previous lines:</strong></p>\n\
<p><span class=\'code\'>global rad = 10   sphere radius:rad</span></p>\n\
</blockquote>\n\
<p>Now that &quot;<span class=\'code\'>rad</span>&quot; has been defined, MAXScript was able to use it in the definition of a sphere. In fact, since &quot;<span class=\'code\'>rad</span>&quot; is a global variable, it can be used throughout the rest of the script.</p>\n\
<p>There are several global variables that <em>can</em> be used without defining them first.</p>\n\
<p>They are the system global variables, which have already been created and assigned to a default value. Most of these variables can be reassigned to different values. For more information on the system global variables, see the <a href=\'#!/url=./developer/MAXScript-Language-Reference/Reserved-Keywords-Symbols/3ds-Max-System-Globals.html\' title=\'\'>3ds Max System Globals</a> topic in the MAXScript reference.</p>\n\
<p>Unlike global variables, local variables can be used only within the block in which they are defined.</p>\n\
<p>A block is a grouping of MAXScript code, such as the statements within loops and conditional statements.</p>\n\
<blockquote>\n\
<p><strong>HERE IS AN EXAMPLE OF A FOR LOOP</strong></p>\n\
<p><span class=\'code\'>for i = 1 to 3 do   (     local rad = 10     s = sphere()     s.pos.x = i * 10     s.radius = rad   )</span></p>\n\
</blockquote>\n\
<p>Local variables can only exist within a block. For this reason, they must be created in a block. If you try to define a local variable from the top level of MAXScript, you will receive an error message.</p>\n\
<p>In the previous example, you defined a local variable named &quot;<span class=\'code\'>rad</span>&quot;. This variable is active only within the parentheses inside the for loop; if you attempt to use the variable &quot;<span class=\'code\'>rad</span>&quot; elsewhere, you will get an error.</p>\n\
<p>Although <span class=\'code\'>rad</span> is initialized to a specific value, this is not necessary. When you define variables using a &quot;local&quot; or &quot;global&quot; identifier, you can do so without assigning an initial value. The name of the variable will be recognized. However, the software will not know the type of the variable (name, number, color, etc.). MAXScript automatically assigns the variable a special value of &quot;undefined&quot;. The first time you assign something to the variable, it will become defined by the data type that you have assigned it to. In practice, it is always best to define variables with an initial value.</p>\n\
<p>It is important to note that <span class=\'code\'>rad</span> is not the only local variable in the previous example. The variable &quot;<span class=\'code\'>s</span>&quot; is also a local variable, and cannot be accessed outside of the parentheses. It is not necessary to declare every variable with a &quot;global&quot; or &quot;local&quot; statement. You learned previously that you can implicitly create a variable by simply assigning a value to it. If you do not make the &quot;global&quot; or &quot;local&quot; distinction upon your variable, MAXScript will create the appropriate association, depending on where the variable is defined in the script. For example if you create a variable inside a block, MAXScript automatically treats it as a local variable. On the other hand, any variable created at the top level of MAXScript (outside of all blocks) is always a global variable. As mentioned previously, MAXScript does not allow for the creation of local variables outside of a block.</p>\n\
<p>These concepts are presented in the following</p>\n\
<blockquote>\n\
<p><strong>HERE IS AN EXAMPLE OF A FOR LOOP</strong></p>\n\
<p><span class=\'code\'>for i = 1 to 5 do   (     global rad = 10     cyl_height = 25     c = cylinder()     c.radius = rad     c.height = cyl_height     c.pos.x = i * 25   )   s = sphere radius:rad</span></p>\n\
</blockquote>\n\
<p>In this example, four variables are created: <span class=\'code\'>rad, cyl_height, c</span>, and <span class=\'code\'>s</span>. Because they were implicitly created within a block, <span class=\'code\'>c</span> and <span class=\'code\'>cyl_height</span> are both local variables. The other two variables are both global; <span class=\'code\'>s</span>, because it was created outside of a block, and <span class=\'code\'>rad</span>, because it was declared as a global variable. For this reason, you can use<span class=\'code\'>rad</span> again to define the sphere, <span class=\'code\'>s</span>.</p>\n\
<p><strong>Next Topic</strong></p>\n\
<p><a href=\'#!/url=./developer/Learning-MAXScript/Creating-Your-Own-Scripts/Defining-Custom-Functions.html\' title=\'\'>Defining Custom Functions</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";