var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Applying Standard Transformations</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Applying Standard Transformations</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"applying-standard-transformations\"></a></div>\n\
<p>Note: This is a continuation of the <a href=\'#!/url=./developer/Learning-MAXScript/Manipulating-The-Box-First-Steps.html\' title=\'\'>&quot;Manipulating The Box - First Steps in MAXScript&quot;</a> tutorial&#39;s previous lessons <a href=\'#!/url=./developer/Learning-MAXScript/Manipulating-The-Box-First-Steps/Drawing-a-Box-with-MAXScript.html\' title=\'\'>&quot;Drawing a Box with MAXScript&quot;</a> and <a href=\'#!/url=./developer/Learning-MAXScript/Manipulating-The-Box-First-Steps/Modifying-the-Box.html\' title=\'\'>&quot;Modifying the Box&quot;</a>. It requires the variable <span class=\'code\'>mybox</span> to be already defined and containing an instance of a Box primitive. If you are <strong>not</strong> continuing directly from these previous lessons, you must at least evaluate the line</p>\n\
<div class=\'codeBlock\'><pre>mybox = box()\n\
</pre></div><p>in order to apply the following examples to the <strong>3ds Max</strong> scene.</p>\n\
<p>Now that you know how to <a href=\'#!/url=./developer/Learning-MAXScript/Manipulating-The-Box-First-Steps/Drawing-a-Box-with-MAXScript.html\' title=\'\'>create</a> and <a href=\'#!/url=./developer/Learning-MAXScript/Manipulating-The-Box-First-Steps/Modifying-the-Box.html\' title=\'\'>modify</a> the basic properties of a box, you need to learn how to apply the standard transformations (move, scale, and rotate) to it. It is possible to designate position, size, and orientation when the box is created; however, you can also carry out these operations after you have created your object, just as you would in <strong>3ds Max</strong>.</p>\n\
<div class=\'section\'><a id=\"moving-the-box\"></a><h2 id=\"moving-the-box\">Moving the Box</h2></div>\n\
<p>Moving an object in MAXScript is very simple:</p>\n\
<div class=\'codeBlock\'><pre>move name_obj [&lt;x,y,z&gt;]\n\
\n\
</pre></div><p>where name_objis the name of the object you want to move and <span class=\'code\'>&lt;x,y,z&gt;</span> is the amount you want it to move.</p>\n\
<p>It is <strong>important to note</strong> that you are not moving the object <strong>to</strong> <span class=\'code\'>&lt;x,y,z&gt;</span>, but <strong>by</strong> the amounts <span class=\'code\'>&lt;x,y,z&gt;</span>.</p>\n\
<p>Therefore, if you apply the move function more than once, the object continues to move. This is also true for the scale and rotate transforms.</p>\n\
<p>This is in contrast to setting a property of an object. If you set the object position, scale, and rotation properties several times, the object won’t change, assuming that you assign the same value each time.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` mybox.pos = [10,0,0] mybox.pos = [10,0,0] mybox.pos = [10,0,0]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>will only change the position of your box after the first line is executed.</p>\n\
<p>The second and third lines do not affect the position of your box, as they do not change the absolute position of the box:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-09BD30C4-0FD2-46AE-80D9-F0105C1CBA3E-low.gif\' title=\'\'></div>\n\
<p>If you entered the above three commands, click <img src=\'developer/images/GUID-062EDDCE-D844-4382-A665-C8A36D8FFCDB-low.gif\' title=\'\'>Undo three times to move the box back to its original position.</p>\n\
<blockquote>\n\
<p><strong>ON THE OTHER HAND, ENTERING</strong></p>\n\
<p>``` move mybox [10,0,0] move mybox [10,0,0] move mybox [10,0,0]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>will move your box 30 units along the X-axis:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-011EEED2-7DCA-4E8E-8497-6EC86DB62554-low.gif\' title=\'\'></div>\n\
<p>If you entered the above commands, click <img src=\'developer/images/GUID-062EDDCE-D844-4382-A665-C8A36D8FFCDB-low.gif\' title=\'\'>Undo three times to move the box back to its original position.</p>\n\
<div class=\'section\'><a id=\"scaling-the-box\"></a><h2 id=\"scaling-the-box\">Scaling the Box</h2></div>\n\
<p>Scaling is performed in a similar manner:</p>\n\
<div class=\'codeBlock\'><pre>scale name_obj [&lt;x,y,z&gt;]\n\
\n\
</pre></div><p>where <span class=\'code\'>name_obj</span> is the name of the object and <span class=\'code\'>&lt;x,y,z&gt;</span> is a 3D coordinate that corresponds to the amount you would like to scale the object along the X, Y, and Z-axis, respectively.</p>\n\
<p>Again, the scale transformation is different from the scale object property. Setting the object’s scale property (<span class=\'code\'>name_obj.scale</span>= …) repeatedly with the same values will only scale the object the first time, but applying the scale transformation repeatedly will continue to scale the object relatively to the previous scale.</p>\n\
<div class=\'section\'><a id=\"rotating-the-box\"></a><h2 id=\"rotating-the-box\">Rotating the Box</h2></div>\n\
<p>The rotate transformation is not as simple as the move and rotate transforms. In fact, there are three ways to express rotation values in MAXScript:</p>\n\
<p><strong>[<a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/EulerAngles-Values.html\' title=\'\'>Euler Angles</a>]</strong>, <strong>[<a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/Quat-Values.html\' title=\'\'>Quaternions</a> ]</strong> and <strong>[<a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/AngleAxis-Values.html\' title=\'\'>Angleaxis</a> ]</strong>.</p>\n\
<p>This lesson will only consider Euler Angles. If you would like further information on any of these transformations, see the MAXScript Reference.</p>\n\
<p>To apply a rotation transform in MAXScript, you must first define the rotation as a sort of <em>rotation object</em>, and then apply the rotation object to the object you want to rotate. The rotation object is defined in the following way:</p>\n\
<div class=\'codeBlock\'><pre>rot_obj = eulerangles x y z\n\
\n\
</pre></div><p>whererot_objcan be any name and x,y, and z represent the amount you want to rotate your object (in degrees) around the X, Y, and Z-axes, respectively.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>``` rot_box = eulerangles 0 30 0</p>\n\
<p>```</p>\n\
<p>creates an object called rot_box, which will rotate an object around the Y-axis by 30 degrees. This rotation can be applied to your box in the following way:</p>\n\
<p>``` rotate mybox rot_box</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-9DD41A18-3F60-434E-A1EF-F1026777152F-low.gif\' title=\'\'></div>\n\
<p>In fact, this rotation could be applied to any object by writing the same line as above and replacing <span class=\'code\'>mybox</span> with the name of the object you want to rotate.</p>\n\
<p>If you entered the above commands, click <img src=\'developer/images/GUID-062EDDCE-D844-4382-A665-C8A36D8FFCDB-low.gif\' title=\'\'>Undo to change the box back to its original orientation.</p>\n\
<blockquote>\n\
<p><strong>IF YOU DESIGNATE ANGLES FOR MORE THAN ONE AXIS:</strong></p>\n\
<p>``` rot_box2 = eulerangles 30 45 60</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The rotation is applied to an object, with the X-axis rotation occurring first, followed by the Y-axis rotation, and then the Z-axis rotation.</p>\n\
<p>Note:</p>\n\
<p>Moving, scaling, or rotating objects, or setting transform-related properties operates in the World Coordinate System, by default. If you want to perform these transformations in another coordinate system, see <a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/coordsys.html\' title=\'\'>Coordsys</a>.</p>\n\
<p><strong>Next Topic</strong></p>\n\
<p><a href=\'#!/url=./developer/Learning-MAXScript/Manipulating-The-Box-First-Steps/More-Box-Transformations.html\' title=\'\'>More Box Transformations</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";