var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Modifying the Box</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Modifying the Box</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"modifying-the-box\"></a></div>\n\
<p>In the <a href=\'#!/url=./developer/Learning-MAXScript/Manipulating-The-Box-First-Steps/Drawing-a-Box-with-MAXScript.html\' title=\'\'>previous lesson</a>, you created a box by assigning it to a named variable.</p>\n\
<p>Because you used a variable for the box, you can now access all of the box’s properties easily.</p>\n\
<p>The variable name <span class=\'code\'>mybox</span> is the <em>handle</em> to your box. To access the properties of the handle, append a &quot;.&quot; (period), and then the property name.</p>\n\
<p>For example, <span class=\'code\'>mybox.height</span> can be read as &quot;the height of mybox.&quot;</p>\n\
<p>All <strong>3ds Max</strong> objects have creation parameters such as width, length, and height for boxes, or radius for spheres and circles.</p>\n\
<p>These objects also have transformation properties, such as scale, rotation, or position, and general properties like name, wirecolor, etc.</p>\n\
<p>To change any of these properties, you can set the property to a new value.</p>\n\
<div class=\'section\'><a id=\"changing-object-properties\"></a><h2 id=\"changing-object-properties\">Changing Object Properties</h2></div>\n\
<div class=\'section\'><a id=\"object-name\"></a><h3 id=\"object-name\">Object Name</h3></div>\n\
<p>If you don’t like the default object name Box001, you can change the name property of the box:</p>\n\
<p>Enter <span class=\'code\'>mybox.name = &quot;BlueBox&quot;</span> in the Listener window and the software renames the box.</p>\n\
<p>You can see the new name in the Name edit box when you go to the Modify panel:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-D2686E09-A228-414A-8AEA-685AF0B862B0-low.gif\' title=\'\'></div>\n\
<div class=\'section\'><a id=\"color\"></a><h3 id=\"color\">Color</h3></div>\n\
<p>By default, 3ds Max assigns the color of objects randomly at creation time. Therefore, the color of your box is not necessarily blue. In this case, BlueBox wouldn’t be an appropriate name for your box. However, you can change the color of your box to match the name:</p>\n\
<p>Enter <span class=\'code\'>mybox.wirecolor = blue</span> and watch the box in your viewports turn blue. You may have to select the box again to reflect the new color in the color swatch next to the object name in the Modify panel.</p>\n\
<p>The color <span class=\'code\'>blue</span> is a predefined color constant in MAXScript and its RGB value is defined as (0,0,255). The other predefined color variables are red, green, white, black, orange, yellow, and brown. Instead of using a predefined color, you can assign a color with different RGB values, such as:</p>\n\
<div class=\'codeBlock\'><pre>mybox.wirecolor = (color 255 0 255)\n\
\n\
</pre></div><p>Notice the special syntax for entering specific color values.</p>\n\
<p>The example shown would change the box to magenta. If you entered this command, click <img src=\'developer/images/GUID-062EDDCE-D844-4382-A665-C8A36D8FFCDB-low.gif\' title=\'\'>Undo to change the box back to blue.</p>\n\
<p>For more information on colors, see the <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/Color-Values.html\' title=\'\'>Color Values</a> topic in the MAXScript reference.</p>\n\
<div class=\'section\'><a id=\"position\"></a><h3 id=\"position\">Position</h3></div>\n\
<p>You can change the position of the box by changing the box’s position property.</p>\n\
<p>You refer to the position property for this example box with <span class=\'code\'>mybox.pos</span>.</p>\n\
<p>The position is expressed as the X, Y, Z coordinates.</p>\n\
<p>For example <span class=\'code\'>\\[0,-75,0\\]</span> will position the box 75 units along the negative Y axis.</p>\n\
<p>Enter <span class=\'code\'>mybox.pos = \\[0,-75,0\\]</span> and watch the box jump in the perspective view.</p>\n\
<p>Click <img src=\'developer/images/GUID-062EDDCE-D844-4382-A665-C8A36D8FFCDB-low.gif\' title=\'\'>Undo to move the box back to the origin.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-9E79A889-A802-4451-9428-5919BBBA2905-low.gif\' title=\'\'></div>\n\
<div class=\'section\'><a id=\"size\"></a><h3 id=\"size\">Size</h3></div>\n\
<p>To make the box bigger, you can use the scale property of the box:</p>\n\
<blockquote>\n\
<p><strong>ENTER:</strong></p>\n\
<p>``` mybox.scale = [1.5,1.5,1.5]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>to see the box resized to 1.5 times its original size.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-3893148A-C193-442C-8C17-FFD3CCF0D505-low.gif\' title=\'\'></div>\n\
<p>Click<img src=\'developer/images/GUID-062EDDCE-D844-4382-A665-C8A36D8FFCDB-low.gif\' title=\'\'> Undo to undo the scale and return the box to its original size.</p>\n\
<p>The scale property requires a scaling factor for each of the X, Y, and Z axes, or, in this case, the width, length and height of the box. You don’t have to use the same value for each axis unless you want to resize the box uniformly.</p>\n\
<p>If you want to change the scale to affect only the height and the width, but not the length, use the following</p>\n\
<blockquote>\n\
<p><strong>ENTER:</strong></p>\n\
<p>``` mybox.scale = [1,3,2]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>When you scale your original [20,20,20] box by any factor, the box’s parameters are still 20 for width, 20 for length, and 20 for height. You can see this when you open the Modify panel. The box parameters are not changed by the scale transformation:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-ACFBEF8A-BE0F-4E2F-A57E-E9A48DEA7D88-low.gif\' title=\'\'></div>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-D965438C-6631-4D9F-B105-42C048A0DD12-low.gif\' title=\'\'></div>\n\
<p>Although altering the height and width properties of the box achieves the same result, <em>visually</em>, the above scale modification is <em>not</em> equivalent to using the following two commands:</p>\n\
<div class=\'codeBlock\'><pre>mybox.height = 40 -- 2 times the original 20 units \n\
mybox.width = 60 -- 3 times the original 20 units\n\
\n\
</pre></div><p>The reason for this is that changing the height property of the box changes the creation parameter of the box’s height. Using the scale property to transform the height of the box does not.</p>\n\
<p>Again, the effect of using either method is visually the same. However, when you want to maintain the original creation parameters of an object (so that you can alter them even after a number of different transformations), you must use the scale property to manipulate the size of the box, not the individual creation properties.</p>\n\
<p>Also note that in real world production, scaling objects is generally a bad idea as it can interfere with the animation of hierarchically linked objects and other features of <strong>3ds Max</strong>. Using an XForm modifier&#39;s and scaling its Gizmo is the preferred approach as it localizes the scale to the Modifier Stack and does not affect the animation transformations.</p>\n\
<p>Click <img src=\'developer/images/GUID-062EDDCE-D844-4382-A665-C8A36D8FFCDB-low.gif\' title=\'\'>Undo to change the box back to its original scale of [1,1,1].</p>\n\
<div class=\'section\'><a id=\"finding-additional-parameters\"></a><h3 id=\"finding-additional-parameters\">Finding Additional Parameters</h3></div>\n\
<p>The Parameters rollout shows all the creation parameters for a box. You can change them using the spinners in the rollout. If you want to change the value of the length, width, and height segments, or the setting of the mapping coordinates in MAXScript, you need to know the syntax for these parameters. In order to find the syntax for <em>all</em> of the parameter settings, there are two different inspector functions.</p>\n\
<p>The first of these is <span class=\'code\'>showclass()</span>.</p>\n\
<p>The <span class=\'code\'>showClass()</span> function prints information about a specified <strong>3ds Max</strong> class or classes. The information entered in the parentheses is a string containing a wild-card pattern to match against <strong>3ds Max</strong> class names, superclass names, and property names.</p>\n\
<blockquote>\n\
<p><strong>ENTER:</strong></p>\n\
<p>``` showclass &quot;box.*&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>MAXScript shows all the box parameters that are equivalent to the ones you see in the Parameters rollout, including which object class the box object belongs to, and the data type that each parameter requires:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-D1A4DC42-3812-434A-BAF7-F8D664068EF3-low.gif\' title=\'\'></div>\n\
<p>Notice that you can use the &quot;<em>&quot; character as a wildcard to see all box parameters. If you had entered <span class=\'code\'>showClass &quot;box*.*,&quot;</span> MAXScript would have listed all of the parameters of the<span class=\'code\'>Box</span> </em>and* the <span class=\'code\'>BoxGizmo</span> classes.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` showClass &quot;box<em>&quot; -- all 3ds max classes starting &quot;box&quot; showClass &quot;box.</em>&quot; -- all the accessible properties of the box class showClass &quot;<em>:mod</em>&quot; -- all the modifier classes showClass &quot;<em>.</em>rad*&quot; -- all the classes with a property name containing &quot;rad&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The second inspector function is <span class=\'code\'>showProperties()</span>.</p>\n\
<p>The <span class=\'code\'>showProperties()</span> function is used to display the properties for a specific object that is an instance of one of the <strong>3ds Max</strong> classes. It can be used in place of <span class=\'code\'>showClass()</span> in situations where you have an actual object in hand. Unlike <span class=\'code\'>showClass()</span>, it can display the dynamic properties that may appear in individual objects as you work on them in the scene.</p>\n\
<p>To learn more about these functions, see <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Identifying-and-Accessing/Class-and-Object-Inspector.html\' title=\'\'>Class and Object Inspector Functions</a>.</p>\n\
<p><strong>Next Topic</strong></p>\n\
<p><a href=\'#!/url=./developer/Learning-MAXScript/Manipulating-The-Box-First-Steps/Applying-Standard.html\' title=\'\'>Applying Standard Transformations</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";