var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Controlling the Listener Contents and the Insertion Point</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Controlling the Listener Contents and the Insertion Point</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"controlling-the-listener-contents-and-the-insertion-point\"></a></div>\n\
<p>The Listener output pane’s content and insertion point placement can be controlled with the following methods:</p>\n\
<div class=\'codeBlock\'><pre>clearListener()\n\
</pre></div><p>Clears all text from the Listener output pane.</p>\n\
<div class=\'codeBlock\'><pre>setListenerSel #(&lt;start_integer&gt;,&lt;end_integer&gt;)\n\
</pre></div><p>Sets the current text selection in Listener.</p>\n\
<p>The start and end values are the character offsets in the Listener output pane text, starting at <span class=\'code\'>0</span> .</p>\n\
<p>If the start and end values are the same, no text is selected and the insertion point is placed at the specified point.</p>\n\
<p>You can specify <span class=\'code\'>-1</span> for the start or end values, which specifies the end of the Listener output pane text.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>the following would put the insertion point at the end of the text:</p>\n\
<p>``` setListenerSel #(-1,-1)</p>\n\
<p>```</p>\n\
<p>while the following would select all of the text in the Listener output pane text:</p>\n\
<p>``` setListenerSel #(0,-1)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><span class=\'code\'>&lt;start_integer&gt;</span> and <span class=\'code\'>&lt;end_integer&gt;</span> are integer literals, or expressions that evaluate to an integer.</p>\n\
<p>In versions prior to <strong>3ds Max 2014</strong>, this function was unusable because it would return OK printing this value destroyed the newly set text selection.</p>\n\
<p>this function returns the predefined global value <span class=\'code\'>silentValue</span>, which does not print anything, and so the text selection in the Listener is not destroyed. Available in <strong>3ds Max 2019.2 Update and higher</strong>.</p>\n\
<p>From <strong>3ds Max 2014</strong> to <strong>3ds Max 2019.1 Update</strong>, this function returned the value <span class=\'code\'>noValue</span>, which did not print anything, but was not defined as a global variable .</p>\n\
<div class=\'codeBlock\'><pre>getListenerSel()\n\
</pre></div><p>Returns the current text selection indexes as a two-element array, <span class=\'code\'>#(start, end)</span> . These values are the character offsets in the Listener output pane text, starting at <span class=\'code\'>0</span> . If there is no selection, but only an insertion point, the start and end values are equal. Only the selections set using the <span class=\'code\'>setListenerSel()</span> method are recognized by this method. If no selection has been set using the <span class=\'code\'>setListenerSel()</span> method, the start and end values returned are the offset to the end of the Listener output pane text.</p>\n\
<div class=\'codeBlock\'><pre>getListenerSelText()\n\
</pre></div><p>Returns the currently selected text, or an empty string if no text is selected and only the insertion point is showing. Only the selections set using the <span class=\'code\'>setListenerSel()</span> method are recognized by this method. If no selection has been set using the <span class=\'code\'>setListenerSel()</span> method, an empty string is returned.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>the following lines would capture the entire contents of the Listener output pane to variable <span class=\'code\'>ListenerText</span>:</p>\n\
<p>``` ( global ListenerText -- Declare variable to capture the Listener to setListenerSel #(0,-1) -- Select all the text ListenerText=getListenerSelText() -- Get selected text setListenerSel #(-1,-1) -- Set insertion point at end of output pane )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>setListenerSelText &lt;replacement_string&gt;\n\
</pre></div><p>Replaces the currently selected text with the replacement string. If no text is selected and only the insertion point is showing, <span class=\'code\'>setListenerSelText()</span> inserts the replacement string at the insertion point. Only the selections set using the <span class=\'code\'>setListenerSel()</span> method are recognized by this method. If no selection has been set using the <span class=\'code\'>setListenerSel()</span> method, the insertion point is the end of the Listener output pane text. &lt; <span class=\'code\'>replacement_string</span> &gt; is a string literal or an expression that evaluates to a string.</p>\n\
<div class=\'codeBlock\'><pre>include &lt;filename_string&gt;\n\
</pre></div><p>Inserts the specified file’s content into the Listener output pane. The inserted text is not evaluated. You can use this method to load a script and then step through it, executing any selected text with SHIFT+ENTER. <span class=\'code\'>&lt;filename_string&gt;</span> is a string literal or an expression that evaluates to a string, and specifies the name of the file to insert.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE USAGES ARE:</strong></p>\n\
<p>``` include &quot;my_script.ms&quot;</p>\n\
<p>```</p>\n\
<p>or</p>\n\
<p>``` scriptfile=&quot;c:\\my_scripts\\my_script.ms&quot; include scriptfile</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>If you don’t explicitly specify a directory in the file name, the file will be searched for in the following directories, in the order listed:</p>\n\
<ul>\n\
<li><p>The current MAXScript directory</p></li>\n\
<li><p>The <strong>3ds Max</strong> executable main directory</p></li>\n\
<li><p>The Windows NT 32-bit system directory (system32)</p></li>\n\
<li><p>The Windows 16-bit system directory (system)</p></li>\n\
<li><p>The Windows directory</p></li>\n\
<li><p>The directories that are listed in the PATH environment variable</p></li>\n\
</ul>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";