var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Startup Scripts</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Startup Scripts</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"startup-scripts\"></a></div>\n\
<p>When <strong>3ds Max</strong> is first started, MAXScript searches for any startup script files that it then automatically loads and runs. This feature is useful if you have function libraries you always use and want preloaded, or if you want to establish custom UI settings, define scripted plug-ins, or load scripted utility rollouts.</p>\n\
<p>When <strong>3ds Max</strong> starts up, it will always follow the script loading order described below. Certain parts of the software will still not be up and running at different stages of the startup process. Understanding the order and the reasons for it will help you organize your code and have all functions and UI auto-loading and working correctly together.</p>\n\
<p>Note: 3ds Max looks for scripts of type <span class=\'code\'>.ms</span>, <span class=\'code\'>.mcr</span>, <span class=\'code\'>.mse,</span> and <span class=\'code\'>.mzp</span>. If you have scripts that you don&#39;t want to load automatically, for example library scripts you explicitly load in other scripts, you can give them the <span class=\'code\'>.mxs</span> extension. This extension is still recognized as executable by the MAXScript Editor.</p>\n\
<p>Note: You can use the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Miscellaneous-Functions.html\' title=\'\'><span class=\'code\'>getMaxscriptStartupState()</span></a> function to determine if standard or startup scripts are currently loading, or are loaded.</p>\n\
<div class=\'section\'><a id=\"hidden-scripts\"></a><h2 id=\"hidden-scripts\">Hidden Scripts</h2></div>\n\
<p>To enhance system security, startup scripts that have the hidden file or system attribute set are not loaded. Scripts that are in a hidden or system folder (other than <span class=\'code\'>%LocalAppData%</span> and <span class=\'code\'>%ProgramData%</span>) are also not loaded. If a script is discovered that meets one of these criteria, it is logged to the system log with the script path and name, the file attributes, and &quot;Action: not loaded&quot;. <strong>Available in 3ds Max 2021.3 Update and higher.</strong> ## Launching 3ds Max Without a File</p>\n\
<div class=\'section\'><a id=\"step-1---standard-scripts\"></a><h3 id=\"step-1---standard-scripts\">STEP 1 - Standard Scripts</h3></div>\n\
<p><strong>3ds Max</strong> will evaluate the shipping scripts found in <em>stdplugs\\stdscripts</em>. These define functions needed by several scripted elements of the base <strong>3ds Max</strong> software.</p>\n\
<p>If you need to have some functions/global variables defined for use by your own MacroScript, those should go into an .ms file in <em>stdplugs\\stdscripts</em>. This will ensure that they will be defined first.</p>\n\
<div class=\'section\'><a id=\"step-2---user-defined-plug-in-paths\"></a><h3 id=\"step-2---user-defined-plug-in-paths\">STEP 2 - User-Defined Plug-in Paths</h3></div>\n\
<p>Next, <strong>3ds Max</strong> will load script files in directories and plug-in packages defined in <strong>Customize... &gt; Configure Paths... &gt; Plug-Ins</strong> <em>and their subdirectories</em>. Note that this is different from the way regular plug-ins are loaded. Plug-ins will only load from the specified path and not search sub-directories. Here you can define functions, methods, and structures used by other scripts, particularly MacroScripts.</p>\n\
<p>The <strong>3ds Max</strong> scene has not been created and the viewports have not been created at this point. You cannot create scene objects or do anything UI related in these scripts. Of course you can define functions that do these operations, you just can&#39;t call these functions at this point.</p>\n\
<p>In this pass, any script files with the name <em>startup.ms</em> are ignored. This allows you to place your scripted plug-in scripts in the plug-in folders for automatic loading. They can be managed like DLL plug-ins, and used to organize your startup scripts into groups in their own directories for easier management. You can prevent a nested directory from being scanned by placing its name in parentheses, for example &quot;(old-versions)&quot;, allowing you to enable and disable scripts in handy directory-based groupings.</p>\n\
<div class=\'section\'><a id=\"step-3---plug-in-packages\"></a><h3 id=\"step-3---plug-in-packages\">STEP 3 - Plug-in Packages</h3></div>\n\
<p>Next, scripts found in plug-in packages are evaluated (such as appbundles from the Autodesk App Store). When found in a plug-in package, only scripts that are specified as a <strong>PreStartupScript</strong> (&quot;pre-start-up scripts parts&quot; in the <span class=\'code\'>PackageContents.xml</span> file) are run during this step. Note that the <strong>3ds Max</strong> UI is not yet present at this step.</p>\n\
<div class=\'section\'><a id=\"step-4---macroscripts\"></a><h3 id=\"step-4---macroscripts\">STEP 4 - MacroScripts</h3></div>\n\
<p>Next, MacroScript .mcr files in <em>ui\\macroscripts</em> will be evaluated - they define Action Items that can be displayed in the UI. At this point, UI has not been built yet, the MacroScripts will be needed to fill in their related buttons.</p>\n\
<div class=\'section\'><a id=\"step-5---startup-scripts\"></a><h3 id=\"step-5---startup-scripts\">STEP 5 - Startup Scripts</h3></div>\n\
<p>Finally, the <em>startup.ms</em> and then any scripts found in the startup folders will be evaluated. At this point, scene, viewports, and UI are up. You can do anything here you want.</p>\n\
<p>In <strong>3ds Max 9 and higher</strong>, startup scripts in the <strong>3ds Max system startup scripts</strong> directory are run first, then the startup scripts in the <strong>user startup scripts</strong> directory are run, providing that the user startup scripts directory is different than the max system startup scripts directory. Finally, any scripts from plug-in packages that are specified as <strong>PostStartupScript</strong> (&quot;post-start-up scripts parts&quot; in the PackageContents.xml file) are run.</p>\n\
<p>MAXScript first searches for a file named <em>startup.ms</em> in the following directories, in the order listed:</p>\n\
<ul>\n\
<li>The user scripts directory<br></li>\n\
<li>The user startup scripts directory<br></li>\n\
<li>The 3ds Max system scripts directory<br></li>\n\
<li>The 3ds Max system startup scripts directory<br></li>\n\
<li>The 3ds Max executable main directory<br></li>\n\
<li>The Windows NT 32-bit system directory (system32)<br></li>\n\
<li>The Windows 16-bit system directory (system)<br></li>\n\
<li>The Windows directory<br></li>\n\
<li>The directories that are listed in the PATH environment variable</li>\n\
</ul>\n\
<p>MAXScript stops searching when it finds the first occurrence of <em>startup.ms</em>.</p>\n\
<p>The automatic loading of startup script files can be deactivated by turning off the Auto Start MAXScript option in the MAXScript page of the Preferences dialog, as described in the MAXScript Preferences Settings topic in the main product online help.</p>\n\
<div class=\'section\'><a id=\"launching-3ds-max-with-a-file\"></a><h2 id=\"launching-3ds-max-with-a-file\">Launching 3ds Max With a File</h2></div>\n\
<p>Consider the following two use cases:</p>\n\
<ol>\n\
<li><p>Starting <strong>3ds Max</strong> from the command line, eventually with a <a href=\'#!/url=./developer/MAXScript-Introduction/General-MAXScript-Topics/Running-Scripts-from-the-Command.html\' title=\'\'>command line script</a>:</p>\n\
<blockquote>\n\
<p><span class=\'code\'>3dsmax.exe somefile.max   3dsmax.exe somefile.max -U MAXScript somescript.ms</span></p>\n\
</blockquote></li>\n\
<li><p>Dragging a <span class=\'code\'>.MAX</span> file onto a <strong>3ds Max</strong> shortcut on your desktop</p></li>\n\
</ol>\n\
<p>In both cases, <strong>3ds Max</strong> boots up as described above and then loads the file.</p>\n\
<p>The order of script folders and callbacks getting executed is as follows:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">Folder / Callback Processed</th>\n\
<th align=\"left\">Comments</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>stdplugs\\stdscripts\\</span></td>\n\
<td align=\"left\">3ds Max scene and UI not created yet.</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>plugin paths</span></td>\n\
<td align=\"left\">3ds Max scene and UI not created yet.</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>MacroScripts</span></td>\n\
<td align=\"left\">UI not created yet.</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>\\Startup</span></td>\n\
<td align=\"left\">UI Created. Startup scripts loaded before callbacks.</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#filePreOpenProcess</span></td>\n\
<td align=\"left\">Scene created.</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#filePreOpen</span></td>\n\
<td align=\"left\">File objects not accessible yet.</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>.MAX File</span></td>\n\
<td align=\"left\">Loading the command line / dropped file</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#filePostOpen</span></td>\n\
<td align=\"left\">Scene objects are accessible from here on.</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#filePostOpenProcess</span></td>\n\
<td align=\"left\">File has finished loading.</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>Command Line -U MAXScript script</span></td>\n\
<td align=\"left\">Executing the command line script (if any)</td>\n\
</tr>\n\
</table>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";