var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Inheritance and Polymorphism</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Inheritance and Polymorphism</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"inheritance-and-polymorphism\"></a></div>\n\
<p>Inheritance and polymorphism are the two defining characteristics of object-oriented languages. <em>Inheritance</em> is the ability of an object class to inherit the operations and properties of its parent class. <em>Polymorphism</em> is the ability of a single-named operation to work on different values of different object classes. We&#39;ll explore them here to see how they are used in <strong>3ds Max</strong> and MAXScript.</p>\n\
<p>First and foremost, both characteristics depend on the system having a well-defined type, or <em>class</em>, for every value. Assigning classes to values divides all the values you can work with into groups, each of which have well-defined operations and properties for their values. In some languages, like standard C++, the class is only manifest at compile-time. In others, like Smalltalk and MAXScript, the classes are actual runtime entities and every value has a runtime class-tag that says what class it is. This is the main reason MAXScript can have type-free variables. It can look at the class-tag of the value in a variable at runtime to determine its class.</p>\n\
<p>Once the objects are grouped into classes, the groups themselves can be arranged into hierarchies. We do this all the time in real life. A classic example is the biological hierarchy, arranging real-life objects hierarchically into animals and plants and mammals and vertebrates and humans and adults and children, and so on. An object-oriented language provides a way to arrange value classes into hierarchies and, like the hierarchies we are used to, a class at some point in the hierarchy shares all the operations and properties of all its parent classes. This sharing is known as <em>inheritance</em> in object-oriented languages, and the operations and properties defined for a class are automatically inherited by all of its descendant classes.</p>\n\
<p>As an example, the following is the hierarchy for the Box class:</p>\n\
<blockquote>\n\
<p>``` Value MAXWrapper Node GeometryClass Box</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Various characteristics are defined for a class, and each lower class inherits those characteristics. For example, the <span class=\'code\'>classOf()</span> method is defined for class Value, and class Box inherits this method through its hierarchy. Thus you can specify a Box object as a parameter to the <span class=\'code\'>classOf()</span> method.</p>\n\
<p>In the MAXScript Class Hierarchy topic, all the built-in classes in MAXScript are laid out in their place in the hierarchy so you can see for each class the classes it inherits characteristics from. Some of the hierarchy comes from within <strong>3ds Max</strong> itself which is internally object-oriented. All of its objects, modifiers, controllers, and so on are arranged in a well-defined inheritance hierarchy.</p>\n\
<p>Once the objects have been grouped into classes, the symbology for the operations that can be performed on objects of each class can be simplified. The classic example of this comes from mathematics. The symbolic operators &#39;+&#39;, &#39;-&#39;, &#39;<em>&#39;, and &#39;/&#39; are shared among many types of values (integers, reals, complex, vectors, matrices, and so on), and perform the correct action on the types they are applied to. This capability for a single-named operation to work on different types is called </em>polymorphism*. Object-oriented languages let you use the same name for different methods or operators across different classes, and the correct method to apply is automatically determined based on the class of the value it is used with.</p>\n\
<p>In MAXScript, all math operators and methods are polymorphic in this sense and reflect the standard mathematical conventions. An interesting example for <strong>3ds Max</strong> use is the <span class=\'code\'>random()</span> method. It takes two arguments and generates a random value between them. So, if you give it floats it gives you a float back; if you give it 3D points, it gives you a random point in the box they define the corners of; if you give it quaternions, it gives you back a random rotation between them, and so on.</p>\n\
<p>Further, all the methods that work on <strong>3ds Max</strong> objects are polymorphic within their hierarchies. So move, hide, and select work on all types of scene objects; time scaling and insertion work on all the types of controllers, and so on.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";