var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Syntax Definitions in This Document</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Syntax Definitions in This Document</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"syntax-definitions-in-this-document\"></a></div>\n\
<p>The ways you can write MAXScript tokens and clauses are given using a set of shorthand rules as shown in the following example:</p>\n\
<div class=\'codeBlock\'><pre>[-]{&lt;digit&gt;}[.{&lt;digit&gt;}][(e|E)[+|-]{&lt;digit&gt;}+]\n\
</pre></div><p>These rules, or <em>syntax definitions</em>, follow the standard EBNF notation (Extended Backus-Naur Form).</p>\n\
<p>The previous example shows the syntax for a decimal number in MAXScript. The rules typically contain a number of characters with special meanings. For example, brackets enclose optional items, such as the minus sign in front of the number. Braces enclose items you can use repeatedly, and bars separate multiple items from which you can choose one. Sometimes, rules are given names so they can be referred to in the documentation or as parts of other rules. The special characters in the rules have the following meaning:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">Characters</th>\n\
<th align=\"left\">Meaning</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>[...]</span></td>\n\
<td align=\"left\">items inside the brackets are optional</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>(...|...|...)</span></td>\n\
<td align=\"left\">choose one of the items separated by the bars</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>{...}</span></td>\n\
<td align=\"left\">you can specify the braced item ZERO or more times</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>{...}+</span></td>\n\
<td align=\"left\">you can specify the braced item ONE or more times</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>::=</span></td>\n\
<td align=\"left\">define a name for a syntax rule</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>&lt;rule&gt;</span></td>\n\
<td align=\"left\">you can insert what is defined by the named rule</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>bold_characters</span></td>\n\
<td align=\"left\">characters or token as written</td>\n\
</tr>\n\
</table>\n\
<p>The previous number syntax example is interpreted as follows:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">Syntax</th>\n\
<th align=\"left\">Definition</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">[<span class=\'code\'>-</span>]<span class=\'code\'>{&lt;digit&gt;}</span></td>\n\
<td align=\"left\">an optional minus sign (the sign), followed by 0 or more digits (the integer part), followed by</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">[<span class=\'code\'>.</span>{<digit>}]</digit></td>\n\
<td align=\"left\">an optional sequence (the fraction part) comprised of: a period character, followed by 0 or more digits, followed by</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">[(<span class=\'code\'>e</span>|<span class=\'code\'>E</span>)[<span class=\'code\'>+</span>|<span class=\'code\'>-</span>]<span class=\'code\'>{&lt;digit&gt;}</span>+]</td>\n\
<td align=\"left\">an optional sequence (the exponent part) comprised of: either an ’r;e’ or ’r;E’, followed by an optional plus or minus sign, followed by one or more digits.</td>\n\
</tr>\n\
</table>\n\
<p>Examples of valid numbers are:</p>\n\
<blockquote>\n\
<p>``` 123 1.456 -0.89e-7 1.536E23</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>THE FOLLOWING NUMBERS ARE NOT VALID:</strong></p>\n\
<p>``` 12x34 -0.45x10^3 0e</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The syntax definitions in <a href=\'#!/url=./developer/MAXScript-Language-Reference/MAXScript-Grammar.html\' title=\'\'>MAXScript Grammar</a> are in the form of named rule definitions.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p><span class=\'code\'>number ::= [-]{&lt;digit&gt;}[.{&lt;digit&gt;}](e|E)[+|-]{&lt;digit&gt;}+]</span></p>\n\
<p>allowing the rule to be referred to by name in other rules in the grammar.</p>\n\
<p><strong>AN EXAMPLE OF SUCH RULE IS:</strong></p>\n\
<p><span class=\'code\'>mod &lt;number1&gt; &lt;number2&gt;</span></p>\n\
<p>modulo arithmetic, the remainder when <span class=\'code\'>&lt;number1&gt;</span> is divided by <span class=\'code\'>&lt;number2&gt;</span></p>\n\
</blockquote>\n\
<p>Some definitions throughout this document also use the convention of showing alternative definitions for a rule on consecutive lines instead of separating them with the &#39; <span class=\'code\'>|</span> &#39; symbol.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";