var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Assert Functions</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Assert Functions</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"assert-functions\"></a></div>\n\
<p>You can use the Assert function to place assertions in the MAXScript code. Additionally, an <a href=\'#!/url=./developer/MAXScript-Introduction/The-MAXScript-Debugger/GUID-821E791F-6D80-48C7-8A65-65BE73C551C6.html\' title=\'\'>advanced set of assert functions and an AssertReporter message log system</a> are available, and are being used for test suites by Autodesk during the development of <strong>3ds Max</strong>.</p>\n\
<p><strong>Overview:</strong></p>\n\
<p>An assertion is a predicate (a true|false statement) placed in the code to indicate that the developer thinks the predicate always evaluates to true at that place.</p>\n\
<p>Assertions are used to help reason about program correctness.</p>\n\
<p><strong>Syntax:</strong></p>\n\
<div class=\'codeBlock\'><pre>assert &lt;expression&gt; [message:&lt;string&gt;] [options:#( #dialog | #listener | #debug_output_window | #debugBreak | #c_break | #all)] [showstack:&lt;boolean&gt;]\n\
</pre></div><p><strong>Asserts</strong> that the <strong>result of the expression</strong> passed as the first argument to the function <strong>must be true</strong> at the given place in the code.</p>\n\
<p>The expression <strong>must</strong> resolve to a Boolean value, otherwise a MAXScript exception is thrown.</p>\n\
<p>If the expression returns <span class=\'code\'>true</span>, the code continues normally.</p>\n\
<p>If the expression returns <span class=\'code\'>false</span>, the execution will be interrupted depending on the following options:</p>\n\
<p><span class=\'code\'>message:</span> - If this optional keyword is supplied, the string is displayed as the assert&#39;s message.</p>\n\
<p><span class=\'code\'>options:</span> - An array of the following MAXScript name options. If the array is empty, it defaults to <span class=\'code\'>#listener</span>.</p>\n\
<p><span class=\'code\'>#dialog</span>- brings up a modal dialog that halts execution of the application.</p>\n\
<p><span class=\'code\'>#listener</span> - prints out the failure info to theMAXScript Listener</p>\n\
<p><span class=\'code\'>#debug_output_window</span> - prints out to the Visual Studio output debugger window, (if present)</p>\n\
<p><span class=\'code\'>#debugBreak</span> - Halts execution in the MAXScript Debugger. If specified, the #dialog option is ignored. This option is only valid if quiet mode is false. Otherwise nothing happens.</p>\n\
<p><span class=\'code\'>#c_break</span> - Breaks execution in Visual Studio under the Debugger. This only works if running a debug build of <strong>3ds Max</strong> under the Debugger. If specified, it first turns on the <span class=\'code\'>#debug_output_window</span> flag internally to aid in debugging. The <span class=\'code\'>#debugBreak</span> and <span class=\'code\'>#dialog</span> option will be ignored and it always occurs last to allow the other options to output their data.</p>\n\
<p><span class=\'code\'>#all</span> - All of the above, except <span class=\'code\'>#dialog</span> and <span class=\'code\'>#c_break</span></p>\n\
<p><span class=\'code\'>showstack:</span> - defines whether to include the MAXScript stack traceback in the printouts. This only applies for the <span class=\'code\'>#listener</span> and <span class=\'code\'>#debug_output_window</span> options. For all other options the stack information is ignored. Default is false.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>In the following example, the function loops through all objects in the scene and accumulates their positions. At the end, it divides the resulting value by the number of objects to calculate the average position.</p>\n\
<p>The script developer has assumed that the scene will never be empty, thus the final result would be a valid position. If the number of objects is zero, the division by zero would not crash the program, but would produce a Point3 value of[-1.#IND,-1.#IND,-1.#IND].</p>\n\
<p>``` fn averageObjectPosition = ( theSum = [0,0,0] theCount = objects.count for i = 1 to theCount do ( theSum += objects[i].pos ) assert (theCount &gt; 0) message: &quot;theCount expected to be positive, but was found not to be!&quot; options:#(#all) showstack:true theSum /= theCount )</p>\n\
<p>averageObjectPosition()</p>\n\
<p>```</p>\n\
<p>The developer has opted to include an <span class=\'code\'>assert()</span> call, which postulates that <span class=\'code\'>theCount</span> is expected to be always greater than zero and if that is not the case, the execution of the code will break in the debugger and will show the stack in the Listener.</p>\n\
<p>In this example, this is done for demonstration and to illustrate how the <span class=\'code\'>assert()</span> function works.</p>\n\
<p>In real world, the <span class=\'code\'>assert()</span> would be typically used to ensure the correctness of values going through much more complex calculations where catching irregularities with IF tests would be difficult because the developer cannot anticipate what can be the possible cases to test. In addition, the <span class=\'code\'>assert()</span> has several report modes that could be useful (like breaking in the C++ Debugger when running a Debug build of <strong>3ds Max</strong>).</p>\n\
<p>If the above function is executed with an empty scene, the result would be</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-A940F022-D1F8-4820-920D-58B521648984-low.gif\' title=\'\'></div>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"test-framework-assert-functions\"></a><h2 id=\"test-framework-assert-functions\">Test Framework Assert Functions</h2></div>\n\
<p>A number of assert functions and an <span class=\'code\'>AssertReporter</span> struct to manage their messages have been implemented and are now being used for internal testing at Autodesk.</p>\n\
<p>These functions are available to all MAXScript users and can be employed in custom test frameworks to ensure the correctness of the program flow.</p>\n\
<p>These Test Framework functions have the following advantages:</p>\n\
<ol>\n\
<li>They report the file</li>\n\
<li>They report the line number</li>\n\
<li>They report the calling function</li>\n\
<li>They report the expected and actual values</li>\n\
</ol>\n\
<p>All asserts are reported automatically.</p>\n\
<p>This new system should significantly reduce the visual clutter of the asserts as developers have the option of NOT having to construct massive error strings for the message of the asserts (although they still can provide custom messages where needed). Also, these asserts run quietly and gather their messages in a dedicated <span class=\'code\'>AssertReporter</span> to be queried and analyzed after running the code without interrupting the actual test run.</p>\n\
<p><strong>The assert functions are:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assert_true &lt;expression&gt;expectedToBeTrue [message:&lt;string&gt;]\n\
</pre></div><p>Returns false and logs an assert failure message with the <span class=\'code\'>AssertReporter</span> if the return value of the expression is not true.</p>\n\
<p>Will log a default message in the form of <strong><em>&quot;Assert - Expected true, got false - (No File) in frame <no stack=\"\" frame=\"\">, at line 1&quot;</no></em></strong> unless the optional <span class=\'code\'>message:</span> keyword argument is provided.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assert_false &lt;expression&gt;expectedToBeFalse [message:&lt;string&gt;]\n\
</pre></div><p>Returns false and logs an assert failure message with the <span class=\'code\'>AssertReporter</span> if the return value of the expression is not false.</p>\n\
<p>Will log a default message in the form of <strong><em>&quot;Assert - Expected false, got true - (No File) in frame <no stack=\"\" frame=\"\">, at line 1&quot;</no></em></strong> unless the optional <span class=\'code\'>message:</span> keyword argument is provided.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assert_equal &lt;value&gt;expected &lt;expression&gt;actual [message:&lt;string&gt;]\n\
</pre></div><p>Returns false and logs an assert failure message with the <span class=\'code\'>AssertReporter</span> if the return value of the expression passed as second argument is not equal to the expected value passed as first argument.</p>\n\
<p>Will log a default message in the form of <strong><em>&quot;Assert - Expected 1, got 2 - (No File) in frame <no stack=\"\" frame=\"\">, at line 1&quot;</no></em></strong> unless the optional <span class=\'code\'>message:</span> keyword argument is provided.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assert_not_equal &lt;value&gt;expected &lt;expression&gt;actual [message:&lt;string&gt;]\n\
</pre></div><p>Returns false and logs an assert failure message with the <span class=\'code\'>AssertReporter</span> if the return value of the expression passed as second argument is equal to the expected value passed as first argument.</p>\n\
<p>Will log a default message in the form of <strong><em>&quot;Assert - Expected value not equal to <expected>, got <actual> - (No File) in frame <no stack=\"\" frame=\"\">, at line 1&quot;</no></actual></expected></em></strong> unless the optional <span class=\'code\'>message:</span> keyword argument is provided.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assert_defined &lt;expression&gt;expectedToBeDefined [message:&lt;string&gt;]\n\
</pre></div><p>Returns false and logs an assert failure message with the <span class=\'code\'>AssertReporter</span> if the returns value of the expression is undefined.</p>\n\
<p>Will log a default message in the form of <strong><em>&quot;Assert - Expected &quot;defined&quot;, got undefined - (No File) in frame <no stack=\"\" frame=\"\">, at line 1&quot;</no></em></strong> unless the optional <span class=\'code\'>message:</span> keyword argument is provided.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assert_undefined &lt;expression&gt;expectedToBeUndefined [message:&lt;string&gt;]\n\
</pre></div><p>Returns false and logs an assert failure message with the <span class=\'code\'>AssertReporter</span> if the returns value of the expression is not undefined.</p>\n\
<p>Will log a default message in the form of <strong><em>&quot;Assert - Expected undefined, got 1 - (No File) in frame <no stack=\"\" frame=\"\">, at line 1&quot;</no></em></strong> unless the optional <span class=\'code\'>message:</span> keyword argument is provided.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assert_float &lt;float&gt;expected &lt;expression&gt;actual [tolerance:&lt;float&gt;delta] [message:&lt;string&gt;]\n\
&lt;boolean&gt;assert_float_equal &lt;float&gt;expected &lt;expression&gt;actual [tolerance:&lt;float&gt;delta] [message:&lt;string&gt;]                                                                                                        \n\
</pre></div><p>Returns false and logs an assert failure message with the <span class=\'code\'>AssertReporter</span> if the returns value of the expression passed as second argument is not the expected float value.</p>\n\
<p>If the <strong><span class=\'code\'>tolerance:</span></strong> optional keyword argument is provided, the assert will return false if the actual return value is different from the expected one beyond the tolerance delta value.</p>\n\
<p>Will log a default message in the form of <strong><em>&quot;Assert - Expected 1.0, got 2 - (No File) in frame <no stack=\"\" frame=\"\">, at line 1&quot;</no></em></strong> unless the optional <span class=\'code\'>message:</span> keyword argument is provided. The <span class=\'code\'>assert_float_equal()</span> version is identical to <span class=\'code\'>assert_float()</span>, but is provided as it has a more meaningful name that matches the other assert functions.<br> <strong>Available in 3ds Max 2021.1 Update and higher.</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assert_string_equal &lt;string&gt;expected &lt;exression&gt;actual [ignorecase:&lt;boolean&gt;val]\n\
[message:]\n\
</pre></div><p>Returns false if the return value of the expression passed as second argument is not equal to the expected string.</p>\n\
<p>The default for the optional <span class=\'code\'>ignorecase:</span> keyword argument is true. It should be supplied as false to perform case sensitive comparison.</p>\n\
<p>Will log a default message in the form of <strong><em>&quot;Assert - Expected &quot;A&quot;, got &quot;b&quot; - (No File) in frame <no stack=\"\" frame=\"\">, at line 1&quot;</no></em></strong> unless the optional <span class=\'code\'>message:</span> keyword argument is provided.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assert_point3_equal &lt;point3&gt;expected &lt;expression&gt;actual [tolerance:&lt;float&gt;delta]\n\
[message:]\n\
</pre></div><p>Returns false if the return value of the expression passed as second argument is not equal to the expected Point3 value.</p>\n\
<p>If the <strong><span class=\'code\'>tolerance:</span></strong> optional keyword argument is provided, the assert will return false if any of the actual return value&#39;s components is different from the expected ones&#39; corresponding component beyond the tolerance delta value.</p>\n\
<p>Will log a default message in the form of <strong><em>&quot;Assert - Expected [1,2,3], got [1.1,2.1,3.1] - (No File) in frame <no stack=\"\" frame=\"\">, at line 1&quot;</no></em></strong> unless the optional <span class=\'code\'>message:</span> keyword argument is provided.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assert_matrix_equal &lt;matrix&gt;expected &lt;matrix&gt;actual [tolerance:&lt;float&gt;delta]\n\
[message:]\n\
</pre></div><p>Returns false if the return value of the expression passed as second argument is not equal to the expected matrix value.</p>\n\
<p>If the <strong><span class=\'code\'>tolerance:</span></strong> optional keyword argument is provided, the assert will return false if any of the components of the actual return value is different from the expected ones&#39; corresponding component beyond the tolerance delta value.</p>\n\
<p>Will log a default message in the form of <strong><em>&quot;Assert - Expected (matrix3 [1,0,0] [0,1,0] [0,0,1] [0,0,0]), got (matrix3 [1,0,0] [0,1,0] [0,0,1] [42.1234,43.8329,0]) - (No File) in frame <no stack=\"\" frame=\"\">, at line 1&quot;</no></em></strong> unless the optional <span class=\'code\'>message:</span> keyword argument is provided.</p>\n\
<p>Note that due to the limited precision of numbers representation in computers, values at the exact edge of the tolerance delta might or might not cause an assert to be logged when using the <span class=\'code\'>assert_float()</span> and <span class=\'code\'>assert_point3_equal()</span> methods.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>floatVariable = 1.0   assert_float 1.1 floatVariable tolerance:0.1   --&gt;&quot;Assert - Expected 1.1, got 1.0 ...&quot;</span></p>\n\
<p>But when using the following code, there is no assert:</p>\n\
<p><span class=\'code\'>point3Variable = [1,2,3]   assert_point3_equal [1.0,2.0,3.1] point3Variable tolerance:0.1</span></p>\n\
</blockquote>\n\
<p>The explanation for the above results is that the first method checks whether the difference of the expected and actual values is less than the tolerance value and in this case, it is not. The two values are converted to doubles internally and the first 7 decimal places are identical (all zeros), so the difference is NOT less than the tolerance delta.</p>\n\
<p>In the second case though, the Point3 value [1.0,2.0,3.1] is actually represented internally as [1.0,2.0,3.0999999]. Thus the difference between 3.0 and 3.0999999 is just below the tolerance and due to this precision error, the assert passes as true.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assert_array_equal expected actual [message:&lt;string&gt;] [tolerance:&lt;boolean&gt;] [ignoreCase:&lt;boolean&gt;]\n\
</pre></div><p>Returns false if the return value of the expression passed as second argument is not equal to the expected array. <strong>Available in 3ds Max 2021.1 Update and higher.</strong> The default for the optional <span class=\'code\'>ignorecase:</span> keyword argument is true. It should be supplied as false to perform case sensitive comparison for arrays that contain strings.</p>\n\
<p>If the <strong><span class=\'code\'>tolerance:</span></strong> optional keyword argument is provided, the assert will return false if any of the numeric elements of the actual return value is different from the expected ones&#39; corresponding elements beyond the tolerance delta value.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>The following will all return false:</p>\n\
<p><span class=\'code\'>assert_array_equal #(1) #(1.)   assert_array_equal #(1) #(1,2)   assert_array_equal #(1,2) #(1)   assert_array_equal #(1) #(2)   assert_array_equal #(1.) #(2.)   assert_array_equal #([1,2]) #([1,3])   assert_array_equal #([1,2,3]) #([1,2,4])   assert_array_equal #([1,2,3,4]) #([1,2,3,5])   assert_array_equal #(matrix3 1) #(transmatrix [1,1,1])   assert_array_equal #(&quot;aa&quot;) #(&quot;ab&quot;)   assert_array_equal #(1.) #(2.) tolerance:0.5   assert_array_equal #(&quot;aa&quot;) #(&quot;AA&quot;) ignoreCase:false</span></p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assert_matchpattern expected actual [message:&lt;string&gt;] [ignoreCase:&lt;boolean&gt;]\n\
</pre></div><p><img src=\'developer/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> <a href=\'#!/url=./developer/What-is-New-in-MAXScript/What-s-New-in-MAXScript-in-3ds.html\' title=\'\'>NEW</a> <strong>in 3ds Max 2021.1 Update:</strong> Returns false if the return value of the expression passed as second argument is not equal to the expected string. The second argument (<span class=\'code\'>actual</span>) can be a match pattern, where ? represents a single character and * represents one or more characters.</p>\n\
<p>The default for the optional <span class=\'code\'>ignorecase:</span> keyword argument is true. It should be supplied as false to perform case sensitive comparison for the strings.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>The following will all return false:</p>\n\
<p><span class=\'code\'>s=&quot;text1&quot;   assert_matchpattern &quot;tex?&quot; s   assert_matchpattern &quot;T*&quot; s ignoreCase:false</span></p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;assert_bitarray_equal expected_bitarray actual_bitarray [message:&lt;string&gt;]\n\
</pre></div><p>Returns false if the return value of the expression passed as second argument is not equal to the expected array.<br> <strong>Available in 3ds Max 2021.1 Update and higher.</strong>### The <span class=\'code\'>AssertReporter</span> Struct</p>\n\
<p>The global <span class=\'code\'>AssertReporter</span> C++ struct collects the results of the asserts and provides methods for managing and accessing the results after a test run.</p>\n\
<p><strong>General Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;AssertReporter.Clear()\n\
</pre></div><p>Removes all assertion entries from the <span class=\'code\'>AssertReporter</span> and resets all failures and exceptions results to zero.</p>\n\
<p><strong>Reporting Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;string array&gt;AssertReporter.GetAssertFailures()\n\
</pre></div><p>Returns an array of strings containing the assert failures stored in the <span class=\'code\'>AssertReporter</span>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;AssertReporter.GetAssertFailuresCount()\n\
</pre></div><p>Returns the count of the assert failures stored in the <span class=\'code\'>AssertReporter</span>. This is faster than calling <span class=\'code\'>(AssertReporter.GetAssertFailuresCount()).count</span></p>\n\
<div class=\'codeBlock\'><pre>&lt;string array&gt;AssertReporter.GetExceptionFailures()\n\
</pre></div><p>Returns an array of strings containing any exceptions logged with the <span class=\'code\'>AssertReporter</span>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;AssertReporter.GetExceptionFailuresCount()\n\
</pre></div><p>Returns the count of the exception failures stored in the <span class=\'code\'>AssertReporter</span>. This is faster than calling <span class=\'code\'>(AsserReporter.GetExceptionFailuresCount()).count</span></p>\n\
<div class=\'codeBlock\'><pre>&lt;array of strings&gt;AssertReporter.GetMessages()\n\
</pre></div><p>Returns an array of strings containing any messages that were logged through the <span class=\'code\'>AssertReporter</span>, regardless of their type.</p>\n\
<p><strong>Logging Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;AssertReporter.LogMessage &lt;string&gt;Message\n\
</pre></div><p>Saves a message with the <span class=\'code\'>AssertReporter</span>. The messages can be retrieved later using <span class=\'code\'>AssertReporter.GetMessages()</span></p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;AssertReporter.LogException &lt;string&gt;Message\n\
</pre></div><p>Saves a message as an exception with the <span class=\'code\'>AssertReporter</span>. The exception messages can be retrieved later using <span class=\'code\'>AssertReporter.GetExceptionFailures()</span></p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;AssertReporter.LogAssertFailure &lt;string&gt;Message\n\
</pre></div><p>Saves a message as an assert failure with the <span class=\'code\'>AssertReporter</span>. The failure messages can be retrieved later using <span class=\'code\'>AssertReporter.GetAssertFailures()</span></p>\n\
<p><strong>State Methods:</strong></p>\n\
<p>The following two methods can be used for saving some sort of state during test runs, and is only provided for future flexibility.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;AssertReporter.SetUserData &lt;string&gt;UserData\n\
</pre></div><p>Saves a custom user defined string in the <span class=\'code\'>AssertReporter</span>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;AssertReporter.GetUserData &lt;value&gt;argument\n\
</pre></div><p>Gets a custom user defined string from the <span class=\'code\'>AssertReporter</span>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>The following example demonstrates the functionality of the assert functions and the AssertReporter in an artificial test situation where a number of variable have been defined in the local scope of a function and each variable is tested by an assert to verify its value (and of course most of these tests were designed to produce actual assert messages!)</p>\n\
<p>``` fn TestAsserts = ( local undefinedValue local booleanTrueVariable = true local booleanFalseVariable = false local floatVariable = 1.0 local stringVariable = &quot;MAXScript&quot; local point3Variable = [1,2,3] local matrix3Variable = matrix3 [1,0,0] [0,1,0] [0,0,1] [100,200,-300] --this is line 10 AssertReporter.Clear()<br> AssertReporter.LogMessage &quot;Asserts Demo Start...&quot;<br> AssertReporter.SetUserData (&quot;Tested Values Were:&quot;+ undefinedValue as string + &quot;,&quot; + booleanTrueVariable as string + &quot;,&quot; + booleanFalseVariable as string + &quot;,&quot; + floatVariable as string + &quot;,&quot;+stringVariable+&quot;,&quot;+point3Variable as string + &quot;,&quot;+matrix3Variable as string) assert_true booleanFalseVariable assert_false booleanTrueVariable assert_equal 2.0 floatVariable assert_not_equal 2.0 floatVariable assert_defined undefinedValue assert_undefined floatVariable assert_float 1.1 floatVariable tolerance:0.01 assert_float 1.1 floatVariable tolerance:0.2 assert_string_equal &quot;Python&quot; stringVariable assert_string_equal &quot;maxscript&quot; stringVariable ignorecase:false message:(&quot; MAXScript is usually case-insensitive, but this assert isn&#39;t!&quot;) assert_point3_equal [1.0,2.0,3.1] point3Variable assert_point3_equal [1.0,2.0,3.1] point3Variable tolerance:0.1 assert_matrix_equal (matrix3 1) matrix3Variable if floatVariable &gt; 0.0 do AssertReporter.LogAssertFailure &quot;FloatVariable seems to be positive, I am upset!&quot; AssertReporter.LogException &quot;Nothing Really Worked!&quot; AssertReporter.LogMessage &quot;Asserts Demo End.&quot;<br> --this is line 30 format &quot;--All Logged Messages:\\n&quot; print (AssertReporter.GetMessages()) format &quot;--User Data:\\n&quot; print (AssertReporter.GetUserData 0)<br> format &quot;--Failures: %\\n&quot; (AssertReporter.GetAssertFailuresCount()) print (AssertReporter.GetAssertFailures()) format &quot;--Exceptions: %\\n&quot; (AssertReporter.GetExceptionFailuresCount()) print (AssertReporter.GetExceptionFailures()) )</p>\n\
<p>TestAsserts()</p>\n\
<p>```</p>\n\
<p>After saving the above code to a file called &quot;c:\\temp\\TestAsserts.ms&quot;, evaluating the script produced the following output:</p>\n\
<p><span class=\'code\'>TestAsserts()   --All Logged Messages:   &quot;Asserts Demo Start...&quot;   &quot;Assert - Expected true, got false - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 14&quot;   &quot;Assert - Expected false, got true - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 15&quot;   &quot;Assert - Expected 2.0, got 1.0 - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 16&quot;   &quot;Assert - Expected &quot;defined&quot;, got undefined - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 18&quot;   &quot;Assert - Expected undefined, got 1.0 - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 19&quot;   &quot;Assert - Expected 1.1, got 1.0 - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 20&quot;   &quot;Assert - Expected &quot;Python&quot;, got &quot;MAXScript&quot; - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 22&quot;   &quot;Assert - MAXScript is usually case-insensitive, but this assert isn&#39;t! - Expected &quot;maxscript&quot;, got &quot;MAXScript&quot; (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 23&quot;   &quot;Assert - Expected [1,2,3.1], got [1,2,3] - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 24&quot;   &quot;Assert - Expected (matrix3 [1,0,0] [0,1,0] [0,0,1] [0,0,0]), got (matrix3 [1,0,0] [0,1,0] [0,0,1] [100,200,-300]) - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 26&quot;   &quot;FloatVariable seems to be positive, I am upset!&quot;   &quot;Nothing Really Worked!&quot;   &quot;Asserts Demo End.&quot;   --User Data:   &quot;Tested Values Were:undefined,true,false,1.0,MAXScript,[1,2,3],(matrix3 [1,0,0] [0,1,0] [0,0,1] [100,200,-300])&quot;   --Failures: 11   &quot;Assert - Expected true, got false - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 14&quot;   &quot;Assert - Expected false, got true - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 15&quot;   &quot;Assert - Expected 2.0, got 1.0 - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 16&quot;   &quot;Assert - Expected &quot;defined&quot;, got undefined - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 18&quot;   &quot;Assert - Expected undefined, got 1.0 - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 19&quot;   &quot;Assert - Expected 1.1, got 1.0 - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 20&quot;   &quot;Assert - Expected &quot;Python&quot;, got &quot;MAXScript&quot; - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 22&quot;   &quot;Assert - MAXScript is usually case-insensitive, but this assert isn&#39;t! - Expected &quot;maxscript&quot;, got &quot;MAXScript&quot; (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 23&quot;   &quot;Assert - Expected [1,2,3.1], got [1,2,3] - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 24&quot;   &quot;Assert - Expected (matrix3 [1,0,0] [0,1,0] [0,0,1] [0,0,0]), got (matrix3 [1,0,0] [0,1,0] [0,0,1] [100,200,-300]) - (C:\\Temp\\TestAsserts.ms) in frame TestAsserts, at line 26&quot;   &quot;FloatVariable seems to be positive, I am upset!&quot;   --Exceptions: 1   &quot;Nothing Really Worked!&quot;   OK</span></p>\n\
<p>Note that the Assert on line 21 did not output a failure because the tolerance was set to 0.2, allowing 1.0 to pass a test against 1.1, which the Assert on the previous line 20 did not allow.</p>\n\
<p>Line 23 had a custom message prepended to the default message.</p>\n\
<p>Line 25 also passed due to a higher tolerance delta.</p>\n\
<p>As you can see, with these assert functions you can collect data about the state of variables with various value types or the return values of expressions and collect the information in the AssertReporter to analyze after a test run of the code or dump to a log file for later processing.</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";