var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Regular Expressions Find and Replace in the MAXScript Editor</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Regular Expressions Find and Replace in the MAXScript Editor</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"regular-expressions-find-and-replace-in-the-maxscript-editor\"></a></div>\n\
<p>The following topic is based on the public domain document located on <a href=\'https://www.scintilla.org/SciTERegEx.html\' title=\'\' target=\'_blank\'>http://www.scintilla.org/SciTERegEx.html</a></p>\n\
<div class=\'section\'><a id=\"purpose\"></a><h2 id=\"purpose\">Purpose</h2></div>\n\
<p><strong>Regular Expressions</strong> (RegEx) can be used for searching for patterns rather than literals.</p>\n\
<p>For example, using the following posix-mode Regular Expression, it is possible to <strong>search</strong> for variables in property files which look like $(name.subname)</p>\n\
<div class=\'codeBlock\'><pre>\\$([a-z.]+)\n\
</pre></div><p>This Regular Expression can be read like this:</p>\n\
<ul>\n\
<li><p>Find a string which matches the following rules:</p>\n\
<ul>\n\
<li><p>Starts with <span class=\'code\'>$</span> , denoted as the special character <span class=\'code\'>\\\\$</span></p></li>\n\
<li><p>Is followed by a lower case character between <strong>a</strong> and <strong>z</strong> followed by <strong>any character</strong> specified by a period <strong>.</strong></p></li>\n\
<li><p>The above set repeated one or more times, as denoted by the <span class=\'code\'>\\+</span> sign after the <span class=\'code\'>\\[\\]</span> set definition.</p></li>\n\
</ul></li>\n\
</ul>\n\
<p><strong>Replacement</strong> with regular expressions allows for complex transformations with the use of tagged expressions.</p>\n\
<p>For example, pairs of numbers separated by a comma could be reordered by replacing the posix-mode regular expression</p>\n\
<div class=\'codeBlock\'><pre>([0-9]+),([0-9]+)\n\
</pre></div><p>with:</p>\n\
<div class=\'codeBlock\'><pre>\\2,\\1\n\
</pre></div><p>The first RegEx means: Match one or more digits between 0 and 9 before the comma and one or more digits between 0 and 9 after the comma.</p>\n\
<p>In non-posix mode, the same would be written as</p>\n\
<div class=\'codeBlock\'><pre>\\([0-9]+\\),\\([0-9]+\\)\n\
</pre></div><p>The replacement RegEx <span class=\'code\'>\\\\2, \\\\1</span> means: Take the second matched expression and put it before the comma, then place the first matched expression after the comma.</p>\n\
<p>The first posix mode RegEx could even be written as</p>\n\
<div class=\'codeBlock\'><pre>(\\d+),(\\d+))\n\
</pre></div><p>which also means any number of digits before the comma and any number of digits after the comma.</p>\n\
<div class=\'section\'><a id=\"syntax-styles---posix-vs.-old-unix-style\"></a><h2 id=\"syntax-styles---posix-vs.-old-unix-style\">Syntax Styles - Posix vs. Old Unix Style</h2></div>\n\
<p>Regular expression syntax depends on the parameter</p>\n\
<p><span class=\'code\'>find.replace.regexp.posix</span></p>\n\
<p>If set to 0 (default), the Regular Expression syntax uses the old Unix style where <strong>\\(</strong> and <strong>\\)</strong> mark capturing sections while <strong>(</strong> and <strong>)</strong> represent themselves.</p>\n\
<p>If set to 1, the RegEx syntax uses the more common style where opening and closing parentheses <strong>(</strong> and <strong>)</strong> mark capturing sections while <strong>\\(</strong> and <strong>\\)</strong> are plain parentheses.</p>\n\
<div class=\'section\'><a id=\"syntax-rules\"></a><h2 id=\"syntax-rules\">Syntax Rules</h2></div>\n\
<div class=\'section\'><a id=\"char\"></a><h4 id=\"char\">[1] char</h4></div>\n\
<p>A character matches itself, unless it is a special character (metachar): .  [ ] * + ^ $ and( ) in posix mode.</p>\n\
<div class=\'section\'><a id=\"section\"></a><h4 id=\"section\">[2] .</h4></div>\n\
<p>matches any character.</p>\n\
<div class=\'section\'><a id=\"section-1\"></a><h4 id=\"section-1\">[3]<br></h4></div>\n\
<p>matches the character following it, except:</p>\n\
<ul>\n\
<li><p>\\a,\\b,\\f,\\n,\\r,\\t,\\v match the corresponding C escape char, respectively BEL, BS, FF, LF, CR, TAB and VT; Note that \\r and \\n are never matched because in Scintilla, regular expression searches are made line per line (stripped of end-of-line chars).</p></li>\n\
<li><p>if not in posix mode, when followed by a left or right round bracket (see [7]);</p></li>\n\
<li><p>when followed by a digit 1 to 9 (see [8]);</p></li>\n\
<li><p>when followed by a left or right angle bracket (see[9]);</p></li>\n\
<li><p>when followed by d, D, s, S, w or W (see [10]);</p></li>\n\
<li><p>when followed by x and two hexa digits (see [11]);</p></li>\n\
</ul>\n\
<p>Backslash is used as an escape character for all other meta-characters, and itself.</p>\n\
<div class=\'section\'><a id=\"set\"></a><h4 id=\"set\">[4] [set]</h4></div>\n\
<p>matches one of the characters in the set.</p>\n\
<p>If the first character in the set is ^, it matches the characters NOT in the set, i.e. complements the set.</p>\n\
<p>A shorthand S-E (start dash end) is used to specify a set of characters S up to E, inclusive.</p>\n\
<p>The special characters ]and-have no special meaning if they appear as the first chars in the set. To include both, put - first: [-]A-Z], or just add a backslash before each of them, like [A-Z\\]\\-]</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">example</th>\n\
<th align=\"left\">match</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>[-]|]</span></td>\n\
<td align=\"left\">matches these 3 chars,</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>[]-|]</span></td>\n\
<td align=\"left\">matches from ] to</td>\n\
<td align=\"left\">chars</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>[a-z]</span></td>\n\
<td align=\"left\">any lowercase alpha</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>[^-]]</span></td>\n\
<td align=\"left\">any char except - and ]</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>[^A-Z]</span></td>\n\
<td align=\"left\">any char except uppercase alpha</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>[a-zA-Z]</span></td>\n\
<td align=\"left\">any alpha</td>\n\
</tr>\n\
</table>\n\
<div class=\'section\'><a id=\"section-2\"></a><h4 id=\"section-2\">[5] *</h4></div>\n\
<p>any regular expression form [1] to [4] (except [7] , [8] and [9] forms of [3] ), followed by closure char ( * ) matches <em>zero or more</em> matches of that form.</p>\n\
<p>For example, [a-z]* means &quot;Zero or more occurrences of a lower case alpha character&quot;.</p>\n\
<div class=\'section\'><a id=\"section-3\"></a><h4 id=\"section-3\">[6] +</h4></div>\n\
<p>same as [5] , except it matches <em>one or more</em>.</p>\n\
<p>Both [5] and [6] are <em>greedy</em>- they match as many characters as possible, until a mismatch is encountered.</p>\n\
<div class=\'section\'><a id=\"section-4\"></a><h4 id=\"section-4\">[7]</h4></div>\n\
<p>a regular expression in the form [1]to[12], enclosed as \\(form\\)(or(form)with posix flag) matches what form matches. The enclosure creates a set of tags, used for[8]and for pattern substitution. The tagged forms are numbered starting from 1.</p>\n\
<div class=\'section\'><a id=\"section-5\"></a><h4 id=\"section-5\">[8]</h4></div>\n\
<p>a  followed by a digit 1 to 9 matches whatever a previously tagged regular expression ([7]) matched.</p>\n\
<div class=\'section\'><a id=\"section-6\"></a><h4 id=\"section-6\">[9] \\&lt; \\&gt;</h4></div>\n\
<p>a regular expression <em>starting with a</em> \\&lt; construct and/or <em>ending with a</em> \\&gt; construct, restricts the pattern matching to the beginning of a word, and/or the end of a word. A word is defined to be a character string beginning and/or ending with the characters A-Z a-z 0-9 and _. The Editor extends this definition by user setting. The word must also be preceded and/or followed by any character outside those mentioned.</p>\n\
<div class=\'section\'><a id=\"l\"></a><h4 id=\"l\">[10] \\l</h4></div>\n\
<p>a <em>backslash</em> followed by <em>d</em>, <em>D</em>, <em>s</em>, <em>S</em>, <em>w</em> or <em>W</em>, becomes a character class (both inside and outside <em>[]</em> sets).</p>\n\
<ul>\n\
<li><p><em>d</em>: decimal digits</p></li>\n\
<li><p><em>D</em>: any char <em>except decimal digits</em></p></li>\n\
<li><p><em>s</em>:<em>whitespace</em> (space, \\t \\n \\r \\f \\v)</p></li>\n\
<li><p><em>S</em>: any char <em>exceptwhitespace</em> (anything but space, \\t \\n \\r \\f \\v)</p></li>\n\
<li><p><em>w</em>:<em>alphanumeric</em> and <em>underscore</em> (changed by user setting)</p></li>\n\
<li><p><em>W</em>: any char <em>except alphanumeric</em> and <em>underscore</em> (see above)</p></li>\n\
</ul>\n\
<div class=\'section\'><a id=\"xhh\"></a><h4 id=\"xhh\">[11] \\xHH</h4></div>\n\
<p>a <em>backslash</em> followed by <em>x</em> and <em>two hexadecimal digits</em>, becomes the character whose Ascii code is equal to these digits. If not followed by two digits, it represents the character &#39;x&#39; itself.</p>\n\
<div class=\'section\'><a id=\"section-7\"></a><h4 id=\"section-7\">[12]</h4></div>\n\
<p>a composite regular expression xy where x and y are in the form [1] to [10] matches the <em>longest match of x</em> followed by a <em>match for y</em>.</p>\n\
<div class=\'section\'><a id=\"section-8\"></a><h4 id=\"section-8\">[13] ^ $</h4></div>\n\
<p>a regular expression starting with a ^ character and/or ending with a $ character, restricts the pattern matching to the beginning of the line, or the end of line. Elsewhere in the pattern, ^ and $ are treated as ordinary characters.</p>\n\
<div class=\'section\'><a id=\"acknowledgments\"></a><h2 id=\"acknowledgments\">Acknowledgments</h2></div>\n\
<p>Most of this documentation was originally written by Ozan S. Yigit. Additions by Neil Hodgson and Philippe Lhoste. All of this document is in the public domain.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";