var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Array Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Array Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"array-values\"></a></div>\n\
<p>An <strong>array</strong> is a variable length <strong>indexable sequence of values</strong>.</p>\n\
<p>The values in an array can be of <strong>any type</strong>.</p>\n\
<p>Array values are <strong>mappable</strong>.</p>\n\
<p><strong>Literals</strong></p>\n\
<div class=\'codeBlock\'><pre>#(&lt;value&gt;, &lt;value&gt;, ...)\n\
#() -- an empty array\n\
</pre></div><p>See also <a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Literal-Constants/Array-Literals.html\' title=\'\'>Array Literals</a>.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;collection&gt; as array \n\
</pre></div><p>Convert collection to an array.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;array&gt;.count : Integer   \n\
</pre></div><p>Get/Set the number of elements in the array. In <strong>3ds Max</strong> versions prior release 5, this property was read-only.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;array&gt;[&lt;integer&gt;  ] \n\
</pre></div><p>Returns element of array. Indexes start at 1.</p>\n\
<div class=\'codeBlock\'><pre>&lt;array&gt;[&lt;integer&gt;] = &lt;value&gt; \n\
</pre></div><p>Sets element of array to value, growing array as necessary.</p>\n\
<div class=\'codeBlock\'><pre>&lt;array&gt; + &lt;collection&gt;\n\
</pre></div><p>Like <span class=\'code\'>join</span> except a completely new array is constructed containing all the elements of the first and second operands</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` a = #(1,2,3,4) join a #(5,6,7,8) (cameras as array) + lights props = getPropNames Node join props (getPropNames(classOf Box)) join props (getPropNames Box #dynamicOnly) sort props</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>append &lt;array&gt; &lt;value&gt; \n\
</pre></div><p>Append value to array, growing it as necessary. Returns the resulting array.</p>\n\
<div class=\'codeBlock\'><pre>appendIfUnique &lt;array&gt; &lt;value&gt; \n\
</pre></div><p>Appends the value to the array if the value is not already in the array.</p>\n\
<p>Returns true if the value is added, false if not.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously available in the free <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` ( local h = #(1,2,3,4) appendIfUnique h 60 -- should work appendIfUnique h 4 -- shouldn&#39;t work if ((h.count != 5) or (h[5] != 60)) do throw &quot;Entry 5 in the array is incorrect&quot; format &quot;%\\n&quot; h )</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` #(1, 2, 3, 4, 60) OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>makeUniqueArray &lt;array&gt; \n\
</pre></div><p>Returns a new array with only unique members of source array.</p>\n\
<p>Available in <strong>3ds Max 2008and higher</strong>. Previously available in the free <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` makeUniqueArray # (1, 2, 3, 4, 3, 2, 1)</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` # (1, 2, 3, 4)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>copy &lt;array&gt; [#noMap] -- mapped \n\
</pre></div><p>Creates a copy of all the elements in the array. Returns a value of <span class=\'code\'>OK</span> .</p>\n\
<p>If <span class=\'code\'>#noMap</span> is specified, the copy made is what is called a <em>shallow copy</em> - only a copy of the upper-level value itself (that is, the <span class=\'code\'>array</span> value) is created. Copies aren&#39;t made of values stored in the array, rather a reference to the same value is stored in both <span class=\'code\'>array</span> values.</p>\n\
<div class=\'codeBlock\'><pre>deepCopy &lt;array&gt; \n\
</pre></div><p>Creates a copy of all elements in the array, including nested sub-arrays and returns the new array as the result.</p>\n\
<p>The deepCopy() method guarantees that if the copied array contains multiple references to the same value, these will be copied as a single reference rather than multiple unique copies. Available in <strong>3ds Max 2019 and higher</strong>. See the example below.</p>\n\
<p>Available in <strong>3ds Max 9</strong> and higher.</p>\n\
<blockquote>\n\
<p><strong>COPY AND DEEPCOPY EXAMPLES:</strong></p>\n\
<p>``` --REFERENCING WITHOUT COPYING: a = #(10,# (1,2,3),30,&quot;test&quot;) --create an array --&gt; # (10, # (1, 2, 3), 30, &quot;test&quot;) b = a --array is b is referencing the same array a --&gt; # (10, # (1, 2, 3), 30, &quot;test&quot;) b[1] = 5 --so if we change an element in b, a will also change! --&gt; 5 a --&gt; # (5, # (1, 2, 3), 30, &quot;test&quot;) b --&gt; # (5, #(1, 2, 3), 30, &quot;test&quot;)</p>\n\
<p>```</p>\n\
<p>``` --#NOMAP SHALLOW COPY - TOP-LEVEL VALUE COPIED: a = # (10,#(1,2,3),30,&quot;test&quot;) --create an array --&gt; #(10, #(1, 2, 3), 30, &quot;test&quot;) b = copy a #nomap --create a shallow copy --&gt; #(10, #(1, 2, 3), 30, &quot;test&quot;) b[1] = 5 --changing a top-level element in b does not change a: --&gt; 5 b --&gt; #(5, #(1, 2, 3), 30, &quot;test&quot;) a --&gt; #(10, #(1, 2, 3), 30, &quot;test&quot;)</p>\n\
<p>--But if we change the sub-array in b, a will also change. --This is because the sub-arrays are not copied recursively. --See deepcopy() below for a solution. b[2][2] = 42 --&gt; 42 b --&gt; #(5, #(1, 42, 3), 30, &quot;test&quot;) a --&gt; #(10, #(1, 42, 3), 30, &quot;test&quot;)</p>\n\
<p>--Same applies to the string which is similar to an array b[4][2] = &quot;E&quot; -- changing the second character in b affects a: --&gt; &quot;E&quot; b --&gt; #(5, #(1, 42, 3), 30, &quot;tEst&quot;) a --&gt; #(10, #(1, 42, 3), 30, &quot;tEst&quot;)</p>\n\
<p>```</p>\n\
<p>``` -- #DEEPCOPY COPY - ALL LEVELS COPIED: a = # (10,# (1,2,3),30,&quot;test&quot;) -- create an array --&gt; # (10, # (1, 2, 3), 30, &quot;test&quot;) b = deepcopy a -- create a deep copy --&gt; # (10, # (1, 2, 3), 30, &quot;test&quot;)</p>\n\
<p>b[1] = 5 -- changing a value in array b has no effect on array a --&gt; 5 b --&gt; # (5, # (1, 2, 3), 30, &quot;test&quot;) a --&gt; # (10, # (1, 2, 3), 30, &quot;test&quot;)</p>\n\
<p>b[2][2] = 42 -- changing a sub-array value in b has no effect on a --&gt; 42 b --&gt; # (5, # (1, 42, 3), 30, &quot;test&quot;) a --&gt; # (10, # (1, 2, 3), 30, &quot;test&quot;)</p>\n\
<p>-- Same applies to the string which is similar to an array b[4][2] = &quot;E&quot; -- changing the string in b does NOT affect a: --&gt; &quot;E&quot; b --&gt; # (5, # (1, 42, 3), 30, &quot;tEst&quot;) a --&gt; # (10, # (1, 2, 3), 30, &quot;test&quot;)</p>\n\
<p>-- Objects copied as a reference to a single value c = #(a,a) --&gt; #(#(10, #(1, 2, 3), 30, &quot;test&quot;), #(10, #(1, 2, 3), 30, &quot;test&quot;)) d = deepcopy c -&gt;&gt; #(#(10, #(1, 2, 3), 30, &quot;test&quot;), #(10, #(1, 2, 3), 30, &quot;test&quot;)) d[1][1] = 11 --&gt; 11 d --&gt; #(#(11, #(1, 2, 3), 30, &quot;test&quot;), #(11, #(1, 2, 3), 30, &quot;test&quot;))</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Using an <a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Simple-Expressions/Comparison-Expressions.html\' title=\'\'>equality comparison expression</a> on two arrays, even if the one is a deep copy of the other, will not perform per-element comparison but will check whether the two variables reference the same data in memory. Thus, the result of such a comparison will always be false unless the two variables point at the same memory address:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` a = # (1,2,3,4,5,10,42) --create an array and store in variable a --&gt; # (1, 2, 3, 4, 5, 10, 42) b = deepcopy a --deep-copy the array into variable b --&gt; # (1, 2, 3, 4, 5, 10, 42) a == b --although the two have the same elements, they are not considered equal --&gt; false</p>\n\
<p>c = a --if variable c is referencing the same array in memory, --&gt; # (1, 2, 3, 4, 5, 10, 42) c == a --the two are considered equal --&gt; true</p>\n\
<p>--To compare arrays a and b, we have to compare their elements. --If no elements are compound values (like other arrays, matrix3 values etc.), --the following expression would work: a.count == b.count AND<br> (for i = 1 to a.count where a[i]!=b[i] collect i).count == 0 --&gt; true</p>\n\
<p>--A simpler alternative is to compare the two arrays by turning them into strings. --We have to use the &#39;with PrintAllElements on&#39; context because otherwise --longer arrays would be shortened after the 20th element:</p>\n\
<p>with PrintAllElements on a as string == b as string --&gt; true</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>deleteItem &lt;array&gt; &lt;number&gt; \n\
</pre></div><p>Delete element indexed by number from array, shrinking it in size by 1. Returns the resulting array.</p>\n\
<div class=\'codeBlock\'><pre>join &lt;array&gt; &lt;collection&gt; \n\
</pre></div><p>Appends all the elements of the second argument to the <span class=\'code\'>array</span> (first) argument.</p>\n\
<div class=\'codeBlock\'><pre>insertItem &lt;value&gt; &lt;array&gt; &lt;integer&gt; \n\
</pre></div><p>Inserts the value at the specified index in the array, growing the array if necessary. Returns OK.</p>\n\
<div class=\'codeBlock\'><pre>findItem &lt;array&gt; &lt;value&gt; \n\
</pre></div><p>Does a MAXScript <strong>&#39;==&#39;</strong> comparison between elements in the array and the target object and then returns the index of the <strong>first occurrence</strong> of the given value in the array or <strong>0 (zero)</strong> if the value is not in the array.</p>\n\
<p>Values such as Point3s and Strings match if they have the same contents.</p>\n\
<div class=\'codeBlock\'><pre>sort &lt;array&gt; \n\
</pre></div><p>Sorts the elements of the array into ascending order. All the elements must be comparable.</p>\n\
<div class=\'codeBlock\'><pre>qsort &lt;array&gt; &lt;function&gt; [start:&lt;integer&gt;] [end:&lt;integer&gt;] [user-defined key args passed to function] \n\
</pre></div><p>Sorts the array using the specified function for element-by-element comparison.</p>\n\
<p>The comparison function must take 2 values as arguments, and return an integer number &lt; 0 if the first value is less than the second value, 0 if the values are equivalent, and an integer number &gt; 0 if the first value is greater than the second value.</p>\n\
<p>The entire array is sorted unless a start or end value is specified.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>The following script generates 10 random positions, and then sorts the positions based on their distance from [0,0,0]:</p>\n\
<p>``` positions =for i = 1 to 10 collect (random [0,0,0] [100,100,0])</p>\n\
<p>fn compareFN v1 v2 = ( local d = (length v1)-(length v2) case of ( (d &lt; 0.): -1 (d &gt; 0.): 1 default: 0 ) )</p>\n\
<p>qsort positions compareFN for p in positions do print p</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>All key arguments are passed to the comparison function. This allows you to do things like an <strong>indexed sort:</strong></p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` fn compareFN v1 v2 valArray: = ( local v1i = valArray[v1] local v2i = valArray[v2] local d = (length v1i) - (length v2i) case of ( (d &lt; 0.): -1 (d &gt; 0.): 1 default: 0 ) ) positions = for i = 1 to 10 collect (random [0,0,0] [100,100,0] ) indexArray = for i = 1 to positions.count collect i qsort indexArray compareFN valArray:positions</p>\n\
<p>for i = 1 to positions.count do print positions [indexArray[i] ]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>bsearch &lt;key&gt; &lt;array&gt; &lt;function&gt; [start:&lt;integer&gt;] [end:&lt;integer&gt;] [index:&amp;variable] [user-defined key args passed to function] \n\
</pre></div><p>Performs binary search in a sorted list of arrays, returning the found element, or undefined if no match is found. Can be used to efficiently find an item in an array by a search key in <strong>3ds Max 2009 and higher</strong>.</p>\n\
<p>The <span class=\'code\'>&lt;key&gt;</span> argument defines the search key. It will be passed to the search function as its first argument.</p>\n\
<p>The <span class=\'code\'>&lt;array&gt;</span> argument is the array to search for the key in.</p>\n\
<p>The <span class=\'code\'>&lt;function&gt;</span> argument is a user-defined search function. By default, it will be passed two arguments - the search key and the current element of the array. The function is similar to the one used by the <strong><span class=\'code\'>qsort()</span></strong> method described earlier on this page.</p>\n\
<p>Additional optional keyword arguments can be defined in the function and passed to it by name from the bsearch call.</p>\n\
<p>The <strong><span class=\'code\'>start:</span> and <span class=\'code\'>end:</span></strong> optional keyword arguments can be used to limit the search in the given range.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` -- Compare function used by bsearch: fn LookupTableComparator a b = ( if a[1] &gt; b[1] then 1 else if a[1] &lt; b[1] then -1 else 0 )</p>\n\
<p>searchTable =for i = 1 to 10 collect #( (i as string), &quot;Test&quot;+(i as string), i)</p>\n\
<p>bsearch &quot;4&quot; searchTable LookupTableComparator -- output: #(&quot;4&quot;, &quot;Test4&quot;, 4) bsearch &quot;0&quot; searchTable LookupTableComparator -- output: undefined</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Since <strong>3ds Max 2015</strong>, if the optional by-reference keyword argument <span class=\'code\'>index:</span> is specified, the index of the found item will be written into it.</p>\n\
<p>In version prior to <strong>3ds Max 2015</strong>, there is an indirect way to achieve the same result:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` fn compareFn val index valArray: = ( arrayVal = valArray[index] format &quot;val = % index = % arrayVal = %\\n&quot; val index arrayVal -- do comparison of val and arrayVal here: case of ( (val &lt; arrayVal): -1 (val &gt; arrayVal): 1 default: 0 ) )</p>\n\
<p>--valArray is the sorted array: valArray = #(1, 16, 20, 22, 30, 100, 234) indexArray = for i = 1 to valArray.count collect i foundIndex = bsearch 20 indexArray compareFn valArray:valArray format &quot;Index was %\\n&quot; foundIndex</p>\n\
<p>--Since bsearch returns the found element, and we are using the indices as elements, --the variable foundIndex will contain the index of the found element instead of the valArray element itself.</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` compareFn() #(1, 16, 20, 22, 30, 100, 234) #(1, 2, 3, 4, 5, 6, 7) val = 20 index = 4 arrayVal = 22 val = 20 index = 2 arrayVal = 16 val = 20 index = 3 arrayVal = 20 3 Index was 3 OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>For additional examples and detailed benchmarks of <strong><span class=\'code\'>bsearch()</span></strong> compared to MAXScript-based search functions, see <a href=\'#!/url=./developer/Frequently-Asked-Questions/Writing-Better-and-Faster/How-To-Make-It-Faster-/Using-Bsearch-For-Fast-Table.html\' title=\'\'>Using Bsearch For Fast Table Lookup</a> in the &quot;How To Make It Faster&quot; chapter of the Frequently Asked Questions section.</p>\n\
<div class=\'codeBlock\'><pre>amin ( &lt;array&gt; | {value} ) \n\
</pre></div><p>Returns minimum value of items in the array or of the argument values. If the array size is zero or no arguments are specified, the value undefined is returned.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` myMin1 = amin #(5,1,4,2,8) myMin2 = amin 5 1 4 2 8f</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>amax ( &lt;array&gt; | {value} ) \n\
</pre></div><p>Returns maximum value of items in the array or of the argument values. If the array size is zero or no arguments are specified, the value undefined is returned.</p>\n\
<p>Note: As described in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Reference-Assignment.html\' title=\'\'>Reference Assignment</a>, the elements in an array are stored by reference rather than by value. When you operate directly on array elements, and the reference to the array is stored in more than one place, unexpected results may occur. An example of this is shown in the following script.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` RandomSets=#() -- create array RandomSet=#() -- create array for i = 1 to 3 do -- loop i (for j=1 to 3 do -- for each i loop j RandomSet[j] = random 1 100 -- set array element to random value print RandomSet #nomap -- print array of random values RandomSets[i] = RandomSet -- store random value array in array ) print RandomSets -- print array of arrays of random values</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` #() -- result of line 1 #() -- result of line 2 #(33, 47, 31) -- output from line 6, i =1 #(4, 52, 39) -- output from line 6, i =2 #(52, 36, 23) -- output from line 6, i =3 OK -- result of for loop, lines 3 to 8 #(52, 36, 23) -- 3 lines of output from line 7 #(52, 36, 23) #(52, 36, 23) OK -- result of line 9</p>\n\
<p>```</p>\n\
<p>As can be seen in the output lines 7 to 9, all the elements of array <span class=\'code\'>RandomSets</span> contain the same values, which is not the result as expected from the output shown on lines 3 to 5. The reason the same values are stored in each element of <span class=\'code\'>RandomSets</span> is only one array value is actually ever created for <span class=\'code\'>RandomSet</span> (in line 2), and line 5 of the script is only changing the elements of that array value. Thus each element of <span class=\'code\'>RandomSets</span> is actually pointing at the exact same value.</p>\n\
<p>The easiest fix for the above script is to move line 2 into the <span class=\'code\'>for i</span> loop expression, thereby creating a new array value which will then be stored in RandomSets.</p>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>```</p>\n\
<p>RandomSets =# () for i = 1 to 3 do ( RandomSet =# () --create a new array value for RandomSet for j = 1 to 3 do RandomSet[j]=random 1 100 print RandomSet #nomap RandomSets[i]=RandomSet ) print RandomSets</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` #() #(89, 27, 88) #(87, 87, 10) #(74, 27, 64) OK #(89, 27, 88) #(87, 87, 10) #(74, 27, 64) OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>You can convert object sets and wild-card pathnames to arrays using the <span class=\'code\'>as</span> operator.</p>\n\
<p>This has the effect of taking a &quot;snapshot&quot; into the array of the current objects in the set or those matched by the pathname, so that you can then later work on that collection of objects without worrying if the set or match has changed.</p>\n\
<p>This is similar to named selection sets in the <strong>3ds Max</strong> user interface, and can be used, for example, to keep track of selections as you work interactively with MAXScript.</p>\n\
<p>If the user deletes from the scene any of the objects in the array, you will get an error if you try to map operations over the array.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` sel1 = selection as array boxes_at_load = $box* as array snap_children = $torso...* as array original_cameras = cameras as array</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>free &lt;array&gt;\n\
</pre></div><p>Frees the memory used by the array value without waiting for garbage collection.</p>\n\
<p>Available in <strong>3ds Max 9 and higher</strong>.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";