var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>BitArray Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>BitArray Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"bitarray-values\"></a></div>\n\
<p>The MAXScript <strong>BitArray</strong> class provides direct access ’s SDK BitArray class.</p>\n\
<p>The SDK BitArray is used throughout <strong>3ds Max</strong> to compactly encode selections as a string of bits.</p>\n\
<p><strong>Literals</strong></p>\n\
<div class=\'codeBlock\'><pre>#{ &lt;selection&gt; } -- these are curly brackets!\n\
</pre></div><p>where <span class=\'code\'>&lt;selection&gt;</span> is a comma-separated list of the following</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt; -- integers must be &gt; 0\n\
&lt;integer&gt; .. &lt;integer&gt;\n\
</pre></div><p>For example, #{1, 5, 10..200, 302} says that the bits 1, 5, 10 to 200, and 302 are &quot;turned on&quot;.</p>\n\
<p>When used in connection with selections in <strong>3ds Max</strong> (such as vertex or face or control vertex) the &quot;on&quot; bits imply the elements or sub-objects with those indexes are selected.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;bitarray&gt;.count : Integer   \n\
</pre></div><p>Returns the largest possible index held in the BitArray at that point in time.</p>\n\
<p>This value is independent of whether any particular indexes are selected or not. BitArrays grow dynamically as needed to accommodate the indexes used on it, just as with arrays.</p>\n\
<p>Writing to the <span class=\'code\'>.count</span> property sets the storage to the specified number of bits.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;bitarray&gt;[&lt;integer&gt;]\n\
</pre></div><p>Yields true if selected, else false</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitarray&gt;[&lt;integer&gt;] = &lt;boolean&gt;\n\
</pre></div><p>Sets or clears indexed bit</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitarray&gt; + &lt;bitarray&gt;\n\
</pre></div><p>Union (&quot;OR&quot; operation)</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitarray&gt; * &lt;bitarray&gt;\n\
</pre></div><p>Intersection (&quot;AND&quot; operation)</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitarray&gt; - &lt;bitarray&gt;\n\
</pre></div><p>Difference</p>\n\
<div class=\'codeBlock\'><pre>-&lt;bitarray&gt;\n\
</pre></div><p>Invert the bitarray</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>append &lt;bitarray&gt; &lt;integer&gt;   \n\
</pre></div><p>Adds index to bitarray, growing bitarray if necessary.</p>\n\
<div class=\'codeBlock\'><pre>join &lt;bitarray&gt; &lt;bitarray&gt; \n\
</pre></div><p>Union (&quot;OR&quot; operation) of the two bitarrays.</p>\n\
<div class=\'codeBlock\'><pre>findItem &lt;bitarray&gt; &lt;integer&gt; \n\
</pre></div><p>Yields index <span class=\'code\'>&lt;integer&gt;</span> if selected, 0 otherwise.</p>\n\
<div class=\'codeBlock\'><pre>deleteItem &lt;bitarray&gt; &lt;integer&gt; \n\
</pre></div><p>Clears the index selection.</p>\n\
<div class=\'codeBlock\'><pre>copy &lt;bitarray&gt; \n\
</pre></div><p>Creates an independent copy of the bitarray.</p>\n\
<p>Note: BitArrays can be used interchangeable with ordinary #(...) <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/Array-Values.html\' title=\'\'>arrays</a> of index numbers where ever a selection array is applicable, such as in mesh sub-object selections.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` $foo.verts[#{20..1023}] --selects all vertices between 20 and 1023</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>You can sequence over BitArrays with a for-loop, which yields a sequence of index numbers corresponding to the currently selected items.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` for i in #{2..200} do print i -- print the numbers between 2 &amp; 200</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>You can perform an &quot;AND&quot; operation between two BitArrays by inverting the difference between them.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` a=#{1..5} b=#{3..10} c=-(a-b) -- result in c is #{3..5}</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Coercion of bitArray to array and integer arrays to bitArrays:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;bitArray&gt; as array \n\
&lt;integer array&gt; as bitArray \n\
<blockquote>\n\
</blockquote></pre></div><p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` a=#{1..5,10} b=a as array c=b as bitarray</p>\n\
<p>```</p>\n\
\n\
<p>If an element of the array cannot be coerced to an integer, an error is thrown. <span class=\'code\'>.numberSet</span> and <span class=\'code\'>.isEmpty</span> are read-only properties, which have been added to the <span class=\'code\'>BitArrayValue</span> class.</p>\n\
<div class=\'codeBlock\'><pre>.numberSet \n\
</pre></div><p>Returns the number of bits set</p>\n\
<div class=\'codeBlock\'><pre>.isEmpty \n\
</pre></div><p>Returns true if no bits are set and false if one or more bits are set.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` a=#{1..5,10..20} a.numberset --&gt; 16 a.isEmpty --&gt; false a=#{} a.numberset --&gt; 0 a.isEmpty --&gt; true</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";