var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Dictionary Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Dictionary Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"dictionary-values\"></a></div>\n\
<p>Available in <strong>3ds Max 2017.1 Update and higher</strong>: A Dictionary is a collection of key/value pairs, also known as an associative array. Keys can be of type name, string, or integer. For a given dictionary, the key type specified at the time of creation, and is always the same. The value can be of any type.</p>\n\
<p>Dictionaries support iteration in a for loop, where each element is processed as a <span class=\'code\'>DataPair</span>. Each <span class=\'code\'>DataPair</span> contains the key as <span class=\'code\'>v1</span>, the value as <span class=\'code\'>v2</span>, the <span class=\'code\'>value1_name</span> of <span class=\'code\'>#key</span>, and <span class=\'code\'>value2_name</span> of <span class=\'code\'>#value</span>.</p>\n\
<blockquote>\n\
<p><strong>Example</strong></p>\n\
<p><span class=\'code\'>d = Dictionary #(#ss, 1) #(#tt, 2)   for ele in d do print ele</span></p>\n\
<p><strong>Results</strong></p>\n\
<p><span class=\'code\'>Dictionary #name ss:1 tt:2    (DataPair key:#ss value:1)   (DataPair key:#tt value:2)   OK</span></p>\n\
</blockquote>\n\
<p>The Dictionary value class can be specified in a persistent global variable. All values in the Dictionary must be specifiable as a persistent global variable in order for the Dictionary to be fully restored on scene file load.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>Dictionary() -- empty dictionary of type #name\n\
Dictionary (#integer | #name | #string) -- empty dictionary of the specified type\n\
Dictionary {#(key, value)}+ -- one or more two-value arrays\n\
Dictionary {key:value}+ -- one or more explicit key:value pairs\n\
Dictionary {(DataPair key value)} -- one or more DataPair objects\n\
</pre></div><p>Dictionaries can be constructed using different types at once, for example with an array and a <span class=\'code\'>DataPair</span>, but the key type must always be the same.</p>\n\
<p>The default key type for a dictionary is <span class=\'code\'>#name</span>. If the dictionary constructor uses <span class=\'code\'>DataPairs</span>, the key type is the type of the first <span class=\'code\'>DataPair</span>&#39;s key value. All remaining <span class=\'code\'>DataPairs</span> must have the same key value type. If the dictionary constructor uses Arrays, the key type is the type of the first Array’s element 1 value. All remaining Arrays must have the same element 1 value type. If keyword arguments are used, their key type is <span class=\'code\'>#name</span>. For dictionaries of type <span class=\'code\'>#integer</span>, the actual key value type can be any of <span class=\'code\'>Integer</span>, <span class=\'code\'>IntegerPtr</span>, or <span class=\'code\'>Integer64</span>, interchangeably.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;dictionary&gt;.count : Integer, read-only\n\
</pre></div><p>A count of items in the dictionary</p>\n\
<div class=\'codeBlock\'><pre>&lt;dictionary&gt;.type read-only \n\
</pre></div><p>The type of the dictionary, which can be <span class=\'code\'>#name</span>, <span class=\'code\'>#string</span>, <span class=\'code\'>#integer</span>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;dictionary&gt;.keys : Array, read-only\n\
</pre></div><p>An array of the dictionary&#39;s keys. Note: changing this array does not affect the dictionary.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;dictionary&gt;[key] \n\
</pre></div><p>Gets the value for <span class=\'code\'>key</span>. If there is not an entry for the key, the value <span class=\'code\'>undefined</span> is returned.</p>\n\
<div class=\'codeBlock\'><pre>&lt;dictionary&gt;[key] = &lt;value&gt;\n\
</pre></div><p>Sets the value for key. An existing entry does not need to exist for the key.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>GetDictValue &lt;dictionary&gt; &lt;key &gt;\n\
</pre></div><p>Gets a value from the dictionary based on <span class=\'code\'>key</span>. If there is no entry for the key, a value of undefined is returned.</p>\n\
<div class=\'codeBlock\'><pre>SetDictValue &lt;dictionary&gt; &lt;key &gt; &lt;value&gt;\n\
</pre></div><p>Sets the value for an existing entry in dictionary based on <span class=\'code\'>key</span>. If there is no entry for the key, nothing happens.</p>\n\
<div class=\'codeBlock\'><pre>PutDictValue &lt;dictionary&gt; &lt;key &gt; &lt;value&gt; putOnlyIfNew:&lt;boolean&gt; -- defaults false\n\
</pre></div><p>Puts a value in dictionary based on key.</p>\n\
<p>If <span class=\'code\'>putOnlyIfNew</span> is true, the value is added only if there is no existing entry for the key. If <span class=\'code\'>putOnlyIfNew</span> is false, the value is added even if there is an existing entry for the key. If there is an entry, its value is set.</p>\n\
<div class=\'codeBlock\'><pre>RemoveDictValue &lt;dictionary&gt; &lt;key &gt;\n\
</pre></div><p>Removes the existing entry in the dictionary based on <span class=\'code\'>key</span>. If there is no entry for the key, nothing happens.</p>\n\
<div class=\'codeBlock\'><pre>HasDictValue &lt;dictionary&gt; &lt;key &gt;\n\
</pre></div><p>Returns whether there is an existing entry in the dictionary for the given <span class=\'code\'>key</span>.</p>\n\
<div class=\'codeBlock\'><pre>GetDictKeys &lt;dictionary&gt;\n\
</pre></div><p>Returns an array of key values in the dictionary.</p>\n\
<div class=\'codeBlock\'><pre>GetDictKeyType &lt;dictionary&gt;\n\
</pre></div><p>Returns the key type of the dictionary - <span class=\'code\'>#name</span>, <span class=\'code\'>#string</span>, or <span class=\'code\'>#integer</span>.</p>\n\
<div class=\'codeBlock\'><pre>copy &lt;dictionary&gt; [#nomap]\n\
</pre></div><p>Creates a shallow copy of the dictionary. Note that unlike with other collection types, <span class=\'code\'>copy()</span> always makes a shallow copy of Dictionaries, the <span class=\'code\'>#nomap</span> option is not actually required.</p>\n\
<div class=\'codeBlock\'><pre>deepCopy &lt;dictionary&gt;\n\
</pre></div><p>Creates a deep copy of the dictionary. Available in <strong>3ds Max 2019 and higher</strong>. The dictionary is recursively traversed, and new copies are generated of all items in the dictionary. Note that if the dictionary contains multiple references to a single value, the deep copy will contain multiple references to a single, new value.</p>\n\
<div class=\'codeBlock\'><pre>free &lt;dictionary&gt;\n\
</pre></div><p>Frees the internal memory associated with the dictionary. This effectively removes all items from the dictionary.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";