var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>EdgeSelection Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>EdgeSelection Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"edgeselection-values\"></a></div>\n\
<p>An <strong>EdgeSelection</strong> represents a set of edges for a scene mesh node as a virtual array.</p>\n\
<p>As such, you can access an edge by index, iterate over the edges, and apply mapped functions to the edges.</p>\n\
<p>See also <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Editable_Mesh-GeometryClass-and.html\' title=\'\'>Editable Mesh</a>.</p>\n\
<p>The EdgeSelection array is <strong>dynamic</strong> (its contents change as the edges or selected edges of the mesh node change).</p>\n\
<p>EdgeSelection values are <strong>mappable</strong>.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.selectedEdges \n\
</pre></div><p>The currently selected edges of the mesh object.</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.Edges \n\
</pre></div><p>All of the edges of the mesh object (read-only).</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;edgeselection&gt;.count : Integer, read-only \n\
</pre></div><p>Returns the number of edges in the edge array.</p>\n\
<div class=\'codeBlock\'><pre>&lt;edgeselection&gt;.selSetNames : Array of names, read-only \n\
</pre></div><p>Returns an array of names of the current edge-level named selection sets for the object the EdgeSelection is associated with.</p>\n\
<p>The following property is present for singleton selections (of the form $foo.edges[n]):</p>\n\
<div class=\'codeBlock\'><pre>&lt;edgeselection&gt;.index : Integer, read-only \n\
</pre></div><p>Returns the index of the selected element in the mesh,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` $foo.selectedEdges[2].index --returns the edge index of the 2nd edge in the current selection.</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Iterating over a selection yields singleton selections in the loop body:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` se = for i in $foo.selectedVerts collect i.index --se contains selected edges as array</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.selectedEdges = (&lt;array&gt; | &lt;bitarray&gt;) \n\
</pre></div><p>Selects the specified edges.</p>\n\
<div class=\'codeBlock\'><pre>&lt;edgeselection&gt;[&lt;integer&gt;] \n\
</pre></div><p>Retrieves the indexed edge as a singleton EdgeSelection. Index starts at 1.</p>\n\
<div class=\'codeBlock\'><pre>&lt;edgeselection&gt;[(&lt;integer_array&gt; | &lt;bitarray&gt;)] \n\
</pre></div><p>Retrieves the indexed edges as an EdgeSelection. Index starts at 1.</p>\n\
<div class=\'codeBlock\'><pre>&lt;edgeselection&gt;[(&lt;#name&gt; | &lt;string&gt;)] \n\
</pre></div><p>Retrieves the edge-level named selection set, where the name of the named selection set can be specified as a name or string value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;edgeselection&gt;[(&lt;#name&gt; | &lt;string&gt;)] = (&lt;faceselection&gt; | &lt;integer_array&gt; | &lt;bitarray&gt;) \n\
</pre></div><p>Sets the edge-level named selection set to the specified edges.</p>\n\
<p>The name of the named selection set can be specified as a name or string value, and the edges can be specified as an array, a bitArray, or an EdgeSelection from the same object.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>move &lt;edgeselection&gt; &lt;point3&gt; \n\
</pre></div><p>Moves the edges in the EdgeSelection.</p>\n\
<div class=\'codeBlock\'><pre>select &lt;edgeselection&gt; \n\
</pre></div><p>Selects the edges in the EdgeSelection.</p>\n\
<div class=\'codeBlock\'><pre>deselect &lt;edgeselection&gt; \n\
</pre></div><p>Deselects the edges in the EdgeSelection.</p>\n\
<div class=\'codeBlock\'><pre>delete &lt;edgeselection&gt; \n\
</pre></div><p>Deletes the edges in the EdgeSelection.</p>\n\
<div class=\'codeBlock\'><pre>append &lt;edgeselection&gt; (&lt;edgeselection&gt; | &lt;integer&gt;) \n\
</pre></div><p>Appends the edge(s) to the EdgeSelection.</p>\n\
<div class=\'codeBlock\'><pre>findItem &lt;edgeselection&gt; (&lt;edgeselection[&lt;integer&gt;] | &lt;integer&gt;) \n\
</pre></div><p>Returns the selection index of the matching item or 0 if not found. The item is selection index or singleton EdgeSelection.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` -- move edges in &#39;mouth&#39; named selection set move $foo.edges[#mouth] [0,0,10] -- select edges in &#39;front edges&#39; set select $baz.edges[&quot;front edges&quot;] -- set &#39;baz&#39; named selection set to given edges $foo.edges[#baz] = #(1,3,4,5,10) -- set &#39;cursel&#39; set to current selection $baz.edges[#cursel] = $baz.selectedEdges -- all the names of the edge-level named selection sets for object $foo $foo.edges.selSetNames -- print out all edge-level named selection sets for n in $.edges.selSetNames do print $.edges[n] -- print all selected edges, but gets truncated to the first 20 by default print $.selectedEdges -- use printAllElements context to view all edges with printAllElements on print $.selectedEdges</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";