var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>FaceSelection Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>FaceSelection Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"faceselection-values\"></a></div>\n\
<p>A <strong>FaceSelection</strong> represents a set of faces for a scene mesh node as a virtual array.</p>\n\
<p>As such, you can access a face by index, iterate over the faces, and apply mapped functions to the faces.</p>\n\
<p>See also <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Editable_Mesh-GeometryClass-and.html\' title=\'\'>Editable Mesh</a>.</p>\n\
<p>The FaceSelection array is <strong>dynamic</strong> (its contents change as the faces or selected faces of the mesh node change).</p>\n\
<p>FaceSelection values are <strong>mappable</strong>.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.selectedFaces \n\
</pre></div><p>The currently selected faces of the mesh object.</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.Faces \n\
</pre></div><p>All of the faces of the mesh object (read-only).</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;faceselection&gt;.count : Integer, read-only \n\
</pre></div><p>Returns the number of faces in the FaceSelection array.</p>\n\
<div class=\'codeBlock\'><pre>&lt;faceselection&gt;.selSetNames : Array of names, read-only \n\
</pre></div><p>Returns an array of names of the current face-level named selection sets for the object the FaceSelection is associated with.</p>\n\
<p>The following property is present for singleton selections (of the form $foo.faces[n]):</p>\n\
<div class=\'codeBlock\'><pre>&lt;faceselection&gt;.index : Integer, read-only \n\
</pre></div><p>Returns the index of the selected element in the mesh,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` $foo.selectedFaces[2].index -- returns the face index of the 2nd face in the current selection.</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Iterating over a selection yields singleton selections in the loop body:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` sf = for i in $foo.selectedFaces collect i.index --sf contains selected faces as array</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.selectedFaces = (&lt;array&gt; | &lt;bitarray&gt;) \n\
</pre></div><p>Selects the specified faces.</p>\n\
<div class=\'codeBlock\'><pre>&lt;faceselection&gt;[&lt;integer&gt;] \n\
</pre></div><p>Retrieves the indexed face as a singleton FaceSelection. Index starts at 1.</p>\n\
<div class=\'codeBlock\'><pre>&lt;faceselection&gt;[&lt;integer&gt;] = &lt;point3&gt; \n\
</pre></div><p>Sets the vertices of the indexed face to the vertex indices specified in the point3 value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;faceselection&gt;[(&lt;integer_array&gt; | &lt;bitarray&gt;)] \n\
</pre></div><p>Retrieves the indexed faces as a FaceSelection. Index starts at 1.</p>\n\
<div class=\'codeBlock\'><pre>&lt;faceselection&gt;[(&lt;#name&gt; | &lt;string&gt;)] \n\
</pre></div><p>Retrieves the face-level named selection set, where the name of the named selection set can be specified as a name or string value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;faceselection&gt;[(&lt;#name&gt; | &lt;string&gt;)] = (&lt;faceselection&gt; | &lt;integer_array&gt; | &lt;bitarray&gt;) \n\
</pre></div><p>Sets the face-level named selection set to the specified faces.</p>\n\
<p>The name of the named selection set can be specified as a name or string value, and the faces can be specified as an array, a bitArray, or a FaceSelection from the same object.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>move &lt;faceselection&gt; &lt;point3&gt; \n\
</pre></div><p>Moves the faces in the FaceSelection.</p>\n\
<div class=\'codeBlock\'><pre>select &lt;faceselection&gt; \n\
</pre></div><p>Selects the faces in the FaceSelection.</p>\n\
<div class=\'codeBlock\'><pre>deselect &lt;faceselection&gt; \n\
</pre></div><p>Deselects the faces in the FaceSelection.</p>\n\
<div class=\'codeBlock\'><pre>delete &lt;faceselection&gt; \n\
</pre></div><p>Deletes the faces in the FaceSelection.</p>\n\
<div class=\'codeBlock\'><pre>append &lt;faceselection&gt; (&lt;faceselection&gt; | &lt;integer&gt;) \n\
</pre></div><p>Appends the face(s) to the FaceSelection.</p>\n\
<div class=\'codeBlock\'><pre>findItem &lt;faceselection&gt; (&lt;faceselection[&lt;integer&gt;] | &lt;integer&gt;) \n\
</pre></div><p>Returns the selection index of the matching item or 0 if not found. The item is selection index or singleton FaceSelection.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES</strong></p>\n\
<p>``` -- move faces in &#39;mouth&#39; named selection set move $foo.faces[#mouth] [0,0,10] -- select faces in &#39;front faces&#39; set select $baz.faces[&quot;front faces&quot;] -- set &#39;baz&#39; named selection set to given faces $foo.faces[#baz] = #(1,3,4,5,10) -- set &#39;cursel&#39; set to current selection $baz.faces[#cursel] = $baz.selectedFaces -- all the names of the face-level named selection sets for object $foo $foo.faces.selSetNames -- print out all face-level named selection sets for n in $.faces.selSetNames do print $.faces[n] -- print all selected edges, with printAllElements context on so the list is not truncated with printAllElements on print $foo.selectedFaces</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";