var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>MAXKeyArray Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>MAXKeyArray Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"maxkeyarray-values\"></a></div>\n\
<p>A <strong>MAXKeyArray</strong> represents all the keyframe keys in a <strong>3ds Max</strong> controller track.</p>\n\
<p>See also <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/MAXKey-Values/MAXKey-Values-1.html\' title=\'\'>MAXKey Values</a>, <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/MAXKey-Values/Working-with-MAXKey-Values.html\' title=\'\'>Working with MAXKey Values</a>, and <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Common-Properties/Controller-Common-Properties-1.html\' title=\'\'>Controller Common Properties, Operators, and Methods</a>.</p>\n\
<p>MAXKeyArray values are <strong>mappable</strong>.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;.&lt;animatable_property&gt;.keys \n\
</pre></div><p>The key array can be accessed using the <span class=\'code\'>keys</span> property on an animated <strong>3ds Max</strong> object property.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` $foo.position.keys $foo.twist.angle.keys</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>If the <strong>3ds Max</strong> object parameter is not yet animated (no controller has been assigned to the parameter), a value of <span class=\'code\'>undefined</span> is returned.</p>\n\
<div class=\'codeBlock\'><pre>&lt;controller&gt;.keys \n\
</pre></div><p>The key array can be accessed using the <span class=\'code\'>keys</span> property on a controller.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` $foo.position.controller.keys $foo[3][1].keys</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;key_array&gt;.count : Integer, read-only \n\
</pre></div><p>Returns the number of keys in the key array.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;key_array&gt;[&lt;index_integer&gt;] \n\
</pre></div><p>Returns a <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/MAXKey-Values/MAXKey-Values-1.html\' title=\'\'>MAXKey</a> value representing the indexed key in the key array. Indexes start at 1.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>append &lt;key_array&gt; &lt;key&gt; \n\
</pre></div><p>Appends key to key array.</p>\n\
<div class=\'codeBlock\'><pre>deleteItem &lt;key_array&gt; &lt;index_integer&gt; \n\
</pre></div><p>Deletes the indexed key. Key indexes are <strong>1-based</strong>.</p>\n\
<div class=\'codeBlock\'><pre>addNewKey &lt;key_array&gt; &lt;time&gt; [ #select ] \n\
</pre></div><p>Adds a new key to the key array at the time specified. The value for the new key is the interpolated controller value at the specified time.</p>\n\
<p>The new key is also selected if the <span class=\'code\'>#select</span> optional argument is specified.</p>\n\
<p>The value for the new key is the interpolated controller value at that time. <span class=\'code\'>addNewKey()</span> will not add a key if a key already exists at the specified time.</p>\n\
<p>The return value in this case is the key located at the specified time.</p>\n\
<div class=\'codeBlock\'><pre>deleteKeys &lt;key_array&gt; [ #allKeys ] [ #selection ] \n\
</pre></div><p>Deletes keys from the controller according to the optional symbolic argument supplied.</p>\n\
<p><span class=\'code\'>#allKeys (default)</span>: deletes <strong>all</strong> keys in the controller.</p>\n\
<p><span class=\'code\'>#selection</span> : deletes the currently selected keys.</p>\n\
<div class=\'codeBlock\'><pre>deleteKey &lt;key_array&gt; &lt;index_integer&gt; \n\
</pre></div><p>Deletes the indexed key. Key indexes are <strong>1-based</strong>.</p>\n\
<div class=\'codeBlock\'><pre>moveKeys &lt;key_array&gt; &lt;time&gt; [ #selection ] \n\
</pre></div><p>Moves all keys by the time given. If <span class=\'code\'>#selection</span> is specified, move the current selection. Otherwise, move all keys.</p>\n\
<div class=\'codeBlock\'><pre>sortKeys &lt;key_array&gt; \n\
</pre></div><p>Re-sorts keys according to their times. Some MAXKey operations can result in out of order keys and this function must be called to correctly order keys.</p>\n\
<p>Note:</p>\n\
<p>All of the above methods might re-sequence keys in the key array and cause existing keys to take on <strong>different</strong> indexes because key array indexes are time positional.</p>\n\
<p>Take care when inserting and deleting keys into arrays that have individual keys in variables and other containers. MAXKey values are defined internally in terms of this index and might point to <strong>different</strong> keys if you re-arrange the keys in a controller.</p>\n\
<p>MAXKeyArrays also support mapped property assignment in their contents in the same way that pathname and array collections do in their contents.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` b = box() c = cylinder() for i = 1 to 3 do b.pos.controller[i].controller.keys.time += 10f --bumps all position key times by 10 frames, --this is necessary because Position_XYZ has 3 sub-controllers</p>\n\
<p>c.bend.angle.keys.value *= 1.2 --scales all the bend angle key values up by 1.2.</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` keys = $box01.bend.angle.keys for t in 0f to 100f by 10f do addNewKey keys t</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";