var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>MaterialLibrary Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>MaterialLibrary Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"materiallibrary-values\"></a></div>\n\
<p>A <strong>MaterialLibrary</strong> contains a table of materials as an array.</p>\n\
<p>The <strong>3ds Max</strong> system global variables <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/MaterialLibrary-Values.html\' title=\'\'>currentMaterialLibrary</a> and <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/MaterialLibrary-Values.html\' title=\'\'>sceneMaterials</a> contain MaterialLibrary instances.</p>\n\
<p>System global variable <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/MaterialLibrary-Values.html\' title=\'\'>meditMaterials</a> is not a MaterialLibrary value, rather it is a virtual array of the materials in the Material Editor sample slots.</p>\n\
<p>In most cases, <span class=\'code\'>meditMaterials</span> can be considered a MaterialLibrary value with the exception that you can assign a material or textureMap value to a <span class=\'code\'>meditMaterials</span> element.</p>\n\
<p>MaterialLibrary values are <strong>mappable</strong>.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>currentMaterialLibrary \n\
</pre></div><p>A <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/MaterialLibrary-Values.html\' title=\'\'>system global</a> containing the current material library.</p>\n\
<div class=\'codeBlock\'><pre>sceneMaterials \n\
</pre></div><p>A <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/MaterialLibrary-Values.html\' title=\'\'>system global</a> containing all materials in the scene.</p>\n\
<div class=\'codeBlock\'><pre>meditMaterials \n\
</pre></div><p>A <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/MaterialLibrary-Values.html\' title=\'\'>system global</a> containing the 24 sample slot materials in the Material Editor.</p>\n\
<div class=\'codeBlock\'><pre>materialLibrary { &lt;material&gt; } \n\
</pre></div><p>Creates a <strong>temporary</strong> material library. You can add materials to this library with the <span class=\'code\'>append</span> function, and save it to disk and load it from disk using the <span class=\'code\'>saveTempMaterialLibrary</span> and <span class=\'code\'>loadTempMaterialLibrary</span> functions documented <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/MaterialLibrary-Values.html\' title=\'\'>farther in this topic</a>.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;mat_lib&gt;.count : Integer, read-only \n\
</pre></div><p>Returns the number of materials in the library.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;mat_lib&gt;[ &lt;integer&gt; | &lt;name&gt; | &lt;string&gt; ] \n\
</pre></div><p>Retrieves a material from the material library. Material libraries can be indexed just like arrays with an integer index, or by using the material name as a Name or String value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;mat_lib&gt;[ &lt;integer&gt; | &lt;name&gt; | &lt;string&gt; ] = ( &lt;material&gt; | &lt;textureMap&gt; ) \n\
</pre></div><p>Assigns the specified material or textureMap to the material library.</p>\n\
<p>Material libraries can be indexed just like arrays with an integer index, or by using the material name as a Name or String value.</p>\n\
<p>If the material library is indexed by an index value, and the index value is larger than the size of the material library, a runtime error is generated.</p>\n\
<p>If the material library is indexed by a material name, and the material name is not already present in the material library, the material or textureMap is appended to the material library.</p>\n\
<div class=\'codeBlock\'><pre>meditMaterials[&lt;slot_index_integer&gt;] \n\
</pre></div><p>Returns the material or textureMap in the indexed material editor slot.</p>\n\
<p>Valid <span class=\'code\'>&lt;slot_index_integer&gt;</span> values are 1 through 24.</p>\n\
<div class=\'codeBlock\'><pre>meditMaterials[&lt;slot_index_integer&gt;] = ( &lt;material&gt; | &lt;textureMap&gt; ) \n\
</pre></div><p>Assigns the specified material or textureMap to the indexed material editor slot.</p>\n\
<p>Valid <span class=\'code\'>&lt;slot_index_integer&gt;</span> values are 1 through 24.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` meditMaterials[3]= standard() --sets the third slot of the Material Editor --to a new standard material.</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>append &lt;mat_lib&gt; &lt;material&gt; \n\
</pre></div><p>Append the specified material to the material library. This method is not applicable to the <span class=\'code\'>meditMaterials</span> material library.</p>\n\
<div class=\'codeBlock\'><pre>deleteItem &lt;mat_lib&gt; ( &lt;integer&gt; | &lt;name&gt; | &lt;string&gt; ) \n\
</pre></div><p>Delete the specified material from the material library. The material can be specified as the indexed material in the material library, as a String or as a Name. This method is not applicable to the <span class=\'code\'>meditMaterials</span> material library.</p>\n\
<div class=\'codeBlock\'><pre>findItem &lt;mat_lib&gt; &lt;material&gt; \n\
</pre></div><p>Returns the index of the material in the material library or <strong>zero</strong> if the material is not in the material library.</p>\n\
<p><strong>Associated Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>getMeditMaterial &lt;slot_index_integer&gt; \n\
</pre></div><p>Returns the top level material or textureMap in the specified material editor slot. Valid <span class=\'code\'>&lt;slot_index_integer&gt;</span> values are 1 through 24.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` theMat = getMeditMaterial 3 --gets the material from the third slot of the Material Editor.</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>setMeditMaterial &lt;slot_index&gt; ( &lt;material&gt; | &lt;textureMap&gt; ) \n\
</pre></div><p>Complements the <span class=\'code\'>getMeditMaterial</span> function allowing you to place a material or textureMap into the numbered material editor slot.</p>\n\
<div class=\'codeBlock\'><pre>loadDefaultMatLib() \n\
</pre></div><p>Loads the default <strong>3ds Max</strong> material library file.</p>\n\
<div class=\'codeBlock\'><pre>loadMaterialLibrary &lt;filename_string&gt; \n\
</pre></div><p>Loads the named <strong>3ds Max</strong> material library file, which becomes the current material library. If the file name does not have a fully specified directory path, the function searches through all the currently configured bitmap paths. Returns <span class=\'code\'>true</span> if loading is successful, <span class=\'code\'>false</span> if it fails.</p>\n\
<div class=\'codeBlock\'><pre>saveMaterialLibrary &lt;filename_string&gt; \n\
</pre></div><p>Saves the current material library into the named file. Returns <span class=\'code\'>true</span> if saving is successful, <span class=\'code\'>false</span> if it fails.</p>\n\
<div class=\'codeBlock\'><pre>fileOpenMatLib() \n\
</pre></div><p>This method displays the File Open dialog and allows the user to select a material library to load.</p>\n\
<p>Note: If the Material/Map Browser is open when <span class=\'code\'>fileOpenMatLib()</span> is called, the Material/Map Browser display is not updated.</p>\n\
<div class=\'codeBlock\'><pre>fileSaveAsMatLib() \n\
</pre></div><p>Displays the standard Save File As dialog to allow the user to save the current material library.</p>\n\
<div class=\'codeBlock\'><pre>fileSaveMatLib [quiet:&lt;boolean&gt;] \n\
</pre></div><p>If the current material library has been saved previously (has been named) this method saves the material library to the same file. Otherwise, it displays the standard Save File As dialog to allow the user to save the current material library.</p>\n\
<p>For details on the <span class=\'code\'>quiet:</span> option available in <strong>3ds Max 8 and higher</strong>, please see <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Network-Render-Interface/Quiet-Mode.html\' title=\'\'>Quiet Mode</a>.</p>\n\
<div class=\'codeBlock\'><pre>getMatLibFileName() \n\
</pre></div><p>Returns the current material library file name as a String value.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>You can use the standard array indexing accessors to get and set materials in the library. MaterialLibraries also allow you to use name and string literals as indexes to get materials in them by name:</p>\n\
<p>``` $foo.material = currentMaterialLibrary[&quot;Rough Gold&quot;]</p>\n\
<p>```</p>\n\
<p>``` for m in sceneMaterials do print m.name</p>\n\
<p>```</p>\n\
<p>``` append currentMaterialLibrary $baz.material</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;MAXMaterialLibrary&gt;loadTempMaterialLibrary &lt;mtllib_file_name&gt; \n\
</pre></div><p>Loads the named 3ds Max material library file. Unlike <span class=\'code\'>loadMaterialLibrary()</span> , the material library does not become the current material library. If the file name does not have a fully specified directory path, the function searches the material library path and all the currently configured bitmap paths. Returns MAXMaterialLibrary value if loading is successful, undefined if it fails.</p>\n\
<p>Available in <strong>3ds Max 9</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;saveTempMaterialLibrary &lt;MAXMaterialLibrary&gt; &lt;mtllib_file_name&gt; \n\
</pre></div><p>Saves the specified MAXMaterialLibrary value into the named file. Returns true if saving is successful, false if it fails.</p>\n\
<p>Available in <strong>3ds Max 9</strong> and higher.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>You can use the standard array indexing accessors to get and set materials in the library. MaterialLibraries also allow you to use name and string literals as indexes to get materials in them by name:</p>\n\
<p>``` a = loadTempMaterialLibrary &quot;mrArch_DesignTemplates.mat&quot; --&gt; #materialLibrary() a[1] --&gt; brushed metal:Arch___Design__mi saveTempMaterialLibrary a &quot;$matlibs/test.mat&quot; --&gt; true</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt; UpdateSceneMaterialLib() \n\
</pre></div><p>Forces an update to the Scene Material Library (the <strong>sceneMaterials</strong> global). The Scene Material library is not guaranteed to be accurate after some scene operations. For example, if you delete a node, the material for that node may still appear in the Scene Material library.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";