var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>ObjectSet Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>ObjectSet Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"objectset-values\"></a></div>\n\
<p><strong>ObjectSets</strong> represent the main scene object categories in <strong>3ds Max</strong>. The &quot;constructors&quot; below are all reserved system variables. ObjectSet values are mappable.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>objects  --all the objects\n\
geometry  --the standard 3ds Max categories... \n\
lights\n\
cameras\n\
helpers\n\
shapes\n\
systems\n\
spacewarps\n\
selection  --the current selection\n\
</pre></div><p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;objectset&gt;.center : Point3, read-only\n\
</pre></div><p>Returns center of bounding box of all objects in set.</p>\n\
<div class=\'codeBlock\'><pre>&lt;objectset&gt;.max : Point3, read-only\n\
</pre></div><p>Returns maximum corner of bounding box.</p>\n\
<div class=\'codeBlock\'><pre>&lt;objectset&gt;.min : Point3, read-only\n\
</pre></div><p>Returns minimum corner of bounding box.</p>\n\
<div class=\'codeBlock\'><pre>&lt;objectset&gt;.count : Integer, read-only\n\
</pre></div><p>Returns number of objects in set.</p>\n\
<div class=\'codeBlock\'><pre>&lt;objectset&gt;.boundingBox\n\
</pre></div><p><img src=\'developer/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/What-s-New-in-MAXScript-in-3ds.html\' title=\'\'>NEW</a> <strong>in 3ds Max 2022:</strong>: Read-only. Returns a Box3 value representing the bounding box of the nodes in the ObjectSet.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;objectset&gt;[&lt;integer&gt;]\n\
</pre></div><p>Accesses member of collection. Indexes start at 1.</p>\n\
<div class=\'codeBlock\'><pre>&lt;objectset&gt; as array\n\
</pre></div><p>Converts objectset collection to an array.</p>\n\
<p><strong>Associated Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>clearSelection()\n\
</pre></div><p>Clears current scene node selection.</p>\n\
<div class=\'codeBlock\'><pre>deselect &lt;PathName&gt;\n\
</pre></div><p>Deselects given node(s).</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` deselect $box* --deselects all items whose names start with &quot;box&quot;.</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>select &lt;PathName&gt;\n\
</pre></div><p>Deselects any current selection first, then selects the specified nodes.</p>\n\
<div class=\'codeBlock\'><pre>selectMore &lt;PathName&gt;\n\
</pre></div><p>Adds the specified node(s) to the current selection.</p>\n\
<div class=\'codeBlock\'><pre>getCurrentSelection()\n\
</pre></div><p>Returns the current selection as an array. This is similar to <strong>selection as array</strong>, however <span class=\'code\'>selection as array</span> returns a <em>copy</em> of the selection.</p>\n\
<p>Note:</p>\n\
<p>ObjectSets are actually special types of value that denote their sets, stored in reserved system variables of the same name, so you can assign them to other variables and pass them around as function arguments, etc.</p>\n\
<p>When storing an ObjectSet in a variable, <strong>the ObjectSet value is stored</strong> rather than the objects in the ObjectSet. Thus, if the scene changes and the ObjectSet is affected by this change, the value assigned to the variable will also change dynamically to reflect the scene changes.</p>\n\
<p>To store a snapshot of the objects currently in the ObjectSet to a variable, first convert the ObjectSet to an array using the <span class=\'code\'>as</span> operator.</p>\n\
<p>You can use ObjectSets as the <strong>root of a pathname</strong>,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` $helpers/d*</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>which limits the pathname searching to the object set you&#39;ve specified. So, in the above example, it will name only helper objects that start with &#39;d&#39;.</p>\n\
<p>The order of sequencing is consistent in a stable scene but somewhat arbitrary - it depends on how <strong>3ds Max</strong> stores its object hierarchy internally which is effected mostly by order of additions and deletions to and from the scene.</p>\n\
<p>The <span class=\'code\'>lights</span> and <span class=\'code\'>cameras</span> object sets include the target objects, if any, for the lights and cameras. If you want to change a property value for all the lights or cameras, you will need process each object in the ObjectSet individually, testing to make sure it is a light or camera.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>to increase the <span class=\'code\'>multiplier</span> property value for all lights, you would say:</p>\n\
<p>``` for obj in lights do if iskindof obj light do obj.multiplier *= 1.3</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>EXAMPLES</strong></p>\n\
<p>``` s = selection[1] --grab the first object in the current selection move cameras[2] [x, y, z + 10] --move the second camera</p>\n\
<p>```</p>\n\
<p>``` --select everything within a 100 units of $foo select (for o in objects where distance o $foo &lt; 100 collect o)</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";