var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>PathName Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>PathName Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"pathname-values\"></a></div>\n\
<blockquote>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Values-1.html\' title=\'\'>Value</a> &gt;<a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collections-1.html\' title=\'\'>Collections</a> &gt; <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/Collection-Types-1.html\' title=\'\'>Collection Types</a> &gt; PathName Values</p>\n\
</blockquote>\n\
<p><strong>PathNames</strong> provide the mechanism for naming objects in the <strong>3ds Max</strong> scene. See also <a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Literal-Constants/Pathname-Literals.html\' title=\'\'>Pathname Literals</a>. Pathname values are mappable.</p>\n\
<p><strong>Example Literals</strong></p>\n\
<div class=\'codeBlock\'><pre>$box01\n\
$torso/left_upper_arm/left_lower_arm\n\
$*box*\n\
$torso/*\n\
$torso...*\n\
</pre></div><p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;pathname&gt;.center : Point3, read-only\n\
</pre></div><p>Returns the center of the bounding box of all objects in pathname.</p>\n\
<div class=\'codeBlock\'><pre>&lt;pathname&gt;.max : Point3, read-only\n\
</pre></div><p>Returns the maximum corner of the bounding box.</p>\n\
<div class=\'codeBlock\'><pre>&lt;pathname&gt;.min : Point3, read-only\n\
</pre></div><p>Returns the minimum corner of the bounding box.</p>\n\
<div class=\'codeBlock\'><pre>&lt;pathname&gt;.count : Integer, read-only\n\
</pre></div><p>Returns the number of objects in set. This property is only valid for wild-carded pathnames (a pathname that can contain more than one scene object).</p>\n\
<div class=\'codeBlock\'><pre>&lt;pathname&gt;.boundingBox\n\
</pre></div><p><img src=\'developer/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/What-s-New-in-MAXScript-in-3ds.html\' title=\'\'>NEW</a> <strong>in 3ds Max 2022:</strong>: Read-only. Returns a Box3 value representing the bounding box of the nodes specified by the pathname.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;pathname&gt;[&lt;integer&gt;]\n\
</pre></div><p>Accesses the member of collection. Indexes start at 1.</p>\n\
<div class=\'codeBlock\'><pre>&lt;pathname&gt; as array\n\
</pre></div><p>Converts the pathname collection to an array</p>\n\
<p><strong>Associated Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>isDeleted &lt;MAXWrapper_object&gt;\n\
</pre></div><p>This function yields the result as <span class=\'code\'>true</span> if the object has been deleted and <span class=\'code\'>false</span> if it still exists in the scene.</p>\n\
<p>Using the function only makes sense in situations where references to <strong>3ds Max</strong> objects are held in variables or arrays, or passed as parameters and you want to determine whether the object has been deleted from the scene.</p>\n\
<p>Otherwise, performing an operation on a deleted <strong>3ds Max</strong> object referenced in a variable or array generates an exception.</p>\n\
<p>Any kind of <strong>3ds Max</strong> object can be tested in this way such as, scene objects, modifiers, controllers, materials, and others.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` myBoxes = $box* as array -- store list of all boxes in array myBoxes --... -- <one or=\"\" more=\"\" objects=\"\" in=\"\" the=\"\" selection=\"\" are=\"\" deleted=\"\" --=\"\" by=\"\" the=\"\" user=\"\" or=\"\" other=\"\" scripts=\"\"> --... for obj in myBoxes where not isDeleted obj do move obj [10,0,0]<p>\n\
<p>```</p>\n\
</one></blockquote>\n\
<p>Note: The order of sequencing is consistent in a stable scene, but somewhat arbitrary. It depends on how <strong>3ds Max</strong> stores its object hierarchy internally, which is affected mostly by order of additions and deletions to and from the scene.</p>\n\
<p>MAXScript lets you set up a &#39;working level&#39; in the <strong>3ds Max</strong> scene hierarchy that affects pathnames and coordinate systems, and object creation. You can do this with a <span class=\'code\'>&lt;level_expr&gt;</span> , one of the many <strong>context expressions</strong> that are described in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions.html\' title=\'\'>Context Expressions</a>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` b = box name: &quot;foo&quot; isSelected:true s = sphere name: &quot;feet&quot;</p>\n\
<p>a = $<em>feet</em>[1] -- retrieves the first object in the <em>feet</em>&#39;s -- tell me what things inside dummy have a non-identity scale for obj in $dummy...<em> where obj.scale != [1,1,1] do format &quot;% has non-identity scale: %\\n&quot; obj.name obj.scale -- place $foo&#39;s pivot point at the max corner of the set of &#39;box</em>&#39; objects. b.pivot = $box<em>.max in $dummy ( sphere name:&quot;ear1&quot; pos:[10,10,10] -- create as children of $dummy sphere name:&quot;ear2&quot; pos:[-10,10,10] scale $foo/</em> [1,1,2] -- looks for &#39;foo&#39; as a child of $dummy )</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";