var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>SelectionSetArray Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>SelectionSetArray Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"selectionsetarray-values\"></a></div>\n\
<p>The <strong>SelectionSetArray</strong> class has only one instance, <strong>selectionSets</strong>, which is an array of all the named selection sets in the current scene.</p>\n\
<p>The named selection sets correspond to the selection sets in the <strong>Named Selection Set</strong> drop-down list on the <strong>3ds Max</strong> toolbar.</p>\n\
<p>SelectionSet values are mappable.</p>\n\
<p>Also see <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/SelectionSet-Values.html\' title=\'\'>SelectionSet Values</a>.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>selectionSets\n\
</pre></div><p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;selectionsetarray&gt;.count : Integer, read-only\n\
</pre></div><p>Returns the number of named selection sets.</p>\n\
<div class=\'codeBlock\'><pre>&lt;selectionsetarray&gt;.boundingBox\n\
</pre></div><p><img src=\'developer/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/What-s-New-in-MAXScript-in-3ds.html\' title=\'\'>NEW</a> <strong>in 3ds Max 2022:</strong>: Read-only. Returns a Box3 value representing the bounding box of the nodes in the SelectionSetArray.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;selectionsetarray&gt;[&lt;set_name&gt;]\n\
</pre></div><p>Accesses the member of collection by named selection set name. <span class=\'code\'>set_name</span> can be either a String or Name value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;selectionsetarray&gt;[&lt;set_index_integer&gt;]\n\
</pre></div><p>Accesses the member of collection by an index number. Indexes start at 1.</p>\n\
<div class=\'codeBlock\'><pre>&lt;selectionsetarray&gt;[&lt;set_name&gt;] = &lt;node_array&gt;\n\
</pre></div><p>Creates or replaces the named selection set with the name <span class=\'code\'>set_name</span> , which can be either a String or Name value. <span class=\'code\'>node_array</span> must be an array of nodes.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>deleteItem &lt;selectionsetarray&gt; [&lt;set_name&gt; | &lt;selectionset&gt;]\n\
</pre></div><p>Deletes the selection set. The first argument is the selection sets array <span class=\'code\'>selectionSets</span> .</p>\n\
<p>The second argument can be the name of the selection set that can be either a String or Name value or the selection set itself (which is a new option in <strong>3ds Max 9</strong>).</p>\n\
<p>The method <span class=\'code\'>isDeleted()</span> is valid for named selection sets since <strong>3ds Max 9</strong>. See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/SelectionSet-Values.html\' title=\'\'>SelectionSet Values</a> for details and examples.</p>\n\
<p><strong>Associated Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>getNumNamedSelSets()\n\
</pre></div><p>Returns the number of named selection sets as an integer.</p>\n\
<div class=\'codeBlock\'><pre>getNamedSelSetName &lt;set_index&gt;\n\
</pre></div><p>Returns the name of the indexed named selection set as a string. <span class=\'code\'>&lt;set_index&gt;</span> is 1 based.</p>\n\
<div class=\'codeBlock\'><pre>getNamedSelSetItemCount &lt;set_index&gt;\n\
</pre></div><p>Returns the number of nodes in the indexed named selection set as an integer. <span class=\'code\'>&lt;set_index &gt;</span> is 1 based.</p>\n\
<div class=\'codeBlock\'><pre>getNamedSelSetItem &lt;set_index&gt; &lt;node_index&gt;\n\
</pre></div><p>Returns the indexed node in the indexed named selection set as a node. <span class=\'code\'>&lt;set_index&gt;</span> and <span class=\'code\'>&lt;node_index&gt;</span> are 1 based.</p>\n\
<p>You can access an individual selection set by indexing the <span class=\'code\'>selectionSets</span> array with its name or index.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` set1 = selectionSets[&quot;my set 1&quot;]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>You can then use that set just as you use any other object set in MAXScript such as, selection, objects, lights, and others.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` move set1 [10,0,0] --moves all the objects in the set across 10 in x.</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>You can use strings or MAXScript names (starting with #) interchangeably as indexes for the <span class=\'code\'>selectionSets</span> array or you can use an integer as an index if you want to loop over all the sets.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` selectionSets[#set2].wireColor = red for i in 1 to selectionSets.count do saveNodes selectionSets[i] (&quot;set&quot; + i as string + &quot;.max&quot;)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>You can <strong>change</strong>, <strong>add</strong>, and <strong>delete</strong> new Named Selection Sets by using the standard array methods on the <span class=\'code\'>selectionSets</span> array:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` selectionSets[&quot;new set&quot;] = selection --snap the current selection selectionSets[&quot;old spheres&quot;] = $sphere* --all the current objects named &quot;sphere*&quot; selectionSets[#foo] = #(obj1, obj2, obj3) deleteItem selectionSets&quot;old set&quot; --delete the set named &quot;old set&quot; nss = selectionSets[&quot;another set&quot;] --get the selection set by name deleteItem selectionSets nss --possible syntax since 3ds Max 9</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";