var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>VertexSelection Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>VertexSelection Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"vertexselection-values\"></a></div>\n\
<p>A <strong>VertexSelection</strong> represents a set of vertices for a scene mesh node as a virtual array.</p>\n\
<p>As such, you can access a vertex by index, iterate over the vertices, and apply mapped functions to the vertices.</p>\n\
<p>See also <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Editable_Mesh-GeometryClass-and.html\' title=\'\'>Editable Mesh</a>.</p>\n\
<p>The VertexSelection array is dynamic (its contents will change as the vertices or selected vertices of the mesh node change).</p>\n\
<p>VertexSelection values are mappable.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.selectedVerts \n\
</pre></div><p>The currently selected vertices of the mesh object.</p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.verts \n\
</pre></div><p>All of the vertices of the mesh object. Read-only.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;vertexselection&gt;.count : Integer, read-only \n\
</pre></div><p>Returns the number of vertices in the VertexSelection array.</p>\n\
<div class=\'codeBlock\'><pre>&lt;vertexselection&gt;.selSetNames : Array of names, read-only \n\
</pre></div><p>Returns an array of names of the current vertex-level named selection sets for the object the VertexSelection is associated with.</p>\n\
<p>The following properties are present for singleton selections (of the form $foo.verts[n]):</p>\n\
<div class=\'codeBlock\'><pre>&lt;vertexselection&gt;.index : Integer, read-only \n\
</pre></div><p>Returns the index of the selected element in the mesh,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` $foo.selectedVerts[2].index</p>\n\
<p>```</p>\n\
<p>returns the vertex index of the second vertex in the current selection.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;vertexselection&gt;.pos : Point3 \n\
</pre></div><p>Returns or sets the position of the selected element in the mesh,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` $foo.verts[i].pos = $baz.verts[j].pos + [10,0,0]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Iterating over a selection yields singleton selections in the loop body:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` sv = for i in $foo.selectedVerts collect i.index --sv contains selected vertices as array</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;mesh&gt;.selectedVerts = (&lt;array&gt; | &lt;bitarray&gt;) \n\
</pre></div><p>Selects the specified vertices.</p>\n\
<div class=\'codeBlock\'><pre>&lt;vertexselection&gt;[&lt;integer&gt;] \n\
</pre></div><p>Retrieves the indexed vertex as a singleton VertexSelection. Index starts at 1.</p>\n\
<div class=\'codeBlock\'><pre>&lt;vertexselection&gt;[&lt;integer&gt;] = &lt;point3&gt; \n\
</pre></div><p>Sets the position of the indexed vertex.</p>\n\
<div class=\'codeBlock\'><pre>&lt;vertexselection&gt;[(&lt;integer_array&gt; | &lt;bitarray&gt;)] \n\
</pre></div><p>Retrieves the indexed vertices as a VertexSelection. Index starts at 1.</p>\n\
<div class=\'codeBlock\'><pre>&lt;vertexselection&gt;[(&lt;#name&gt; | &lt;string&gt;)] \n\
</pre></div><p>Retrieves the vertex-level named selection set, where the name of the named selection set can be specified as a name or string value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;vertexselection&gt;[(&lt;#name&gt; | &lt;string&gt;)] = (&lt;vertexselection&gt; | &lt;integer_array&gt; | &lt;bitarray&gt;) \n\
</pre></div><p>Sets the vertex-level named selection set to the specified vertices. The name of the named selection set can be specified as a name or string value and the vertices can be specified as an array, bitArray, or a VertexSelection from the same object.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>move &lt;vertexselection&gt; &lt;point3&gt; \n\
</pre></div><p>Moves the vertices in the VertexSelection.</p>\n\
<div class=\'codeBlock\'><pre>select &lt;vertexselection&gt; \n\
</pre></div><p>Selects the vertices in the VertexSelection.</p>\n\
<div class=\'codeBlock\'><pre>deselect &lt;vertexselection&gt; \n\
</pre></div><p>Deselects the vertices in the VertexSelection.</p>\n\
<div class=\'codeBlock\'><pre>delete &lt;vertexselection&gt; \n\
</pre></div><p>Deletes the vertices in the VertexSelection.</p>\n\
<div class=\'codeBlock\'><pre>append &lt;vertexselection&gt; (&lt;vertexselection&gt; | &lt;integer&gt;) \n\
</pre></div><p>Appends the vertex or vertices to the VertexSelection.</p>\n\
<div class=\'codeBlock\'><pre>findItem &lt;vertexselection&gt; (&lt;vertexselection[&lt;integer&gt;] | &lt;integer&gt;) \n\
</pre></div><p>Returns the selection index of the matching item or 0 if not found. The item is selection index or singleton VertexSelection.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` -- move vertices in &#39;mouth&#39; named selection set move $foo.verts[#mouth] [0,0,10] -- select vertices in &#39;front verts&#39; set select $baz.verts[&quot;front verts&quot;] -- set &#39;baz&#39; named selection set to given vertices $foo.verts[#baz] = #(1,3,4,5,10) -- set &#39;cursel&#39; set to current selection $baz.verts[#cursel] = $baz.selectedVerts -- all the names of the vertex-level named selection sets for object $foo $foo.verts.selSetNames -- print out all vertex-level named selection sets for n in $.verts.selSetNames do print $.verts[n] -- coerce selected verts to a string with printAllElements on $foo.selectedVerts as string</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";