var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Collections</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Collections</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"collections\"></a></div>\n\
<p>Many of the values you work with in MAXScript are sequenced <strong>collections</strong>, notably <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/Array-Values.html\' title=\'\'>arrays</a>, wild-card <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/PathName-Values.html\' title=\'\'>pathname</a> selections, and the built-in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/ObjectSet-Values.html\' title=\'\'>object sets</a>.</p>\n\
<p>In the manner of most operating system shell command languages, MAXScript will <strong>automatically</strong> apply appropriate operations to each of the members in these target collections. This is called a <strong>mapped operation</strong>.</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">EXAMPLES:</th>\n\
<th align=\"left\"></th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>hide $lights/key*</span></td>\n\
<td align=\"left\">Hide all the &#39;key&#39; lights in the scene</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>$box*.position = [0,0,0]</span></td>\n\
<td align=\"left\">Re-center all boxes</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>delete dead_objects</span></td>\n\
<td align=\"left\">Delete all the objects in the array &#39;dead_objects&#39;</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>obj.pos.keys.intangent=#fast</span></td>\n\
<td align=\"left\">Set in tangent to fast for all obj&#39;s position keys</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>lights.value *= 0.8</span></td>\n\
<td align=\"left\">Turn down all the lights 20%</td>\n\
</tr>\n\
</table>\n\
<p>MAXScript determines whether to perform a <strong>mapped operation</strong> by looking at <strong>the first argument</strong> to a function or the target in a property assignment to see if it is a sequenced collection. In the case of a function call, it also looks to see if the function is of the appropriate kind, evaluates all the other argument expressions <strong>only once</strong>.</p>\n\
<p>MAXScript then calls the function on each of the members of the first argument collection passing along the other evaluated arguments. In the case of a property assignment, it evaluates the right-hand-expression <strong>only once</strong> and assigns the value to the named property of each of the elements in the target value collection.</p>\n\
<p>This means that every element in the collection <strong>must be</strong> a valid target for the function or have the named property in question. If MAXScript comes across an inappropriate target it will report an error and stop the automatic operation.</p>\n\
<p>Except for certain common properties, MAXScript currently only allows automatic collection mapping of property assignment <strong>one level deep</strong>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>the following will perform collection mapping across the objects <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/ObjectSet-Values.html\' title=\'\'>ObjectSet</a>:</p>\n\
<p>``` objects.pos = [0,0,0] --move all objects to world center</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>If the last level specified is one of the following component names, the automatic collection mapping is performed on the preceding property:</p>\n\
<div class=\'codeBlock\'><pre>.angle .b .blue .axis .controller .g .green .isAnimated .keys .r .red .track .x .x_rotation .y .y_rotation .z .z_rotation \n\
<blockquote>\n\
</blockquote></pre></div><p><strong>EXAMPLE</strong></p>\n\
<p>the following will perform collection mapping across the <strong>objects</strong> ObjectSet:</p>\n\
<p>``` objects.pos.z = 0.0 --move all objects to world XY plane</p>\n\
<p>```</p>\n\
\n\
<p>This behavior of calling a function on all the elements of a collection is known as <strong>mapping</strong> in computer science. In the description of each collection type, you will find those kinds of sequenced collections that can be mapped over identified as <strong>mappable</strong>.</p>\n\
<p>In the descriptions of the various functions and operators throughout this document, those that act on each element in a collection are labeled <strong>mapped</strong>.</p>\n\
<p>In general, the functions that are mapped are those that have some side-effect on the value they take, such as moves, and deletes and hides.</p>\n\
<p>Others, like the test function <span class=\'code\'>isHidden()</span> , are <span class=\'code\'>not</span> mapped because it would be pointless since the result would not be able to represent the state of multiple objects.</p>\n\
<p>All mapped functions defined by MAXScript, such as <span class=\'code\'>copy()</span> , <span class=\'code\'>delete()</span> , or <span class=\'code\'>move()</span> , take an optional last argument, <span class=\'code\'>#noMap</span> . This causes the functions not to be mapped when called on collection arguments such as arrays. When used with <span class=\'code\'>copy()</span> on arrays in particular, this will return a top-level copy of the array itself and not perform an individual <span class=\'code\'>copy()</span> on each element of the array.</p>\n\
<p>You can make your own <a href=\'#!/url=./developer/MAXScript-Language-Reference/Creating-Functions/Creating-Functions-1.html\' title=\'\'>mapped scripted functions</a> by preceding the function definition with the reserved word <span class=\'code\'>mapped</span> ,</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>the following will perform collection mapping across the objects ObjectSet:</p>\n\
<p>``` mapped function rand_color x = (x.wireColor = random black white)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>This causes such functions to be automatically called repeatedly on the elements of a collection if a collection is given as the first argument to the function. The <span class=\'code\'>#noMap</span> argument is not applicable to user-written functions!</p>\n\
<p>As described in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/For-Loop.html\' title=\'\'>For Loop</a>, a <span class=\'code\'>for</span> loop can be set up to iterate through a collection set assigning successive elements in the collection to the loop value each time through the loop. <span class=\'code\'>For</span> loops can also be set up to return an array collection set as its result.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` -- sequence an array: for item in table1 do x = x + item.height</p>\n\
<p>```</p>\n\
<p>``` -- you can sequence pathnames: bigones = for obj in $box* where obj.height &gt; 100 collect obj -- collect the big boxes into an array</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>When iterating through a collection set using a <span class=\'code\'>for</span> loop, or when passing a collection to a mapped function, care must be taken not to reorder or remove elements in the collection set within the <span class=\'code\'>for</span> loop or function.</p>\n\
<p>Take for an example a script that is supposed to convert all of the selected splines into NURBS curves.</p>\n\
<blockquote>\n\
<p><strong>TWO SCRIPTS THAT DO NOT EXECUTE PROPERLY ARE:</strong></p>\n\
<p>``` for obj in selection do ( convertToNURBSCurve obj)</p>\n\
<p>```</p>\n\
<p>``` convertToNURBSCurve selection</p>\n\
<p>```</p>\n\
<p>The reason neither of these lines execute properly is that the <span class=\'code\'>convertToNURBSCurve()</span> function clears the current selection. So only the first spline is passed to <span class=\'code\'>convertToNURBSCurve()</span> and converted. Since <span class=\'code\'>convertToNURBSCurve()</span> is a built-in function, there is no way to modify this behavior.</p>\n\
<p>To get around this problem, you need to first &quot;snapshot&quot; the selection collection set as an array using the <span class=\'code\'>as</span> operator, or use the <span class=\'code\'>getCurrentSelection()</span> function, which returns the current selection set as an array.</p>\n\
<p><strong>TWO SCRIPTS THAT EXECUTE PROPERLY ARE:</strong></p>\n\
<p>``` for obj in (selection as array) do ( convertToNURBSCurve obj)</p>\n\
<p>```</p>\n\
<p>``` convertToNURBSCurve (getCurrentSelection())</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";