var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Case Expression</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Case Expression</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"case-expression\"></a></div>\n\
<p>The <span class=\'code\'>case</span> expression is used to select an expression to be evaluated from a set of labeled expressions based on a test value compared against the labels.</p>\n\
<p>Only the first expression whose label matches the test expression is evaluated.</p>\n\
<p>All labels must be comparable to the test expression.</p>\n\
<p>Labeled expressions can be block-expressions, so you can use the <span class=\'code\'>case</span> expression as a case statement, choosing between blocks of code to execute.</p>\n\
<p>The <strong>syntax</strong> for <span class=\'code\'>&lt;case_expr&gt;</span> is:</p>\n\
<div class=\'codeBlock\'><pre>case [ &lt;expr&gt; ]  of ( &lt;cases&gt; )\n\
</pre></div><p>where <span class=\'code\'>&lt;expr&gt;</span> is the test expression and <span class=\'code\'>&lt;cases&gt;</span> is a sequence of labeled expressions:</p>\n\
<div class=\'codeBlock\'><pre>&lt;factor&gt;: &lt;expr&gt;\n\
default: &lt;expr&gt;   \n\
<blockquote>\n\
</blockquote></pre></div><p><strong>FOR EXAMPLE,</strong></p>\n\
<p>``` b = Box() copy_type = 2 --copy new_obj = case copy_type of ( 2: copy b 3: instance b default: reference b )</p>\n\
<p>```</p>\n\
\n\
<p>A special label, <span class=\'code\'>default</span> , can be optionally used to tag the expression that will be evaluated if no other labels match the test expression.</p>\n\
<p>If the <span class=\'code\'>default</span> label is not used, and no label matches the test expression, the <span class=\'code\'>case</span> expression returns a value of <span class=\'code\'>undefined</span> .</p>\n\
<p>The labels are <span class=\'code\'>&lt;factors&gt;</span> - elements such as, number literals, name literals, string literals, variables, or block-expressions.</p>\n\
<p>When a <span class=\'code\'>case</span> expression is evaluated, the test expression is evaluated once, then each label expression is evaluated in order until one is found that compares equally to the test expression value.</p>\n\
<p>The expression it labels is then evaluated and this becomes the result of the <span class=\'code\'>case</span> expression.</p>\n\
<p>No further labels are evaluated or tested.</p>\n\
<p>The test expression is optional.</p>\n\
<p>If it is not supplied, the labels are expected to be Boolean values or expressions and the first label evaluated as <span class=\'code\'>true</span> determines the chosen case.</p>\n\
<p>In this variant, it is common to use expressions as labels, so be sure to parenthesize them.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>``` a= random 1 20 b = random 1 20 c = random 1 20 d = random 1 20 case of ( (a &gt; b): print &quot;a is big&quot; (b &lt; c): print &quot;b is little&quot; (c &lt;= d*3): print &quot;c is less than 3 times d&quot; default: print &quot;none of the above&quot; )</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";