var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>For Loop</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>For Loop</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"for-loop\"></a></div>\n\
<p>The <span class=\'code\'>for</span> loop iterates through a range of numbers, time values, or a sequenced collection of values such as, an array or object set.</p>\n\
<p>The syntax for the <span class=\'code\'>for</span> loop is:</p>\n\
<div class=\'codeBlock\'><pre>for &lt;var_name&gt; [, &lt;index_name&gt;[, &lt;filtered_index_name&gt;]] ( in | = )&lt;sequence&gt; ( do | collect ) &lt;expr&gt;\n\
</pre></div><p>where <span class=\'code\'>&lt;var_name&gt;</span> is the name of the loop item variable that holds the loop value, and <span class=\'code\'>&lt;sequence&gt;</span> is the source of values for the loop.</p>\n\
<p>The <span class=\'code\'>&lt;index_name&gt;</span> and <span class=\'code\'>&lt;filtered_index_name&gt;</span> are optional variables that hold the loop&#39;s index. The <span class=\'code\'>&lt;index_name&gt;</span> is unaffected by any filtering expressions (where), and corresponds to the value&#39;s position in the original list. The <span class=\'code\'>&lt;filtered_index_name&gt;</span> is the position of the value in the filtered list. See the examples below for an illustration of the difference between these two indices. <strong>Available in 3ds Max 2021 and higher.</strong> The <span class=\'code\'>&lt;sequence&gt;</span> can be one of the following:</p>\n\
<div class=\'codeBlock\'><pre>&lt;expr&gt; to &lt;expr&gt; [ by &lt;expr&gt; ] [while &lt;expr&gt;] [where &lt;expr&gt; ]\n\
&lt;expr&gt; [while &lt;expr&gt;] [ where&lt;expr&gt; ]\n\
&lt;expr&gt; to &lt;expr&gt; [ by &lt;expr&gt; ] [where &lt;expr&gt; ]\n\
&lt;expr&gt; [where &lt;expr&gt;]\n\
<blockquote>\n\
</blockquote></pre></div><p><strong>EXAMPLES:</strong></p>\n\
<p><span class=\'code\'>for i = 1 to 10 do print i -- sequence numbers</span></p>\n\
<p><span class=\'code\'>for item in table1 do x = x + item.height -- sequence an array</span></p>\n\
<p><span class=\'code\'>for t in 0f to 100f by 5f do sliderTime=t -- sequence time (given as frames, here)</span></p>\n\
<p><span class=\'code\'>bigones = for obj in $box* -- you can sequence pathnames!   where obj.height &gt; 100 collect obj -- collect the big boxes into an array</span></p>\n\
<p>``` for i,j,k = 12 to 24 where (mod i 3 == 0) do ( -- filter numbers divisible by 3 format &quot;val:% index:% filtered index:%\\n&quot; i j k ) --&gt; produces this output: val:12 index:1 filtered index:1 val:15 index:4 filtered index:2 val:18 index:7 filtered index:3 val:21 index:10 filtered index:4 val:24 index:13 filtered index:5</p>\n\
<p>```</p>\n\
\n\
<p>The first <span class=\'code\'>&lt;sequence&gt;</span> form is the standard number loop, the first <span class=\'code\'>&lt;expr&gt;</span> value is the start value, the <span class=\'code\'>to &lt;expr&gt;</span> value is the limit value and the optional <span class=\'code\'>by &lt;expr&gt;</span> value is the loop value increment. The allowable value types are <strong>integer</strong>, <strong>float</strong>, and <strong>time</strong>. If the <span class=\'code\'>by</span> value is not given, it defaults to 1.</p>\n\
<p>The second form of <span class=\'code\'>&lt;sequence&gt;</span> takes a sequencable collection such as, an <a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Literal-Constants/Array-Literals.html\' title=\'\'>array</a> or <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/ObjectSet-Values.html\' title=\'\'>ObjectSet</a>, and iterates through all its values assigning successive elements in the collection to the loop value each time through the loop. MAXScript contains several sequence collections including <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/PathName-Values.html\' title=\'\'>PathName values</a>, the current selection set, the children of a node, and the stack of modifiers on an object. See also <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collections-1.html\' title=\'\'>Collections</a> for caveats when using a collection in a <span class=\'code\'>for</span> loop.</p>\n\
<p>If an optional <span class=\'code\'>while &lt;expr&gt;</span> test is specified, the <span class=\'code\'>for</span> loop terminates if the test evaluates to <span class=\'code\'>false</span> . The <span class=\'code\'>while</span> test expression must evaluate to a boolean ( <span class=\'code\'>true</span> / <span class=\'code\'>false</span> ).</p>\n\
<blockquote>\n\
<p><strong>PERFORMANCE WARNING</strong></p>\n\
<p>Breaking out of a loop using an <span class=\'code\'>exit</span> construct is implemented internally using try/catch, which is <strong>extremely slow</strong>.</p>\n\
<p>This is why the use of the <span class=\'code\'>while</span> test is recommended over the use of <span class=\'code\'>exit</span> for performance reasons. The <span class=\'code\'>while</span> expression is evaluated before the <span class=\'code\'>where</span> expression.</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` function findByClass _obj _className = ( local notFound = true local res = 0 local searchName = _className as name for i = 1 to _obj.NumBakeElements() while notFound do ( local myElement = _obj.GetBakeElement i if myElement.enabled do ( local eleName = (classof myElement as string) as name if eleName == searchName do ( res = i notFound = false ) ) ) return res )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Each <span class=\'code\'>&lt;sequence&gt;</span> source form takes an optional <span class=\'code\'>where &lt;expr&gt;</span> that must evaluate to <span class=\'code\'>true</span> or <span class=\'code\'>false</span> . The <span class=\'code\'>where</span> expression is evaluated at the beginning of each loop and only executes the loop body for that loop value if the <span class=\'code\'>where</span> expression is <span class=\'code\'>true</span> .</p>\n\
<p>The <span class=\'code\'>do &lt;expr&gt;</span> form simply evaluates the body expression once for each value in the sequence. The loop variable is visible to the code in the body expression as though it was declared locally and initialized to the successive loop values each time. When the <span class=\'code\'>do &lt;expr&gt;</span> form of a <span class=\'code\'>for</span> loop is used as an expression, its return value is always <span class=\'code\'>OK</span> .</p>\n\
<p>The <span class=\'code\'>collect &lt;expr&gt;</span> form gathers the expression values from the loop iterations and stores them in an array, which is then yielded as the value of the overall <span class=\'code\'>for</span> loop. For example, this is a good way to gather procedural selections of objects from a scene. If the <span class=\'code\'>where</span> expression is used with the <span class=\'code\'>collect</span> form of the <span class=\'code\'>for</span> loop, only the values from those iterations for which the <span class=\'code\'>where</span> expression is <span class=\'code\'>true</span> are collected. This can be used to collect a filtered sub-set of the iterated values. You can also achieve this collection filtering in a <span class=\'code\'>for</span> loop that does not use a <span class=\'code\'>where</span> expression by yielding the special value <span class=\'code\'>dontCollect</span> for those iterations that must not be added to the collection.</p>\n\
<p>As described in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Scope-of-Variables.html\' title=\'\'>Scope of Variables</a>, a <span class=\'code\'>for</span> loop creates a new scope context. The <span class=\'code\'>for</span> loop index variable&#39;s scope is always the extent of the <span class=\'code\'>for</span> loop, even if another variable of the same name already exists. Once the <span class=\'code\'>for</span> loop exits, the <span class=\'code\'>for</span> loop index variable is no longer accessible. The scope of any variables created in a <span class=\'code\'>for</span> loop is always the extent of the <span class=\'code\'>for</span> loop. This is shown in the following example:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` obj=box() avg_pos=[0,0,0] offset_pos=[100,100,0] -- new for loop index variable obj created even though -- a variable named obj already exists, scope is for loop for obj in $* do ( -- new variable pos created, scope is for -- loop offset_pos already exists outside -- for loop, its value will be used pos=obj.pos-offset_pos -- avg_pos already exists outside for loop, -- its value will be used for loop index since variable -- obj goes out of scope avg_pos += pos ) avg_pos /= $*.count</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";