var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Try Expression</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Try Expression</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"try-expression\"></a></div>\n\
<p>MAXScript provides simple exception-handling with the <span class=\'code\'>try</span> expression, a simplified form of the C++ exception-handling scheme.</p>\n\
<p>The <span class=\'code\'>try</span> expression lets you bracket a piece of code and catch any runtime errors.</p>\n\
<p>This allows you to respond appropriately or take corrective action, rather than let MAXScript halt the execution of your script and print an error message.</p>\n\
<p>The <strong>syntax</strong> for the <span class=\'code\'>try</span> expression is:</p>\n\
<div class=\'codeBlock\'><pre>try &lt;protected_expr&gt; catch &lt;on_err_expr&gt; \n\
</pre></div><p>The <span class=\'code\'>&lt;protected_expr&gt;</span> is executed and any errors that occur are trapped and the <span class=\'code\'>&lt;on_err_expr&gt;</span> is executed.</p>\n\
<p>If the <span class=\'code\'>&lt;protected_expr&gt;</span> is a block-expression, the block-expression stops executing at the point of the error.</p>\n\
<p>If there are no errors in the protected expression, the <span class=\'code\'>&lt;on_err_expr&gt;</span> is not executed.</p>\n\
<p>This is a very simple error-trapping scheme, but limited heavily by the fact that you only get limited error codes or information about the error that occurred. See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Controlling-Program-Flow/GUID-36BA05E8-2F9A-4761-8D9B-40E3BC6503BF.html\' title=\'\'>getCurrentException()</a> below.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` f = openFile &quot;foo.dat&quot; try while not eof f do read_some_data f catch ( messageBox &quot;bad data in foo.dat&quot; results = undefined ) close f</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In this example, any errors in reading or processing the data in the <span class=\'code\'>read_some_data()</span> function are trapped, then a Message box is displayed and some clean-up is done.</p>\n\
<p>This is a good example of a use for the simple error-trapping.</p>\n\
<div class=\'section\'><a id=\"throw\"></a><h2 id=\"throw\">Throw</h2></div>\n\
<p>There is also an associated function, <span class=\'code\'>throw()</span> , which can be used to generate your own runtime error and pass on an error you caught when doing some interim clean-up, or do a non-local jump.</p>\n\
<p>It has the form:</p>\n\
<div class=\'codeBlock\'><pre>throw &lt;error_message_string&gt; [ &lt;value&gt; ] [ debugBreak:&lt;boolean&gt; ]\n\
throw() \n\
</pre></div><p>If you have no intervening catches in your script, calling <span class=\'code\'>throw()</span> with error message arguments will cause a runtime error to be signaled and MAXScript will report the error message using its standard error reporting.</p>\n\
<p>The optional <span class=\'code\'>&lt;value&gt;</span> argument can be any value you want printed with the error message, perhaps the object involved in the error. This argument can not be specified if the <span class=\'code\'>throw</span> is in the body of a <span class=\'code\'>catch()</span> and will generate a compile error if present.</p>\n\
<p>The optional <span class=\'code\'>debugBreak:&lt;boolean&gt;</span> argument specifies whether to break and display the MAXScript Debugger window. The default setting for this argument is set by the MAXScript Debugger configuration setting &quot;Default Throw debugBreak:on&quot;, which you can query with the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/M/Interface-MXSDebugger.html\' title=\'\'>MXSDebugger.defaultBreakOnThrow</a> property. Note that even if specified as true, if the &quot;Allow Break On Throw&quot; option is disabled for the debugger, the debugger will not display. You can query this setting with the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/M/Interface-MXSDebugger.html\' title=\'\'>MXSDebugger.allowBreakOnThrow</a> property.</p>\n\
<p>If the <span class=\'code\'>try</span> / <span class=\'code\'>catch</span> is within another <span class=\'code\'>try</span> expression, calling <span class=\'code\'>throw()</span> will cause the <span class=\'code\'>catch</span> expression associated with the outer <span class=\'code\'>try</span> expression to be executed.</p>\n\
<p>If you have no intervening catches in your script, calling <span class=\'code\'>throw()</span> will cause MAXScript to continue running the script from just after the top-most set of parenthesis surrounding the <span class=\'code\'>try</span> / <span class=\'code\'>catch</span> , or will stop the currently running script if there are no parenthesis surrounding the <span class=\'code\'>try</span> / <span class=\'code\'>catch</span> .</p>\n\
<p>If you want to catch an error, perhaps to do some clean-up processing, and then pass the error on to outer handlers or MAXScript for error reporting, you can call <span class=\'code\'>throw()</span> with <strong>no</strong> arguments.</p>\n\
<p>This throws the current error again and must <strong>only</strong> be done inside a <span class=\'code\'>catch</span> expression.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` try ( i=10 try ( i.x=1 ) -- will generate a run-time error catch ( print &quot;Bad Error&quot; -- error message printed try (i.pos=[0,0,0]) -- will also generate a run-time error catch (throw()) -- throw() will cause outer catch -- to execute ) ) catch (print &quot;Really Bad Error Occurred&quot;) -- error message printed</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"current-exception\"></a><h2 id=\"current-exception\">Current Exception</h2></div>\n\
<div class=\'codeBlock\'><pre>getCurrentException() \n\
</pre></div><p>This method returns the text of the current exception.</p>\n\
<p>It is only useful inside a catch statement - if used outside a catch, it will return &#39;undefined&#39;.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` try ( throw &quot;AAAAA&quot; ) catch ( format &quot;*** % ***\\n&quot; (getCurrentException()) )</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` *** -- Runtime error: AAAAA ***</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>hasCurrentExceptionStackTrace()\n\
</pre></div><p><strong>Available since 3ds Max 2017</strong>: Returns true if a MAXScript stack trace is available. It is only useful inside a catch statement - if used outside a catch, it will return false. It should always return true within a catch.</p>\n\
<div class=\'codeBlock\'><pre>hasCurrentExceptionCallStack()\n\
</pre></div><p><strong>Available since 3ds Max 2017</strong>: Returns true if a C++ stack trace is available. It is only useful inside a catch statement - if used outside a catch, it will return false. Within a catch, it will be true only if the exception that was caught was a system exception, such as an access violation or an integer divide by 0.</p>\n\
<div class=\'codeBlock\'><pre>getCurrentExceptionStackTrace()\n\
</pre></div><p><strong>Available since 3ds Max 2017</strong>: Returns the MAXScript stack trace as a string. It is only useful inside a catch statement - if used outside a catch, it will return false. It should always return true within a catch.</p>\n\
<div class=\'codeBlock\'><pre>getCurrentExceptionCallStack()\n\
</pre></div><p><strong>Available since 3ds Max 2017</strong>: Returns the C++ stack trace captured at the time an exception was thrown, as a string. It is only useful inside a catch statement - if used outside a catch, it will return &#39;undefined&#39;. Within a catch, if the C++ stack trace was not captured, an empty string is returned.</p>\n\
<div class=\'codeBlock\'><pre>CaptureCallStack [skipFirstNStackLevels:&lt;int&gt;]\n\
</pre></div><p><strong>Available since 3ds Max 2017</strong>: Captures the MAXScript call stack. The <span class=\'code\'>skipFirstNStackLevels</span> parameter defaults to 3 if not specified.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt; getErrorSourceFileName()\n\
</pre></div><p><strong>Available since 3ds Max 2018</strong>: Returns the name of the source file causing the error, when called inside a catch statement. This can be useful if running code from multiple scripts, for example by using <span class=\'code\'>fileIn()</span>.</p>\n\
<p>Note: This method is only useful inside a catch statement. If used outside a catch statement, it will return <span class=\'code\'>undefined</span>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt; getErrorSourceFileLine()\n\
</pre></div><p><strong>Available since 3ds Max 2018</strong>: Returns the line number where the error occurred, when called inside a catch statement..</p>\n\
<p>Note: This method is only useful inside a catch statement. If used outside a catch statement, it will return <span class=\'code\'>undefined</span>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt; getErrorSourceFileOffset()\n\
</pre></div><p><strong>Available since 3ds Max 2018</strong>: Returns offset where the error occurred, when called inside a catch statement. This is the end of the expression being evaluated, including any comments.</p>\n\
<p>Note: This method is only useful inside a catch statement. If used outside a catch statement, it will return <span class=\'code\'>undefined</span>.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";