var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>By Reference Parameter Passing</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>By Reference Parameter Passing</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"by-reference-parameter-passing\"></a></div>\n\
<p>MAXScript supports by-reference parameter passing. This allows a reference to be passed to a variable, property, or array element in the caller&#39;s context as a parameter to a function and any assignments to that parameter in the called function is assigned directly to the caller&#39;s variable, property, or array element. This is often used as a mechanism for passing multiple results back from a function.</p>\n\
<p>To define by-reference parameters for a function, you need to prefix them with an &#39;<strong>&amp;</strong>&#39; character.</p>\n\
<p><strong>System Exception Note:</strong></p>\n\
<p>The following example is an error:</p>\n\
<blockquote>\n\
<p><strong>ERROR EXAMPLE</strong></p>\n\
<p>``` fn test1 &amp;p3 = return &amp;p3.x p=[1,2,3] r=test1 p *r</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Result: access violation!</strong></p>\n\
<p>It is <strong>an error</strong> to pass back a reference to a local that has gone from the call stack, but it is very difficult to detect this efficiently. Be careful <span class=\'code\'>not to pass back &amp;refs</span> to local variables as it might cause system exceptions.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` function foo x y &amp;z = ( -- ... z = x * y -- ... return true ) -- test function z = 12 foo 5 6 &amp;z</p>\n\
<p>```</p>\n\
<p>Declares a function taking three parameters, x, y and z. The <span class=\'code\'>&amp;z</span> in the parameter list indicates the z parameter is to be passed by-reference. To call this function, you provide a reference value for the z parameter using the new &#39;<strong>&amp;</strong>&#39; reference operator.</p>\n\
<p>``` local var1, var2 ... var1 = foo 2 3 &amp;var2</p>\n\
<p>```</p>\n\
<p>The above example calls the foo function with the arguments 2, 3 and <span class=\'code\'>&amp;var2</span> . The <span class=\'code\'>&amp;var2</span> is a reference to the var2 local variable. When the function is called, the z parameter in the body is a reference to <span class=\'code\'>var2</span> local in the caller, and the</p>\n\
<p>``` z = x * y</p>\n\
<p>```</p>\n\
<p>in the body of foo will cause x * y to be assigned to the <span class=\'code\'>var2</span> local in the caller. After</p>\n\
<p>``` var1 = foo 2 3 &amp;var2</p>\n\
<p>```</p>\n\
<p><span class=\'code\'>var1</span> will contain <span class=\'code\'>true</span> and <span class=\'code\'>var2</span> will contain <span class=\'code\'>x * y</span> or <span class=\'code\'>6</span> .</p>\n\
</blockquote>\n\
<p>Any number of by-reference parameters can be used and they can be keyword parameters if needed:</p>\n\
<blockquote>\n\
<p>``` fn foo x y &amp;z: = ...</p>\n\
<p>```</p>\n\
<p>called like this:</p>\n\
<p><span class=\'code\'>var1 = foo 2 3 z:&amp;var2</span></p>\n\
</blockquote>\n\
<p>The &#39; <span class=\'code\'>&amp;</span> &#39; reference operator used to supply references in a call can be applied to any <span class=\'code\'>&lt;accessor&gt;</span> construct in MAXScript. These are:</p>\n\
<div class=\'codeBlock\'><pre>variables (locals, globals, rollout locals, plug-in locals, etc.)\n\
property access\n\
array index\n\
parameter (of a scripted plug-in)\n\
\n\
<blockquote>\n\
</blockquote></pre></div><p><strong>EXAMPLE</strong></p>\n\
<p>``` p = [1, 2, 3] foo 2 3 &amp;p.x</p>\n\
<p>```</p>\n\
<p>would cause the x coordinate in the point to be passed by-reference and so after the call, the value in p would be</p>\n\
<p>``` [6, 2, 3]</p>\n\
<p>```</p>\n\
\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` a = #(1, 2, 3, 4, 5) foo 2 3 &amp;a[3]</p>\n\
<p>```</p>\n\
<p>would cause the 3rd element in the array to be passed by-reference and so after the call, the value in a would be #(1, 2, 6, 4, 5)</p>\n\
</blockquote>\n\
<p>Note:</p>\n\
<p>This mechanism is used by the Function Publishing interface in MAXScript to support BY-REF interface method parameters and results. Any parameter defined as by-ref (or with a type code suffix _BR) in the published interface, requires an &#39;&amp;&#39; reference value.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";