var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Creating Functions</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Creating Functions</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"creating-functions\"></a></div>\n\
<p>Functions are defined in MAXScript using the function definition expression.</p>\n\
<p>The <strong>syntax</strong> for <span class=\'code\'>&lt;function_def&gt;</span> is:</p>\n\
<div class=\'codeBlock\'><pre>[mapped] ( function | fn) &lt;name&gt; { &lt;parameter&gt; } = &lt;expr&gt; \n\
</pre></div><p>Here, <span class=\'code\'>&lt;name&gt;</span> is the name of the function.</p>\n\
<p>The optional sequence of <span class=\'code\'>&lt;parameter&gt;</span> can be one of:</p>\n\
<div class=\'codeBlock\'><pre>&lt;name&gt;\n\
&lt;name&gt;: [&lt;operand&gt;] --keyword parameter with optional default value   \n\
</pre></div><p>The <span class=\'code\'>&lt;expr&gt;</span> after the <span class=\'code\'>&#39;=&#39;</span> (equal sign) is the body of the function.</p>\n\
<p>The function <span class=\'code\'>&lt;name&gt;</span> is actually used to name a variable into which a value representing the function is placed.</p>\n\
<p>When you call a function by using its name, you are accessing its definition in a variable of that name.</p>\n\
<p>The scope of the function name variable is the current MAXScript scope.</p>\n\
<p>The parameters for a function are either <strong>positional</strong> or <strong>keyword</strong>.</p>\n\
<p><em>Positional parameters</em> are defined with a simple <span class=\'code\'>&lt;name&gt;</span> and must be placed before any keyword parameters.</p>\n\
<p><em>Keyword parameters</em> have a &#39;:&#39; (colon) after the name and an optional default value. The caller of the function can optionally supply keyword arguments in any order. Those not supplied is set to the given default value, or the special value <span class=\'code\'>unsupplied</span> if a default value is not given.</p>\n\
<p>Using the <span class=\'code\'>mapped</span> prefix on a function definition marks this function to be automatically mapped over collections.</p>\n\
<p>This means the function is automatically called repeatedly on the elements of a collection if the collection is given as the first argument to the function.</p>\n\
<p>This allows you to define scripted functions that behave in a similar manner to the <strong>mapped</strong> built-in functions such as, copy, delete, move, and so on, which can be applied to an object set, path name pattern, or array.</p>\n\
<p>See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collections-1.html\' title=\'\'>Collections</a> for more information.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` function my_add a b = a + b fn factorial n = if n &lt;= 0 then 1 else n * factorial (n - 1) mapped function rand_color x = x.wireColor = random (color 0 0 0) (color 255 255 255) fn starfield count extent:[200,200,200] pos:[0,0,0] = ( local f = pos - extent / 2, t = pos + extent / 2 for i = 1 to count do sphere name: &quot;star&quot;<br> radius:(random 0.1 2.0)<br> position:(random f t)<br> segs:4 smooth:false )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>A scripted function returns as its value the value of the body <span class=\'code\'>&lt;expr&gt;</span> . If the body is a block-expression, the function evaluates to the value of the last expression in the block.</p>\n\
<p>A function can be called recursively (that is, the function can call itself), as is the <span class=\'code\'>factorial</span> function in the previous examples.</p>\n\
<p>If you need to locate the source of a scripted function, you can use the <span class=\'code\'>showSource()</span> function. It displays a script Editor containing the source file in which the function was defined and positioned at the function&#39;s definition.</p>\n\
<p>The form is:</p>\n\
<div class=\'codeBlock\'><pre>showSource &lt;fn&gt; \n\
</pre></div><p>This is useful for browsing definitions if you are working on many scripted functions that were defined in several script files.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";