var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Function Parameters</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Function Parameters</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"function-parameters\"></a></div>\n\
<p>The parameters to a function are implicitly declared as local variables at the head of the function body, and are initialized with the arguments given by the caller. The parameters have a scope that extends to the end of the function body <span class=\'code\'>&lt;expr&gt;</span> . They can be assigned to and hidden by nested local variables with the same name as can other local variables.</p>\n\
<p>Keyword parameters can be given default values in the function definition, implicitly making them optional to the caller. If the caller does not supply one of the keyword arguments, it is initialized to the default value upon function entry. The default values are specified after the <span class=\'code\'>&#39;:&#39;</span> (colon).</p>\n\
<p>If a keyword parameter is defined with no default value and is not supplied by the caller, it is initialized to the special value <span class=\'code\'>unsupplied</span> . You can check for this value in the body of your function and handle missing required keyword argument errors accordingly.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` fn foo a b: c:&quot;default c&quot; = (</p>\n\
<div class=\'codeBlock\'><pre>  if b == unsupplied then format &quot;Where&#39;s the b: argument??&quot;\n\
  else format &quot;a:% b:% c:%&quot; a b c\n\
</pre></div><p>)</p>\n\
<p>foo &quot;A&quot; b:&quot;B&quot; --&gt; a:A b:B c:default c foo &quot;A&quot; b:&quot;B&quot; c:&quot;C&quot; --&gt; a:A b:B c:C foo &quot;A&quot; c:&quot;C&quot; --&gt; Where&#39;s the b: argument??</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>For more information about keyword arguments and default values, see <a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Simple-Expressions/Function-Calls/Positional-and-Keyword-Arguments.html\' title=\'\'>Positional and Keyword Arguments</a>.</p>\n\
<p>As described in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Reference-Assignment.html\' title=\'\'>Reference Assignment</a>, MAXScript uses an assignment called <em>reference assignment</em>. In a function, each parameter variable contains a reference to the value passed to the function by the caller. Assigning to a parameter variable places a new reference in the parameter variable, and has no effect on the variable values in the caller (it is an entirely local action). An exception to this is when the parameter value is a compound value such as, a 3D Point, string, or array, and you assign a new value to one of the components of the compound value. In this case, the variable&#39;s reference does not change, and the changed compound value is still referenced by the variable in the caller.</p>\n\
<p>While in some cases you might want a function to return multiple values, it is typically not a good practice to do this by assigning to the components of a parameter variable compound value. To manipulate a compound value passed as a parameter, a compound value needs to be created in the caller and passed to the function, which can give results as shown in this example:</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` fn getXYZset val = ( val.x=random -100 100 val.y=random 100 100 val.z=random val.x val.y ) ( v1=[0,0,0] v4=v1 getXYZSet v1 format &quot;v1= %; v4= %\\n&quot; v1 v4 getXYZSet v4 format &quot;v1= %; v4= %\\n&quot;v1 v4 )</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` getXYZset() -- result lines 1 to 5 v1= [-84,100,78.1224]; v4= [-84,100,78.1224] -- output line 10 v1= [10,100,18.6575]; v4= [10,100,18.6575] -- output line 12 OK -- result lines 6 to 12</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note that it appears the value for both variables <span class=\'code\'>v1</span> and <span class=\'code\'>v4</span> are set in the calls to <span class=\'code\'>getXYZset</span> , even though only one variable is being passed. The reason for this is in line 8, variable <span class=\'code\'>v4</span> is initialized to the value of <span class=\'code\'>v1</span> . What actually occurs is that in line 7, a reference to a Point3 value of [0,0,0] is created and this reference is stored in <span class=\'code\'>v1</span> . In line 8, that same reference is retrieved from <span class=\'code\'>v1</span> and assigned to <span class=\'code\'>v4</span> . Rather than storing two different values, both <span class=\'code\'>v1</span> and <span class=\'code\'>v4</span> reference the same value. When you set the components of the compound value in <span class=\'code\'>getXYZset</span> , the reference to the Point3 value is not being changed, and both variables still reference that value.</p>\n\
<p>The proper way to return multiple values from a function is to have the return value of the function be an array or a structure. For example,</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` fn readDataFile filename = ( f=openfile filename data=#() avg=0 nVals=0 while not eof f do ( val = readvalue f append data val avg += val nVals += 1 ) close f #(data,(avg/nVals)) ) result=readDataFile &quot;c:\\datafiles\\run1.dat&quot; data=result[1] avg=result[2]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Normally, if you are writing a function that is operating on a compound value that is passed as a parameter, you must make a <span class=\'code\'>copy</span> of the value. This prevents the value in the caller from inadvertently being changed. For example,</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` fn uppercase instring = ( local upper, lower, outstring upper=&quot;ABCDEFGHIJKLMNOPQRSTUVWXYZ&quot; lower=&quot;abcdefghijklmnopqrstuvwxyz&quot; outstring=copy instring -- operate on copy of instring for i=1 to outstring.count do ( j=findString lower outstring[i] if j != undefined do outstring[i]=upper[j] ) return outstring )</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";