var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Function Variables</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Function Variables</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"function-variables\"></a></div>\n\
<p>When you define a function, the following events occur:</p>\n\
<ul>\n\
<li><p>The function definition is evaluated, creating a function value.</p></li>\n\
<li><p>The function <span class=\'code\'>&lt;name&gt;</span> is used to declare a new variable with that name.</p></li>\n\
<li><p>The function value is placed into that variable.</p></li>\n\
<li><p>The function value is returned as the result of the function definition expression.</p></li>\n\
</ul>\n\
<p>Because the function itself is a value stored in a variable, you not only can call the function through the function name variable. By simply referring the function&#39;s variable you can also assign the function value to another variable, store it in an array, or pass it as an argument to another function.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` surface_functions=#() fn build_math_mesh x = print &quot;build math mesh&quot;</p>\n\
<p>-- some 3D surface functions fn saddle x y = sin x * sin y fn sombrero x y = cos (x^2 + y^2) / (1 + (x^2 + y^2)) print (saddle 1 1) -- try one out surface_functions[1] = saddle -- store the functions in an array surface_functions[2] = sombrero -- call one of them from within the array: z = (surface_functions[1]) 10 10 -- pass one in to a higher-order function: build_math_mesh sombrero</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The scope of a function variable is the current MAXScript scope context. The variables used inside a function have a local scope, unless the variable was already defined at a higher scope or is declared as global in the function. An exception to this is the function parameter variables, which always have a local scope.</p>\n\
<p>When writing scripts, it is <strong>good programming practice</strong> to <strong>explicitly declare your local and global variables</strong>. Implicit declaration is provided as a short-hand, typically used when working in the Listener interactively or developing short scripts. When developing extended scripts, explicitly declaring variables can reduce errors and improve readability of the code. It is also recommend that you declare as local all variables unless you really want them to be global variables. The reasons for this are described in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Scope-of-Variables.html\' title=\'\'>Scope of Variables</a>.</p>\n\
<p>If a function variable is assigned to another variable, a reference to the function value is stored in that variable. Thus while a function variable may no longer be in scope, the function itself still is if the variable it is assigned to has a scope that extends outside the current MAXScript scope context.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` fn funcA which = ( if which == 1 then fn saddle x y = sin x * sin y else fn sombrero x y = cos (x^2 + y^2) / (1 + (x^2 + y^2)) ) myfunc=funcA 2 z=myfunc 10 10</p>\n\
<p>```</p>\n\
<p>In the above example, the scope of variables <span class=\'code\'>saddle</span> and <span class=\'code\'>sombrero</span> is local to <span class=\'code\'>funcA</span> , and the variables are out of scope outside the function. The return value of <span class=\'code\'>funcA</span> is either the function value <span class=\'code\'>saddle()</span> or <span class=\'code\'>sombrero()</span> , and is assigned to variable <span class=\'code\'>myfunc</span> . As also can be seen in this example, you can define a function within any expression.</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";