var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>MAXScript Grammar</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>MAXScript Grammar</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"maxscript-grammar\"></a></div>\n\
<p>The following is the complete MAXScript grammar in Extended Backus-Naur Form (EBNF). It differs slightly in factoring from the syntax forms given in the online reference so that all precedence is explicit in the rules.</p>\n\
<p>These rules or <em>syntax definitions</em> follow the standard EBNF notation. The rules typically contain a number of characters with special meanings. For example, brackets enclose optional items such as, the minus sign in front of the number. Braces enclose items you can use repeatedly, and bars separate multiple items from which you can choose one. Sometimes, rules are given names, so they can be referred to in the documentation or as parts of other rules. The special characters in the rules have the following meaning:</p>\n\
<div class=\'codeBlock\'><pre>[...] -- items inside the brackets are optional\n\
(...|...|...) -- choose one of the items separated by the bars\n\
{...} -- you can specify the braced item ZERO or more times\n\
{...}+ -- you can specify the braced item ONE or more times\n\
::= -- define a name for a syntax rule\n\
&lt;rule&gt; -- you can insert what is defined by the named rule\n\
\n\
bold_characters -- characters or token as written\n\
</pre></div><p>An example of an EBNF form is:</p>\n\
<div class=\'codeBlock\'><pre>[-]{&lt;digit&gt;}[.{&lt;digit&gt;}][(e | E)[+ | -]{&lt;digit&gt;}+]\n\
</pre></div><p>This example is interpreted as follows:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">Syntax</th>\n\
<th align=\"left\">Definition</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>[-]{&lt;digit&gt;}</span></td>\n\
<td align=\"left\">an optional minus sign (the sign), followed by 0 or more digits (the integer part), followed by</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>.{&lt;digit&gt;}]</span></td>\n\
<td align=\"left\">an optional sequence (the fraction part) comprised of: a period character, followed by 0 or more digits, followed by</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>[(e | E)[+ | -]{&lt;digit&gt;}+]</span></td>\n\
<td align=\"left\">an optional sequence (the exponent part) comprised of: either an ’e’ or &#39;E’, followed by an optional plus or minus sign, followed by one or more digits.</td>\n\
</tr>\n\
</table>\n\
<div class=\'codeBlock\'><pre>&lt;program&gt; ::= { &lt;expr&gt; }+\n\
&lt;expr&gt; ::= &lt;simple_expr&gt;\n\
&lt;variable_decls&gt;\n\
&lt;assignment&gt;\n\
&lt;if_expr&gt;\n\
&lt;while_loop&gt;\n\
&lt;do_loop&gt;\n\
&lt;for_loop&gt;\n\
&lt;loop_exit&gt;\n\
&lt;case_expr&gt;\n\
&lt;struct_def&gt;\n\
&lt;try_expr&gt;\n\
&lt;variable_decls&gt;\n\
&lt;function_def&gt;\n\
&lt;function_return&gt;\n\
&lt;context_expr&gt;\n\
&lt;max_command&gt;\n\
&lt;utility_def&gt;\n\
&lt;rollout_def&gt;\n\
&lt;tool_def&gt;\n\
&lt;rcmenu_def&gt;\n\
&lt;macroscript_def&gt;\n\
&lt;plugin_def&gt;\n\
&lt;variable_decls&gt; ::= ( local | global ) &lt;decl&gt; { , &lt;decl&gt; }\n\
persistent global &lt;decl&gt; { , &lt;decl&gt; }\n\
&lt;decl&gt; ::= &lt;var_name&gt; [=&lt;expr&gt; ] -- name and optional initial value\n\
&lt;var_name&gt; ::= { &lt;alphanumeric&gt; | _ }\n\
&#39;{ &lt;any_char_except_quote&gt; }&#39;\n\
&lt;assignment&gt; ::= &lt;destination&gt;=&lt;expr&gt;\n\
&lt;destination&gt; += &lt;expr&gt;\n\
&lt;destination&gt; -= &lt;expr&gt;\n\
&lt;destination&gt; *= &lt;expr&gt;\n\
&lt;destination&gt; /= &lt;expr&gt;\n\
&lt;destination&gt; ::= &lt;var_name&gt;\n\
&lt;property&gt;\n\
&lt;index&gt;\n\
&lt;if_expr&gt; ::= if &lt;expr&gt; then &lt;expr&gt; [ else &lt;expr&gt; ]\n\
if &lt;expr&gt; do &lt;expr&gt;\n\
&lt;while_loop&gt; ::= while &lt;expr&gt; do &lt;expr&gt;\n\
&lt;do_loop&gt; ::= do &lt;expr&gt; while &lt;expr&gt;\n\
&lt;for_loop&gt; ::= for &lt;name&gt;( in | = ) &lt;source&gt; (do | collect) &lt;expr&gt;\n\
&lt;source&gt; ::= &lt;expr&gt; to &lt;expr&gt; [by &lt;expr&gt;] [where &lt;expr&gt;]\n\
\n\
&lt;expr&gt; [where &lt;expr&gt;]\n\
&lt;loop-exit&gt; ::=exit [with &lt;expr&gt;]\n\
&lt;loop-continue&gt; ::= continue\n\
&lt;case_expr&gt; ::= case [&lt;expr&gt;] of ( { &lt;case_item&gt; }) \n\
\n\
&lt;case_item&gt; ::= &lt;factor&gt; : &lt;expr&gt;\n\
default : &lt;expr&gt;\n\
&lt;struct_def&gt; ::= struct ( &lt;member&gt; {,&lt;member&gt; } )\n\
\n\
&lt;member&gt; ::= &lt;name&gt; [=&lt;expr&gt; ] -- name and optional initial value\n\
&lt;function_def&gt;\n\
&lt;try_expr&gt; ::= try &lt;expr&gt; catch &lt;expr&gt;\n\
&lt;function_def&gt; ::= [ mapped ] ( function | fn ) &lt;var_name&gt; { &lt;arg&gt; }= &lt;expr&gt;\n\
\n\
&lt;arg&gt; ::= &lt;var_name&gt;\n\
&lt;var_name&gt;: [ &lt;operand&gt; ]\n\
&lt;function_return&gt; ::= return &lt;expr&gt;\n\
&lt;context_expr&gt; ::= &lt;context&gt; { , &lt;context&gt; } &lt;expr&gt;\n\
\n\
&lt;context&gt; ::= [with] animate &lt;logical_expr&gt;\n\
at level &lt;operand&gt;\n\
at time &lt;operand&gt;\n\
in &lt;operand&gt;\n\
[in] coordsys ( local | world | parent | &lt;operand&gt; )\n\
about ( pivot | selection | coordsys | &lt;operand&gt; )\n\
[ with ] undo &lt;logical_expr&gt;\n\
\n\
&lt;set_context&gt; ::= set &lt;context&gt;\n\
&lt;utility_def&gt; ::= utility &lt;var_name&gt; &lt;string&gt; { &lt;var_name&gt;:&lt;operand&gt; } \\\n\
( { &lt;utility_clause&gt; }+ )\n\
\n\
&lt;utility_clause&gt; ::= &lt;rollout&gt;\n\
&lt;rollout_clause&gt;\n\
&lt;rollout_def&gt; ::= rollout &lt;var_name&gt; &lt;string&gt; { &lt;var_name&gt;:&lt;operand&gt; } \\\n\
( { &lt;rollout_clause&gt; }+ )\n\
\n\
&lt;rollout_clause&gt; ::= local &lt;decl&gt; { , &lt;decl&gt; }\n\
&lt;function_def&gt;\n\
&lt;struct_def&gt;\n\
&lt;mousetool&gt;\n\
&lt;item_group&gt;\n\
&lt;rollout_item&gt;\n\
&lt;rollout_handler&gt;\n\
\n\
&lt;item_group&gt; ::= group &lt;string&gt; ( { &lt;rollout_item&gt; } )\n\
\n\
&lt;rollout_handler&gt; ::= on &lt;var_name&gt; &lt;var_name&gt; { &lt;var_name&gt; } do &lt;expr&gt;\n\
\n\
&lt;rollout_item&gt; ::= &lt;item_type&gt; &lt;var_name&gt; [ &lt;string&gt; ] { &lt;var_name&gt;:&lt;operand&gt; }\n\
\n\
&lt;item_type&gt; ::= label button edittext combobox dropdownList listbox spinner slider pickbutton radiobuttons checkbox checkbutton colorPicker mapbutton materialbutton progressbar timer bitmap\n\
&lt;rcmenu_def&gt; ::= rcmenu &lt;var_name&gt; ( { &lt;rcmenu_clause&gt; }+ )\n\
\n\
&lt;rcmenu_clause&gt; ::= local &lt;decl&gt; { , &lt;decl&gt; }\n\
&lt;function_def&gt;\n\
&lt;struct_def&gt;\n\
&lt;rcmenu_item&gt;\n\
&lt;rcmenu_handler&gt;\n\
\n\
&lt;rcmenu_handler&gt; ::= on &lt;var_name&gt; &lt;var_name&gt; do &lt;expr&gt;\n\
\n\
&lt;rcmenu_item&gt; ::= &lt;rcmenu_item_type&gt; &lt;var_name&gt; &lt;string&gt; { &lt;var_name&gt;:&lt;operand&gt; }\n\
&lt;rcmenu_item_type&gt;::= menuitem separator submenu\n\
&lt;macroscript_def&gt; ::= macroscript &lt;var_name&gt; &lt;string&gt; { &lt;var_name&gt;:&lt;operand&gt; } ( &lt;expr_seq&gt; )\n\
&lt;mousetool_def&gt; ::= tool &lt;var_name&gt; { &lt;var_name&gt;:&lt;operand&gt; }({ &lt;tool_clause&gt; }+)\n\
\n\
&lt;tool_clause&gt; ::= local &lt;decl&gt; { , &lt;decl&gt; }\n\
&lt;function_def&gt;\n\
&lt;struct_def&gt;\n\
&lt;tool_handler&gt;\n\
\n\
&lt;tool_handler&gt; ::=  on &lt;var_name&gt; &lt;var_name&gt; { &lt;var_name&gt; } do &lt;expr&gt;\n\
&lt;plugin_def&gt; ::= plugin &lt;var_name&gt; &lt;var_name&gt; { &lt;var_name&gt;:&lt;operand&gt; } \\\n\
( { &lt;plugin_clause&gt; }+ )\n\
\n\
&lt;plugin_clause&gt; ::= local &lt;decl&gt; { , &lt;decl&gt; }\n\
&lt;function_def&gt;\n\
&lt;struct_def&gt;\n\
&lt;parameters&gt;\n\
&lt;mousetool_def&gt;\n\
&lt;rollout_def&gt;\n\
&lt;plugin_handler&gt;\n\
\n\
&lt;parameters&gt; ::= parameters &lt;var_name&gt; { &lt;var_name&gt;:&lt;operand&gt; } ( { &lt;param_clause&gt; }+ )\n\
\n\
&lt;param_clause&gt; ::= { &lt;param_defs&gt; }+\n\
{ &lt;param_handler&gt; }\n\
\n\
&lt;param_defs&gt; ::= &lt;var_name&gt; { &lt;var_name&gt;:&lt;operand&gt; }\n\
\n\
&lt;param_handler&gt; ::= on &lt;var_name&gt; &lt;var_name&gt; { &lt;var_name&gt; } do &lt;expr&gt;\n\
\n\
&lt;plugin_handler&gt; ::= on &lt;var_name&gt; do &lt;expr&gt;\n\
&lt;simple_expr&gt; ::= &lt;operand&gt;\n\
&lt;math_expr&gt;\n\
&lt;compare_expr&gt;\n\
&lt;logical_expr&gt;\n\
&lt;function_call&gt;\n\
&lt;expr_seq&gt;\n\
&lt;math_expr&gt; ::= &lt;math_operand&gt; + &lt;math_operand&gt; -- standard arithmetic addition\n\
&lt;math_operand&gt; - &lt;math_operand&gt; -- standard arithmetic subtraction\n\
&lt;math_operand&gt; * &lt;math_operand&gt; -- standard arithmetic multiplication\n\
&lt;math_operand&gt; / &lt;math_operand&gt; -- standard arithmetic division\n\
&lt;math_operand&gt; ^ &lt;math_operand&gt; -- exponential, raise to the power\n\
&lt;math_operand&gt; as &lt;class&gt; -- conversion between types\n\
\n\
&lt;math_operand&gt; ::= &lt;operand&gt;\n\
&lt;function_call&gt;\n\
&lt;math_expr&gt;\n\
&lt;logical_expr&gt; ::= &lt;logical_operand&gt; or &lt;logical_operand&gt;\n\
&lt;logical_operand&gt; and &lt;logical_operand&gt;\n\
not &lt;logical_operand&gt;\n\
&lt;logical_operand&gt; ::= &lt;operand&gt;\n\
&lt;compare_expr&gt;\n\
&lt;function_call&gt;\n\
&lt;logical_expr&gt;\n\
&lt;compare_expr&gt; ::= &lt;compare_operand&gt; = = &lt;compare_operand&gt; -- equal\n\
&lt;compare_operand&gt; != &lt;compare_operand&gt; -- not equal\n\
&lt;compare_operand&gt; &gt; &lt;compare_operand&gt; -- greater than\n\
&lt;compare_operand&gt; &lt; &lt;compare_operand&gt; -- less than\n\
&lt;compare_operand&gt; &gt;= &lt;compare_operand&gt; -- greater than or equal\n\
&lt;compare_operand&gt; &lt;= &lt;compare_operand&gt; -- less than or equal\n\
&lt;compare_operand&gt; ::= &lt;math_expr&gt;\n\
&lt;operand&gt;\n\
&lt;function_call&gt;\n\
&lt;function_call&gt; ::= &lt;operand&gt; ( )\n\
&lt;operand&gt; { &lt;parameter&gt; } -- up to an end of line or lower precedence token\n\
&lt;parameter&gt; ::= &lt;operand&gt;\n\
&lt;name&gt;:&lt;operand&gt;\n\
&lt;operand&gt; ::= &lt;factor&gt;\n\
&lt;property&gt;\n\
&lt;index&gt;\n\
&lt;property&gt; ::= &lt;operand&gt; . &lt;var_name&gt; -- properties and indexes left associate\n\
&lt;index&gt; ::= &lt;operand&gt; [ &lt;expr&gt; ] \n\
&lt;factor&gt; ::= &lt;number&gt;\n\
&lt;string&gt;\n\
&lt;path_name&gt;\n\
&lt;var_name&gt;\n\
#&lt;var_name&gt;\n\
&lt;array&gt;\n\
&lt;bitarray&gt;\n\
&lt;point3&gt;\n\
&lt;point2&gt;\n\
true false on off ok undefined unsupplied\n\
- &lt;expr&gt; -- unary minus\n\
&lt;expr_seq&gt;\n\
? -- last Listener result\n\
&lt;expr_seq&gt; ::= ( &lt;expr&gt; { ( ; | &lt;eol&gt;) &lt;expr&gt; } )\n\
&lt;number&gt; ::= [-]{&lt;digit&gt;}[.{&lt;digit&gt;}[(e | E)[+ | -]{&lt;digit&gt;}+] -- decimal number\n\
0x{&lt;hex_digit&gt;}+ -- hexadecimal number\n\
&lt;string&gt; ::= &quot;{ &lt;any_char_except_quote&gt;| \\&quot; | \\n | \\r | \\t | \\* | \\? | \\\\ | \\% | \\x {&lt;hex_digit&gt;}+ }&quot;\n\
&lt;time&gt; ::= [-]{&lt;decimal_number&gt;[m | s | f | t]}+ -- minutes/sec/frames/ticks\n\
[-]{&lt;digit&gt;}:{&lt;digit&gt;}[.{&lt;digit&gt;}] -- SMPTE mins:secs.frame\n\
[-]&lt;decimal_number&gt;n -- active segment normalized time\n\
&lt;box2&gt; ::= [ &lt;expr&gt;, &lt;expr&gt;, &lt;expr&gt;, &lt;expr&gt; ]\n\
&lt;point3&gt; ::= [ &lt;expr&gt;, &lt;expr&gt;, &lt;expr&gt; ]\n\
&lt;point2&gt; ::= [ &lt;expr&gt;, &lt;expr&gt; ]\n\
&lt;array&gt; ::= #( ) #( &lt;expr&gt; { , &lt;expr&gt; } )\n\
&lt;bitarray&gt; ::= #{ } #{ [&lt;expr&gt; | &lt;expr&gt;. .&lt;expr&gt;] { , [&lt;expr&gt; | &lt;expr&gt;. .&lt;expr&gt;] } }\n\
&lt;path_name&gt; ::= $&lt;path&gt; | $\n\
&lt;path&gt; ::= [ &lt;objectset&gt; ] [ / ] [ &lt;levels&gt; ] &lt;level_name&gt;\n\
&lt;levels&gt; ::= &lt;level&gt; { / &lt;level&gt; }\n\
\n\
&lt;level&gt; ::= &lt;level_name&gt;\n\
\n\
&lt;level_name&gt; ::= { &lt;alphanumeric&gt; | _ | * | ? | \\ }\n\
&#39;{ &lt;any_char_except_single_quote&gt;| \\* | \\? | \\\\ }&#39;\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";