var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Context Expressions</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Context Expressions</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"context-expressions\"></a></div>\n\
<p>Context expressions are parts of the MAXScript syntax that are specifically designed for use with <strong>3ds Max</strong>. Context expressions are mirrors of some of the most important abstractions in the <strong>3ds Max</strong> user interface - the animate button, the time-line slider, the working coordinate system, and so on. Context expressions make it as easy to create animation and perform geometry manipulation in MAXScript as these tools do in the user interface.</p>\n\
<p>The basic idea for this is a prefix that is supplied to set up a context for the evaluation of its expression.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>``` b1 = box() b2 = box() animate on ( move $box001 [20, 0, 0] rotate $box002 45 x_axis )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>This effectively &quot;turns on&quot; the animate button for the duration of its block-expression. The move and rotate automatically generate keyframes, just as it happens when you turn the animate button on in the <strong>3ds Max</strong> user interface and move objects around.</p>\n\
<p>Another kind of context expression has a prefix for setting the current animation time, as though you had moved the time slider. If we mix the two forms together, you can see how to do keyframe animation in MAXScript.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>``` animate on ( at time 0 $box001.position = [-100, 0, 0] at time 100 $box001.position = [100, 0, 0] )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The full syntax for <span class=\'code\'>&lt;context_expr&gt;</span> is:</p>\n\
<div class=\'codeBlock\'><pre>&lt;context&gt; { , &lt;context&gt; } &lt;expr&gt;\n\
</pre></div><p>where <span class=\'code\'>&lt;context&gt;</span> is one of:</p>\n\
<div class=\'codeBlock\'><pre>[ with ] animate &lt;boolean&gt; \n\
at level &lt;node&gt;\n\
in &lt;node&gt;\n\
at time &lt;time&gt;\n\
[ in ] coordsys &lt;coordsys&gt;\n\
about &lt;center_spec&gt;\n\
[ with ] undo &lt;boolean&gt;\n\
[ with ] redraw &lt;boolean&gt;\n\
[ with ] quiet &lt;boolean&gt;\n\
[ with ] redraw &lt;boolean&gt;\n\
[ with ] printAllElements &lt;boolean&gt;\n\
[ with ] defaultAction &lt;action&gt;\n\
[ with ] MXSCallstackCaptureEnabled &lt;boolean&gt;\n\
[ with ] dontRepeatMessages &lt;boolean&gt;\n\
[ with ] macroRecorderEmitterEnabled &lt;boolean&gt;\n\
\n\
<blockquote>\n\
</blockquote></pre></div><p><strong>EXAMPLES:</strong></p>\n\
<p>``` -- randomly jiggle each object in the selection around + or - 20 units in coordsys local selection.pos = random [-20,20,20] [20,20,20] -- rotate all the boxes 30 degrees about the y_axis of $foo about $box001 rotate $box002* 30 y_axis -- generate a keyframed animation of $foo randomly chasing $baz animate on for t in 0 to 100 by 5 do at time t $box001.pos = $box002.pos + random [-10,-10,-10] [10,10,10]</p>\n\
<p>```</p>\n\
\n\
<p>The individual context expressions are described in the following topics:</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/animate.html\' title=\'\'>animate</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/at-level-in.html\' title=\'\'>at level, in</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/at-time.html\' title=\'\'>at time</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/coordsys.html\' title=\'\'>coordsys</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/about.html\' title=\'\'>about</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/undo.html\' title=\'\'>undo</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/quiet-Context.html\' title=\'\'>quiet</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/redraw-Context.html\' title=\'\'>redraw</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/PrintAllElements-Variable-and.html\' title=\'\'>PrintAllElements</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/defaultAction-Context.html\' title=\'\'>defaultAction</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Macro-Recorder-Emission-From.html\' title=\'\'>macroRecorderEmitterEnabled</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/MXSCallstackCaptureEnabled.html\' title=\'\'>MXSCallstackCaptureEnabled</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Context-Expressions/dontRepeatMessages-Context.html\' title=\'\'>dontRepeatMessages</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";