var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>undo</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>undo</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"undo\"></a></div>\n\
<p>The <span class=\'code\'>undo &lt;boolean&gt;</span> context provides control over whether scripted scene changes will be undoable.</p>\n\
<p>By default, the operations performed in MAXScript are undoable.</p>\n\
<p>This means that scene-modifying commands typed in the Listener are undoable by default. Making this a context-controlled activity allows you to decide when the <span class=\'code\'>undo</span> overhead is to be taken.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` undo on ( delete $box<em> delete $sphere</em> clearUndoBuffer() )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The undoable operations appear as items labeled &quot;MAXScript&quot; in the <strong>3ds Max</strong> Undo menu.</p>\n\
<p>It is important to note that the granularity of the undoable operations is at the level of entire undo clauses.</p>\n\
<p>In the previous example, one entry is added to the Undo stack containing both the deletes as a single operation.</p>\n\
<p>Choosing undo for this entry in the Undo menu causes both the deletes to be undone.</p>\n\
<p>Therefore, you can control the granularity of an undo by choosing the appropriate undo block expression groupings.</p>\n\
<p>You can invoke an undo from MAXScript with the <span class=\'code\'>max</span> command:</p>\n\
<div class=\'codeBlock\'><pre>max undo \n\
</pre></div><p>When you script very large scene changes, you must consider turning undo <span class=\'code\'>off</span> as it easily fills up the Undo stack and consumes substantial amounts of memory. Disabling undo can improve performance in this situation.</p>\n\
<p>If the actions performed by your script can interfere with entries already in the Undo stack, you must explicitly clear the Undo stack before enabling undo.</p>\n\
<p>An entry in the Undo stack generally expects the scene to be in the state it was when the entry was placed in the Undo stack.</p>\n\
<p>If you interrupt the storing of Undo stack entries and modify the scene in an incompatible way (such as, deleting an object that an entry assumes is still around), then a <strong>3ds Max</strong> crash is likely if you try to perform an undo.</p>\n\
<p>Using the following functions you can control the undo and scene save states in <strong>3ds Max</strong>:</p>\n\
<div class=\'codeBlock\'><pre>clearUndoBuffer()   \n\
</pre></div><p>Empties the Undo stack, both providing a way to reset the undo state and another way to control the save-changes requester.</p>\n\
<div class=\'codeBlock\'><pre>setSaveRequired &lt;boolean&gt; \n\
</pre></div><p>Lets you set the <strong>3ds Max</strong> system &quot;dirty&quot; flag. If this flag is set or there are entries in the Undo stack, you are prompted to save the scene file on a File &gt; New or File &gt; Reset.</p>\n\
<div class=\'codeBlock\'><pre>getSaveRequired() \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the <strong>3ds Max</strong> system &quot;dirty&quot; flag is set to <span class=\'code\'>true</span> or if the Undo buffer is not empty. If the Undo buffer is not empty, this function will still return <span class=\'code\'>true</span> even if you just called <span class=\'code\'>setSaveRequired false</span> .</p>\n\
<p>Generally, if there are entries in the Undo stack when the scene is closed, <strong>3ds Max</strong> will prompt with a save-changes requester. In some cases, where you are controlling undo in MAXScript, you might want to force the need for a save-changes prompt.</p>\n\
<p>MAXScript provides some control over the labels displayed in the <strong>3ds Max undo/redo</strong> dropdown list for undoable MAXScript operations.</p>\n\
<p>This is an improvement to just displaying &quot;MAXScript&quot; in all cases, as it did in versions prior to <strong>3ds Max 4</strong>.</p>\n\
<p>Any undoable macroScript execution such as, through a toolbar button, menu item, hotkey, or quad-menu item will be displayed in the <strong>undo/redo</strong> list with the name of the macroScript.</p>\n\
<p>The <strong>&#39;undo on&#39;</strong> context prefix accepts an optional string literal (text in double quotes) after the <strong>&#39;undo&#39;</strong> keyword, which will be used as the label for the undo block in the <strong>3ds Max</strong> undo/redo lists.</p>\n\
<div class=\'section\'><a id=\"syntax\"></a><h3 id=\"syntax\">Syntax</h3></div>\n\
<div class=\'codeBlock\'><pre>undo [&quot;undo_item_label&quot; | label:&lt;string_operand&gt; | variable_name ] &lt;bool_expr&gt; &lt;expr&gt; \n\
</pre></div><p>Where:</p>\n\
<p><span class=\'code\'>&quot;undo_item_label&quot;</span> must be a string literal,</p>\n\
<p><span class=\'code\'>&lt;string_operand&gt;</span> evaluates to a string at runtime, and</p>\n\
<p><span class=\'code\'>variable_name</span> is a global or local variable containing a string value.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` rollout test &quot;test&quot; ( local undoString = &quot;Button Press&quot; local buttonPress = 0 button b &quot;press me&quot; on b pressed do with undo label:(undoString + (buttonPress +=1) as string) on box() ) createdialog test</p>\n\
<p>```</p>\n\
<p>``` undo &quot;add background&quot; on ( ... )</p>\n\
<p>```</p>\n\
<p>``` my_context_name = &quot;An Undo Context&quot; undo my_context_name on ( --... )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>These examples will generate an undo-block for all the operations in the block-expression following the prefix, which will display in the undo/redo lists with the given string as its name.</p>\n\
<p>The name must be a literal string and is optional, and will default to &quot;MAXScript&quot;.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";