var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Expressions</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Expressions</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"expressions\"></a></div>\n\
<p>MAXScript is an <em>expression-based</em> language. Every construct in the language is an expression and yields a result. This includes constructs that other languages consider as statements. The simplified syntax of the language allows you to build very expressive code. Anywhere you can write an <span class=\'code\'>&lt;expr&gt;</span> expression, and you can write any construct in MAXScript.</p>\n\
<p>A good example of this is the <span class=\'code\'>if</span> construct. In statement-based languages, there is usually one syntax for <span class=\'code\'>if</span> statements and another for conditional expressions. In MAXScript, a single syntax is used for both cases.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>The following two lines of code are both valid and their meaning is obvious:</p>\n\
<p>``` if a &gt; b then print c else print d x = if a &gt; b then c else d</p>\n\
<p>```</p>\n\
<p>You can also write the following line with a nested <span class=\'code\'>if</span> expression and a nested assignment, which itself is an expression:</p>\n\
<p>``` x = if (if a &gt; b then c else d) &lt; e then f else (g = 23)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Another example is the block-expression, denoted by <span class=\'code\'>&lt;block_expr&gt;</span>. It contains a series of <span class=\'code\'>&lt;expr&gt;</span> expressions enclosed in parentheses.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>``` a = 2 b = 1 ( print a print b if a &gt; b then print &quot;the big a&quot; )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Each expression in the block is separated by a line break. You can also write several expressions in one line using a &quot;;&quot; (semicolon) to separate them.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>``` (print a; print b; if a &gt; b then print &quot;the big a&quot;)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Block-expressions are themselves <span class=\'code\'>&lt;expr&gt;</span> expressions. They evaluate their component expressions in sequence and their value is the value of the last expression in the block.</p>\n\
<p>To create classic block-structured statements:</p>\n\
<blockquote>\n\
<p><strong>YOU MIGHT WRITE</strong></p>\n\
<p>``` c = 3 d = 4 if a &gt; b then ( print c x = sqrt (c) ) else ( print d x = sin (e) )</p>\n\
<p>```</p>\n\
<p><strong>OR</strong></p>\n\
<p>Use a nested block-expression to compute a comparison operand.</p>\n\
<p>``` if a &gt; (y = sin b; sqrt(y * z)) then print c</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>At its simplest, a MAXScript program is made up of <span class=\'code\'>&lt;expr&gt;</span> expressions.</p>\n\
<p>An <span class=\'code\'>&lt;expr&gt;</span> is defined as any of the following:</p>\n\
<div class=\'codeBlock\'><pre>&lt;simple_expr&gt;\n\
&lt;variable_decls&gt;\n\
&lt;assignment&gt;\n\
&lt;context_expr&gt;\n\
&lt;if_expr&gt;\n\
&lt;while_loop&gt;\n\
&lt;do_loop&gt;\n\
&lt;for_loop&gt;\n\
&lt;loop_exit&gt;\n\
&lt;case_expr&gt;\n\
&lt;try_expr&gt;\n\
&lt;function_def&gt;\n\
&lt;function_return&gt;\n\
&lt;struct_def&gt;\n\
&lt;max_command&gt;\n\
&lt;utility_def&gt;\n\
&lt;rollout_def&gt;\n\
&lt;tool_def&gt;\n\
&lt;rcmenu_def&gt;\n\
&lt;plugin_def&gt;\n\
\n\
</pre></div><p>These expressions constitute the main constructs in MAXScript.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";