var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Pathname Literals</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Pathname Literals</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"pathname-literals\"></a></div>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Names.html\' title=\'\'>Names</a> identify entities such as variables and parameters inside the running MAXScript program. If you want to identify objects by name in the <strong>3ds Max</strong> scene, you use a pathname. Pathnames can name a single object in the scene, specify a particular object using a path through the object hierarchy, or name sets of objects using pattern matching.</p>\n\
<p>The full syntax for a pathname literal is:</p>\n\
<div class=\'codeBlock\'><pre>&lt;path_name&gt; ::= $&lt;path&gt; | $ \n\
&lt;path&gt; ::= [ &lt;objectset&gt; ] [ / ] [ &lt;levels&gt; ] &lt;level_name&gt; \n\
&lt;levels&gt; ::= &lt;level&gt; { / &lt;level&gt; } \n\
&lt;level&gt; ::= &lt;level_name&gt;\n\
\n\
&lt;level_name&gt; ::= { &lt;alphanumeric &gt; | _ | * | ? | \\ }\n\
&#39;{ &lt;alphanumeric &gt; | _ | * | ? | \\ }&#39;\n\
</pre></div><p>The root of a <span class=\'code\'>&lt;path&gt;</span> can be an <span class=\'code\'>&lt;objectset&gt;</span> , which limits the pathname searching to the object set you specify. ObjectSets are described in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/ObjectSet-Values.html\' title=\'\'>ObjectSet Values</a>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` $box01 -- object named &#39;box01&#39; $torso/left_up_arm/left_low_arm -- hierarchy path name $<em>box</em> -- all objects with &#39;box&#39; in -- the name $torso/* -- all the direct children of -- $torso $helpers/d* -- all helper objects whose name starts with &#39;d&#39;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>All objects in a <strong>3ds Max</strong> scene are arranged in a hierarchy as presented in Track View. This is both an important organizing scheme in <strong>3ds Max</strong>, and it suggests a MAXScript naming scheme for objects based on the path to an object through the hierarchy. It is also very similar to path names in an operating system&#39;s directory structure.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>$dummy/head/neck</span></p>\n\
<p>names the scene object <span class=\'code\'>neck</span> whose parent is object <span class=\'code\'>head</span> , which has the top-level parent object <span class=\'code\'>dummy</span> . This pathname helps you identify a specific object in a <strong>3ds Max</strong> scene, even if several objects have the same name. If <span class=\'code\'>head</span> is unique in the scene, MAXScript lets you use the shorthand <span class=\'code\'>$head</span> to refer to it regardless of its hierarchy position. Even if the object is not uniquely named you can use the shorthand form, but it is undetermined which of the same-named objects you will get.</p>\n\
</blockquote>\n\
<p>Pathnames also provide a powerful way to refer to several objects at once, such as all the children of a certain parent, or all the objects with names containing the string <span class=\'code\'>foot</span> . For this, you can use <strong>wild-card patterns</strong>, as you can with operating system shell file naming schemes.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>$dummy/*</span></p>\n\
<p>names all the immediate children of <span class=\'code\'>dummy</span> . The <span class=\'code\'>&quot;*&quot;</span> character is used as a wild card.</p>\n\
<p><span class=\'code\'>$neck*</span></p>\n\
<p>finds all the objects, whose names start with the string <span class=\'code\'>neck</span> , anywhere in the hierarchy.</p>\n\
</blockquote>\n\
<p>You can use <strong>wild cards</strong> anywhere in a pathname.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>$*foot*</span></p>\n\
<p>finds all the objects with <span class=\'code\'>foot</span> anywhere in their names. The <span class=\'code\'>&quot;*&quot;</span> wild-card character effectively matches any number other characters.</p>\n\
</blockquote>\n\
<p>You can also use the <strong>&quot;?&quot;</strong> wild-card character to match exactly one &quot;don&#39;t care&quot; character. This is, the <strong>&quot;?&quot;</strong> wild-card character will match any single character.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>$box0?</span></p>\n\
<p>finds all the objects that begin with <span class=\'code\'>box0</span> and have exactly one character after the <span class=\'code\'>0</span> in their names.</p>\n\
</blockquote>\n\
<p>Wild-card characters can also be used for specifying parent levels in a hierarchy.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>$dummy/*/*</span></p>\n\
<p>names all the children of all the children of <span class=\'code\'>$dummy</span> .</p>\n\
</blockquote>\n\
<p>If you want to find an object and all the children of the object at any nested level, you use the special ellipsis level name &quot;...&quot;,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>$dummy/.../box*</span></p>\n\
<p>names all the children of all the children of <span class=\'code\'>$dummy</span> .</p>\n\
<p>This refers to <span class=\'code\'>$dummy</span> and all the <span class=\'code\'>box*</span> children at any level below <span class=\'code\'>$dummy</span> . The <span class=\'code\'>&quot;...&quot;</span> indicates to search the entire hierarchy below the level of the ellipsis. MAXScript lets you omit the &quot;/&quot; when using &quot;...&quot; because it is unambiguous:</p>\n\
<p><span class=\'code\'>$dummy...box*</span></p>\n\
<p>Or, in another common example,</p>\n\
<p><span class=\'code\'>$dummy...*</span></p>\n\
<p>names <span class=\'code\'>$dummy</span> and all the children of <span class=\'code\'>$dummy</span> at any level.</p>\n\
</blockquote>\n\
<p>If you use a wild card in an object pathname MAXScript will manipulate all matching objects at one time.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>hide $*foot*</span></p>\n\
<p>hides all objects whose names contain <span class=\'code\'>foot</span> .</p>\n\
</blockquote>\n\
<p>You can also perform automatic collection mapping, where a property for each matching object is set.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>$*box*.position += [10, 10, 0]</span></p>\n\
<p>adds <span class=\'code\'>\\[10,10,0\\]</span> to the positions of all scene objects whose names contain <span class=\'code\'>box</span> . For more information, see <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collections-1.html\' title=\'\'>Collections</a>.</p>\n\
</blockquote>\n\
<p>You can use a shorthand form for specifying the currently selected object or objects with the pathname syntax. A lone &quot;$&quot; character refers to either the currently selected object if a single object is selected, the current selection set as an ObjectSet if more than one object is selected, or <span class=\'code\'>undefined</span> if no objects are selected. This is a useful shorthand for use in the Listener when working on selections.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>$.pos = [0,0,0]   hide $   rotate $ 35 z_axis</span></p>\n\
</blockquote>\n\
<p>Note:</p>\n\
<p>Inside a script, it is better to use the <span class=\'code\'>selection</span> ObjectSet rather than <span class=\'code\'>$</span> .</p>\n\
<p><span class=\'code\'>selection</span> always contains an ObjectSet regardless of the number of selected objects. Where <span class=\'code\'>hide $</span> will generate an error if no objects are selected (because <span class=\'code\'>$</span> contains the value <span class=\'code\'>undefined</span> ), <span class=\'code\'>hide selection</span> will not generate an error.</p>\n\
<p>Due to the way that <strong>3ds Max</strong> internally processes notification signals, the <span class=\'code\'>$</span> form of accessing selected objects is <strong>not recommended</strong> in a <span class=\'code\'>select</span> change handler. To access the selected objects, you should use the <span class=\'code\'>selection</span> ObjectSet. This is because <span class=\'code\'>$</span> relies on information that has not yet been set in the selection processing whereas <span class=\'code\'>selection</span> uses a different method of accessing selections and the information it uses has been set up.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";