var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Names</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Names</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"names\"></a></div>\n\
<p>Names are used in MAXScript to identify variables, functions, parameters, properties, and so on. Names start with an alphabetic character or &quot;<strong><em><strong>&quot; (underscore), and can contain any number of alphanumeric characters or &quot;</strong></em></strong>&quot;.</p>\n\
<p><strong>EXAMPLES OF VALID NAMES ARE:</strong></p>\n\
<ul>\n\
<li><span class=\'code\'>foo</span></li>\n\
<li><span class=\'code\'>bar123</span></li>\n\
<li><span class=\'code\'>this_is_a_very_long_identifier</span></li>\n\
<li><span class=\'code\'>_heresOneWithStudlyCaps</span></li>\n\
</ul>\n\
<p><strong>THE FOLLOWING NAMES ARE NOT VALID:</strong></p>\n\
<ul>\n\
<li><span class=\'code\'>1object</span> - First character not an alphabetic character</li>\n\
<li><span class=\'code\'>pressed?</span> - ? is not a valid alphanumeric character</li>\n\
<li><span class=\'code\'>a big number</span> - spaces not allowed in names</li>\n\
<li><span class=\'code\'>seven(7)</span> - ( and ) are not valid alphanumeric characters</li>\n\
</ul>\n\
<p>In contrast to most general purpose programming languages, MAXScript names are <strong>not case-sensitive</strong>. For example,the names in the following list refer to the same variable in MAXScript:</p>\n\
<div class=\'codeBlock\'><pre>BitMapTexture\n\
bitmaptexture\n\
BITMAPtexture\n\
</pre></div><p>In syntax descriptions, name identifiers are specified as:</p>\n\
<div class=\'codeBlock\'><pre>&lt;var_name&gt;\n\
</pre></div><p>An example of a syntax where a name identifier is specified is:</p>\n\
<div class=\'codeBlock\'><pre>for &lt;var_name&gt; ( in | = )&lt;sequence&gt; ( do | collect ) &lt;expr&gt;\n\
</pre></div><p>In this example, <span class=\'code\'>&lt;var_name&gt;</span> specifies the <span class=\'code\'>for</span> loop variable.</p>\n\
<p>A name in a program is always interpreted as the name of a variable or parameter and it effectively stands for the current value of that variable or parameter in any expression in which it is used.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE, CONSIDER THE FOLLOWING SCRIPT:</strong></p>\n\
<p>``` i=10 j=i+5 print j</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In this script, <span class=\'code\'>i</span> and <span class=\'code\'>j</span> are variable names. In the first line, the value 10 is assigned to variable <span class=\'code\'>i</span> . In the second line, the value 5 is added to the value stored in variable <span class=\'code\'>i</span> , and then the result is stored in variable <span class=\'code\'>j</span> . In the third line, the value 15 is printed, which is the value stored in variable <span class=\'code\'>j</span> .</p>\n\
<p>MAXScript also allows you to work directly with names as values at runtime, as you can with numbers and strings. To write a name value in MAXScript, you preface the name with a &quot;#&quot;:</p>\n\
<div class=\'codeBlock\'><pre>#&lt;var_name&gt;\n\
</pre></div><p>In syntax descriptions, name values are specified as:</p>\n\
<div class=\'codeBlock\'><pre>&lt;name&gt;\n\
</pre></div><p>Name values are primarily used for symbolic parameters in function calls, and many of the built-in functions use them as such. The allowed values specified for symbolic parameters are defined by the function, and are documented with the function.</p>\n\
<p>As an example, consider the <span class=\'code\'>setBeforeORT()</span> function. Its syntax is:</p>\n\
<div class=\'codeBlock\'><pre>setBeforeORT &lt;controller&gt; &lt;ORT_type_name&gt;\n\
</pre></div><p>Sets the Out-of-Range (ORT) type for the controller for the time <strong>before</strong> the <strong>first</strong> key. The <span class=\'code\'>&lt;ORT_type_name&gt;</span> must be one of the following name values:</p>\n\
<div class=\'codeBlock\'><pre>#constant #cycle #loop #pingPong #linear #relativeRepeat\n\
<blockquote>\n\
</blockquote></pre></div><p><strong>AN EXAMPLE USAGE OF THIS FUNCTION IS:</strong></p>\n\
<p>``` setBeforeORT $box01.position.controller #pingPong</p>\n\
<p>```</p>\n\
\n\
<p>Name values can also be used as an index in certain <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collections-1.html\' title=\'\'>Collections</a>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>the index for a <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collection-Types/ModifierArray-Values.html\' title=\'\'>ModifierArray</a> can be an integer, name, or string:</p>\n\
<p>``` -- access modifier on object loft01 called Optimize: $loft01.modifiers[#Optimize]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Quoted Names</strong></p>\n\
<p>Names set in single quotes allow you to write names that contain illegal identifier characters, such as spaces and other punctuation. They are primarily intended for specifying <strong>3ds Max</strong> object classes and properties that have special characters in their names.</p>\n\
<p><strong>The form is:</strong></p>\n\
<div class=\'codeBlock\'><pre>&#39;&lt;any_char_except_quote&gt;&#39; -- for an identifier or property name\n\
#&#39;&lt;any_char_except_quote&gt;&#39; -- for a name literal\n\
&#39;&lt;any_char_except_quote&gt;&#39;: -- for a keyword parameter label\n\
\n\
<blockquote>\n\
</blockquote></pre></div><p><strong>EXAMPLES:</strong></p>\n\
<p>``` snow &#39;starttime(start)&#39;:5 b.&#39;lifetime(life)&#39; $box01.modifiers[#&#39;FFD 4x4x4&#39;]</p>\n\
<p>```</p>\n\
\n\
<p><strong>Spaces in Names</strong></p>\n\
<p>Because of the large amount of names in <strong>3ds Max</strong> that include spaces, the underscore character (&quot; <span class=\'code\'>_</span> &quot;) can be used instead of a space in a name.</p>\n\
<p>The following is equivalent to the last line of the above example:</p>\n\
<blockquote>\n\
<p>``` $box01.modifiers[#FFD_4x4x4]</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";