var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Block-Expressions</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Block-Expressions</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"block-expressions\"></a></div>\n\
<p>Block-expressions are the basic constructors for structured code. They allow you to group a sequence of expressions and evaluate them in sequence as though they were a single expression.</p>\n\
<p>The syntax for <span class=\'code\'>&lt;block_expr&gt;</span> is:</p>\n\
<div class=\'codeBlock\'><pre>( &lt;expr&gt; { (; | &lt;eol&gt;) &lt;expr&gt; } )\n\
</pre></div><p>It is a parenthesized sequence of expressions with each <span class=\'code\'>&lt;expr&gt;</span> separated by either a line break or a <strong>;</strong> semicolon.</p>\n\
<p>MAXScript also allows empty block-expressions, <span class=\'code\'>()</span> . This is useful when incrementally building code to place an empty expression in a path to be filled in later. When evaluated, empty expressions yield the value <span class=\'code\'>undefined</span> .</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` x = 2 y = 3 z = 4 p = [10,10,10] centre = [20,20,20] ( d = centre.x^2 - (p.x^2 + p.y^2) newz =if d &gt; 0 then sqrt d else p.z print newz ) if x &lt; y then (print x; print y; u += 10; print u)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>You can use a mixture of line breaks or semicolons:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` ( print x; print y p.x += 10 print p.x; print p.y )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Because a block-expression is an <span class=\'code\'>&lt;operand&gt;</span> , you can insert a block-expression anywhere you can put an <span class=\'code\'>&lt;operand&gt;</span>. This is <strong>unlike most languages</strong> that limit where you can put blocks of code to only a few places.</p>\n\
<p>Further, because all constructs are expressions in MAXScript, a block-expression yields a value defined to be the last <span class=\'code\'>&lt;expr&gt;</span> in the block. This allows you to use a nested sequence of expressions to compute an operand for some operation:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` b = box() b.pos.z = ( d = x^2 - y^2 if d &gt; 0 then sqrt d else z )</p>\n\
<p>```</p>\n\
<p>Here, the result of the block-expression is the result of the final <span class=\'code\'>if</span> expression, which is then assigned to <span class=\'code\'>b.pos.z</span> .</p>\n\
</blockquote>\n\
<p>Because the item in parentheses can be <span class=\'code\'>any&lt;expr&gt;</span>, you can turn any construct in MAXScript into an operand by putting it in parentheses. This allows you to write the following example, in which the operand to be indexed is the conditional result of an <span class=\'code\'>if</span> expression:</p>\n\
<blockquote>\n\
<p>``` (if a &gt; b then c else d)[n + 1]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>As described in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Scope-of-Variables.html\' title=\'\'>Scope of Variables</a>, top-level open parentheses in a script file or in the Listener create a new variable scope. Any block-expressions with the top-level block-expression do not create a new variable scope, even if the variable is explicitly declared as local in the inner block-expression. A variable’s scope extends into any block-expressions within the variable’s scope. If you declare a variable as local in a scope, the newly declared local variable hides any outer variables with the same name. Any reference to that variable name later in the local variable&#39;s scope refers to the new local variable. At the end of the local variable&#39;s scope, the next outer variable becomes visible again. This is shown in the following script:</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` a=1 ( local a=2 ( local a=3 ) print a ) a</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` 1 -- result of line 1 3 -- output of line 7 3 -- result of block-expression lines 2 to 8 1 -- result of line 9</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Any variable names used in a block-expression which have not been created at a higher scope level are implicitly declared as local in the present scope. This can result in unexpected execution results for scripts that are not set up correctly.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE, CONSIDER THE FOLLOWING SCRIPT:</strong></p>\n\
<p>``` (b=bend();addmodifier Objs b) -- create bend modifier and apply to objects b.angle=10</p>\n\
<p>```</p>\n\
<p>The first time you execute this script, the following <strong>error message</strong> is generated:</p>\n\
<p>``` -- Unknown property: &quot;angle&quot; in undefined</p>\n\
<p>```</p>\n\
<p>If you execute the script again, it works properly. The reason is there are actually two variables with the name <span class=\'code\'>b</span> - one is local to the block-expression and contains the bend modifier value, and the other is global and has the value <span class=\'code\'>undefined</span> . During the second execution, global <span class=\'code\'>b</span> exists, so the block-expression does not implicitly declare a new variable <span class=\'code\'>b</span> , rather it uses the global variable <span class=\'code\'>b</span> .</p>\n\
</blockquote>\n\
<p>When writing scripts, it is also a good programming practice to explicitly declare as local all variables unless you really want them to be global variables. There are several reasons for this practice:</p>\n\
<ul>\n\
<li><p>All the variable names used in the block or function will be together, which makes it easier to find the variable names and helps prevent using incorrect names in the script.</p></li>\n\
<li><p>If more than one script is executing at the same time (for example, you are running a scripted utility and have a scripted controller in the scene) and both scripts use the same global variable name, the two scripts can interfere with one another. This can cause apparently random failures of one or both scripts.</p></li>\n\
<li><p>You are sure you are using the correct variable in the event that a variable with the same name has already been declared at a higher scope, and you will not inadvertently change the higher-level variable&#39;s value.</p></li>\n\
<li><p>Values of variables explicitly defined as local are displayed in error call stack trace-backs.</p></li>\n\
<li><p>In <strong>3ds Max</strong> R2.5, if a <strong>3ds Max</strong> class, a MAXScript method, or a MAXScript read-only global variable has the same name as an implicitly declared local variable, a MAXScript runtime error will be generated if an assignment to that variable name occurs. Since the variable name already existed with a global scope, an implicitly declared local variable was not created. Since one or more new <strong>3ds Max</strong> classes will be created by any third party plug-ins the user has loaded, you were not be able to tell ahead of time if a variable name was a global variable name. In <strong>3ds Max 4 and higher</strong>, if the MAXScript compiler detects that the first reference to such a variable is an assignment, it will implicitly declare a local variable, rather than leaving it as a reference to a read-only system global.</p></li>\n\
</ul>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>executing the following expression in <strong>3ds Max R2.5</strong> would result in a value of <span class=\'code\'>Box</span> , since <span class=\'code\'>Box</span> is a <strong>3ds Max</strong> object class.</p>\n\
<p>In <strong>3ds Max 4 and higher</strong>, MAXScript detects that the first use of variable <span class=\'code\'>box</span> is an assignment and creates an implicitly declared local variable <span class=\'code\'>box</span> .</p>\n\
<p>The result of this expression in <strong>3ds Max 4 and higher</strong> is the value <span class=\'code\'>undefined</span> .</p>\n\
<p>``` (if false do box=10;box)</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";