var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Defining Local Functions in Structures</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Defining Local Functions in Structures</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"defining-local-functions-in-structures\"></a></div>\n\
<p>You can define local functions in structures, providing a convenient mechanism for packaging a set of related functions and avoiding possible name conflicts when many global functions are defined, possibly by several separate scripts.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>``` struct foo ( a, b, c, fn baz n = sqrt (n + 1), fn bar x y = print (x ^ 2 + y ^ 2) )</p>\n\
<p>```</p>\n\
<p>This defines a structure definition <span class=\'code\'>foo</span> with three elements named <span class=\'code\'>a</span> , <span class=\'code\'>b</span> , and <span class=\'code\'>c</span> , and two local functions: <span class=\'code\'>bar</span> and <span class=\'code\'>baz</span> . You can access these functions as properties of either the structure definition value itself or an instance of the foo structure:</p>\n\
<p>``` p = foo.baz q -- access as property of the structure definition value foo.bar x y f = foo 2 3 4 f.bar x y -- access as property of the structure instance</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Local functions declared in a structure definition can make references to the member data variables defined in the structure, such that when that member function in some instance of the structure is called, the references access the members of that instance. This allows you to initialize and maintain data structures for the structure functions within the structure itself. An example of including functions that use members of the structure is shown in the following script.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` struct RandVals ( RndVals=#(), ptr, eedVal, fn generateRV num fromVal toVal = ( if seedVal != undefined do seed seedVal RndVals=for i=1 to num collect random fromVal toVal ptr=1 RndVals ), fn deleteRv = ( RndVals=#() ptr=undefined undefined ), fn getNextRV = ( if Nvals == 0 do return undefined val=RndVals[ptr] ptr += 1 if ptr &gt;RndVals.count do ptr=1 val ), fn sortRV =(sort RndVals), fn setSeed val = (SeedVal = val), fn setPointer val = ( if val &gt; 0 and val &lt;= RndVals.count then (ptr=val;true) else false ) ) MyRandomVals= RandVals() MyRandomVals.setSeed 12345 MyRandomVals.generateRV 10 0 100 MyRandomVals.getNextRV() MyRandomVals.sortRV() MyRandomVals.setPointer 1 MyRandomVals.getNextRV() MyRandomVals.deleteRv()</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` #Struct:RandVals( -- result of struct def lines 1 to 29 RndVals:<data>; Public, sortRV:<fn>; Public, ptr:<data>; Public, seedVal:<data>; Public, generateRV:<fn>; Public, deleteRv:<fn>; Public, getNextRV:<fn>; Public, setSeed:<fn>; Public, setPointer:<fn>; Public) (RandVals RndVals:#() ptr:undefined seedVal:undefined) -- result line 30 12345 -- result line 31 #(23, 59, 79, 68, 17, 72, 84, 16, 89, 72) -- result line 32 23 -- result line 33 #(16, 17, 23, 59, 68, 72, 72, 79, 84, 89) -- result line 34 true -- result line 35 16 -- result line 36 undefined -- result line 37<p>\n\
<p>```</p>\n\
</fn></fn></fn></fn></fn></data></data></fn></data></blockquote>\n\
<p>In this script, the structure has three data members and six function members. Note the references to the structure data members in the <span class=\'code\'>generateRV()</span> function. In line 30, an instance of the <span class=\'code\'>RndVals</span> structure is created and stored in variable <span class=\'code\'>MyRandomVals</span> . In line 31, the <span class=\'code\'>setSeed()</span> function in the structure instance is called, which initializes the random seed variable by storing the specified value in data member <span class=\'code\'>seedVal</span> in the structure instance. In line 32, the <span class=\'code\'>generateRV()</span> function in the structure instance is called, which initializes the random number using the seed value specified by <span class=\'code\'>setSeed()</span> , sets up and stores an array of random numbers in data member <span class=\'code\'>RndVals</span> , updates data member <span class=\'code\'>ptr</span> , and then returns the random number array.</p>\n\
<p>Local functions defined in structures are not stored in every instance of the structure. The local function is stored once in the structure definition and references to them in the instances refer to their definitions in the structure definition.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";