var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Structure Definition</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Structure Definition</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"structure-definition\"></a></div>\n\
<p>You can create your own compound values in MAXScript using <strong>Structure definitions</strong>.</p>\n\
<p>Structure definitions let you define the layout of new &#39;classes&#39; of values that you can then create and work with in your code.</p>\n\
<p>The <strong>syntax</strong> for a structure definition is:</p>\n\
<div class=\'codeBlock\'><pre>struct &lt;struct_name&gt; ( &lt;member&gt; { , &lt;member&gt; } )\n\
</pre></div><p>where each <span class=\'code\'>&lt;member&gt;</span> can be one of:</p>\n\
<div class=\'codeBlock\'><pre>&lt;name&gt; [ = &lt;expr&gt; ] --name and optional initial value\n\
&lt;function_def&gt;\n\
\n\
<blockquote>\n\
</blockquote></pre></div><p><strong>EXAMPLE</strong></p>\n\
<p>``` struct person (name, height, age, sex)</p>\n\
<p>```</p>\n\
\n\
<p>The above example defines a new &#39;person&#39; class. You can create values of this class using the &#39;person&#39; constructor:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` bill = person name: &quot;Bill&quot; height:72 age:34 sex:#male</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>This creates an instance of the <span class=\'code\'>person</span> class, storing the instance in variable <span class=\'code\'>bill</span> . Member <span class=\'code\'>name</span> is initialized to the string value &quot;Bill&quot;, <span class=\'code\'>height</span> to the integer value 72, <span class=\'code\'>age</span> to the integer value 34, and <span class=\'code\'>sex</span> to the name value #male.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` joe = person name: &quot;Joseph&quot; sex:#male</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>This creates an instance of the <span class=\'code\'>person</span> class, storing the instance in variable <span class=\'code\'>joe</span> . Member <span class=\'code\'>name</span> is initialized to the string value &quot;Joseph&quot; and <span class=\'code\'>sex</span> to the name value #male. As the <span class=\'code\'>height</span> and <span class=\'code\'>age</span> members are not assigned values and do not have optional initial values supplied in the structure definition, they default to a value of <span class=\'code\'>undefined</span> .</p>\n\
<p>You can access structured values using the standard property accessing syntax in MAXScript.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` bill.age --returns 34 joe.age --returns undefined joe.age = bill.age-4 --assigns Bill&#39;s age less 4 to Joe&#39;s age.</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Structure definitions are useful as an alternative to arrays when you have a fixed, usually small number of independent components and the code to work with them is much clearer when they can be referenced by property name, rather than by index number.</p>\n\
<p>As with function definitions, a structure definition actually creates a value to represent the definition and stores it in a variable of the same name as the structure. You can store the structure definitions in other compound objects or pass them as function arguments. The <span class=\'code\'>classOf()</span> function returns this structure definition value when applied to these values, so you can use it to test the definition of structure instances at runtime.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` classOf bill --returns person</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The <span class=\'code\'>struct</span> value constructors are just like function calls and take positional argument initializers as well as keyword initializers. The elements of the new <span class=\'code\'>struct</span> are filled in order from any positional arguments and then by name from any keyword arguments.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>given the following <span class=\'code\'>struct</span> definition:</p>\n\
<p>``` struct foo (name, age, height, hair=&quot;brown&quot;)</p>\n\
<p>```</p>\n\
<p>you can create instances in several ways:</p>\n\
<p>``` f1 = foo &quot;bill&quot; 23 72 --fills in name, age, height in order f2 = foo age:45 name: &quot;sam&quot; --random named initializers f3 = foo &quot;mary&quot; hair: &quot;red&quot; --first name, then keywords</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>There are several methods associated with <span class=\'code\'>struct</span> values:</p>\n\
<div class=\'codeBlock\'><pre>getProperty &lt;struct&gt; &lt;propname&gt;\n\
</pre></div><p>Allows you to access properties of the structure.</p>\n\
<div class=\'codeBlock\'><pre>getPropNames &lt;struct&gt;\n\
</pre></div><p>Returns the properties of the structure as an array.</p>\n\
<div class=\'codeBlock\'><pre>copy &lt;struct&gt;\n\
</pre></div><p>Creates a copy of the structure. The copy made is called a <em>shallow copy</em>. Only a copy of the upper-level value itself (that is, the <span class=\'code\'>struct</span> value) is created. Copies are not made of compound values stored in the structure, rather the same compound value is stored in both the <span class=\'code\'>struct</span> values. This can be seen in the following example, where changing a component value of a compound value in a copy of a <span class=\'code\'>struct</span> value also changes the value in the original <span class=\'code\'>struct</span> value:</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` Struct test (pos1, pos2) --define a structure testval = test [1,2,3] [4,5,6] --create struct value testval_copy=copy testval --copy the struct value testval_copy.pos1.x=10 --change component value of a compound --value in the copy testval --look at original struct value</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` #Struct:test( --result line 1 pos1:<data>; Public, pos2:<data>; Public) test(pos1:[1,2,3] pos2:[4,5,6]) --result line 2 test(pos1:[1,2,3] pos2:[4,5,6]) --result line 3 10 --result line 4 (test pos1:[10,2,3] pos2:[4,5,6]) --result line 6<p>\n\
<p>```</p>\n\
</data></data></blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";