var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>ArrayParameter Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>ArrayParameter Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"arrayparameter-values\"></a></div>\n\
<p>Certain plug-ins in <strong>3ds Max</strong> store parameter data in a form that is accessible by MAXScript as <strong>ArrayParameters</strong>. As such, you can access the parameter data by index and iterate over the parameter data.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;MAXWrapper&gt;.parameter\n\
</pre></div><p>Where the parameter contains an ArrayParameter.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;ArrayParameter&gt;.count\n\
</pre></div><p>Returns the number of values in the ArrayParameter. Read-only in most cases with exceptions noted in the MAXWrapper object description where an adjustable ArrayParameter is used.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;ArrayParameter&gt;[&lt;integer&gt;]\n\
</pre></div><p>Returns the element of ArrayParameter. Indexes start at 1.</p>\n\
<div class=\'codeBlock\'><pre>&lt;ArrayParameter&gt;[&lt;integer&gt;] = &lt;value&gt;\n\
</pre></div><p>Sets the element of ArrayParameter to a value.</p>\n\
<p>Each ArrayParameter can only contain data of a certain type (for example, Float), or a controller that matches that data type. The <span class=\'code\'>showProperties()</span> function indicates these array parameters as <span class=\'code\'>&lt;type&gt; array</span> , for example, <span class=\'code\'>int array</span> , <span class=\'code\'>texmap array</span> , and so on.</p>\n\
<p>A plug-in can also define parameter names that point to specific entries in one of its ArrayParameters. For example, <span class=\'code\'>mapAmounts</span> is a property of Standard materials containing an ArrayParameter. Each element in this ArrayParameter contains the map amount for one of the map channels. For easier access in a script, the Standard <span class=\'code\'>.ambientMapAmount</span> property is provided as an alias for <span class=\'code\'>mapAmounts\\[1\\]</span> (along with aliases for all the other common maps). You can access the controller for the <span class=\'code\'>ambientMapAmount</span> alias either through the <span class=\'code\'>.controller</span> property on the alias or on the <span class=\'code\'>.mapAmounts\\[1\\]</span> property.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>either</p>\n\
<p>``` $foo.material.ambientMapAmount.controller</p>\n\
<p>```</p>\n\
<p>or</p>\n\
<p>``` $foo.material.mapAmounts[1].controller</p>\n\
<p>```</p>\n\
<p>will get the controller on the ambient map amount material property.</p>\n\
</blockquote>\n\
<p>ArrayParameter values can be coerced to Array in <strong>3ds Max 6 and higher</strong>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` mtl = standard() mapsArray = mtl.maps as array</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The following script shows the use of <span class=\'code\'>showProperties()</span> to show the data type for elements of ArrayParameters, access to ArrayParameter elements, and a case of a plug-in defining parameter names that point to a specific entry in one of its ArrayParameters.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` m=CompositeMaterial() -- create a Composite material showproperties m -- show the properties for the material m.amount -- show value of parameter amount m.amount[1] *= .5 -- reduce the value for one element m=standard() -- create a Standard material showproperties m -- show it’s properties m.ambientMapAmount=13 -- set the value for one element via its alias m.mapAmounts[1] -- and show the element was changed</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT</strong></p>\n\
<p>``` compositematerial:Composite -- result line 1 .materialList (Material : material array -- output line 2 .mixType (Composite Type) : int array -- ArrayParameter elements are integer .mapEnables (Map Enable) : boolean array -- ArrayParameter elements are boolean .amount : float array -- ArrayParameter elements are float OK -- result line 2 #(100, 100, 100, 100, 100, 100, 100, 100, 100, 100) -- result line 3 50.0 -- result line 4 Standardmaterial:Standard -- result line 5 .mapEnables (Map Enables) : boolean array -- pruned output line 6 .maps : texmap array .mapAmounts (Map Amounts) : percent array .ambientMap (alias for maps[0]) .ambientMapAmount (alias for mapAmounts[0]) .ambientMapEnable (alias for mapEnables[0]) .bumpMap (alias for maps[8]) .bumpMapAmount (alias for mapAmounts[8]) .bumpMapEnable (alias for mapEnables[8]) 13 -- result line 7 13.0 -- result line 8</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";