var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>BigMatrix Values, BigMatrixRowArray Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>BigMatrix Values, BigMatrixRowArray Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"bigmatrix-values-bigmatrixrowarray-values\"></a></div>\n\
<p>The <span class=\'code\'>BigMatrix</span> class implements an MxN matrix for situations and calculations where the usual 4x3 Matrix3 class is not adequate.</p>\n\
<p>The <span class=\'code\'>BigMatrixRowArray</span> class implements an N element vector.</p>\n\
<p>Each row in a BigMatrix value is a <span class=\'code\'>BigMatrixRowArray</span> value.</p>\n\
<p>Only Float values can be stored in the elements of a <span class=\'code\'>BigMatrixRowArray</span>.</p>\n\
<p>Note: Both <span class=\'code\'>BigMatrix</span> and <span class=\'code\'>BigMatrixRowArray</span> values can be coerced to strings, but will be truncated to the first 20 items if the <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/PrintAllElements-Variable-and.html\' title=\'\'>PrintAllElements</a> context is off.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>BigMatrix &lt;rows&gt; &lt;columns&gt;\n\
</pre></div><p>Constructs a BigMatrix value with the given number of rows and columns.</p>\n\
<p>All elements will be initially filled with 0.0 values.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;BigMatrix&gt;.rows: Integer, read-only\n\
&lt;BigMatrix&gt;.columns: Integer, read-only\n\
</pre></div><p>Get the number of rows and number of columns in the BigMatrix value.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;BigMatrix&gt; + &lt;BigMatrix&gt;\n\
</pre></div><p>Adds the two BigMatrix values together.</p>\n\
<p>Both BigMatrix values must have the same size</p>\n\
<div class=\'codeBlock\'><pre>&lt;BigMatrix&gt;[&lt;int_row&gt;] \n\
</pre></div><p>Returns the BigMatrixRowArray value of the indexed row. This value is not independent of the BigMatrix, so for example:</p>\n\
<div class=\'codeBlock\'><pre>bm = BigMatrix 3 3\n\
row1 = bm[1]\n\
row1[1]=2.0\n\
bm\n\
--&gt; #BigMatrix(\n\
    [2.00,0.00,0.00],\n\
    [0.00,0.00,0.00],\n\
    [0.00,0.00,0.00]\n\
)\n\
\n\
&lt;BigMatrix&gt;[&lt;int_row&gt;]= &lt;float_array&gt;\n\
</pre></div><p>Sets the value of the BixMatrixRowArray at the specified index to the specified float array. The array does not need to have the same number of elements as the row. If it has fewer elements, those corresponding elements are set in the row. If there are more elements, the first <em>n</em> elements are copied, where <em>n</em> is the size of the BixMatrixRowArray. <strong>Available in 3ds Max 2021.1 Update and higher.</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;BigMatrixRowArray&gt;[&lt;int_column&gt;]\n\
</pre></div><p>Returns the float value of the indexed column stored in the BigMatrixRowArray value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;BigMatrixRowArray&gt;[&lt;int_column&gt;]= &lt;float_value&gt;\n\
</pre></div><p>Sets the value in the indexed column in the BigMatrixRowArray value.</p>\n\
<p>Because accessors are themselves operands, these definitions are recursive, which means that you can string accessors together:</p>\n\
<div class=\'codeBlock\'><pre>&lt;BigMatrix&gt;[&lt;int_row&gt;][&lt;int_column&gt;]\n\
</pre></div><p>Returns the float value of the indexed row and column.</p>\n\
<div class=\'codeBlock\'><pre>&lt;BigMatrix&gt;[&lt;int_row&gt;][&lt;int_column&gt;]= &lt;float_value&gt;\n\
</pre></div><p>Sets the float value of the indexed row and column in the matrix.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>invert &lt;BigMatrix&gt;\n\
</pre></div><p>Inverts the matrix in place (the input BigMatrix is modified).</p>\n\
<p>The return value is also the inverted matrix.</p>\n\
<p><strong>Note</strong> that this method only works if this matrix is &quot;square&quot; (if m = n).</p>\n\
<div class=\'codeBlock\'><pre>transpose &lt;BigMatrix&gt;\n\
</pre></div><p>Returns the transpose of <span class=\'code\'>&lt;BigMatrix&gt;</span> (result <span class=\'code\'>BigMatrix\\[i\\]\\[j\\]</span> = <span class=\'code\'>BigMatrix\\[j\\]\\[i\\]</span> ).</p>\n\
<div class=\'codeBlock\'><pre>clear &lt;BigMatrix&gt;\n\
</pre></div><p>Frees all the elements and sets the matrix size to be 0x0</p>\n\
<div class=\'codeBlock\'><pre>setSize &lt;BigMatrix&gt; &lt;rows&gt; &lt;columns&gt;\n\
</pre></div><p>Deletes the current elements and sets the size of the matrix to <span class=\'code\'>&lt;rows&gt;</span> x <span class=\'code\'>&lt;columns&gt;</span>.</p>\n\
<div class=\'codeBlock\'><pre>identity &lt;BigMatrix&gt; -- mapped function\n\
</pre></div><p>If the number of rows and columns are not equal, this method does nothing.</p>\n\
<p>If the number of rows and columns are equal, this method sets the matrix to the identity (diagonal elements = 1, all other elements = 0).</p>\n\
<p>If the parameter is an array of matrices, this function returns the value <span class=\'code\'>OK</span> .</p>\n\
<p>In both cases, the input BigMatrix values are set to the identity.</p>\n\
<p>Note:</p>\n\
<p>A BigMatrix object is a compound object, similar to an array of arrays. All of the BigMatrix methods operate directly on the components of the input BigMatrix. As described in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Reference-Assignment.html\' title=\'\'>Reference Assignment</a>, this can cause complications if a BigMatrix object is referenced by more than one variable. If you assign a new value to an element of the matrix, or use any of the BigMatrix methods, the same object is still referenced by the variables.</p>\n\
<p>This can be seen in the following example:</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` bm1=bigmatrix 2 2 for i=1 to 2 do for j=1 to 2 do bm1[i][j]=random 0 10 bm2=bm1 invert bm1 bm2</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` #BigMatrix( --result of line 1, contents of bm1 [0.00,0.00], [0.00,0.00] ) OK -- result of line 2 #BigMatrix( --result of line 3, contents of bm2 [4.00,6.00], [4.00,9.00] ) #BigMatrix( --result of line 4, contents of bm1 [0.75,-0.50], [-0.33,0.33] ) #BigMatrix( --result of line 5, contents of bm2 [0.75,-0.50], [-0.33,0.33] )</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";