var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Box2 Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Box2 Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"box2-values\"></a></div>\n\
<p>The <strong>Box2</strong> class describes a 2D rectangular region using integer coordinates. The Box2 class provides methods that return individual coordinates of the box, scale and translate it, retrieve its center, modify its size, and determine if points are inside the box. Box2 values are primarily used in the viewport graphics methods described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Viewports/Viewport-Drawing-Methods.html\' title=\'\'>Viewport Drawing Methods</a>.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>Box2 &lt;x_integer&gt; &lt;y_integer&gt; &lt;w_integer&gt; &lt;h_integer&gt;\n\
</pre></div><p>Constructs a Box2 with the upper left corner at <span class=\'code\'>\\[x,y\\]</span> with width <span class=\'code\'>w</span> and height <span class=\'code\'>h</span> .</p>\n\
<p>Note: The y-axis is positive in the <em>down</em> direction.</p>\n\
<div class=\'codeBlock\'><pre>Box2 &lt;upperleft_point2&gt; &lt;lowerRight_point2&gt;\n\
</pre></div><p>Constructs a Box2 object from the specified corners.</p>\n\
<p><strong>Example</strong></p>\n\
<div class=\'codeBlock\'><pre>upperLeft = [0, 0]\n\
width = 60\n\
height = 30\n\
mybox1 = Box2 upperLeft.x upperLeft.y width height\n\
\n\
upperLeft = [0, 0]\n\
lowerRight = [59, 29]\n\
mybox2 = Box2 upperLeft lowerRight \n\
\n\
</pre></div><p>This will result in a box that looks like:</p>\n\
<div class=\'figure\'><img src=\'developer/images/box2.png\' title=\'\'></div>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;Box2&gt;.x: Integer\n\
&lt;Box2&gt;.y: Integer\n\
&lt;Box2&gt;.w: Integer\n\
&lt;Box2&gt;.h: Integer\n\
&lt;Box2&gt;.left: Integer, alias of x property\n\
&lt;Box2&gt;.right: Integer\n\
&lt;Box2&gt;.top: Integer, alias of y property\n\
&lt;Box2&gt;.bottom: Integer\n\
&lt;Box2&gt;.center: Point2, read-only\n\
</pre></div><p>The <span class=\'code\'>right</span> property is calculated as <span class=\'code\'>right = x + w - 1</span> . The <span class=\'code\'>bottom</span> property is calculated as <span class=\'code\'>bottom = y + h - 1</span> . Setting the <span class=\'code\'>right</span> or <span class=\'code\'>bottom</span> property will normally change the <span class=\'code\'>w</span> and <span class=\'code\'>h</span> properties, respectively. However, if <span class=\'code\'>right</span> is set less than <span class=\'code\'>left</span> , the <span class=\'code\'>right</span> and <span class=\'code\'>left</span> values will be swapped, and then the new value will be used as the <span class=\'code\'>left</span> value. Likewise, if <span class=\'code\'>bottom</span> is set less than <span class=\'code\'>top</span> , the <span class=\'code\'>bottom</span> and <span class=\'code\'>top</span> values will be swapped, and then the new value will be used as the <span class=\'code\'>top</span> value.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;Box2&gt; == &lt;Box2&gt;\n\
&lt;Box2&gt; != &lt;Box2&gt;\n\
</pre></div><p>Standard comparison operators. Two Box2 values are equal if all of their component values are equal.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Box2&gt; + (&lt;Box2&gt; | &lt;point2&gt; | &lt;point2 array&gt;)\n\
</pre></div><p>New in *3ds Max 2022**: Expands the Box2 value to include the argument value.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>scale &lt;Box2&gt; &lt;float&gt;\n\
</pre></div><p>Scales the coordinates of the box about the center of the box.</p>\n\
<div class=\'codeBlock\'><pre>translate &lt;Box2&gt; &lt;point2&gt;\n\
</pre></div><p>Translates the coordinates of the box by the distance specified.</p>\n\
<div class=\'codeBlock\'><pre>contains &lt;Box2&gt; &lt;point2&gt;\n\
</pre></div><p>Determines if the point2 value is contained within the Box2. Returns <span class=\'code\'>true</span> if the point is inside the Box2 or on the Box2 edge; otherwise <span class=\'code\'>false</span> .</p>\n\
<div class=\'codeBlock\'><pre>rectify &lt;Box2&gt;\n\
</pre></div><p>Adjusts the coordinates of the box such that <span class=\'code\'>top</span> &lt; <span class=\'code\'>bottom</span> and <span class=\'code\'>left</span> &lt; <span class=\'code\'>right</span> .</p>\n\
<div class=\'codeBlock\'><pre>empty &lt;Box2&gt;\n\
</pre></div><p>Sets the Box2 to a special &quot;empty&quot; value.</p>\n\
<div class=\'codeBlock\'><pre>isEmpty &lt;Box2&gt;\n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the Box2 contains the special &quot;empty&quot; value, <span class=\'code\'>false</span> otherwise.</p>\n\
<div class=\'codeBlock\'><pre>enlargeBy &lt;Box2&gt; &lt;integer&gt;\n\
</pre></div><p><img src=\'developer/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/What-s-New-in-MAXScript-in-3ds.html\' title=\'\'>NEW</a> <strong>in 3ds Max 2022:</strong>: Makes the Box2 larger in each direction by the specified value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;box2&gt; expandToInclude &lt;box2&gt; (&lt;box2&gt; | &lt;point2&gt; | &lt;point2 array&gt;)\n\
</pre></div><p><img src=\'developer/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/What-s-New-in-MAXScript-in-3ds.html\' title=\'\'>NEW</a> <strong>in 3ds Max 2022:</strong>: Expands the Box2 to include the specified value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;bool&gt; intersects &lt;Box2&gt; &lt;Box2&gt;\n\
</pre></div><p>Returns true if the two boxes intersect.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Box2&gt; copy &lt;Box2&gt;\n\
</pre></div><p>Returns a copy of the Box2 value.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";