var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Color Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Color Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"color-values\"></a></div>\n\
<p>All the places that colors turn up in MAXScript (such as, wireColor, light color, and others) are represented by instances of the <strong>Color</strong> class. You can also use <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/Point3-Values.html\' title=\'\'>Point3 values</a> to specify colors.</p>\n\
<p><strong>Literals</strong></p>\n\
<div class=\'codeBlock\'><pre> red green blue white black orange yellow brown gray \n\
</pre></div><p>Predefined <a href=\'#!/url=./developer/MAXScript-Language-Reference/Reserved-Keywords-Symbols/Reserved-Global-Variables.html\' title=\'\'>MAXScript globals</a>.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>color &lt;r&gt; &lt;g&gt; &lt;b&gt; [ &lt;a&gt; ]\n\
</pre></div><p>r,g,b and optional alpha are float values, typically in the range of 0 to 255.</p>\n\
<div class=\'codeBlock\'><pre>&lt;point3&gt; as color\n\
</pre></div><p>Interprets x as r, y as g, z as b. Alpha is assumed opaque (255).</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;color&gt;.red or .r: Float\n\
&lt;color&gt;.green or .g: Float\n\
&lt;color&gt;.blue or .b: Float\n\
&lt;color&gt;.alpha or .a: Float\n\
</pre></div><p>Color component properties</p>\n\
<div class=\'codeBlock\'><pre>&lt;color&gt;.hue or .h: Float\n\
&lt;color&gt;.saturation or .s: Float\n\
&lt;color&gt;.value or .v: Float\n\
</pre></div><p>Derived properties</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;color&gt; == &lt;color&gt;\n\
&lt;color&gt; != &lt;color&gt; \n\
&lt;color&gt; + &lt;color_or_number&gt;\n\
&lt;color&gt; - &lt;color_or_number&gt;\n\
&lt;color&gt; * &lt;color_or_number&gt;\n\
&lt;color&gt; / &lt;color_or_number&gt;\n\
</pre></div><p>Channel-by-channel mathematical operations. Numbers operate on R,G,B and A channels equally.</p>\n\
<div class=\'codeBlock\'><pre>-&lt;color&gt;\n\
</pre></div><p>unary minus</p>\n\
<blockquote>\n\
<p><strong>IMPORTANT NOTES ON COLOR OPERATIONS:</strong></p>\n\
<p>The addition and subtraction operations are performed on the R, G, B and A channels equally:</p>\n\
<p>``` aColor = color 1 1 1 (color111) aColor + aColor (color 2 2 2 510)</p>\n\
<p>```</p>\n\
<p>The high Alpha value is caused by the fact that MAXScript does not print the Alpha value if it is 255, but internally the value of the variable aColor is (color 1 1 1 255). Thus, adding the Alpha channels of 255 to 255 produces an Alpha of 512, analogous to the R,G, and B channels.</p>\n\
<p>While the Color Values allow floating point components, when originally implemented in<strong>3ds Max 2</strong>, it was assumed that they would be used <strong>mainly</strong> for 8 bit per channel RGBA values because MAXScript did not support floating point color bitmaps at that point in time. An internal conversion is performed when printing color values or converting other values to color.</p>\n\
<p>Thus, multiplication of two color values leads to seemingly strange results:</p>\n\
<p>``` aColor = color 1 1 1 aColor * aColor (color 0.00392157 0.00392157 0.00392157) aColor * [1,1,1] (color 0.00392157 0.00392157 0.00392157) aColor = color 128 128 128 aColor * aColor (color 64.251 64.251 64.251)</p>\n\
<p>```</p>\n\
<p>The reason for these results when multiplying color values is that the actual component values are float values normally in the range of 0 to 1.</p>\n\
<p>The scaling from 0-1 to 0-255 is an operation that MAXScript performs to the underlying color value when the value is printed or converted to some other value type.</p>\n\
<p>A gray value of 128 multiplied by a gray value of 128 is not really 128*128 = 16384, which is a blown out white, but</p>\n\
<p>(128/255.0 * 128/255.0)*255 or (.501961*.501961)*255</p>\n\
<p>which is the DARKER shade of gray (color 64.251 64.251 64.251)</p>\n\
<p>So, when (color 1 1 1 255) is converted to components in the range from 0 to 1, it also results in RGB components of (1.0/255*1.0/255)*255=0.00392157, while the Alpha of 255 turns into 1.0 and then back into 255.</p>\n\
<p>Thus, the <strong>Color Value</strong> is <strong>not</strong> well suited for <strong>High Dynamic Range Image</strong> calculations with <strong>floating point color components</strong>.</p>\n\
<p>For that type of operations, MAXScript provides a <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/Point4-Values.html\' title=\'\'>Point4 value</a> that can be used to represent floating point colors without implicit conversion from/to the 0-255 range.</p>\n\
</blockquote>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>copy &lt;color&gt;\n\
</pre></div><p>Creates a new copy of the color value.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` newClr = copy oldClr</p>\n\
<p>```</p>\n\
<p>The new value contains a copy of the input color value, and is independent of the input color value.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>random &lt;from_color&gt; &lt;to_color&gt;\n\
</pre></div><p>Returns a random color between the given colors. The alpha component of the result will always be 255.</p>\n\
<div class=\'codeBlock\'><pre>composite &lt;color1&gt; &lt;color2&gt;\n\
</pre></div><p>Composites <span class=\'code\'>color1</span> over <span class=\'code\'>color2</span> through <span class=\'code\'>color1</span> &#39;s alpha. This function is equivalent to:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` color1 + color2*((255. - color1.alpha)/255.)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"d-noise-functions\"></a><h2 id=\"d-noise-functions\">3D Noise Functions</h2></div>\n\
<div class=\'codeBlock\'><pre>noise3 &lt;color&gt;\n\
noise4 &lt;color&gt; &lt;phase_float&gt;\n\
turbulence &lt;color&gt; &lt;frequency_float&gt;\n\
fractalNoise &lt;color&gt; &lt;H_float&gt; &lt;lacunarity_float&gt; &lt;octaves_float&gt;\n\
</pre></div><p>See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/Point3-Values.html\' title=\'\'>Point3 Values</a> for a description of the noise functions.</p>\n\
<p>Note:</p>\n\
<p>The component values of a Color value (r, g, b, and a) are normally in the range of 0.0 to 255.0. However, values outside this range are permissible. When color values outside the normal range are used in <strong>3ds Max</strong>, <strong>3ds Max</strong> clamps the values to the range of 0.0 to 255.0.</p>\n\
<p>The following script shows the use of various literals, constructors, properties, operators, and methods of the Color class.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` -- color test bed magenta=color 255 255 0 255-- create colors using constructors aqua = [0, 255, 255] as color aqua.v /= 2.-- reduce &quot;strength&quot; of aqua color aqua aqua.alpha=128-- set aqua to 50% opacity aqua lightGray=white/4-- create light gray color by dividing -- each component of white by 4 composite aqua lightGray-- composite light gray over aqua random black white-- generate a random color</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` (color 255 255 0)-- result of line 2. Note that if -- alpha=255 it is not displayed (color 0 255 255)-- result of line 3 127.5-- result of line 4 - value property of aqua (color 0 127.5 127.5)-- result of line 5 - color of aqua 128-- result of line 6 - alpha property of aqua (color 0 127.5 127.5 128)-- result of line 7 - color of aqua (color 63.75 63.75 63.75 63.75)-- result of line 8 - each component divided by 4 (color 31.75 159.25 159.25 159.75)-- result of line 10 (color 249.607 27.8243 140.23)-- result of line 11</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";