var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>EulerAngles Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>EulerAngles Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"eulerangles-values\"></a></div>\n\
<p>The <strong>EulerAngles</strong> class provides a representation for orientation in 3D space using rotation angles in degrees about each axis.</p>\n\
<p>Angles can be greater than 360 and so specify multiple revolutions.</p>\n\
<p>Rotations follow the right-hand-rule.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>eulerAngles &lt;x_degrees&gt; &lt;y_degrees&gt; &lt;z_degrees&gt;\n\
&lt;quat&gt; as eulerAngles\n\
&lt;angleAxis&gt; as eulerAngles\n\
&lt;matrix3&gt; as eulerAngles\n\
</pre></div><p>Extracts the rotation component as eulerAngles.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;eulerAngles&gt; == &lt;eulerAngles&gt;\n\
&lt;eulerAngles&gt; != &lt;eulerAngles&gt;\n\
&lt;eulerAngles&gt; as &lt;class&gt;\n\
</pre></div><p>eulerAngles can convert to Matrix3, Quat, angleAxis values.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;eulerAngles&gt;.x: Float\n\
&lt;eulerAngles&gt;.y: Float\n\
&lt;eulerAngles&gt;.z: Float\n\
</pre></div><p>Rotation about each primary axis in float degrees.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>copy &lt;eulerAngles&gt;\n\
</pre></div><p>Creates a new copy of the eulerAngles value.</p>\n\
<p>The new value contains a copy of the input eulerAngles value and is independent of the input eulerAngles value.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>newEulerAngles = copy oldEulerAngles</span></p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>random &lt;eulerAngles&gt; &lt;eulerAngles&gt;\n\
</pre></div><p>Random rotation between the eulerAngles, but uses quat Slerp, so loses multiple revolution angles.</p>\n\
<div class=\'codeBlock\'><pre>quatToEuler &lt;quat&gt; order:&lt;eulertype_integer&gt;\n\
eulerToQuat &lt;eulerAngle&gt; order:&lt;eulertype_integer&gt;\n\
</pre></div><p>Convert between quat and euler angle values. The optional order parameter specifies the order of application of the angles. If not specified, XYZ ordering is used. Its value can be any of the following:</p>\n\
<div class=\'codeBlock\'><pre>1 - XYZ\n\
2 - XZY\n\
3 - YZX\n\
4 - YXZ\n\
5 - ZXY\n\
6 - ZYX\n\
7 - XYX\n\
8 - YZY\n\
9 - ZXZ\n\
\n\
quatToEuler2 &lt;quat&gt;\n\
</pre></div><p>Returns the same Euler value for the given Quaternion as shown in the Transform Type-In dialog.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>.</p>\n\
<p>Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>quatArrayToEulerArray &lt;quat array&gt;\n\
</pre></div><p>Returns an array of smooth Euler values from the Quat array.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>.</p>\n\
<p>Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<p>When converting a series of quat values to eulerAngle values, it is possible for sign flips to occur in the eulerAngle values. This is due to the fact that one single quat value can be expressed through many different eulerAngle values. This flip can be detected based on the eulerAngles/quat ratio. The eulerAngles/quat ratio is the angle difference in eulerAngles space to the angle difference in quat space. If this ratio is bigger than PI the rotation between the two quat to eulerAngles conversions. This method returns the eulerAngles/quat angle ratio between the two quat to eulerAngles conversions as a float value. The actual detection of the flip is dependent on the amount of rotation in between conversions. The smaller the amount of rotation, the more accurate the detection.</p>\n\
<p>Note that the following methods were broken in versions prior to <strong>3ds Max 2012</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;GetEulerQuatAngleRatio &lt;quat1&gt; &lt;quat2&gt; &lt;array1&gt; &lt;array2&gt; \n\
&lt;float&gt;GetEulerQuatAngleRatio &lt;quat1&gt; &lt;quat2&gt; &lt;eulerAngle1&gt; &lt;eulerAngle2&gt; \n\
&lt;float&gt;GetEulerQuatAngleRatio &lt;quat1&gt; &lt;quat2&gt; &amp;&lt;var1&gt; &amp;&lt;var2&gt;  \n\
</pre></div><p>The function returns the eulerAngles/Quat ratio as a Float.</p>\n\
<p>First two arguments are quats used as inputs. The first quat is the previous rotation, the second quat is the current rotation.</p>\n\
<p>The third and fourth arguments are the previous and current converted rotation angles. They will be used as outputs.</p>\n\
<p>In the first signature, the resulting Euler Angle .x, .y, and .z components are stored in the array elements 1, 2, and 3.</p>\n\
<p>In the second signature, the passed arguments <span class=\'code\'>&lt;eulerAngle1&gt;</span> and <span class=\'code\'>&lt;eulerAngle2&gt;</span> are modified to the converted values.</p>\n\
<p>In the third signature, the EulerAngles passed as argument 3 and 4 are written back by-reference.</p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;GetEulerMatAngleRatio &lt;mat1&gt; &lt;mat2&gt; &lt;array1&gt; &lt;array2&gt;\n\
&lt;float&gt;GetEulerMatAngleRatio &lt;mat1&gt; &lt;mat1&gt; &lt;eulerAngle1&gt; &lt;eulerAngle2&gt;  \n\
&lt;float&gt;GetEulerMatAngleRatio &lt;mat1&gt; &lt;mat1&gt; &amp;&lt;var1&gt; &amp;&lt;var2&gt;\n\
</pre></div><p>This method parallels the <span class=\'code\'>getEulerQuatAngleRatio()</span> method, but uses matrix3 values rather than Quat values as inputs.</p>\n\
<p>The first two arguments are matrix3 inputs describing the previous and current orientations.</p>\n\
<p>The third and fourth arguments are the converted previous and current Euler Angles.</p>\n\
<p>In the first signature, the .x, .y, and .z components are stored in the first, second, and third elements of the arrays.</p>\n\
<p>In the second signature, the output Euler Angles are stored in the passed <span class=\'code\'>&lt;eulerAngle1&gt;</span> and <span class=\'code\'>&lt;eulerAngle2&gt;</span> by modifying them.</p>\n\
<p>In the third signature, the eulerAngles are written back to the third and fourth by-reference arguments.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` q1 = (quat 0.412759 0.00141638 -0.113167 0.903782) q2 = (quat -0.150577 -0.378993 0.176638 0.895818) a1 = #(0,0,0) a2 = #(0,0,0) getEulerQuatAngleRatio q1 q2 a1 a2 --&gt;0.583444 a1;a2 --&gt;#(-48.5478, 5.21315, 11.922) --&gt;#(11.509, 47.0722, -17.2825)</p>\n\
<p>a1 = #() a2 = #() getEulerQuatAngleRatio q1 q2 a1 a2 --&gt;0.583444 a1;a2 --&gt;#(-48.5478, 5.21315, 11.922) --&gt;#(11.509, 47.0722, -17.2825)</p>\n\
<p>a1 = eulerAngles 0 0 0 a2 = eulerAngles 0 0 0 getEulerQuatAngleRatio q1 q2 a1 a2 --&gt;0.583444 a1;a2 --&gt;(eulerAngles -48.5478 5.21315 11.922) --&gt;(eulerAngles 11.509 47.0722 -17.2825)</p>\n\
<p>getEulerQuatAngleRatio q1 q2 &amp;r1 &amp;r2 --&gt;0.583444 r1;r2 --&gt;(eulerAngles -48.5478 5.21315 11.922) --&gt;(eulerAngles 11.509 47.0722 -17.2825)</p>\n\
<p>m1 = (quat 0.412759 0.00141638 -0.113167 0.903782) as matrix3 m2 = (quat -0.150577 -0.378993 0.176638 0.895818) as matrix3 a1 = #(0,0,0) a2 = #(0,0,0) GetEulerMatAngleRatio m1 m2 a1 a2 --&gt;0.583444 a1;a2 --&gt;#(-48.5478, 5.21315, 11.922) --&gt;#(11.509, 47.0722, -17.2825)</p>\n\
<p>a1 = #() a2 = #() GetEulerMatAngleRatio m1 m2 a1 a2 --&gt;0.583444 a1;a2 --&gt;#(-48.5478, 5.21315, 11.922) --&gt;#(11.509, 47.0722, -17.2825)</p>\n\
<p>a1 = eulerAngles 0 0 0 a2 = eulerAngles 0 0 0 GetEulerMatAngleRatio m1 m2 a1 a2 --&gt;0.583444 a1;a2 --&gt;(eulerAngles -48.5478 5.21315 11.922) --&gt;(eulerAngles 11.509 47.0722 -17.2825)</p>\n\
<p>GetEulerMatAngleRatio m1 m2 &amp;r3 &amp;r4 --&gt;0.583444 r3;r4 --&gt;(eulerAngles -48.5478 5.21315 11.922) --&gt;(eulerAngles 11.509 47.0722 -17.2825)</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";