var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Matrix3 Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Matrix3 Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"matrix3-values\"></a></div>\n\
<p>The <strong>Matrix3</strong> class implements a 4x3 3D transformation matrix object.</p>\n\
<p>The transform matrix is a 3D homogeneous matrix typically used to hold object coordinate systems and transformations.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>matrix3 &lt;row1_point3&gt; &lt;row2_point3&gt; &lt;row3_point3&gt; &lt;row4_point3&gt;\n\
</pre></div><p>Constructs a matrix from four row vectors.</p>\n\
<div class=\'codeBlock\'><pre>matrix3 0\n\
</pre></div><p>Constructs a zero matrix: <span class=\'code\'>(matrix3 \\[0,0,0\\] \\[0,0,0\\] \\[0,0,0\\] \\[0,0,0\\])</span></p>\n\
<div class=\'codeBlock\'><pre>matrix3 1\n\
</pre></div><p>Constructs an identity matrix: <span class=\'code\'>(matrix3 \\[1,0,0\\] \\[0,1,0\\] \\[0,0,1\\] \\[0,0,0\\])</span></p>\n\
<div class=\'codeBlock\'><pre>&lt;quat&gt; as matrix3\n\
&lt;angleaxis&gt; as matrix3\n\
&lt;eulerangles&gt; as matrix3 \n\
</pre></div><p>Construct and return rotation matrices from arbitrary rotation values.</p>\n\
<div class=\'codeBlock\'><pre>rotateXMatrix &lt;number&gt; -- all angles in degrees rotateYMatrix &lt;number&gt;\n\
rotateZMatrix &lt;number&gt;\n\
</pre></div><p>Construct and return rotation matrices relatively to major world axes.</p>\n\
<div class=\'codeBlock\'><pre>transMatrix &lt;point3&gt;\n\
</pre></div><p>Constructs and returns a translation matrix.</p>\n\
<div class=\'codeBlock\'><pre>scaleMatrix &lt;point3&gt;\n\
</pre></div><p>Constructs and returns a scale matrix.</p>\n\
<div class=\'codeBlock\'><pre>rotateYPRMatrix &lt;yaw_number&gt; &lt;pitch_number&gt; &lt;roll_number&gt;\n\
</pre></div><p>Constructs and returns a Matrix3 value for use as a rotation transformation by specifying yaw, pitch and roll angles. All angles are in degrees.</p>\n\
<div class=\'codeBlock\'><pre>matrixFromNormal &lt;point3&gt;\n\
</pre></div><p>Constructs and returns a Matrix3 value with the normal specified by the given point as the Z axis. The translation portion of the Matrix3 value will be [0,0,0]. The components of the scale portion are the inverse of the values required to normalize the <span class=\'code\'>point3</span> value.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` MatrixFromNormal [0,0,1] MatrixFromNormal [0,1,1]</p>\n\
<p>```</p>\n\
<p>will return</p>\n\
<p>``` (matrix3 [1,0,0], [0,1,0], [0,0,1], [0,0,0]) (matrix3 [0,-0.707107,0.707107] [1.41421,0,0] [0,1,1] [0,0,0])</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;matrix3&gt; + &lt;matrix3&gt;\n\
&lt;matrix3&gt; - &lt;matrix3&gt;\n\
&lt;matrix3&gt; * &lt;matrix3&gt;\n\
&lt;matrix3&gt; as &lt;class&gt;\n\
</pre></div><p>Matrix3 can convert to Quat, AngleAxis, EulerAngle using the matrix&#39;s rotation component</p>\n\
<div class=\'codeBlock\'><pre>&lt;matrix3&gt;[&lt;integer&gt;]\n\
</pre></div><p>Returns a row of the Matrix3 as a Point3. Valid range on this index is 1 to 4.</p>\n\
<div class=\'codeBlock\'><pre>&lt;matrix3&gt;[&lt;integer&gt;] = &lt;Point3&gt;\n\
</pre></div><p>Sets a row of the Matrix3 to the Point3. Valid range on the index is 1 to 4.</p>\n\
<div class=\'codeBlock\'><pre>&lt;matrix3&gt; == &lt;matrxi3&gt;\n\
&lt;matrix3&gt; != &lt;matrix3&gt;\n\
</pre></div><p>Available in <strong>3ds Max 2018 and higher</strong>: Standard comparisons.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;matrix3&gt;.row1: Point3\n\
&lt;matrix3&gt;.row2: Point3\n\
&lt;matrix3&gt;.row3: Point3\n\
&lt;matrix3&gt;.row4: Point3\n\
&lt;matrix3&gt;.translation: Point3\n\
</pre></div><p>read/write access to rows. Row4 is the translation.</p>\n\
<p>Note:</p>\n\
<p>When working with object transformation matrix3 values, the rows and their sub-elements cannot be modified directly. To change a row or an element of the row, assign the matrix3 value to a user variable first, modify the matrix3 rows by assigning to the variable and then assign the variable back to the <span class=\'code\'>.transform</span> property of the original object.</p>\n\
<p><strong>DOES NOTHING:</strong></p>\n\
<div class=\'codeBlock\'><pre>$Teapot01.transform.row4 = [10.0,20.0,30.0]\n\
\n\
</pre></div><p><strong>WORKS:</strong></p>\n\
<div class=\'codeBlock\'><pre>myTransform = $Teapot01.transform\n\
myTransform.row4 = [10.0,20.0,30.0]\n\
$Teapot01.transform = myTransform\n\
\n\
&lt;matrix3&gt;.rotationpart: Quat, read-only\n\
&lt;matrix3&gt;.translationpart: Point3, read-only\n\
&lt;matrix3&gt;.scalerotationpart: Quat, read-only\n\
&lt;matrix3&gt;.scalepart: Point3, read-only\n\
</pre></div><p>Access to various transforms, with the remaining transforms zero-ed out.</p>\n\
<div class=\'codeBlock\'><pre>&lt;matrix3&gt;.determinantsign: Integer, read-only\n\
</pre></div><p>Returns the sign of the matrix&#39; determinant.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>copy &lt;matrix3&gt;\n\
</pre></div><p>Creates a new copy of the matrix3 value.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` newMatrix3 = copy oldMatrix3</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The new value contains a copy of the input matrix3 value, and is independent of the input matrix3 value.</p>\n\
<p>Using the <a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Simple-Expressions/Comparison-Expressions.html\' title=\'\'>equality comparison expression</a> on the original and the copy values will always return false.</p>\n\
<p>To correctly compare two matrix3 values for equality, their four components have to be compared individually, the two values could be converted to strings and compared as strings instead, or the one matrix3 value could be multiplied by the inverse of the other and tested for identity:</p>\n\
<blockquote>\n\
<p><strong>MATRIX COMPARISON EXAMPLE:</strong></p>\n\
<p>``` a = matrix3 1 --create an identity matrix (matrix3 [1,0,0] [0,1,0] [0,0,1] [0,0,0]) b = copy a --copy the value of a into variable b (matrix3 [1,0,0] [0,1,0] [0,0,1] [0,0,0]) a == b --compare a and b - although their values are equal, result is false false</p>\n\
<p>--This is because the equality test of compound values like Matrix3 and Array --is testing to see whether the two variables point at the same memory address --and does not perform a per-component equality test. --Thus: c = a (matrix3 [1,0,0] [0,1,0] [0,0,1] [0,0,0]) a == c --compare a and c - both point at the same memory and are considered equal: true</p>\n\
<p>--To compare a and b, we can either convert both to strings and compare them: a as string == b as string true</p>\n\
<p>--or we can test their components in pairs, a.row1 == b.row1 AND a.row2 == b.row2 AND a.row3 == b.row3 AND a.row4 == b.row4 true</p>\n\
<p>--or we can multiply a with the inverse of b and test if the result is the identity matrix: isIdentity (a * inverse b) true</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>isIdentity &lt;matrix3&gt;\n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the matrix is equal to the identity matrix.</p>\n\
<div class=\'codeBlock\'><pre>inverse &lt;matrix3&gt;\n\
</pre></div><p>Returns the inverse of the matrix.</p>\n\
<div class=\'codeBlock\'><pre>inverseHighPrecision &lt;matrix3&gt;\n\
</pre></div><p>Returns the inverse of the matrix, using doubles for the intermediary results.</p>\n\
<div class=\'codeBlock\'><pre>xformMat &lt;transform_matrix3&gt; &lt;space_matrix3&gt;\n\
</pre></div><p>Returns the transform matrix transformed into a particular space. For example, say you have a rotation you want to apply, but you want to perform the rotation in another coordinate system. To do this, you typically transform into the space of the coordinate system, then apply the transformation, and then transform out of that coordinate system. This method transforms matrix <span class=\'code\'>&lt;transform_matrix3&gt;</span> into the space of matrix <span class=\'code\'>&lt;space_matrix3&gt;</span>. The resulting matrix3 value is calculated as <span class=\'code\'>space_matrix3 * transform_matrix3 * inverse(space_matrix3)</span>.</p>\n\
<div class=\'codeBlock\'><pre>identity &lt;matrix3&gt; -- mapped function\n\
</pre></div><p>Sets the input matrix or matrices to the identity matrix. If the parameter is a single matrix, this function returns an identity matrix. If the parameter is an array of matrices, this function returns the value <span class=\'code\'>OK</span> . In both cases, the input matrix3 values are replaced with the identity matrix.</p>\n\
<div class=\'codeBlock\'><pre>zero &lt;matrix3&gt; -- mapped function\n\
</pre></div><p>Sets the input matrix or matrices to the zero matrix. If the parameter is a single matrix, this function returns a zero matrix. If the parameter is an array of matrices, this function returns the value <span class=\'code\'>OK</span> . In both cases, the input matrix3 values are replaced with the zero matrix.</p>\n\
<div class=\'codeBlock\'><pre>orthogonalize &lt;matrix3&gt; -- mapped function\n\
</pre></div><p>Sets the input matrix or matrices to the an &quot;unbiased&quot; orthogonalization of the matrix. An orthogonal matrix has an axis system where each axis is 90 degrees from the others (it&#39;s not skewed). If the parameter is a single matrix, this function returns the orthogonalized matrix. If the parameter is an array of matrices, this function returns the value <span class=\'code\'>OK</span> . In both cases, the input matrix3 value(s) are replaced with the orthogonalized matrix value(s).</p>\n\
<div class=\'codeBlock\'><pre>translate &lt;matrix3&gt; &lt;point3&gt; --mapped function\n\
</pre></div><p>Applies an incremental translation transformation to the input matrix or matrices. This is equivalent to multiplying on the RIGHT by the transform. If the matrix3 parameter is a single matrix, this function returns the transformed matrix. If the parameter is an array of matrices, this function returns the value <span class=\'code\'>OK</span> . In both cases, the input matrix3 value(s) are replaced with the transformed matrix value(s).</p>\n\
<div class=\'codeBlock\'><pre>-- all angles in degrees\n\
--mapped functions\n\
rotateX &lt;matrix3&gt; &lt;number&gt;  \n\
rotateY &lt;matrix3&gt; &lt;number&gt;\n\
rotateZ &lt;matrix3&gt; &lt;number&gt;\n\
rotate &lt;matrix3&gt; &lt;quat&gt;\n\
</pre></div><p>Applies an incremental rotation transformation to the input matrix or matrices. This is equivalent to multiplying on the RIGHT by the transform. If the matrix3 parameter is a single matrix, this function returns the transformed matrix. If the parameter is an array of matrices, this function returns the value <span class=\'code\'>OK</span> . In both cases, the input matrix3 value(s) are replaced with the transformed matrix value(s).</p>\n\
<div class=\'codeBlock\'><pre>scale &lt;matrix3&gt; &lt;point3&gt; [ &lt;boolean&gt; ] -- mapped function\n\
</pre></div><p>Applies an incremental scale transformation to the input matrix or matrices. This is equivalent to multiplying on the RIGHT by the transform. If <span class=\'code\'>&lt;boolean&gt;</span> is <span class=\'code\'>true</span> , the translation component is scaled. If <span class=\'code\'>&lt;boolean&gt;</span> is <span class=\'code\'>false</span> the translation component is unaffected. When <strong>3ds Max</strong> was originally written there was a bug in the code for this method where the translation portion of the matrix was not being scaled. This meant that when a matrix was scaled the bottom row was not scaled. Thus it would always scale about the local origin of the object, but it would scale the world axes. When this bug was discovered, dependencies existed in the code upon this bug. Thus it could not simply be fixed because it would break the existing code that depended upon it working the incorrect way. To correct this boolean parameter was added. If it is set to <span class=\'code\'>true</span> , the translation component will be scaled correctly. If not specified, the boolean defaults to <span class=\'code\'>false</span> , and the code behaves the old way. If the matrix3 parameter is a single matrix, this function returns the transformed matrix. If the parameter is an array of matrices, this function returns the value <span class=\'code\'>OK</span> . In both cases, the input matrix3 value(s) are replaced with the transformed matrix value(s).</p>\n\
<div class=\'codeBlock\'><pre>preTranslate &lt;matrix3&gt; &lt;point3&gt; -- mapped function\n\
</pre></div><p>Applies an incremental translation transformation to the input matrix or matrices. This is equivalent to multiplying on the LEFT by the transform. If the matrix3 parameter is a single matrix, this function returns the transformed matrix. If the parameter is an array of matrices, this function returns the value <span class=\'code\'>OK</span> . In both cases, the input matrix3 value(s) are replaced with the transformed matrix value(s).</p>\n\
<div class=\'codeBlock\'><pre>-- all angles in degrees\n\
-- mapped functions \n\
preRotateX&lt;matrix3&gt; &lt;number&gt;\n\
preRotateY&lt;matrix3&gt; &lt;number&gt;\n\
preRotateZ&lt;matrix3&gt; &lt;number&gt;\n\
preRotate&lt;matrix3&gt; &lt;quat&gt;\n\
</pre></div><p>Applies an incremental rotation transformation to the input matrix or matrices. This is equivalent to multiplying on the LEFT by the transform. If the matrix3 parameter is a single matrix, this function returns the transformed matrix. If the parameter is an array of matrices, this function returns the value <span class=\'code\'>OK</span> . In both cases, the input matrix3 value(s) are replaced with the transformed matrix value(s).</p>\n\
<div class=\'codeBlock\'><pre>preScale &lt;matrix3&gt; &lt;point3&gt; [ &lt;boolean&gt; ] -- mapped function\n\
</pre></div><p>Applies an incremental scale transformation to the input matrix or matrices. This is equivalent to multiplying on the LEFT by the transform. If <span class=\'code\'>&lt;boolean&gt;</span> is <span class=\'code\'>true</span> , the translation component is scaled. If <span class=\'code\'>&lt;boolean&gt;</span> is <span class=\'code\'>false</span> the translation component is unaffected. If not specified, the boolean defaults to <span class=\'code\'>false</span> . If the matrix3 parameter is a single matrix, this function returns the transformed matrix. If the parameter is an array of matrices, this function returns the value <span class=\'code\'>OK</span> . In both cases, the input matrix3 value(s) are replaced with the transformed matrix value(s).</p>\n\
<p><strong>Related Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;GetEulerMatAngleRatio &lt;mat1&gt; &lt;mat2&gt; &lt;array1&gt; &lt;array2&gt;\n\
&lt;float&gt;GetEulerMatAngleRatio &lt;mat1&gt; &lt;mat1&gt; &lt;eulerAngle1&gt; &lt;eulerAngle2&gt;  \n\
&lt;float&gt;GetEulerMatAngleRatio &lt;mat1&gt; &lt;mat1&gt; &amp;&lt;var1&gt; &amp;&lt;var2&gt;\n\
</pre></div><p>See topic <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/GUID-87BB6468-79E2-4FA2-9BAB-42E427219C4F.html\' title=\'\'>EulerAngles Values</a> for details.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";