var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Point3 Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Point3 Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"point3-values\"></a></div>\n\
<p>The <strong>Point3</strong> class defines the characteristics of points in 3D space. These values are also known as vectors and contain three component floating point numbers. All the coordinates passed to and from <strong>3ds Max</strong> are in these values. See also <a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Literal-Constants/2D-and-3D-Point-Literals.html\' title=\'\'>2D and 3D Point Literals</a>.</p>\n\
<p><strong>Literals</strong></p>\n\
<div class=\'codeBlock\'><pre>[&lt;expr&gt;, &lt;expr&gt;, &lt;expr&gt;]\n\
<blockquote>\n\
</blockquote></pre></div><p><strong>EXAMPLES</strong></p>\n\
<p>``` [x, y, z][10, 10, 10] [sin x, cos y, tan z] x_axis --equivalent to [1,0,0] y_axis --equivalent to [0,1,0] z_axis --equivalent to [0,0,1]</p>\n\
<p>```</p>\n\
\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>point3 &lt;x&gt; &lt;y&gt; &lt;z&gt; \n\
&lt;color&gt; as point3 \n\
</pre></div><p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;point3&gt;.x: Float -- the x coordinate\n\
&lt;point3&gt;.y: Float -- the y coordinate\n\
&lt;point3&gt;.z: Float -- the z coordinate\n\
</pre></div><p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;point3&gt; == &lt;point3&gt;\n\
&lt;point3&gt; != &lt;point3&gt;\n\
&lt;point3&gt; + &lt;point3_or_number&gt;\n\
&lt;point3&gt; - &lt;point3_or_number&gt;\n\
&lt;point3&gt; * &lt;point3_or_number&gt;\n\
&lt;point3&gt; / &lt;point3_or_number&gt;\n\
</pre></div><p>Standard vector arithmetic. If the second operand is a number, the operation is performed on each component of the value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;point3&gt; * &lt;matrix3&gt;\n\
\n\
</pre></div><p>Transforms <span class=\'code\'>point3</span> into the coordinate system specified by <span class=\'code\'>matrix3</span> .</p>\n\
<div class=\'codeBlock\'><pre>&lt;point3&gt; * &lt;quat&gt;\n\
</pre></div><p>Rotates <span class=\'code\'>point3</span>.</p>\n\
<div class=\'codeBlock\'><pre>- &lt;point3&gt;\n\
</pre></div><p>Unary minus.</p>\n\
<div class=\'codeBlock\'><pre>&lt;point3&gt;[&lt;integer&gt;]\n\
</pre></div><p>Returns a component of the Point3 as a float. Valid range on the index is 1 to 3.</p>\n\
<div class=\'codeBlock\'><pre>&lt;point3&gt;[&lt;integer&gt;] = &lt;float&gt;\n\
</pre></div><p>Sets a component of the Point3 to the float. Valid range on the index is 1 to 3.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>copy &lt;point3&gt;\n\
</pre></div><p>Creates a new copy of the point3 value.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` newPos = copy oldPos</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The new value contains a copy of the input point3 value and is independent of the input point3 value.</p>\n\
<div class=\'section\'><a id=\"vector-length\"></a><h2 id=\"vector-length\">Vector Length</h2></div>\n\
<div class=\'codeBlock\'><pre>length &lt;point3&gt;\n\
</pre></div><p>Returns the length of the vector.</p>\n\
<div class=\'section\'><a id=\"vector-dot-product\"></a><h2 id=\"vector-dot-product\">Vector Dot Product</h2></div>\n\
<div class=\'codeBlock\'><pre>dot &lt;point3&gt; &lt;point3&gt;\n\
</pre></div><p>Returns the vector dot product.</p>\n\
<p>The geometric interpretation of the dot product is the length of the projection of the first vector onto the unit vector of the second vector. Obviously, when the two vectors are perpendicular, the dot product is 0.0.</p>\n\
<p>The dot product is <strong>commutative</strong>, which means that <strong>dot X Y == dot Y X</strong>.</p>\n\
<p>The dot product is <strong>associative</strong>, which means that <strong>dot (r*X) Y == r*(dot X Y)</strong>.</p>\n\
<p>The dot product is <strong>distributive</strong>, which means that <strong>dot X (Y+Z) == (dot X Y) + (dot X Z)</strong>.</p>\n\
<p>Because the dot product of two normal vectors is the cosine of the angle between them, the dot product can be used conveniently <strong>to calculate the angle</strong> between two vectors:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` fn GetVectorsAngle v1 v2 = ( theAngle = acos(dot (normalize v1) (normalize v2)) )</p>\n\
<p>```</p>\n\
<p>``` GetVectorsAngle [10,0,0] [10,20,0] 63.435</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"vector-cross-product\"></a><h2 id=\"vector-cross-product\">Vector Cross Product</h2></div>\n\
<div class=\'codeBlock\'><pre>cross &lt;point3&gt; &lt;point3&gt;\n\
</pre></div><p>Returns the vector cross product.</p>\n\
<p>The cross product is a third vector which is always perpendicular to the plane defined by the two vectors with orientation determined by the right-hand rule.</p>\n\
<p>The cross product can be expressed as the length of the first vector multiplied by the length of the second vector, multiplied by the sine of the angle between the two vectors. Because of this, the <strong>cross product of parallel vectors</strong> is 0.0 (because sin 0.0 == 0.0).</p>\n\
<p>The cross product is also equal to the Area of the parallelogram formed by the two vectors. If the two vectors are edges of a face, the cross product is the normal vector to that face (a vector perpendicular to the face) with length equal to the Area of the face multiplied by 2.</p>\n\
<p>The cross product is <strong>anticommutative</strong>, which means that <strong>cross X Y == cross -Y X</strong>.</p>\n\
<p>The cross product is <strong>associative</strong>, which means that <strong>cross (r*X) Y == r*(cross X Y)</strong>.</p>\n\
<p>The cross product is <strong>distributive</strong>, which means that <strong>cross X (Y+Z) == (cross X Y) + (cross X Z)</strong>.</p>\n\
<blockquote>\n\
<p><strong>SEE EXAMPLE IN THE MAXSCRIPT FAQ:</strong></p>\n\
<p><a href=\'#!/url=./developer/Frequently-Asked-Questions/Practical-Questions/Working-with-Editable-Meshes/How-do-I-align-the-UVW_Modifier.html\' title=\'\'>How do I align the UVW_Modifier&#39;s Gizmo to a selected face?</a></p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"normalize-vector\"></a><h2 id=\"normalize-vector\">Normalize Vector</h2></div>\n\
<div class=\'codeBlock\'><pre>normalize &lt;point3&gt;\n\
</pre></div><p>Returns the <span class=\'code\'>point3</span> value normalized such that the vector length equals 1.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` b =[100,30.5,41.3]--take somePoint3 value [100,30.5,41.3] normalB1 =normalize b--getthe normalized vector [0.889603,0.271329,0.367406] length normalB1-- check the length, should be 1.0 1.0-- It is! normalB2 =b / (length b)-- Do-It-Yourself Normalize... [0.889603,0.271329,0.367406]-- same value length normalB2-- of course, the length is also 1.0 1.0</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"distance-between-two-points-vectors\"></a><h2 id=\"distance-between-two-points-vectors\">Distance Between Two Points / Vectors</h2></div>\n\
<div class=\'codeBlock\'><pre>distance &lt;point3&gt; &lt;point3&gt;\n\
</pre></div><p>Returns the distance between the points, equivalent to the length of (point 2 - point 1).</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` a = [10,20,30] b = [100,30.5,41.3] distance a b-- returns 91.3123 distance b a-- returns 91.3123 length (b-a)-- returns 91.3123 length (a-b)-- returns 91.3123</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"pseudo-random-point-vector\"></a><h2 id=\"pseudo-random-point-vector\">Pseudo-Random Point / Vector</h2></div>\n\
<div class=\'codeBlock\'><pre>random &lt;point3&gt; &lt;point3&gt;\n\
</pre></div><p>Generates a pseudo-random point between the given points. If point A and point B are seen as the corners of a world-oriented bounding box, the random points will not reside on the vector B-A, but will fill in the volume of the bounding box.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` a = [-10,-20,-30]-- define point A b = [20,30,50]-- define point B p1 = Point pos:a-- create a Point Helper at point A p2 = Point pos:b-- create a Point Helper at point B -- create 2000 spheres at random positions between point A and B for i = 1 to 2000 do sphere pos:(random a b) radius:2 wirecolor:blue</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"arbitrary-axis-matrix\"></a><h2 id=\"arbitrary-axis-matrix\">Arbitrary Axis Matrix</h2></div>\n\
<div class=\'codeBlock\'><pre>arbAxis &lt;point3&gt;\n\
</pre></div><p>Returns a Matrix3 value representing an arbitrary axis system using <span class=\'code\'>point3</span> as the &quot;up&quot; direction.</p>\n\
<div class=\'section\'><a id=\"matrix-from-normal\"></a><h2 id=\"matrix-from-normal\">Matrix From Normal</h2></div>\n\
<div class=\'codeBlock\'><pre>matrixFromNormal &lt;point3&gt;\n\
</pre></div><p>Returns a Matrix3 value with the normal specified by the given point as the Z axis. The translation portion of the Matrix3 value will be [0,0,0]. The components of the scale portion are the inverse of the values required to normalize the <span class=\'code\'>point3</span> value.</p>\n\
<p>See <a href=\'#!/url=./developer/Frequently-Asked-Questions/Practical-Questions/Working-with-Editable-Meshes/How-do-I-Get-the-Local-Rotation.html\' title=\'\'>How Do I Get the Local Rotation of a Face?</a> for an example.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` MatrixFromNormal [0,0,1] MatrixFromNormal [0,1,1]</p>\n\
<p>```</p>\n\
<p>will return</p>\n\
<p>``` (matrix3 [1,0,0], [0,1,0], [0,0,1], [0,0,0]) (matrix3 [0,-0.707107,0.707107] [1.41421,0,0] [0,1,1] [0,0,0])</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"d-noise-functions\"></a><h2 id=\"d-noise-functions\">3D Noise Functions</h2></div>\n\
<div class=\'codeBlock\'><pre>noise3 &lt;point3&gt;\n\
</pre></div><p>A floating point noise function over 3D space implemented by a pseudo-random tricubic spline. The return value is in the range -1.0 to +1.0. Given the same <span class=\'code\'>point3</span> value, the <span class=\'code\'>noise3()</span> function always returns the same value.</p>\n\
<div class=\'codeBlock\'><pre>noise4 &lt;point3&gt; &lt;phase_float&gt;\n\
</pre></div><p>The same function as noise3 in which the phase can be varied using the second parameter. The return value is in the range -1.0 to +1.0.</p>\n\
<div class=\'codeBlock\'><pre>turbulence &lt;point3&gt; &lt;frequency_float&gt;\n\
\n\
</pre></div><p>This is a simple fractal-loop turbulence built on top of the noise3 function. The second parameter controls the frequency of the turbulence. The return value is in the range 0.0 to +1.0.</p>\n\
<div class=\'codeBlock\'><pre>fractalNoise &lt;point3&gt; &lt;H_float&gt; &lt;lacunarity_float&gt; &lt;octaves_float&gt;\n\
</pre></div><p>This is a fractal function of 3D space implemented using fractional Brownian motion. The function is homogeneous and isotropic. It returns a float.</p>\n\
<p>The parameters are as follows:</p>\n\
<p><span class=\'code\'>point3</span> - The point in space at which the noise is computed.</p>\n\
<p><span class=\'code\'>H_float</span> - The fractal increment parameter in the range [0,1]. When <span class=\'code\'>H_float</span> is 1 the function is relatively smooth; as <span class=\'code\'>H_float</span> goes to 0, the function approaches white noise.</p>\n\
<p><span class=\'code\'>lacunarity_float</span> - The gap between successive frequencies, best set at 2.0.</p>\n\
<p><span class=\'code\'>octaves_float</span> - The number of frequencies in the function.</p>\n\
<p>All the noise functions are based on code and algorithms in the book &quot;Texturing and Modeling: A Procedural Approach&quot;, Musgrave, Peachey, Perlin and Worley. Academic Press, ISBN: 0-12-228760-6.</p>\n\
<p>The following script shows the use of various literals, constructors, properties, operators, and methods of the Point3 class.</p>\n\
<p>The following script was written as a test bed for the noise functions. This script displays a two dimensional slice of the noise function output as a bitmap. By changing the noise parameters in lines 4 through 10 and specifying which noise function to evaluate in line 12, you can see the effects of changes in the parameters and use of different noise functions.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` -- noise functions test bed b_width=320-- specify size of bitmap b_height=320 size=10.-- total distance covered by each row and column z=0.-- z coordinate of 2D slice phase=0.5-- noise4 parameter frequency=10.-- turbulence parameter fract_interval=.5-- fractalNoise parameters lacunarity=2. octaves=5 -- whichfunc=1-- 1 = noise3; 2 = noise4; 3 = turbulence; 4 = fractalNoise -- b=bitmap b_width b_height-- create the bitmap for h=0 to (b_height-1) do-- step through each row of the bitmap ( h_norm=(h as float/(b_height-1))<em>size-- calculate y coordinate row = for w=0 to (b_width-1) collect-- collect row of pixel colors ( w_norm=(w as float/(b_width-1))</em>size-- calculate x coordinate noise_val = case whichfunc of-- store result of selected function ( 1: noise3 [w_norm, h_norm , z] 2: noise4 [w_norm, h_norm , z] phase 3: turbulence [w_norm, h_norm , z] frequency 4: fractalNoise [w_norm, h_norm , z] fract_interval lacunarity octaves ) noise_val = 0.5<em>(1.+noise_val)-- convert output range to 0. to 1. white</em>noise_val-- and multiply by color white ) setpixels b [0,h] row-- store row of pixels in bitmap ) display b-- display bitmap in VFB</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT</strong></p>\n\
<p>The following figures show the bitmap generated by the above script for each noise function type.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-E1A3F292-6EA1-4AEE-AEB1-502E3DCE01CC-low.gif\' title=\'\'></div>\n\
<p><strong>noise3</strong></p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-5FD7748F-FBA6-4D70-8C05-0780FFF85741-low.gif\' title=\'\'></div>\n\
<p><strong>noise4</strong></p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-1CF4BF1F-3EE8-4490-BF1C-A8A05C5DBCB8-low.gif\' title=\'\'></div>\n\
<p><strong>turbulence</strong></p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-99DB7D3A-A175-43E7-BE89-CED16649A430-low.gif\' title=\'\'></div>\n\
<p><strong>fractalNoise</strong></p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";