var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Quat Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Quat Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"quat-values\"></a></div>\n\
<p>The <strong>Quat</strong> class provides a compact representation for orientation in three space and provides methods to perform Quaternion algebra.</p>\n\
<p>Quaternions are used to store object rotations in <strong>3ds Max</strong>.</p>\n\
<p>A quaternion is made up of four terms: a real scalar part that specifies the amount of rotation and an imaginary vector part that defines the axis of rotation.</p>\n\
<p>If the quaternion is normalized, the scalar term equals the cosine of half the angle of rotation, the vector term is the axis of rotation, and the magnitude of the vector term equals the sine of half the angle of rotation.</p>\n\
<p>Interpolation between two key frame orientations is much easier using quaternions and produces smooth and natural motion. Unlike Euler angles, no numerical integration is necessary; quaternions provide an analytic result (no approximations).</p>\n\
<p>Rotations in MAXScript follow the right-hand-rule, namely positive angles rotate counter-clockwise about positive axes, consistent with the convention in the <strong>3ds Max</strong> UI.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>quat &lt;x_float&gt; &lt;y_float&gt; &lt;z_float&gt; &lt;w_float&gt;\n\
</pre></div><p>The x, y, z values make up the vector portion. w is the angle of rotation about the vector.</p>\n\
<div class=\'codeBlock\'><pre>quat &lt;degrees_float&gt; &lt;axis_point3&gt;\n\
&lt;angleaxis&gt; as quat\n\
&lt;eulerangle&gt; as quat\n\
&lt;matrix3&gt; as quat --extracts the rotation component as a quat\n\
</pre></div><p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;quat&gt;.w: Float\n\
&lt;quat&gt;.x: Float\n\
&lt;quat&gt;.y: Float\n\
&lt;quat&gt;.z: Float\n\
</pre></div><p>Access quaternion complex components as Floats.</p>\n\
<div class=\'codeBlock\'><pre>&lt;quat&gt;.angle: Float\n\
&lt;quat&gt;.axis: Point3\n\
</pre></div><p>Access derived properties (an angle in degrees and a rotation axis).</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;quat&gt; + &lt;quat&gt;\n\
&lt;quat&gt; - &lt;quat&gt;\n\
&lt;quat&gt; * &lt;quat_or_number&gt;\n\
&lt;quat&gt; / &lt;number&gt;\n\
- &lt;quat&gt;\n\
</pre></div><p>Quaternion algebra.</p>\n\
<p>Note: The <span class=\'code\'>+</span> operator is the same as the <span class=\'code\'>*</span> operator (product) and the <span class=\'code\'>-</span> operator is the same as the <span class=\'code\'>/</span> operator (ratio).</p>\n\
<div class=\'codeBlock\'><pre>&lt;quat&gt; * &lt;matrix3&gt;\n\
</pre></div><p>Quaternion algebra using rotation portion of the matrix3.</p>\n\
<p>Note: Multiplication with quaternions is not communicative. When multiplying an angle, for example, the quat must be the first term followed by the integer or float.</p>\n\
<div class=\'codeBlock\'><pre>&lt;quat&gt; == &lt;quat&gt;\n\
&lt;quat&gt; != &lt;quat&gt;\n\
&lt;quat&gt; as &lt;class&gt;\n\
</pre></div><p>Quats can convert to Matrix3&#39;s, Angleaxis&#39;s, and Eulerangle&#39;s.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>copy &lt;quat&gt;\n\
</pre></div><p>Creates a new copy of the quat value.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>newQuat = copy oldQuat</span></p>\n\
</blockquote>\n\
<p>The new value contains a copy of the input quat value, and is independent of the input quat value.</p>\n\
<div class=\'codeBlock\'><pre>isIdentity &lt;quat&gt;\n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the quaternion is equal to the identity quaternion (x=y=z=0.0; w=1.0).</p>\n\
<div class=\'codeBlock\'><pre>normalize &lt;quat&gt;\n\
</pre></div><p>Returns a normalized quat, dividing each term of the input quat by a scale factor such that the resulting sum of the squares of all parts equals unity.</p>\n\
<div class=\'codeBlock\'><pre>inverse &lt;quat&gt;\n\
</pre></div><p>Returns the inverse of the quaternion (1/q).</p>\n\
<div class=\'codeBlock\'><pre>conjugate &lt;quat&gt;\n\
</pre></div><p>Returns the conjugate of the quaternion.</p>\n\
<div class=\'codeBlock\'><pre>logN &lt;quat&gt;\n\
</pre></div><p>Returns the natural logarithm of UNIT quaternion.</p>\n\
<div class=\'codeBlock\'><pre>exp &lt;quat&gt;\n\
</pre></div><p>Returns the exponentiated quaternion (where q.w=0).</p>\n\
<div class=\'codeBlock\'><pre>slerp &lt;start_quat&gt; &lt;end_quat&gt; &lt;number&gt;\n\
</pre></div><p>Returns a spherical linear interpolation of UNIT quaternions.</p>\n\
<p>As <span class=\'code\'>&lt;number&gt;</span> goes from 0 to 1, the returned value goes from <span class=\'code\'>&lt;start_quat&gt;</span> to <span class=\'code\'>&lt;end_quat&gt;</span>.</p>\n\
<div class=\'codeBlock\'><pre>LnDif &lt;p_quat&gt; &lt;q_quat&gt;\n\
</pre></div><p>Returns the &quot;log difference&quot; of two quaternions as:</p>\n\
<div class=\'codeBlock\'><pre>logN ((inverse p_quat)*q_quat)\n\
qCompA&lt;prev_quat&gt; &lt;now_quat&gt; &lt;next_quat&gt;\n\
</pre></div><p>Computes <span class=\'code\'>a</span> , the term used in Boehm-type interpolation:</p>\n\
<div class=\'codeBlock\'><pre>a = now_quat * exp(-(1/4)*(logN((inverse now_quat)*next_quat)+logN((inverse now_quat)*prev_quat)))\n\
squad&lt;p_quat&gt; &lt;a_quat&gt; &lt;b_quat&gt; &lt;q_quat&gt; &lt;number&gt;\n\
slerp (slerp p_quatq_quatnumber) (slerp a_quatb_quatnumber) (2*(1-number)*number)\n\
qorthog &lt;quat&gt; &lt;axis_point3&gt; \n\
</pre></div><p>Returns <span class=\'code\'>quat</span> rotated by 180 degrees (quaternion space metric) about the specified axis <span class=\'code\'>axis_point3</span> .</p>\n\
<div class=\'codeBlock\'><pre>transform &lt;quat&gt; &lt;matrix3&gt;\n\
</pre></div><p>Returns the transformation of the specified quaternion by the specified matrix.</p>\n\
<div class=\'codeBlock\'><pre>squadrev &lt;angle_number&gt; &lt;axis_point3&gt; &lt;start_quat&gt; &lt;start_tangent_quat&gt; &lt;end_tangent_quat&gt; &lt;end_quat&gt; &lt;number&gt;\n\
</pre></div><p>Returns quaternion interpolation for angles &gt; 2PI, where <span class=\'code\'>angle_number</span> is the angle of rotation, and <span class=\'code\'>axis_point3</span> is the axis of rotation. As <span class=\'code\'>number</span> goes from 0 to 1, the returned value goes from <span class=\'code\'>start_quat</span> to <span class=\'code\'>end_quat</span> .</p>\n\
<div class=\'codeBlock\'><pre>random &lt;quat&gt; &lt;quat&gt;\n\
</pre></div><p>Returns a random rotation between the two quats, using Slerp.</p>\n\
<p><strong>Related Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>quatToEuler&lt;quat&gt; order:&lt;eulertype_integer&gt;\n\
eulerToQuat&lt;eulerAngle&gt; order:&lt;eulertype_integer&gt;\n\
</pre></div><p>Converts between quat and euler angle values. The optional order parameter specifies the order of application of the angles. If not specified, XYZ ordering is used. Its value can be any of the following:</p>\n\
<div class=\'codeBlock\'><pre>1 - XYZ\n\
2 - XZY\n\
3 - YZX\n\
4 - YXZ\n\
5 - ZXY\n\
6 - ZYX\n\
7 - XYX\n\
8 - YZY\n\
9 - ZXZ\n\
\n\
quatToEuler2 &lt;quat&gt;\n\
</pre></div><p>Returns the same Euler value for the given Quaternion as shown in the Transform Type-In dialog. Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a> .</p>\n\
<div class=\'codeBlock\'><pre>quatArrayToEulerArray &lt;quat array&gt;\n\
</pre></div><p>Returns an array of smooth Euler values from the Quat array. Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>getEulerQuatAngleRatio &lt;quat1&gt; &lt;quat2&gt; &lt;eulerAngles1&gt; &lt;eulerAngles2&gt; [angle:&lt;eulertype_integer&gt;]\n\
</pre></div><p>When converting a series of quat values to eulerAngles values, it is possible for sign flips to occur in the eulerAngles values. This is due to the fact that one single quat value can be expressed through many different eulerAngles values. This flip can be detected based on the eulerAngles/quat ratio. The eulerAngles/quat ratio is the relation of the angle difference in eulerAngles space to the angle difference in quat space. If this ratio is bigger than PI, the rotation between the two quat to eulerAngles conversions. This method returns the eulerAngles/quat angle ratio between the two quat to eulerAngles conversions as a float value. The actual detection of the flip is dependent on the amount of rotation in between conversions. The smaller the amount of rotation, the more accurate the detection is. The parameters to this method are:</p>\n\
<p><span class=\'code\'>quat1</span> and <span class=\'code\'>quat2</span> are the previous and current rotation values.</p>\n\
<p><span class=\'code\'>eulerAngles1</span> and <span class=\'code\'>eulerAngles2</span> are the previous and current converted rotation angles.</p>\n\
<p>The optional <span class=\'code\'>eulertype_integer</span> parameter specifies the order of application of the angles. If not specified, XYZ ordering is used. Its value can be any of the following:</p>\n\
<div class=\'codeBlock\'><pre>1 - XYZ\n\
2 - XZY\n\
3 - YZX\n\
4 - YXZ\n\
5 - ZXY\n\
6 - ZYX\n\
7 - XYX\n\
8 - YZY\n\
9 - ZXZ\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";