var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>String Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>String Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"string-values\"></a></div>\n\
<p>The <strong>String</strong> class defines the characteristics of character strings. The character strings can be of any length.</p>\n\
<p><strong>Literal</strong></p>\n\
<div class=\'codeBlock\'><pre>&quot;&lt;characters&gt;&quot;\n\
</pre></div><p>See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Literal-Constants/String-Literals.html\' title=\'\'>String Literals</a> for a description of String literals.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;value&gt; as string\n\
</pre></div><p>Converts any value into its string representation.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;.count: Integer, read-only\n\
</pre></div><p>The number of characters in the string.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt; + &lt;string&gt;\n\
</pre></div><p>Returns a new string that is the concatenation of two strings.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt; == &lt;string&gt;\n\
&lt;string&gt; != &lt;string&gt;\n\
&lt;string&gt; &gt; &lt;string&gt;\n\
&lt;string&gt; &lt; &lt;string&gt;\n\
&lt;string&gt; &gt;= &lt;string&gt;\n\
&lt;string&gt; &lt;= &lt;string&gt;\n\
\n\
</pre></div><p>Standard lexical string comparisons (case sensitive).</p>\n\
<p>To perform a case insensitive equality comparison, please use the <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/String-Values.html\' title=\'\'>stricmp() method</a> that performs a lower-case comparison.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;[&lt;index_number&gt;]\n\
</pre></div><p>Returns the indexed character as a single-character string, index starts at 1.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;[&lt;index_number&gt;]= &lt;single_character_string&gt;\n\
</pre></div><p>Sets the indexed character to the given character.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;as&lt;class&gt;\n\
</pre></div><p>Converts the string to an instance of the given class. You can convert a string into a Name value using the <span class=\'code\'>as</span> operator.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p><span class=\'code\'>&quot;Foo&quot; as name-- returns #foo</span></p>\n\
</blockquote>\n\
<p>You can also convert strings to numbers using the <span class=\'code\'>as</span> operator.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p><span class=\'code\'>&quot;123.4&quot; as float-- returns 123.4</span></p>\n\
</blockquote>\n\
<p>You can use any of the Number classes as a target class: Number, Float, or Integer. If you use Number, the appropriate class will be used depending on the syntax of the number in the string.</p>\n\
<p>You can convert a string to a StringStream value using the <span class=\'code\'>as</span> operator.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p><span class=\'code\'>&quot;$box01&quot; as stringstream-- returns the string as a stringstream</span></p>\n\
</blockquote>\n\
<p>Converting a string to a StringStream value allows you to read through a string using the MAXScript&#39;s text file I/O operations. See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/StringStream-Values.html\' title=\'\'>StringStream Values</a> for a description of StringStreams.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;copy &lt;string&gt;\n\
</pre></div><p>Creates a new copy of the string value and returns it.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` newstr = copy oldstr</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The new value contains a copy of the text contents of the copied string and is independent of the copied string.</p>\n\
<div class=\'codeBlock\'><pre>free &lt;string&gt;\n\
</pre></div><p><img src=\'developer/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> Frees the memory used by the string value without waiting for garbage collection.</p>\n\
<p>Available in <strong>3ds Max 9 and higher</strong>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p><span class=\'code\'>s = &quot;ABCD&quot;   --&gt; &quot;ABCD&quot;   s   --&gt; &quot;ABCD&quot;   free s   --&gt; OK   s   --&gt; &quot;&quot;</span></p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>execute &lt;string&gt;\n\
</pre></div><p>Compiles and evaluates the contents of the string as a MAXScript expression and returns the result of the evaluation.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` execute&quot;2 + 2&quot;-- yields the value 4 str =&quot;$foo.ffd_2x2x2.control_point_&quot;+ n as string +&quot; = [1,1,1]&quot; execute str</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The result of an <span class=\'code\'>execute()</span> call is the result of the last expression in the string argument.</p>\n\
<p>You can use <span class=\'code\'>execute()</span> to access object using a computed name.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` obj = execute (&quot;$foo/&quot;+ child_name)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>It retrieves the child of <span class=\'code\'>$foo</span> named in the variable <span class=\'code\'>child_name</span> .</p>\n\
<p>Here is a more complex example:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` side =&quot;left&quot; finger = 2 limb =&quot;arm&quot; obj = execute (&quot;$torso/&quot;+ limb +&quot;/&quot;+ side +&quot;/finger/&quot;+ finger as string)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The scope of variables used in the evaluated string is <strong>global</strong> and not the scope in effect when the <span class=\'code\'>execute()</span> method is executed. So, if you call <span class=\'code\'>execute()</span> within a function, scripted utility, or anywhere where the scope is not global, you will need to explicitly specify the scope of any variables used in the string that is executed. In the following example, the scope of variable <span class=\'code\'>posObj</span> is local to utility <span class=\'code\'>myUtil</span> , so the string needs to specify the variable’s name as being in <span class=\'code\'>myUtil</span> ’s scope:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` Utility myUtil&quot;My Utility&quot; ( local posObj fn test obj = ( local i, j, thisCont thisCont=execute (&quot;myUtil.posObj.&#39;&quot;+j+&quot;&#39;pos.controller&quot;) ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In general, you <strong>cannot</strong> access locals from outside of an object, except for top-level locals in rollouts, utilities, tools, and plug-ins (because they are semi-permanent and are stored with these objects). Function parameters and locals are dynamic and stack-based and not accessible as properties of the function definition.</p>\n\
<p>For more information on variable scope, see <a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Scope-of-Variables.html\' title=\'\'>Scope of Variables</a> and <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Accessing-Locals-and-Other-Items.html\' title=\'\'>Accessing Locals and Other Items in a Rollout from External Code</a>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;Point2&gt; GetTextExtent&lt;string&gt;\n\
</pre></div><p>Returns a Point2 value containing the size of the string in pixels if it was displayed in a command panel.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;findString&lt;string&gt; &lt;search_string&gt;\n\
</pre></div><p>Returns the index of <span class=\'code\'>search_string</span> in <span class=\'code\'>string</span> or <span class=\'code\'>undefined</span> if not found.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p><span class=\'code\'>findString &quot;Thanks for all the fish!&quot; &quot;all&quot; -- returns 12</span></p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;array of strings&gt;filterString &lt;string&gt; &lt;token_string&gt; [splitEmptyTokens:&lt;boolean&gt;]\n\
</pre></div><p>Parses <span class=\'code\'>string</span> based on <span class=\'code\'>token_string</span> and returns an array of strings. The <span class=\'code\'>filterString</span> splits the input <span class=\'code\'>string</span> into substrings based on the characters given in <span class=\'code\'>token_string</span> , and returns each substring as a member of the array. The <span class=\'code\'>token_string</span> is simply a list of &#39;splitter characters&#39; (when the string is scanned, any occurrence of any of the tokens is regarded as the start of a substring). This function is useful for file import/export scripts or for any type of manual parsing.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` filterString &quot;MAX Script, is-dead-funky&quot; &quot;, -&quot;</p>\n\
<p>```</p>\n\
<p><strong>WOULD RETURN</strong></p>\n\
<p>``` #(&quot;MAX&quot;,&quot;Script&quot;,&quot;is&quot;,&quot;dead&quot;,&quot;funky&quot;)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>If <span class=\'code\'>splitEmptyTokens</span> is <span class=\'code\'>false</span> or not specified, sequential tokens are handled as a single token and tokens at the beginning or end of the string are ignored. If <span class=\'code\'>splitEmptyTokens</span> is <span class=\'code\'>true</span> , each token found will result in string element in the output, with the string element in the cases ignored above being empty strings. Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` s = &quot;One\\t\\tThree\\tFour&quot; tokens = filterString s &quot;\\t&quot; --&gt; #(&quot;One&quot;, &quot;Three&quot;, &quot;Four&quot;) tokens = filterString s &quot;\\t&quot; splitEmptyTokens:true --&gt; #(&quot;One&quot;, &quot;&quot;, &quot;Three&quot;, &quot;Four&quot;) s =&quot;\\t\\t\\tOne\\t\\t\\tThree\\tFour\\t\\t\\t&quot; tokens = filterString s &quot;\\t&quot; --&gt; #(&quot;One&quot;, &quot;Three&quot;, &quot;Four&quot;) tokens = filterString s &quot;\\t&quot; splitEmptyTokens:true --&gt; #(&quot;&quot;, &quot;&quot;, &quot;&quot;, &quot;One&quot;, &quot;&quot;, &quot;&quot;, &quot;Three&quot;, &quot;Four&quot;, &quot;&quot;, &quot;&quot;, &quot;&quot;)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;replace &lt;string&gt; &lt;from_integer&gt; &lt;length_integer&gt; &lt;new_string&gt;\n\
</pre></div><p>Returns a new string where the substring in <span class=\'code\'>string</span> starting at index <span class=\'code\'>from_integer</span> and of length <span class=\'code\'>length_integer</span> is replaced with the <span class=\'code\'>new_string.new_string</span> of any length. The sum of <span class=\'code\'>from_integer</span> and <span class=\'code\'>length_integer</span> must be less than the length of <span class=\'code\'>string</span> .</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` s=&quot;1234567890&quot; s1=replace s 5 3 &quot;inserted string&quot;</p>\n\
<p>```</p>\n\
<p><strong>RETURNS:</strong></p>\n\
<p>``` &quot;1234inserted string890&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;substring &lt;string&gt; &lt;from_integer&gt; &lt;length_integer&gt;\n\
</pre></div><p>Returns a new string consisting of the substring in <span class=\'code\'>string</span> starting at index <span class=\'code\'>from_integer</span> and of length <span class=\'code\'>length_integer</span> . If the sum of <span class=\'code\'>from_integer</span> and <span class=\'code\'>length_integer</span> is greater than the length of <span class=\'code\'>string</span> , a shorter string is returned containing as many characters as are available in the source. If a negative value is specified for <span class=\'code\'>length_integer</span> , the remainder of the string starting from <span class=\'code\'>from_integer</span> is returned.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p><span class=\'code\'>s =&quot;Balerofon&quot;   ss = substring s 5 3-- returns &quot;rof&quot;   ss = substring s 5 -1-- returns &quot;rofon&quot;   ss = substring s 5 100-- returns &quot;rofon&quot;</span></p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;matchPattern &lt;string&gt; pattern:&lt;pattern_string&gt; [ignoreCase:&lt;boolean&gt;]\n\
</pre></div><p>Returns <span class=\'code\'>true</span> if <span class=\'code\'>string</span> is matched by the wild card <span class=\'code\'>pattern_string</span> , <span class=\'code\'>false</span> otherwise. The comparison is case-insensitive unless <span class=\'code\'>ignoreCase:false</span> is specified.</p>\n\
<p>Note: <span class=\'code\'>matchPattern()</span> executes much faster than <span class=\'code\'>findString()</span> and must be used in its place when possible.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p><span class=\'code\'>s=&quot;text1&quot;   matchPattern s pattern:&quot;text?&quot;-- returns true   matchPattern s pattern:&quot;T*&quot;-- returns true   matchPattern s pattern:&quot;T*&quot;ignoreCase:false-- returns false   matchPattern s pattern:&quot;s*&quot;-- returns false</span></p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt;append &lt;string1&gt; &lt;string2&gt;\n\
</pre></div><p>Appends <span class=\'code\'>string2</span> to <span class=\'code\'>string1</span> . Operates on <span class=\'code\'>string1</span> in place and returns <span class=\'code\'>string1</span> as its result.</p>\n\
<p>Note:</p>\n\
<p>As this method operates on <span class=\'code\'>string1</span> in place, after running the following code snippet, both <span class=\'code\'>s1</span> and <span class=\'code\'>s2</span> will continue to point to the same string value:</p>\n\
<div class=\'codeBlock\'><pre>s1 = &quot;aa&quot;\n\
s2 = s1\n\
append s1 &quot;bb&quot;\n\
s1-- returns &quot;aabb&quot;\n\
s2-- returns &quot;aabb&quot;and not &quot;aa&quot; \n\
</pre></div><p>Append is typically used when incrementally building a large string from many small strings. <strong>As the string is operated on in place, memory usage might be significantly reduced</strong> because intermediate string values will not remain in memory until the next garbage collection.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;stricmp &lt;string1&gt; &lt;string2&gt;\n\
</pre></div><p>In <strong>3ds Max6 and higher</strong>, this method performs a lower case comparison of string1 and string2.</p>\n\
<p>Returns an integer value &lt; 0 if string1 is less than string 2, = 0 if string1 is identical to string 2, and &gt; 1 if string1 is greater than string 2.</p>\n\
<div class=\'codeBlock\'><pre>toUpper &lt;string&gt;\n\
</pre></div><p>Returns a new string value with the string converted to upper case. Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` toUpper &quot;so long and thanks for all the scripts&quot;</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` &quot;SO LONG AND THANKS FOR ALL THE SCRIPTS&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>toLower &lt;string&gt;\n\
</pre></div><p>Returns a new string value with the string converted to lower case. Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` toLower &quot;Life, The Universe And Everything&quot;</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` &quot;life, the universe and everything&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>substituteString &lt;source_string&gt; &lt;from_string&gt; &lt;to_string&gt; \n\
</pre></div><p>Returns a new string with all occurrences of <span class=\'code\'>&lt;from_string&gt;</span> in <span class=\'code\'>&lt;source_string&gt;</span> replaced with <span class=\'code\'>&lt;to_string&gt;</span>. Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` s1 = &quot;Truth, Justice And The American Way&quot; s2 = &quot;The American Way&quot; s3 = &quot;All That Stuff&quot; s4 = substituteString s1 s2 s3</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` &quot;Truth, Justice And All That Stuff&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>replace_LF_with_CRLF &lt;string&gt;\n\
</pre></div><p>Returns a new string where line feeds in input string are replaced with carriage return/line feed, unless the character preceding the line feed is a carriage return. Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>replace_CRLF_with_LF &lt;string&gt;\n\
</pre></div><p>Returns a new string where carriage return/line feeds in input string are replaced with line feeds. Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<p>The following script shows the use of various literals, constructors, properties, operators, and methods of the String class.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` -- strings test bed fn uppercase instring =-- beginning of function definition ( local upper, lower, outstring-- declare variables as local upper=&quot;ABCDEFGHIJKLMNOPQRSTUVWXYZ&quot;-- set variables to literals lower=&quot;abcdefghijklmnopqrstuvwxyz&quot;</p>\n\
<p>-- create an unique copy of the string referenced by instring, -- and store reference to unique copy in outstring outstring=copy instring</p>\n\
<p>-- increment from 1 to number of character in string for i=1 to outstring.count do</p>\n\
<p>-- see if the single character at index i in outstring -- is present instring lower -- If so, j equals position in string lower. -- If not, j equals undefined ( j=findString lower outstring[i]</p>\n\
<p>-- if character was found in lower, -- replace with corresponding character in upper: if (j != undefined) do outstring[i]=upper[j] ) outstring-- value will be returned as function result )-- end of fn uppercase</p>\n\
<p>s1=&quot;AbCdEfGh&quot;-- set variable to literal s2=uppercase s1-- call function uppercase, passing s1 as parameter if s1 == s2 do print &quot;strings s2 and s3 are the same&quot;-- compare strings if s1 != s2 do print &quot;strings s1 and s2 are different&quot;</p>\n\
<p>theObject=&quot;sphere&quot;-- set variable to literal theRadius= (random 10. 100.) as string-- convert number to string -- concatenate strings and execute string myObject=execute (theObject +&quot; radius:&quot;+ theRadius)</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p><span class=\'code\'>uppercase()-- result to function definition   &quot;AbCdEfGh&quot;-- result of line 24   &quot;ABCDEFGH&quot;-- result of line 25   undefined-- result of line 26 - stringsnot equal,   -- and no else expression in if expression   &quot;strings s1 and s2 are different&quot;-- output from line 27   &quot;strings s1 and s2 are different&quot;-- result of line 27   &quot;sphere&quot;-- result of line 29   &quot;75.4091&quot;-- result of line 30   $Sphere:Sphere001 @ [0.000000,0.000000,0.000000]-- result of line 32. Execute function   -- created a sphere object</span></p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";