var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Bitmap Gamma and MAXScript</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Bitmap Gamma and MAXScript</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"bitmap-gamma-and-maxscript\"></a></div>\n\
<p>The handling of Bitmap Gamma in MAXScript has been overhauled in <strong>3ds Max 2014</strong> to solve several long-standing issues.</p>\n\
<div class=\'section\'><a id=\"the-past-problems\"></a><h2 id=\"the-past-problems\">The Past Problems</h2></div>\n\
<p>In versions prior to <strong>3ds Max 2014</strong>, MAXScript had limited access to the Gamma settings of the <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Bitmap-Values/Bitmap-Values-1.html\' title=\'\'>Bitmap Values</a> loaded from files, created by a script, or saved to disk bitmap files in various formats.</p>\n\
<p>Here is a list of some of the problems:</p>\n\
<ul>\n\
<li>When loading a Bitmap Value from a bitmap file, MAXScript had no access to the BitmapInfo describing meta-data including the Gamma.</li>\n\
<li>Similarly, when saving a bitmap value to a bitmap file, MAXScript could only provide the file name, but not the relevant meta-data including the actual Gamma loaded from disk.</li>\n\
<li>Copying a bitmap value to a new value using MAXScript would set the copied data to linear internally.</li>\n\
<li>Since MAXScript does not support the saving of a bitmap value loaded from a bitmap file, a copy of the bitmap value has to be created before saving, but because of the previous issue with copying bitmap values, the gamma was changed implicitly.</li>\n\
<li>The <span class=\'code\'>.gamma</span> property of the MAXScript bitmap value attempted to represent both the loading and saving gamma, which was incorrect or misleading in many cases.</li>\n\
<li>Access to pixel data via the <span class=\'code\'>getPixels()</span> function was always working with the raw data and had no way to respect the Gamma settings.</li>\n\
<li>Similarly, the <span class=\'code\'>compareBitmaps()</span> function would produce false when comparing a JPG (which loads with a gamma of 2.2) to its own copy with would have a gamma of 1.0.</li>\n\
</ul>\n\
<div class=\'section\'><a id=\"gamma-related-maxscript-features-in-3ds-max-2014-and-higher\"></a><h2 id=\"gamma-related-maxscript-features-in-3ds-max-2014-and-higher\">Gamma-Related MAXScript Features in 3ds Max 2014 and higher</h2></div>\n\
<p>To solve the above issues, MAXScript was extended in <strong>3ds Max 2014</strong> to let scripts properly handle the Gamma of Bitmap Values.</p>\n\
<p>In all cases, the additions have been implemented as extensions, in other words old scripts will remain syntactically correct.</p>\n\
<div class=\'section\'><a id=\"gamma-modes---auto-override-and-default\"></a><h3 id=\"gamma-modes---auto-override-and-default\">Gamma Modes - Auto, Override and Default</h3></div>\n\
<p>In <strong>3ds Max 2014 and higher</strong>, the Gamma of a Bitmap Value can be controlled in three ways - as <span class=\'code\'>#auto</span> , <span class=\'code\'>#default</span> or an override.</p>\n\
<ul>\n\
<li><span class=\'code\'>#auto</span> is the new, intelligent mode. It uses the file information when present, or intelligently chooses gamma based on whether the file is Floating point or not. This is the default behavior.</li>\n\
<li>If gamma is an override, an actual floating point value is used.</li>\n\
<li><span class=\'code\'>#default</span> is actually the <strong>old legacy mode</strong> which only exists for completeness and for loading old files.</li>\n\
</ul>\n\
<p><strong>The following extensions have been implemented:</strong></p>\n\
<p>The <span class=\'code\'>openBitmap()</span> function now accepts an optional <span class=\'code\'>gamma:</span> keyword argument, so you can say</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>a = openBitmap &quot;test.jpg&quot; gamma:#auto -- auto mode    b = openBitmap &quot;test.exr&quot; gamma:1.0 -- an override</span></p>\n\
</blockquote>\n\
<p>Similarly, the bitmap <span class=\'code\'>save()</span> method has been extended with an optional <span class=\'code\'>gamma:</span> keyword, so you can say:</p>\n\
<div class=\'codeBlock\'><pre>save a gamma:#auto -- auto mode \n\
save b gamma:1.0 -- an override\n\
</pre></div><p>In addition, the <span class=\'code\'>save()</span> function now provides a <span class=\'code\'>metadata:</span> optional keyword which can be used to pass the dialog settings acquired from the various bitmap filename picking functions - <span class=\'code\'>SelectSaveBitmap()</span> , <span class=\'code\'>getBitmapSaveFilename()</span> and <strong><span class=\'code\'>getBitmapOpenFilename()</span></strong> . See further on this page for details.</p>\n\
<p>If you render to a file using the <span class=\'code\'>render()</span> function, you can also set the Gamma using the optional <span class=\'code\'>gamma:</span> keyword:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>render filename:&quot;something.exr&quot; gamma:#auto -- auto mode    render filename:&quot;somotherthing.jpg&quot; gamma:1.0 -- an override</span></p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"new-and-modified-bitmap-value-gamma-properties\"></a><h3 id=\"new-and-modified-bitmap-value-gamma-properties\">New and Modified Bitmap Value Gamma Properties</h3></div>\n\
<p>The existing <span class=\'code\'>.gamma</span> property has been modified to represent the ACTUAL gamma of the bitmap. In the past, it confused output and input gamma into one parameter, which was problematic.</p>\n\
<p>For this reason, two new properties have been added to explicitly address the input gamma, and how that gamma was obtained:</p>\n\
<p><span class=\'code\'>.inputGamma</span> will inform you of the gamma of the file that was loaded. It will return either #auto, #default or the override value. This can be used to display e.g. where the gamma info comes from. It can also be used to make sure to save a bitmap the same as it was loaded, for example.</p>\n\
<p><strong><span class=\'code\'>.inputGammaValue</span></strong> just returns the actual value that was used, e.g. for #auto it would return 1.0 or 2.2 depending on file type, for #default it would return 2.2, and for an override it returns the override value.</p>\n\
<div class=\'section\'><a id=\"bitmap-file-open-and-save-dialogs-meta-data-access\"></a><h3 id=\"bitmap-file-open-and-save-dialogs-meta-data-access\">Bitmap File Open and Save Dialogs Meta-Data Access</h3></div>\n\
<p>Features have been added to the MAXScript bitmap file dialogs to return as an optional by-reference output parameters the Gamma values, as well as the dialog&#39;s setup data.</p>\n\
<p>When these optional parameters are used, the gamma options are visible and work. When they are not used, the Gamma options will be grayed out in the file dialog.</p>\n\
<p><strong>The functions that have been extended are:</strong></p>\n\
<div class=\'codeBlock\'><pre>getBitmapOpenFilename()\n\
getBitmapSaveFilename() \n\
SelectSaveBitmap()\n\
</pre></div><p>In each one of these functions, an optional keyword argument <span class=\'code\'>gamma:</span> can refer to a by-reference variable that will return <span class=\'code\'>#auto</span> , <span class=\'code\'>#default</span> or a numeric value:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>x = SelectSaveBitmap caption:&quot;Select a file&quot; gamma:&amp;gma</span></p>\n\
<p>If the function returns successfully, the variable &#39;gma&#39; will contain the gamma value from the dialog.</p>\n\
</blockquote>\n\
<p>Similarly, bitmap Save dialogs can return the meta-data stored by the &quot;Setup&quot; button, by requesting it via the <span class=\'code\'>metadata:</span> by-reference optional argument:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>x = SelectSaveBitmap caption:&quot;Select a file&quot; gamma:&amp;gma metadata:&amp;data</span></p>\n\
<p>Upon success, the &#39;gma&#39; variable will contain the gamma, and the &#39;data&#39; variable will contain an array of data stored by the bitmap plugin. This data can then be used in bitmap save operations, for example:</p>\n\
<p>``` bitmap.filename = SelectSaveBitmap caption:&quot;Select a file&quot; gamma:&amp;gma metadata:&amp;data if (bitmap.filename) do save bitmap gamma:gma metadata:data</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"pixels-access---linear-vs.-raw\"></a><h3 id=\"pixels-access---linear-vs.-raw\">Pixels Access - Linear vs. Raw</h3></div>\n\
<p>The function <span class=\'code\'>getPixels()</span> have been extended with the optional <span class=\'code\'>linear:</span> boolean parameter:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>a = openBitmap &quot;hello.jpg&quot; gamma:#auto --this will set gamma to 2.2   p = getPixels a [0,0] 50 linear:true  --get the linear pixel values (gamma 1.0)   p[1].r *= 2.0 --make first pixel twice as red...</span></p>\n\
</blockquote>\n\
<p>The following example script goes through all Bitmap Textures and if they are set to <span class=\'code\'>#default</span> (legacy mode), changes the Gamma to an override of 2.2.</p>\n\
<p>Note that you <strong>cannot change</strong> the Gamma of a bitmap value (this gets burned in when loading it), but you can simply re-load it with the new Gamma from the original source file.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p><span class=\'code\'>for tmap in (getClassInstances BitmapTexture) where (tmap.bitmap.inputGamma == #default) do      tmap.bitmap = openBitmap tmap.bitmap.filename gamma:2.2</span></p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";