var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Bitmap Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Bitmap Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"bitmap-values\"></a></div>\n\
<blockquote>\n\
<p><a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Values-1.html\' title=\'\'>Value</a>&gt; Bitmap Value</p>\n\
</blockquote>\n\
<p>The <strong>Bitmap</strong> class provides storage of <strong>3ds Max</strong> bitmaps and low-level access to them.</p>\n\
<p>Bitmaps can be temporary objects that are resident only in memory, or they can be associated with a file on the disk.</p>\n\
<p>Those bitmaps associated with files have a non-null <span class=\'code\'>.fileName</span> property and are either load-only or save-only, but not both (this is with respect to file I/O; all bitmaps in memory can have their pixels modified by the <span class=\'code\'>setPixel()</span> functions).</p>\n\
<p>You can make load-only bitmaps with the <span class=\'code\'>openBitmap()</span> and <span class=\'code\'>selectBitmap()</span> functions.</p>\n\
<p>You can make temporary or save-only bitmaps with the <span class=\'code\'>bitmap()</span> constructor, or with the <span class=\'code\'>render()</span> , <span class=\'code\'>copy()</span> , or <span class=\'code\'>getChannelAsMask()</span> functions. To make them savable, they must have a valid file name, supplied either on the constructor with a <span class=\'code\'>fileName:</span> parameter or by setting the <span class=\'code\'>.fileName</span> property.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>bitmap &lt;width &lt;height&gt; [filename:&lt;filename_string&gt;] \\ \n\
[numframes:&lt;integer&gt;] \\\n\
[color:&lt;color&gt;] \\ \n\
[gamma:&lt;float&gt;] \\ \n\
[pixelAspect:&lt;float&gt;] \\ \n\
[channels:&lt;channel_name array&gt;]\\ \n\
[hdr:&lt;boolean&gt;] \\\n\
[iconName:&lt;filename&gt;]\\\n\
[iconSize:&lt;point2&gt;]\n\
     \n\
</pre></div><p>Creates an empty bitmap. The bitmap value returned is a savable bitmap.</p>\n\
<p>The <span class=\'code\'>filename:</span> parameter allows you to set the name of the file in which the bitmap will be saved using the <span class=\'code\'>save</span> method. Specifying an existing bitmap file name does not load the contents of the bitmap file into the bitmap value.</p>\n\
<p>The <span class=\'code\'>numframes:</span> parameter allows you to create a multi-frame bitmap.</p>\n\
<p>The <span class=\'code\'>color:</span> parameter allows you to set the initial color of all pixels in the bitmap.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES</strong></p>\n\
<p>``` b = bitmap 320 240 color:white</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The <span class=\'code\'>gamma:</span> parameter allows you to set the gamma for the newly created bitmap.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES</strong></p>\n\
<p>``` b = bitmap 320 240 gamma:1.9 render camera:c to:b</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The <span class=\'code\'>pixelAspect:</span> parameter allows you to set the pixel aspect for the newly created bitmap.</p>\n\
<p>Note:</p>\n\
<p>Once created, it is <strong>not</strong> possible to change the gamma or pixel aspect of a bitmap, though you can copy one bitmap into a newly created one that has a different gamma or pixel aspect to achieve this effect.</p>\n\
<p>The <span class=\'code\'>channels:</span> parameter lets you specify the channels to be created. It is also available as a property. For a list of valid names, see the <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Bitmap-Values/Bitmap-Values-1.html\' title=\'\'>getChannel</a> method documentation.</p>\n\
<p>When the optional <strong>hdr:</strong> parameter introduced in <strong>3ds Max 8</strong> is set to true, the constructor creates a 32 bit per channel bitmap value instead of an 8 bit per channel bitmap value.</p>\n\
<p>The <span class=\'code\'>iconName:</span> parameter allows you to specify an icon file to load. The <span class=\'code\'>iconSize:</span> parameter specifies the icon&#39;s size at 100% DPI scaling.</p>\n\
<div class=\'codeBlock\'><pre>openBitMap &lt;filename_string&gt; \n\
</pre></div><p>Returns a bitmap value containing the contents of the specified bitmap file. The bitmap value returned is a load-only bitmap.</p>\n\
<p>If the specified bitmap file does not exist, a runtime error is generated in <strong>3ds Max 9 and earlier</strong>.</p>\n\
<p>If the specified bitmap does not exist, a value of <span class=\'code\'>undefined</span> is returned in <strong>3ds Max 2008 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>selectBitMap [caption:&lt;open_dialog_title_string&gt;] \n\
</pre></div><p>This method displays an Image Input selection browser for the user to select a bitmap file. Returns a bitmap value containing the contents of the selected bitmap file, or the value <span class=\'code\'>undefined</span> if the user presses <strong>Cancel</strong> in the browser. The bitmap value returned is a load-only bitmap.</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitmap&gt;copy &lt;bitmap&gt; \n\
</pre></div><p>Copies an existing bitmap, creating an unique instance of the bitmap.</p>\n\
<p>If the source bitmap is load-only, the bitmap value returned is a temporary bitmap value with a null filename and just one frame.</p>\n\
<p>If the source is a multi-frame file, it snaps the current frame into the new copy, which becomes frame 0.</p>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;bitmap&gt;.filename : String \n\
</pre></div><p>Lets you get or set the file name associated with the bitmap.</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitmap&gt;.palette : Array \n\
</pre></div><p>Yields an array of 256 colors (a bug in the current <strong>3ds Max</strong> SDK prevents working with paletted files of other than 256 entries). Take care accessing this array with color indexes retrieved by the <span class=\'code\'>getIndexedPixels()</span> function described below because these indexes are 0-based and MAXScript array indexes are 1-based. Yields <span class=\'code\'>undefined</span> if the bitmap is not paletted. Currently, you cannot create a paletted bitmap in MAXScript. However, you can read and write to a pre-existing paletted bitmap.</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitmap&gt;.frame : Integer \n\
</pre></div><p>Get and set the current frame number in a multi-frame file. Setting this property is permitted only on load-only bitmaps. The frame number is 0-based for inherently multi-frame files such as, .avi and .mov.</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitmap&gt;.numframes : Integer \n\
</pre></div><p>The number of frames in a multi-frame file, yields 1 for a single image file.</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitmap&gt;.height : Integer, read-only \n\
</pre></div><p>Returns bitmap&#39;s height in pixels.</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitmap&gt;.width : Integer, read-only \n\
</pre></div><p>Returns bitmap&#39;s width in pixels.</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitmap&gt;.gamma : Float\n\
</pre></div><p>Get and set the gamma value of the bitmap.</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitmap&gt;.inputGamma : {#auto | #default | Float}\n\
</pre></div><p>Returns the input gamma mode of the bitmap.</p>\n\
<p>This value reflects the Gamma mode that was set when a bitmap value was loaded from an image file.</p>\n\
<p>See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Bitmap-Values/Bitmap-Gamma-and-MAXScript.html\' title=\'\'>Bitmap Gamma and MAXScript</a> for details.</p>\n\
<p>Available in <strong>3ds Max 2014</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitmap&gt;.inputGammaValue : Float\n\
</pre></div><p>Returns the actual input gamma value of the bitmap.</p>\n\
<p>See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Bitmap-Values/Bitmap-Gamma-and-MAXScript.html\' title=\'\'>Bitmap Gamma and MAXScript</a> for details.</p>\n\
<p>Available in <strong>3ds Max 2014</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitmap&gt;.aspect : Float, read-only \n\
</pre></div><p>Returns the bitmap&#39;s pixel aspect. Note that this is the aspect of the pixel, not the aspect of the bitmap image.</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitmap&gt;.channels : Array \n\
</pre></div><p>This property lets you get and set the bitmap channels available in the bitmap. For a list of valid names, see the <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Bitmap-Values/Bitmap-Values-1.html\' title=\'\'>getChannel</a> method documentation.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES</strong></p>\n\
<p>``` b = bitmap 100 100 channels:#(#weight) --&gt; BitMap: b.channels --&gt; #(#weight) b.channels = #(#zDepth) --&gt; #(#zDepth)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;bitmap&gt;.hasAlpha : Boolean, read-only \n\
</pre></div><p>This property contains true if the bitmap has an alpha channel and false if it does not.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>display &lt;bitmap&gt; caption:&lt;string&gt;\n\
</pre></div><p>Opens a virtual frame buffer (VFB) displaying the image.</p>\n\
<p>Changes to the bitmap are not automatically displayed to the VFB.</p>\n\
<p>To update the VFB, you need to call this function again.</p>\n\
<p>Setting the <span class=\'code\'>frame</span> property of the bitmap value updates the VFB.</p>\n\
<p>Each bitmap has its own VFB (if you display two different bitmaps, two VFBs will be displayed).</p>\n\
<p>Since <strong>3ds Max 2015</strong>, if the optional keyword argument <span class=\'code\'>caption:</span> is specified as string, it will be displayed as the caption in the title bar of the VFB.</p>\n\
<div class=\'codeBlock\'><pre>unDisplay &lt;bitmap&gt; \n\
</pre></div><p>Close the VFB associated with the bitmap if open.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;save &lt;bitmap&gt; [frame:&lt;integer&gt;] [gamma:{#auto|#default|&lt;float&gt;}] [quiet:&lt;boolean&gt;] \n\
</pre></div><p>Saves the current state of the bitmap. Make sure that the file name is set first.</p>\n\
<p>When saving multi-frame image files, the effect of the <span class=\'code\'>frame:</span> keyword parameter is different depending on the type of output file.</p>\n\
<p>Inherently multi-frame files such as, .avi and .mov ignore the <span class=\'code\'>frame:</span> parameter and always write to the next output file frame in sequence on each <span class=\'code\'>save()</span> . You cannot randomly write frames or rewrite frames that are already saved.</p>\n\
<p>Saving image sequences (such as, .bmp, .jpg, and .tga) requires supplying the <span class=\'code\'>frame:</span> parameter and causes the frame number to be appended to the output file name for each frame saved. This effectively generates a sequence of image files suitable for building an IFL.</p>\n\
<p>The output file remains open until you call <span class=\'code\'>close</span> on the bitmap.</p>\n\
<p>The <span class=\'code\'>save()</span> function can only be called on a savable bitmap. You will get a runtime error if you attempt to save a bitmap opened with <span class=\'code\'>openBitmap()</span> or <span class=\'code\'>selectBitmap()</span> .</p>\n\
<p>The <span class=\'code\'>gamma:</span> keyword parameter can be used in <strong>3ds Max 2014 and higher</strong> to set the Gamma mode or Gamma Override value:</p>\n\
<ul>\n\
<li><span class=\'code\'>#auto</span> is the new, intelligent mode. It uses the file information when present, or intelligently chooses gamma based on whether the file is Floating point or not. This is the default behavior.</li>\n\
<li><span class=\'code\'>#default</span> is actually the <strong>old legacy mode</strong> which only exists for backwards compatibility.</li>\n\
<li>If set to a floating point value, the Gamma will be overridden by that value.</li>\n\
</ul>\n\
<p>For details on the <span class=\'code\'>quiet:</span> option that was added to this method in <strong>3ds Max 8</strong>, please see <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Network-Render-Interface/Quiet-Mode.html\' title=\'\'>Quiet Mode</a></p>\n\
<p>The method will return True on success or False if the saving failed (for example, if attempting to overwrite an existing read-only file) in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>close &lt;bitmap&gt; \n\
</pre></div><p>Closes the bitmap file associated with the bitmap if it is open for output. A bitmap file is opened for output when you call <span class=\'code\'>save</span> on the bitmap value the first time. If a Virtual Frame Buffer (Rendered Frame Window) associated with the bitmap is open, it will be closed. This function also frees all memory allocated by the bitmap, including the internal pixel frame buffer. If you are generating many bitmaps, say in a rendering loop, you can use the <span class=\'code\'>close()</span> function to free these large amounts of memory, which is otherwise not released until the next garbage collection.</p>\n\
<div class=\'codeBlock\'><pre>free &lt;bitmap&gt;\n\
</pre></div><p>Frees the memory used by the bitmap value without waiting for garbage collection.</p>\n\
<p>Available in <strong>3ds Max 9 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>copy &lt;source_bitmap&gt; &lt;dest_bitmap&gt; \n\
</pre></div><p>Copies the source bitmap to the destination bitmap. If the size of the two bitmaps is different, the image will be scaled to fit the destination bitmap.</p>\n\
<div class=\'codeBlock\'><pre>gotoFrame &lt;bitmap&gt; &lt;frame&gt;\n\
</pre></div><p>Position multi-frame file (avi, flc, and so on) to frame <span class=\'code\'>frame</span> . This method is permitted only on load-only bitmaps. The frame number is 0-based for inherently multi-frame files such as, .avi and .mov. Updates VFB if open.</p>\n\
<div class=\'codeBlock\'><pre>getPixels &lt;bitmap&gt; &lt;coord_point2&gt; &lt;num_pixels&gt; linear:&lt;boolean&gt;\n\
</pre></div><p>Retrieve a sequence of pixels from a row in the bitmap as an array of color values.</p>\n\
<p>The coord_point2 argument specifies the starting pixel coordinate with [0,0] at the top-left-hand pixel.</p>\n\
<p>The <span class=\'code\'>.x</span> component of the Point2 coordinate is the column, and the <span class=\'code\'>.y</span> component is the row.</p>\n\
<p>The sequence must come from one row only. You cannot retrieve a sequence of pixels that spans multiple rows.</p>\n\
<p>Using any out of-bounds coordinates or retrieving over row boundaries will fail and yield an empty array.</p>\n\
<p>The optional <span class=\'code\'>linear:</span> keyword parameter introduced in <strong>3ds Max 2014</strong> can be set to True to access linear values with Gamma of 1.0, or False to access raw data (default, old behavior prior to <strong>3ds Max 2014</strong>).</p>\n\
<div class=\'codeBlock\'><pre>setPixels &lt;bitmap&gt; &lt;coord_point2&gt; &lt;color_value_array&gt; \n\
</pre></div><p>Sets the sequence of pixels in a row in the bitmap starting at the Point2 coordinate to the values in the given array. The <span class=\'code\'>.x</span> component of the Point2 coordinate is the column and the <span class=\'code\'>.y</span> component is the row. The number of pixels to set is taken from the size of the array. As with <span class=\'code\'>getPixels()</span> , you cannot set pixel sequences across a row boundary.</p>\n\
<div class=\'codeBlock\'><pre>getIndexedPixels &lt;bitmap&gt; &lt;coord_point2&gt; &lt;num_pixels&gt; \n\
</pre></div><p>Retrieve a row of pixels as an array of palette index numbers. The coord_point2 argument specifies the starting pixel coordinate with 0,0 at the top-left-hand pixel. The index numbers are origin 0.</p>\n\
<p>Note:</p>\n\
<p>This is in keeping with indexed color conventions, but <strong>not</strong> MAXScript&#39;s. Take care accessing any retrieved palette array using these numbers because the retrieved palette is returned as a MAXScript array and these arrays use 1-based indexes. You cannot get pixels sequences that cross row boundaries.</p>\n\
<div class=\'codeBlock\'><pre>setIndexedPixels &lt;bitmap&gt; &lt;coord_point2&gt; &lt;number_array&gt; \n\
</pre></div><p>Sets the row of pixels starting at the Point2 coordinate to the color indexes in the given array. The number of pixels to set is taken from the size of the array. The color indexes are zero-based. You cannot set pixels sequences that cross row boundaries.</p>\n\
<div class=\'codeBlock\'><pre>getChannel &lt;bitmap&gt; &lt;coord_point2&gt; &lt;chan_name&gt; \n\
</pre></div><p>Retrieves the g-buffer channel data for the named channel for the pixel specified by 2D coordinate. The <span class=\'code\'>chan_name</span> argument specifies the channel identifier, chosen from the following:</p>\n\
<div class=\'codeBlock\'><pre>#zDepth \n\
#matID\n\
#objectID \n\
#UVCoords \n\
#normal \n\
#unClamped \n\
#coverage \n\
#node \n\
#mask \n\
#shaderColor \n\
#shaderTransparency \n\
#velocity \n\
#weight \n\
</pre></div><p>If the bitmap contains the requested channel, the returned value is always an array of values, one for each layer present in the channel at that pixel, ordered from front to back. If the bitmap does not contain the requested channel, the function returns the value <span class=\'code\'>undefined</span> . Typically, you get bitmaps containing channels by opening .rla files or using the MAXScript <span class=\'code\'>render()</span> function with the <span class=\'code\'>channels:</span> parameter supplied. You will get multiple values in the array if the front objects have any transparency.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` getChannel bm [x,y] #zDepth</p>\n\
<p>```</p>\n\
<p>might return:</p>\n\
<p>``` #(-354.413, -354.467, -355.271, -1e+030)</p>\n\
<p>```</p>\n\
<p>indicating there is a front surface with non-zero transparency at depth -354.413, another at -354.467, and a final one at -355.271. The -1e+30 value represents the background image plane.</p>\n\
<p>You can retrieve the <span class=\'code\'>#node</span> channel (if it was generated) to get the actual scene objects at those depths,</p>\n\
<p>``` getChannel bm [x,y] #node</p>\n\
<p>```</p>\n\
<p>might return:</p>\n\
<p>``` #($Sphere:Sphere02 @ [-4.7,24.3,0.0], \\(Sphere:Sphere02 @ [-4.7,24.3,0.0],\\)Sphere:Sphere01 @ [-8.3,56.2,5.7])</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The type of values returned in the array depend on the channel, as follows:</p>\n\
<div class=\'codeBlock\'><pre>#zDepth: &lt;float&gt; \n\
#matID: &lt;integer&gt; \n\
#objectID: &lt;integer&gt; \n\
#UVCoords: &lt;point2&gt; \n\
#normal: &lt;point3&gt; \n\
#unClamped: &lt;color&gt; \n\
#coverage: &lt;float&gt; \n\
#node: &lt;node&gt; \n\
#shaderColor: &lt;color&gt; \n\
#shaderTransparency: &lt;color&gt; \n\
#velocity: &lt;point2&gt; \n\
#weight: &lt;color&gt; \n\
</pre></div><p>See the <strong>3ds Max</strong> Software Development Kit Help file for information on the data stored in the g-buffer channels.</p>\n\
<div class=\'codeBlock\'><pre>getChannelAsMask&lt;bitmap&gt; &lt;chan_name&gt; [to:&lt;bitmap&gt;] \\ \n\
[fileName:&quot;filename_string&quot;] [pixelAspect:&lt;float&gt;] \\ \n\
[gamma:&lt;float&gt;] [layer:&lt;integer&gt;] [invert:&lt;boolean&gt;] \\ \n\
[node:&lt;node&gt; |objectID:&lt;integer&gt; |matID:&lt;integer&gt;] \\ \n\
[velocity:#angle | #magnitude] | [angle:&lt;float&gt;] \n\
</pre></div><p>Builds and returns a separate 8-bit gray-level bitmap suitable for use as a mask in materials, maps, effects, and so on. This bitmap corresponds roughly to the display you see in the visual frame buffer if you select a g-buffer channel to view. In addition, you can cause this mask to be masked itself to a selected node, object ID, or material ID. The parameters are as follows:</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitmap&gt;\n\
</pre></div><p>The source bitmap containing the source g-buffer channel data.</p>\n\
<div class=\'codeBlock\'><pre>&lt;chan_name&gt;\n\
</pre></div><p>The channel from which to generate a mask. The <span class=\'code\'>chan_name</span> values are as described for the <span class=\'code\'>getChannel()</span> method.</p>\n\
<p>Note:</p>\n\
<p>The mask is a single 8 bit value while the channel might be a complex value of some kind. In each case, a mapping to 8 bits is performed.</p>\n\
<p>Unless noted differently below, this mapping is the same mapping used by <strong>3ds Max</strong> to generate monochrome images in the Virtual Frame Buffer.</p>\n\
<div class=\'codeBlock\'><pre>to:&lt;bitmap&gt; \n\
</pre></div><p>Specifies an existing bitmap to write the mask into. Its width and height must match the source bitmap.</p>\n\
<div class=\'codeBlock\'><pre>fileName:&quot;filename_string&quot; \n\
</pre></div><p>Specifies the file name associated with the generated bitmap.</p>\n\
<div class=\'codeBlock\'><pre>gamma:&lt;float&gt; \n\
</pre></div><p>Specifies the generated bitmap&#39;s gamma value.</p>\n\
<div class=\'codeBlock\'><pre>pixelAspect:&lt;float&gt; \n\
</pre></div><p>Specifies the generated bitmap&#39;s pixel aspect. Note that this is the aspect of the pixel, not the aspect of the bitmap image.</p>\n\
<div class=\'codeBlock\'><pre>layer: &lt;integer&gt; \n\
</pre></div><p>Specifies the channel layer of the source bitmap to extract data from. Defaults to 1.</p>\n\
<div class=\'codeBlock\'><pre>invert:&lt;boolean&gt; \n\
</pre></div><p>If <span class=\'code\'>true</span> , inverts the generated bitmap. Defaults to . <span class=\'code\'>false</span> .</p>\n\
<div class=\'codeBlock\'><pre>node:&lt;node&gt; objectID:&lt;integer&gt; matID:&lt;integer&gt; \n\
</pre></div><p>Specifies a sub-mask. If one of these parameters is supplied, the generated mask is clipped to contain data only in pixels where the given node, objectID, or materialID is visible. To use this sub-masking, you must ensure the <span class=\'code\'>#node</span> , <span class=\'code\'>#objectID</span> , or <span class=\'code\'>#matID</span> channel is present in the source bitmap. Further, if the <span class=\'code\'>#coverage</span> channel is present in the source bitmap, the sub-mask is anti-aliased by the coverage data.</p>\n\
<div class=\'codeBlock\'><pre>velocity:#angle | #magnitude angle:&lt;float&gt; \n\
</pre></div><p>These parameters can only be specified if the selected channel is <span class=\'code\'>#velocity</span> . The default <span class=\'code\'>velocity</span> parameter value is <span class=\'code\'>#magnitude</span> . These parameters control the generated bitmap as follows:</p>\n\
<div class=\'codeBlock\'><pre>velocity:#angle \n\
</pre></div><p>Generated bitmap pixel values are proportional to angle of pixel movement direction with an angle of direction of 0 degrees (horizontal to the right) mapping to a luminance value of 0, 180 degrees mapping to a luminance value of 127, and 360 degrees mapping to a luminance value of 255.</p>\n\
<div class=\'codeBlock\'><pre>velocity:#magnitude \n\
</pre></div><p>Generated bitmap pixel values are proportional to velocity magnitude. High velocities are darker than low velocities.</p>\n\
<div class=\'codeBlock\'><pre>angle:&lt;float&gt; \n\
</pre></div><p>Generated bitmap pixel values are proportional to movement direction deviation from the given angle with a luminance value of 255 at the exact angle and falling off to a luminance value of 0 at 10 degrees from the specified angle. The specified angle is relative to 0 being horizontal to the right.</p>\n\
<div class=\'codeBlock\'><pre>CompareBitmaps {&lt;filename&gt;File1 | &lt;bitmap&gt;bitmap1} {&lt;filename&gt;File2 | &lt;bitmap&gt;bitmap2}\\ \n\
&lt;int&gt;tolerance(# different pixels) &lt;int&gt;variation(0-255)\\\n\
useAlpha:&lt;boolean&gt;errorMsg:&lt;&amp;string&gt; \n\
</pre></div><p>In <strong>3ds Max 9</strong> and higher, returns true if the bitmaps compare as the same, false if not.</p>\n\
<p>More than&#39;tolerance&#39; number of pixels must be different before the comparison fails.</p>\n\
<p>Two pixels are considered the same if the difference in each component value is less than or equal to &#39;variation&#39;.</p>\n\
<p>If <span class=\'code\'>useAlpha</span> is true, the alpha component value is also tested. If false (the default), the alpha component is not tested.</p>\n\
<p>If specified, the <span class=\'code\'>errorMsg</span> keyword variable (passed by reference) will contain an error message.</p>\n\
<p>The potential messages are:</p>\n\
<ul>\n\
<li><p>&quot;Passed.&quot;</p></li>\n\
<li><p>&quot;Different Pixels: #&quot; (where # is the number of pixels that are different)</p></li>\n\
<li><p>&quot;One or both Bitmaps not found&quot;</p></li>\n\
<li><p>&quot;Bitmaps have different sizes&quot;</p></li>\n\
</ul>\n\
<div class=\'codeBlock\'><pre>pasteBitmap &lt;src_bitmap&gt; &lt;dest_bitmap&gt; (&lt;src_box2&gt; | &lt;src_point2&gt;) &lt;dest_point2&gt; \\\n\
[maskColor:&lt;color&gt;type:{#paste|#composite|#blend|#function}] \\\n\
[function:&lt;composite_fn&gt;] [alphaMultiplier:&lt;float&gt;] \n\
</pre></div><p>Copies a block of pixels from the source bitmap to the destination bitmap.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<ul>\n\
<li><p>The position of the source block is specified by src_box2 or src_point2, and the destination by dest_point2.</p></li>\n\
<li><p>The width and height of the block is specifed by src_box2 or, if src_point2 is specified, by the remaining size of the source bitmap.</p></li>\n\
<li><p>The width and height will be clamped to prevent either source or target overruns.</p></li>\n\
<li><p>If <span class=\'code\'>maskColor:</span> is supplied, pixels with this color in src_bitmap are not copied to dest_bitmap.</p></li>\n\
<li><p>If <span class=\'code\'>type:</span> is <span class=\'code\'>#paste</span> (the default), the source is pasted on the destination ignoring all alpha.</p></li>\n\
<li><p>If <span class=\'code\'>type:</span> is <span class=\'code\'>#composite</span> , the source alpha of the source is used: <span class=\'code\'>clamp (R = S + D * (1-S.alpha))</span> .</p></li>\n\
<li><p>If <span class=\'code\'>type:</span> is <span class=\'code\'>#blend</span> , the source alpha of the source is used: <span class=\'code\'>R = S * S.alpha + D * (1-S.alpha)</span> .</p></li>\n\
<li><p>For both <span class=\'code\'>type:#composite</span> and <span class=\'code\'>type:#blend</span> , <span class=\'code\'>R.alpha = S.alpha + D.alpha * (1-S.alpha)</span> .</p></li>\n\
<li><p>The <span class=\'code\'>type:#composite</span> is typically used for pre-multiplied alpha images.</p></li>\n\
<li><p>If <span class=\'code\'>type:</span> is <span class=\'code\'>#composite</span> or <span class=\'code\'>#blend</span> , the source alpha is multiplied by the <span class=\'code\'>alphaMultiplier:</span> value, which defaults to a value of 1.0 if not supplied.</p></li>\n\
<li><p>If <span class=\'code\'>type:</span> is <span class=\'code\'>#function</span> , an optional <span class=\'code\'>function:</span> parameter can specify a user-defined function taking 4 arguments - the source pixel color, the source pixel location, the second source pixel color, and second source pixel location. The second source is the destination bitmap. The return result of the function is stored in the destination bitmap&#39;s pixel.</p></li>\n\
<li><p>Only RGBA information is copied - no channel data is copied.</p></li>\n\
</ul>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` bm1=bitmap 100 100 color:red bm2=bitmap 100 100 color:green bm3=bitmap 100 100 color:blue pasteBitmap bm2 bm1 (box2 0 0 25 50) [50,50] display bm1 pasteBitmap bm1 bm3 [25,25] [25,50] maskColor:green display bm3</p>\n\
<p>```</p>\n\
<p><strong>RESULTS:</strong></p>\n\
<p><img src=\'developer/images/GUID-00558997-9D51-426E-A83E-D26D379EA62F-low.bmp\' title=\'\'> <img src=\'developer/images/GUID-EBD168FA-3C37-48A5-A1E8-133B9E7E44A0-low.bmp\' title=\'\'></p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>CUSTOM COMPOSITING EXAMPLE</strong></p>\n\
<p>``` resetMaxFile #noPrompt--start a new scene --Create a teapot and two slightly offset target cameras theTeapot = teapot wirecolor:white segs:10 theTarget1 = targetObject pos:[-1,0,10] theCamera1 = TargetCamera pos:[-10,-130,30] target:theTarget1 theTarget2 = targetObject pos:[1,0,10] theCamera2 = TargetCamera pos:[10,-130,30] target:theTarget2</p>\n\
<p>--Create two bitmaps to render and process b1 = bitmap 320 240 b2 = bitmap 320 240 --Render the two cameras into the two bitmaps render camera:theCamera1 to:b1 vfb:off render camera:theCamera2 to:b2 vfb:off</p>\n\
<p>--This is the custom compositing function: fn compfn c1 p1 c2 p2 = ( res = c2--the result will contain the G and B of b2 res.r = c1.r--but the R from b1 res--then we return the resulting color value )</p>\n\
<p>--Perform the compositing using the above function: pastebitmap b1 b2 [0,0] [0,0] type:#function function:compfn display b2</p>\n\
<p>```</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-C4589BE0-DC94-4377-B2ED-2AF47E423C0F-low.gif\' title=\'\'></div>\n\
<p>This method is typically 3 to 5 times faster than using getPixels/SetPixels in a MAXScript loop depending on the complexity of the custom function.</p>\n\
<p>For an example of modifying a single bitmap using this method, see the third example in the <a href=\'#!/url=./developer/Frequently-Asked-Questions/Writing-Better-and-Faster/How-To-Make-It-Faster-/Never-get-a-single-pixel-when.html\' title=\'\'>Never get a single pixel when you can get a whole line</a> topic of the MAXScript Frequently Asked Questions.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>getBitmapInfo {&lt;filename&gt; | &lt;bitmap&gt;} \n\
</pre></div><p>Returns information on the specified bitmap file as a 13 element array. Available in <strong>3ds Max 2008 and higher</strong>. Previously, available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<p><strong>Array elements are:</strong></p>\n\
<p>1. Expanded bitmap file name as String</p>\n\
<p>2. Device name as String</p>\n\
<p>3. Bitmap width as Integer</p>\n\
<p>4. Bitmap height as Integer</p>\n\
<p>5. Number of bits for each RGB component value as Integer</p>\n\
<p>6. Number of bits for alpha component as Integer.</p>\n\
<p>7. The aspect ratio of the bitmap as Float</p>\n\
<p>8. The gamma of the bitmap as Float</p>\n\
<p>9. Whether the bitmap has alpha as a Boolean</p>\n\
<p>10. First frame as Integer</p>\n\
<p>11. Last frame as Integer</p>\n\
<p>12. The bitmap type (from BitmapInfo::Type()) as Integer. See topic &quot;Bitmap Types&quot; in the SDK help file for more info on the bitmap types.</p>\n\
<p>13. The bitmap flags (from BitmapInfo::Flags()) as Integer. See topic &quot;Bitmap Flags&quot; in the SDK help file for more info on the meaning of each bit.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` print (getBitmapInfo (getDir #maxroot +&quot;\\maps\\OAKLEAF.TGA&quot;))</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` &quot;C:\\Program Files\\Autodesk\\3ds Max 2015\\maps\\OAKLEAF.TGA&quot; &quot;Targa Image File&quot; 152 256 8 8 1.0 2.2 false 0 0 3 0 OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>forceReloadBitmapFile &lt;bitmap&gt;\n\
</pre></div><p>Forces the reloading of the Bitmap File associated with the specified bitmap.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;registerFileChangedFunction &lt;bitmap&gt; &lt;callback_functions&gt;\n\
</pre></div><p>Registers a File Change Callback Function for the bitmap specified by the first argument.</p>\n\
<p>The second argument must be a MAXScript function expecting one argument.</p>\n\
<p>Returns True on success, False on failure.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` b = bitmap 100 100 --Create a new bitmap value b.filename = @&quot;c:\\temp\\testme.bmp&quot; --Give it a file name save b --Save it to file</p>\n\
<p>--Now open the file for reading b1 = openbitmap @&quot;c:\\temp\\testme.bmp&quot;</p>\n\
<p>--Define and register a callback function to monitor bitmap file changes fn onFileChanged arg = format &quot;Bitmap Value File Modified: %\\n&quot; arg registerFileChangedFunction b1 onFileChanged</p>\n\
<p>setPixels b [50,50] #(red) --Write a pixel into the original bitmap value... save b --...and save it to disk --The change to the file on disk will trigger the callback function! --&gt; Bitmap Value File Modified: BitMap:c:\\temp\\testme.bmp</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Related Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;setSilentMode &lt;boolean&gt; \n\
</pre></div><p>Sets Silent mode on or off. If Silent mode is off, any errors occurring during bitmap input or output will result in an error message dialog being displayed by the <strong>3ds Max</strong> bitmap I/O routines. If Silent mode is on, error message dialogs are not displayed. Returns a boolean signifying the prior Silent mode state.</p>\n\
<p>The Silent mode state is an internal <strong>3ds Max</strong> state, and other <strong>3ds Max</strong> plug-ins can turn this state on or off. If you use this method, it is recommended that you turn the state on or off saving the return value, perform the bitmap input or output, and then restore the state to its original value.</p>\n\
<div class=\'codeBlock\'><pre>silentMode() \n\
</pre></div><p>Returns a boolean signifying the Silent mode state.</p>\n\
<div class=\'codeBlock\'><pre>selectSaveBitMap [caption:&lt;open_dialog_title_string&gt; ] [gamma:&amp;gama_value] [metadata:&amp;dataArray]\n\
</pre></div><p>Displays a <strong>3ds Max</strong> bitmap save dialog and returns the fully-specified file path name as a string.</p>\n\
<p>Returns <span class=\'code\'>undefined</span> if the user cancels out of the bitmap save dialog.</p>\n\
<p>If the optional <span class=\'code\'>gamma:</span> keyword is provided in <strong>3ds Max 2014 and higher</strong>, the by-reference variable passed as parameter will be set to the gamma mode value: <span class=\'code\'>#auto</span> , <span class=\'code\'>#default</span> , or a Float gamma override value.</p>\n\
<p>If the optional <span class=\'code\'>metadata:</span> keyword is provided in <strong>3ds Max 2014 and higher</strong>, the by-reference variable passed as parameter will be set to the BitmapInfo expressed as an array of values that can be passed to the <span class=\'code\'>save()</span> function&#39;s <span class=\'code\'>metadata:</span> optional keyword. See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Bitmap-Values/Bitmap-Gamma-and-MAXScript.html\' title=\'\'>Bitmap Gamma and MAXScript</a> for details.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>bitmap.filename = SelectSaveBitmap caption:&quot;Select a file&quot; gamma:&amp;gma metadata:&amp;data   if (bitmap.filename) do save bitmap gamma:gma metadata:data</span></p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>freeSceneBitmaps() \n\
</pre></div><p>Frees up all the memory used by the image file bitmap caches. This is useful if memory is fragmented with a lot of different bitmaps and you want to have just the ones currently active reloaded.</p>\n\
<div class=\'codeBlock\'><pre>getBitmapOpenFileName [caption:&lt;title&gt;] [filename:&lt;seed_filename_string&gt;]  [metadata:&amp;dataArray]\n\
\n\
getBitmapSaveFileName [caption:&lt;title&gt;] [filename:&lt;seed_filename_string&gt;] [metadata:&amp;dataArray]\n\
</pre></div><p>Displays the bitmap file selection dialog.</p>\n\
<p>Both functions return a fully-specified file path name or undefined if the user cancels out.</p>\n\
<p>If an existing file name is selected using the <span class=\'code\'>getBitmapSaveFileName()</span> function, a File Exists/Confirm Overwrite dialog will be displayed.</p>\n\
<p>If the optional <span class=\'code\'>metadata:</span> keyword is provided in <strong>3ds Max 2014 and higher</strong>, the by-reference variable passed as parameter will be set to the BitmapInfo expressed as an array of values that can be passed to the <span class=\'code\'>save()</span> function&#39;s <span class=\'code\'>metadata:</span> optional keyword. See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Bitmap-Values/Bitmap-Gamma-and-MAXScript.html\' title=\'\'>Bitmap Gamma and MAXScript</a> for details.</p>\n\
<p>Note:</p>\n\
<p>The <span class=\'code\'>getBitmapOpenFileName()</span> function does not require that an existing file name be selected. A file name is returned if the user types a file name that does not exist. If necessary, you should check the file name that is returned to ensure the file exists.</p>\n\
<p>When you open a bitmap file, an entire frame is loaded into memory. When you are finished processing a bitmap, it is a good idea to either call <span class=\'code\'>close()</span> on the bitmap or assign the value <span class=\'code\'>undefined</span> to the variable storing the bitmap value, and then manually run garbage collection ( <span class=\'code\'>gc light:true</span> ) so that memory can be released. Another technique for conserving memory when using the <span class=\'code\'>render()</span> or <span class=\'code\'>getChannelAsMask()</span> functions repeatedly is to use the <span class=\'code\'>to:&lt;bitmap&gt;</span> keyword argument which allows those functions to overwrite an existing bitmap’s pixel image with the new rendering or mask.</p>\n\
<p>There is currently no access to the properties associated with some of the bitmap output plug-ins. This means that you cannot set the codec used for .avi files. The properties used are the properties that were last used when saving that file type in <strong>3ds Max</strong>.</p>\n\
<p>The following script shows how to properly create and save a multi-frame image file in AVI format.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` theTeapot=teapot()--something to render animate on at time 10 --set animate and time context rotate theTeapot 180 z_axis--rotate the teapot cam=targetcamera pos:[200,0,100] --camera pointed at teapot target:theTeapot renderFrames=#{1,3,5..12}-- specify frames to render b=bitmap 160 120 filename:@&quot;c:\\temp\\testme.bmp&quot;--create a new bitmap for i= 1 to renderFrames.count do--loop though renderFrames ( if renderFrames[i] then--if supposed to render frame... ( at time i--set time context render 160 120 camera:cam to:b-- render to bitmap frame save b frame:i-- save each frame as you advance )-- if you save AFTER the loop, -- just the last frame is saved. ) close b-- close the output file - this will also get rid of --the reference to the bitmap value and free its memory.</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` $Teapot:Teapot004 @ [0.000000,0.000000,0.000000]-- result of line 1 OK-- result of lines 2 and 3 $Target_Camera:Camera005 @ [200.000000,0.000000,100.000000]-- result of lines 4 and 5 #{1, 3, 5..12}-- result of line 6 BitMap:c:\\temp\\testme.bmp-- result of line 7 OK-- result of for loop, lines 8 to 15 OK-- result of line 16</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note:</p>\n\
<p>While the <span class=\'code\'>frame:i</span> keyword argument to the <span class=\'code\'>save()</span> method is optional for AVI files (they would advance automatically after each frame), Quicktime MOV files <strong>require</strong> it to save correctly. Otherwise, each rendered frame will overwrite the first frame in the file and the MOV would end up only one frame long.</p>\n\
<p>The following script reads a bitmap file and outputs a script to Listener that implements a function to recreate the same bitmap. This function can then be copied into your script. This is useful for building button images in MAXScript so that you do not need to distribute bitmap files along with your script.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` ( b=selectbitmap()-- open image file browser bname=&quot;bitmap_&quot;+(getfilenamefile b.filename)-- build name from filename w=b.width-- get properties of bitmap h=b.height format &quot;----------\\nfn load_% = (\\n&quot; bname -- start defining function format &quot;local %=bitmap % %\\n&quot; bname w h -- create bitmap in function -- write out a function that unpacks an integer into a pixel color format &quot;fn unpack val = for p in val collect (r=p/256^2; g=p/256-r<em>256; b=mod p 256; color r g b)\\n&quot; for r = 0 to h-1 do-- for each row in the bitmap -- have function write the column of pixels to the bitmap ( format &quot;setpixels % [0,%] (unpack #(&quot;bname r pixels=getpixels b [0,r] w-- read in the column of pixels for c = 1 to w do-- loop through each pixel ( p = pixels[c]-- get the pixel -- pack the pixel into an integer and write it out format &quot;%&quot; (((p.r as integer)</em>256+(p.g as integer))*256+(p.b as integer)) if c != w then-- if not at end of data format &quot;, &quot;-- write a comma else format &quot;))\\n&quot;-- else close out the line ) ) format &quot;return %\\n&quot; bname-- function returns the bitmap format &quot;)\\n----------\\n&quot;-- finish off function definition )</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">```</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">fn load_bitmap_convert = (</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">local bitmap_convert=bitmap 4 4</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">fn unpack val = for p in val collect (r=p/256^2; g=p/256-r*256; b=mod p 256; color r g b)</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">setpixels bitmap_convert [0,0] (unpack #(12632256, 12632256, 12632256, 12632256))</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">setpixels bitmap_convert [0,1] (unpack #(255, 255, 255, 255))</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">setpixels bitmap_convert [0,2] (unpack #(255, 255, 255, 255))</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">setpixels bitmap_convert [0,3] (unpack #(255, 12632256, 12632256, 12632256))</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">return bitmap_convert</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">)</td>\n\
</tr>\n\
</table>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Also see the example in<a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/Point3-Values.html\' title=\'\'>Point3 Values</a> for another usage of class Bitmap.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";