var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Working with MAXKey Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Working with MAXKey Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"working-with-maxkey-values\"></a></div>\n\
<p>Changing the <span class=\'code\'>.time</span> property of a key may cause it to go out of time order relative to the other keys in the controller. You <strong>must</strong> call the <span class=\'code\'>sortKeys()</span> function on the controller or associated <strong>MAXKeyArray</strong> once all key time manipulations of this kind is complete so that animation will perform correctly.</p>\n\
<p>The class of a key&#39;s value property is determined by the controller it is in, for example, a <span class=\'code\'>linear_float</span> key has a float <span class=\'code\'>.value</span> , a <span class=\'code\'>tcb_rotation</span> key has a quaternion <span class=\'code\'>.value</span> , etc. The properties are all settable and support the math-assignment operators and nested-property access.</p>\n\
<blockquote>\n\
<p><strong>HERE ARE SOME EXAMPLES:</strong></p>\n\
<p>``` $foo.pos.keys[2].time += 20f -- change time of single key $foo.pos.keys.time += 20f -- change time of all keys $box1.uvw_map.center.keys[2].value.x += 20 for k in $baz.bend.angle.keys do k.value *= 1.1</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In some cases, the actual value stored in a key is not the value shown in the command panels, shown in Track View, the value returned by the <span class=\'code\'>.value</span> property of the key, or the value returned when accessing the property to which the key’s controller is assigned. Instead, a scaling factor is applied to the key’s value before the value is made &quot;visible&quot;. For example, percentages are normally displayed with a range of 0-100, rotation angles are in degrees, colors are [0-255,0-255,0-255]. The unscaled key values for percentages are normally in a range of 0-1, rotation angles in radians, and colors are [0-1,0-1,0-1].</p>\n\
<p>In the description of properties for each class, the scaling factor, if any, is identified for each property. Take the following properties for the PArray class</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` <parray>.X_Spin_Vector Float default: 1.0 -- animatable <parray>.Spin_Time_Variation Float default: 0.0 -- animatable, percentage <parray>.Spin_Phase Float default: 0.0 -- animatable, angle <parray>.viewPercent Float default: 10.0 -- percentage<p>\n\
<p>```</p>\n\
</parray></parray></parray></parray></blockquote>\n\
<p>The <span class=\'code\'>.X_Spin_Vector</span> property does not apply any scaling to its controller keys. The <span class=\'code\'>.Spin_Time_Variation</span> property applies percentage scaling to its controller keys (displayed as percentage, stored as fraction). The <span class=\'code\'>.Spin_Phase</span> property applies angle scaling to its controller keys (displayed as degrees, stored as radians). The <span class=\'code\'>.viewPercent</span> property is stored internally with a percentage scaling factor, but since this property is not animatable, this scaling it invisible to MAXScript.</p>\n\
<p>Normally this scaling is not of concern when programming in MAXScript, but there are two cases where it must be taken into account. The first is when using script controllers, and is described in <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Animation-Controllers/Controller-Types/Script-Controllers/Script-Controllers-1.html\' title=\'\'>Script Controllers</a>.</p>\n\
<p>The second case is when one controller is applied as the controller for two or more properties. The scaling is an attribute of the animatable <strong>property</strong>, not the controller, so in (the admittedly rare) situations in which a controller is shared by several animatables that have <strong>different</strong> scaling, unexpected results will occur if you do not take into account the scaling factor. An example of this is shown in the following script, where the same controller is shared between three differently scaled properties.</p>\n\
<blockquote>\n\
<p><strong>FOREXAMPLE:</strong></p>\n\
<p>``` obj=PArray() cont=bezier_float() obj.X_Spin_Vector.controller=cont obj.Spin_Time_Variation.controller=cont obj.Spin_Phase.controller=cont obj.X_Spin_Vector=1 obj.X_Spin_Vector -- no scaling obj.Spin_Time_Variation -- percentage obj.Spin_Phase -- angle</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` $PArray:PArray03 @ [0,0,0] -- result line 1 Controller:Bezier_Float -- result line 2 Controller:Bezier_Float -- result line 3 Controller:Bezier_Float -- result line 4 Controller:Bezier_Float -- result line 5 1 -- result line 6 1.0 -- result line 7, unscaled 100.0 -- result line 8, percentage scaled, 1 = 100% 57.2958 -- result line 9, angle scaled, 1 radian = 57.2958 degrees</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>If you do assign the same controller to properties with different scaling factors, you should take care to access the <span class=\'code\'>.value</span> property through the correct animatable property - this provides a scaling context for the access operation.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";