var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>FileStream Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>FileStream Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"filestream-values\"></a></div>\n\
<p>A <strong>FileStream</strong> class implements text file input and output in MAXScript. A FileStream value represents an open text file in MAXScript. Text file I/O is performed by calling functions on the FileStream value.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre> createFile &lt;filename_string&gt;\n\
[encoding:{ &lt;#current&gt; | &lt;#English&gt; | &lt;#German&gt; | &lt;#French&gt; | &lt;#Japanese&gt; | &lt;#Korean&gt; | &lt;#Chinese&gt; | &lt;#utf8&gt; | &lt;#utf16LE&gt; | &lt;#utf16BE&gt; | &lt;int codepage&gt; } ] \\\n\
[writeBOM:&lt;boolean&gt;]\n\
\n\
</pre></div><p>Creates a new file and returns a <span class=\'code\'>&lt;filestream&gt;</span> value. If the specified file cannot be created, the value <span class=\'code\'>undefined</span> is returned.</p>\n\
<p>The <strong>encoding:</strong> keyword option can be used to enforce a specific character encoding. If not supplied, it defaults to <strong><span class=\'code\'>#current</span></strong> encoding.</p>\n\
<p>The <strong>writeBOM:</strong> keyword option can be used to control whether the Byte-Order-Mark of UTF-8 files will be written.</p>\n\
<p>See the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/Character-Encoding.html\' title=\'\'>Character Encoding</a> topic for details on Unicode and BOM usage in <strong>3ds Max 2013 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre> openFile &lt;filename_string&gt;\n\
[mode:&lt;mode_string&gt;]\n\
[encoding:{ &lt;#current&gt; | &lt;#English&gt; | &lt;#German&gt; | &lt;#French&gt; | &lt;#Japanese&gt; | &lt;#Korean&gt; | &lt;#Chinese&gt; | &lt;#utf8&gt; | &lt;#utf16LE&gt; | &lt;#utf16BE&gt; | &lt;int codepage&gt; } ] \\\n\
[writeBOM:&lt;boolean&gt;]\n\
\n\
</pre></div><p>Opens a file and returns a <span class=\'code\'>&lt;filestream&gt;</span> value. If the specified file cannot be opened, the value <span class=\'code\'>undefined</span> is returned. The optional <span class=\'code\'>&lt;mode_string&gt;</span> can be:</p>\n\
<p><span class=\'code\'>r</span> - read-only text - file must exist</p>\n\
<p><span class=\'code\'>rt</span> - read-only text - file must exist</p>\n\
<p><span class=\'code\'>rb</span> - read-only binary - file must exist</p>\n\
<p><span class=\'code\'>r+</span> - read/write text - file must exist</p>\n\
<p>The default is &quot;rt&quot;.</p>\n\
<p><span class=\'code\'>a</span> - write-only text, append writes - <strong>in 3ds Max 2013</strong> the file is created if it does not exist (in <strong>3ds Max 2012 and earlier</strong>, the file must exist)</p>\n\
<p><span class=\'code\'>at</span> - write-only text, append writes - <strong>in 3ds Max 2013</strong> the file is created if it does not exist (in <strong>3ds Max 2012 and earlier</strong>, the file must exist)</p>\n\
<p><span class=\'code\'>ab</span> - write-only binary, append writes - <strong>in 3ds Max 2013</strong> the file is created if it does not exist (in <strong>3ds Max 2012 and earlier</strong>, the file must exist)</p>\n\
<p><span class=\'code\'>a+</span> - read/write text, append writes - <strong>in 3ds Max 2013</strong> the file is created if it does not exist (in <strong>3ds Max 2012 and earlier</strong>, the file must exist)</p>\n\
<p><span class=\'code\'>w</span> - write-only text - deletes the file contents if it exists</p>\n\
<p><span class=\'code\'>wt</span> - write-only text - deletes the file contents if it exists</p>\n\
<p><span class=\'code\'>wb</span> - write-only binary - deletes the file contents if it exists</p>\n\
<p><span class=\'code\'>w+</span> - read/write text - deletes the file contents if it exists</p>\n\
<p><strong>S</strong> - access is primarily sequential</p>\n\
<p><strong>R</strong> - access is primarily random</p>\n\
<p><strong>T</strong> - temporary storage file (try not to flush)</p>\n\
<p><strong>D</strong> - file is deleted when the last handle is closed</p>\n\
<p><strong>c</strong> - enable the commit flag for the associated filename so that the contents of the file buffer are written directly to the disk if close or flush is called.</p>\n\
<p><strong>n</strong> - reset the commit flag for the associated filename to &quot;no-commit&quot; - contents of the file buffer are written to operating system buffers.</p>\n\
<blockquote>\n\
<p>Warning: These modes are <strong>actual string</strong> and must be always written in quotation marks. They are also <strong>case sensitive</strong>.</p>\n\
</blockquote>\n\
<p>When a file is opened with one of the <span class=\'code\'>&quot;a&quot;</span> access types, all write operations occur at the end of the file. The file pointer can be repositioned using seek, but is always moved back to the end of the file before any write operation is carried out. Thus, existing data cannot be overwritten.</p>\n\
<p>The <span class=\'code\'>&quot;a&quot;</span> mode does not remove the EOF marker before appending to the file. After appending, the MS-DOS TYPE command only shows data up to the original EOF marker and not any data appended to the file.</p>\n\
<p>The <span class=\'code\'>&quot;a+&quot;</span> mode does remove the EOF marker before appending to the file. After appending, the MS-DOS TYPE command shows all data in the file. The <span class=\'code\'>&quot;a+&quot;</span> mode is required for appending to a stream file that is terminated with the CTRL+Z EOF marker.</p>\n\
<p>When the <span class=\'code\'>&quot;r+&quot;</span> , <span class=\'code\'>&quot;w+&quot;</span> , or <span class=\'code\'>&quot;a+&quot;</span> access type is specified, both reading and writing are allowed (the file is said to be open for &quot;update&quot;). However, when you switch between reading and writing, there must be an intervening <span class=\'code\'>flush()</span> or <span class=\'code\'>seek()</span> operation. The current position can be specified for the <span class=\'code\'>seek()</span> operation, if desired.</p>\n\
<p>The <strong>encoding:</strong> keyword option can be used to enforce a specific character encoding. If not supplied, it defaults to <span class=\'code\'>#current</span> encoding.</p>\n\
<p>See the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/Character-Encoding.html\' title=\'\'>Character Encoding</a> topic for details.</p>\n\
<div class=\'codeBlock\'><pre> openEncryptedFile &lt;filename&gt; &lt;key&gt;\n\
[encoding:{ &lt;#current&gt; | &lt;#English&gt; | &lt;#German&gt; | &lt;#French&gt; | &lt;#Japanese&gt; | &lt;#Korean&gt; | &lt;#Chinese&gt; | &lt;#utf8&gt; | &lt;#utf16LE&gt; | &lt;#utf16BE&gt; | &lt;int codepage&gt; } ] \\\n\
[writeBOM:&lt;boolean&gt;]\n\
\n\
</pre></div><p>Opens the encrypted file using the given integer key and returns a FileStream value that you can then do read calls on, exactly as you can on FileStreams returned from the <span class=\'code\'>openFile()</span> function. See <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/Text-and-Binary-File-Input-and/Encrypted-Files.html\' title=\'\'>Encrypted Files</a> for details on encrypted files.</p>\n\
<p>The <strong>encoding:</strong> keyword option can be used to enforce a specific character encoding. If not supplied, it defaults to <strong><span class=\'code\'>#current</span></strong> encoding.</p>\n\
<p>The <strong>writeBOM:</strong> keyword option can be used to control whether the Byte-Order-Mark of UTF-8 files will be written.</p>\n\
<p>See the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/Character-Encoding.html\' title=\'\'>Character Encoding</a> topic for details on Unicode and BOM usage in <strong>3ds Max 2013 and higher</strong>.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>readLine &lt;filestream&gt;\n\
</pre></div><p>Read next line, return as string.</p>\n\
<div class=\'codeBlock\'><pre>readChar &lt;filestream&gt;\n\
</pre></div><p>Read next char, return as string.</p>\n\
<div class=\'codeBlock\'><pre>readChars &lt;filestream&gt; &lt;char_count&gt; errorAtEOF:&lt;boolean&gt;\n\
</pre></div><p>Reads the specified number of characters and returns them in a string.</p>\n\
<p>When the <span class=\'code\'>errorAtEOF</span> parameter is <strong>false</strong>, this method does not throw an exception when it attempts to read past the end of the filestream. As well, setting this parameter to <strong>false</strong> and <span class=\'code\'>&lt;char_count&gt;</span> to -1 causes this method to read to the end of the file. The default is <strong>true</strong>.</p>\n\
<div class=\'codeBlock\'><pre>readDelimitedString &lt;filestream&gt; &lt;string&gt;\n\
</pre></div><p>Takes a delimiter character (as a string) and reads in characters until the delimiter is found (or end-of-file is reached) and returns the characters in a string.</p>\n\
<p>Note: If the delimiter string is more than one character, every single character in the string is treated as a delimiter, rather than the string itself. For example, with a filestream that contains &quot;This is an abc string&quot; and a delimiter of &quot;abc&quot;, this function will return “This is &quot; rather than &quot;This is an&quot;.</p>\n\
<div class=\'codeBlock\'><pre>skipToString &lt;filestream&gt; &lt;string&gt;\n\
</pre></div><p>Takes a character string and scans forward in the file until it finds an occurrence of the string and positions the file just after that string.</p>\n\
<p>If the string is not found, the function returns the value <span class=\'code\'>undefined</span> .</p>\n\
<div class=\'codeBlock\'><pre>skipToNextLine &lt;filestream&gt;\n\
</pre></div><p>Positions the input file at the beginning of the next line.</p>\n\
<div class=\'codeBlock\'><pre>filePos &lt;filestream&gt;\n\
</pre></div><p>Retrieves the current offset into the file.</p>\n\
<div class=\'codeBlock\'><pre>seek &lt;filestream&gt; &lt;integer&gt;\n\
</pre></div><p>Positions the file at the given offset so that the subsequent I/O starts there.</p>\n\
<p>Note: The <span class=\'code\'>seek</span> methods accept <span class=\'code\'>#eof</span> as an argument. Specifying this places you at the end of the file/string stream. A <span class=\'code\'>filePos</span> at this point tells you the length of the file. The <span class=\'code\'>readChars</span> method now also accepts a Boolean keyword parameter called <span class=\'code\'>errorAtEOF</span> . The default value for this keyword parameter is <span class=\'code\'>True</span> to match current behavior. If <span class=\'code\'>False</span> , and an attempt is made to read across the end of the file, no error message is generated and the return string contains the contents up to the end of the file.</p>\n\
<blockquote>\n\
<p><strong>So, you can use:</strong></p>\n\
<p>``` seek fin #eof maxlen=filepos fin seek fin 0 res = readChars fin maxlen errorAtEOF:false</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>eof &lt;filestream&gt;\n\
</pre></div><p>Returns <strong>true</strong> if there is no more data in the file, <strong>false</strong> otherwise.</p>\n\
<div class=\'codeBlock\'><pre>flush &lt;filestream&gt;\n\
</pre></div><p>Ensure all output to file is on the disk, flushes the memory buffers.</p>\n\
<div class=\'codeBlock\'><pre>close &lt;filestream&gt;\n\
</pre></div><p>Flushes the memory buffers and closes the file.</p>\n\
<div class=\'codeBlock\'><pre>free &lt;filestream&gt;\n\
</pre></div><p>Frees the memory used by the filestream value without waiting for garbage collection.</p>\n\
<p>Available in <strong>3ds Max 9 and higher</strong>.</p>\n\
<p>For the following methods, see the description of the <span class=\'code\'>execute()</span> method in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/String-Values.html\' title=\'\'>String Values</a> for information on the scope of variables used in the evaluated expressions.</p>\n\
<div class=\'codeBlock\'><pre>readValue &lt;filestream&gt; [ ignoreStringEscapes:&lt;boolean&gt; ]\n\
</pre></div><p>Read and evaluate the next MAXScript <span class=\'code\'>&lt;operand&gt;</span> from the file.</p>\n\
<p>If the optional <span class=\'code\'>ignoreStringEscapes:</span> keyword argument is not supplied or supplied as false and the value read is a string, &#39;\\&#39; characters in the string are handled as escape characters. If true, &#39;\\&#39; characters in the string are not handled as escape characters. Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>readExpr &lt;filestream&gt;\n\
</pre></div><p>Read and evaluate the next MAXScript <span class=\'code\'>&lt;expr&gt;</span> from the file.</p>\n\
<p>Note that the scope of the evaluation is the <strong>global</strong> scope, and not the current scope.</p>\n\
<div class=\'codeBlock\'><pre>execute &lt;filestream&gt;\n\
</pre></div><p>Read and evaluate all the expressions left in the file. Note that the scope of the evaluation is the <strong>global</strong> scope, and not the current scope.</p>\n\
<p>The differences between the above methods can be seen in the following example. In this example, a stringstream value is created that contains a string containing two expressions - <span class=\'code\'>random 0. 1.</span> and <span class=\'code\'>random red blue</span> . The <span class=\'code\'>readValue</span> , <span class=\'code\'>readExpr</span> , and <span class=\'code\'>execute</span> methods are then used with the stringstream as the argument.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` s=stringstream &quot;random 0. 1.;random red blue&quot; readvalue s -- read and evaluate the first value readvalue s -- read and evaluate the second value seek s 0 -- position at beginning of stringstream readexpr s -- read and evaluate the first expression readexpr s -- read and evaluate the second expression seek s 0 -- position at beginning of stringstream execute s -- evaluate all expressions</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT</strong></p>\n\
<p>``` StringStream: &quot;random 0. 1.;random red blue&quot; -- result line 1 random() -- result line 2 (evaluated &quot;random&quot;) 0.0 -- result line 3 (evaluated &quot;0.&quot;) OK -- result line 4 0.448042 -- result line 5 (evaluated &quot;random 0. 1. &quot;) (color 86.476 0 163.24) -- result line 6 (evaluated &quot;random red blue&quot;) OK -- result line 7 (color 30.2417 0 143.636) -- result line 7 (evaluated all expressions, -- returns result of last expression)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Associated Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>print &lt;value&gt; to:&lt;filestream&gt;\n\
</pre></div><p>Prints the value to the specified file stream.</p>\n\
<div class=\'codeBlock\'><pre>format &lt;fmt_string&gt; { &lt;value&gt; } to:&lt;filestream&gt;\n\
</pre></div><p>Formats the value to the specified file stream.</p>\n\
<p>See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Value-Common-Properties.html\' title=\'\'>Value Common Properties, Operators, and Methods</a> for detailed description of these methods.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";