var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>StringStream Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>StringStream Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"stringstream-values\"></a></div>\n\
<p>The <strong>StringStream</strong> class allows you to construct and parse strings using all the text file I/O functions. For example, you can set up a StringStream and build it up by performing prints and formats to it, just as you would to a text file. Conversely, you can convert a String into a StringStream and then work through it using functions like <span class=\'code\'>readLine()</span> , <span class=\'code\'>readValue()</span> , <span class=\'code\'>skipToString()</span> , etc. Since Strings are easily converted to and from StringStreams, this is often a convenient way to work on large, complex strings.</p>\n\
<p>The StringStream class can be used in conjunction with the <strong>AppData accessing functions</strong> for storing and retrieving large and complex amounts of script-generated data permanently <strong>within</strong> a <strong>3ds Max</strong> scene file.</p>\n\
<p><strong>Constructors</strong></p>\n\
<div class=\'codeBlock\'><pre>stringStream &lt;initial_string&gt;    \n\
</pre></div><p>Create a new StringStream using the initial string.</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt; as stringStream \n\
</pre></div><p>Convert existing String to StringStream.</p>\n\
<p>See also <a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Literal-Constants/String-Literals.html\' title=\'\'>String Literals</a> and <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/String-Values.html\' title=\'\'>String Values</a>.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;stringstream&gt; as string \n\
</pre></div><p>Convert StringStream to a String</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>copy &lt;stringstream&gt; \n\
</pre></div><p>Create a separate copy of the StringStream</p>\n\
<div class=\'codeBlock\'><pre>free &lt;stringStream&gt;\n\
</pre></div><p>Frees the memory used by the stringStream value without waiting for garbage collection.</p>\n\
<p>Available in <strong>3ds Max 9 and higher</strong>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` ss = stringstream &quot;ABCDE&quot; --&gt; StringStream:&quot;ABCDE&quot; ss --&gt; StringStream:&quot;ABCDE&quot; free ss --&gt; OK ss --&gt; StringStream:&quot;&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Associated Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>print &lt;value&gt; to:&lt;stringstream&gt; \n\
format &quot;&lt;fmt_string&gt;&quot; {values} to:&lt;stringstream&gt; \n\
</pre></div><p>The <span class=\'code\'>print()</span> and <span class=\'code\'>format()</span> functions provide a way to build up a StringStream a piece at a time. As with text file output, each call to print or format appends to existing text, the StringStream dynamically grows as needed. Note that you can reposition output streaming using the <span class=\'code\'>seek()</span> function documented below.</p>\n\
<p>The following functions are identical to the text file input functions available for text FileStream values. (See the <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/FileStream-Values.html\' title=\'\'>FileStream Values</a> class documentation). When called on StringStream instances, they read progressively through the string extracting successive values and lines and characters, etc.</p>\n\
<div class=\'codeBlock\'><pre>&lt;stringstream&gt;append &lt;stringstream&gt; &lt;string&gt;\n\
</pre></div><p>Appends the string passed as second argument to the stringstream provided as first argument.</p>\n\
<p>It operates on the stringstream in place, and also returns the resulting stringstream.</p>\n\
<p>Available in <strong>3ds Max 2012 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>readValue &lt;stringstream&gt; [ ignoreStringEscapes:&lt;boolean&gt; ] \n\
</pre></div><p>Read and evaluate the next MAXScript <span class=\'code\'>&lt;operand&gt;</span> from the stringStream.</p>\n\
<p>If the optional <span class=\'code\'>ignoreStringEscapes:</span> keyword argument is not supplied or supplied as false and the value read is a string, &#39;\\&#39; characters in the string are handled as escape characters. If true, &#39;\\&#39; characters in the string are not handled as escape characters. This option is available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` ss = stringstream &quot;&quot;a\\tb&quot;&quot; seek ss 0 readvalue ss</p>\n\
<p>```</p>\n\
<p><strong>RESULT</strong></p>\n\
<p>``` &quot;a b&quot; -- \\t handled as a tab</p>\n\
<p>```</p>\n\
<p><strong>BUT</strong></p>\n\
<p>``` seek ss 0 readvalue ss ignoreStringEscapes:true</p>\n\
<p>```</p>\n\
<p><strong>RESULT</strong></p>\n\
<p>``` &quot;a\\t\\b&quot; -- \\t handled as characters</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>readExpr &lt;stringstream&gt; \n\
</pre></div><p>Read and evaluate the next MAXScript <span class=\'code\'>&lt;expr&gt;</span> from the stringStream. As with <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Basic-Data-Values/String-Values.html\' title=\'\'>execute(),</a> the scope of the evaluation is the global scope, not the current scope.</p>\n\
<div class=\'codeBlock\'><pre>readLine &lt;stringstream&gt; \n\
</pre></div><p>Read next line, return as string</p>\n\
<div class=\'codeBlock\'><pre>readChar &lt;stringstream&gt; \n\
</pre></div><p>Read next char, return as string</p>\n\
<div class=\'codeBlock\'><pre>readChars &lt;stringstream&gt; &lt;number&gt; errorAtEOF:&lt;boolean&gt;\n\
</pre></div><p>Reads the specified number of characters and returns them in a string.</p>\n\
<p>When the <span class=\'code\'>errorAtEOF</span> parameter is <strong>false</strong>, this method does not throw an exception when it attempts to read past the end of the stringstream. As well, setting this parameter to <strong>false</strong> and <span class=\'code\'>&lt;char_count&gt;</span> to -1 causes this method to read to the end of the stringstream. The default is <strong>true</strong>.</p>\n\
<div class=\'codeBlock\'><pre>readDelimitedString &lt;stringstream&gt; &lt;string&gt; \n\
</pre></div><p>Takes a delimiter character (as a string) and reads in characters until the delimiter is found (or end-of-file is reached) and returns the characters in a string.</p>\n\
<p>Note: If the delimiter string is more than one character, every single character in the string is treated as a delimiter, rather than the string itself. For example, <span class=\'code\'>readDelimitedString (stringStream &quot;This is an abc string&quot;) &quot;abc&quot;</span> will return “This is &quot; rather than &quot;This is an&quot;.</p>\n\
<div class=\'codeBlock\'><pre>skipToString &lt;stringstream&gt; &lt;string&gt; \n\
</pre></div><p>Takes a character string and scans forward in the file until it finds an occurrence of the string and positions the file just after that string. If the string is not found, the function returns the value <span class=\'code\'>undefined</span> .</p>\n\
<div class=\'codeBlock\'><pre>skipToNextLine &lt;stringstream&gt; \n\
</pre></div><p>Positions the input file at the beginning of the next line</p>\n\
<div class=\'codeBlock\'><pre>execute &lt;stringstream&gt; \n\
</pre></div><p>Read and evaluate all the expressions left in the stringStream. Note that the scope of the evaluation is the <strong>global</strong> scope, not the current scope!</p>\n\
<div class=\'codeBlock\'><pre>filePos &lt;stringstream&gt; \n\
</pre></div><p>Retrieve the current offset into the file</p>\n\
<div class=\'codeBlock\'><pre>seek &lt;stringstream&gt; &lt;pos&gt; \n\
</pre></div><p>Position the file at the given offset so that subsequent I/O will start there.</p>\n\
<div class=\'codeBlock\'><pre>eof &lt;stringstream&gt; \n\
</pre></div><p>Returns <strong>true</strong> if there is no more data in the stringStream, <strong>false</strong> otherwise.</p>\n\
<div class=\'codeBlock\'><pre>close &lt;stringstream&gt; \n\
flush &lt;stringstream&gt; \n\
</pre></div><p>The <span class=\'code\'>close()</span> and <span class=\'code\'>flush()</span> functions are provided for consistency with file I/O but are not necessary for StringStreams and do nothing if called.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";