var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Time Values</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Time Values</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"time-values\"></a></div>\n\
<p>The <strong>Time</strong> class implements animation time in MAXScript.</p>\n\
<p>Time values reflect the properties of animation time in <strong>3ds Max</strong>.</p>\n\
<p>Resolution is in <a href=\'#!/url=./developer/MAXScript-Introduction/General-MAXScript-Topics/Ticks.html\' title=\'\'>ticks</a>, with <strong>4800 ticks per second</strong>.</p>\n\
<p>You can work with time as ticks, frames, h.m.s, or normalized time.</p>\n\
<p>You can intermix numbers and time values in time computations defined below.</p>\n\
<p>The rule is that numbers are always interpreted as <strong>frame</strong> counts, with floating point numbers specifying fractional frames.</p>\n\
<p>The numbers are always converted to tick-based time values internally and so have an ultimate resolution of 4800 ticks per second.</p>\n\
<p>You can do time arithmetic and comparisons using numbers as well as time values and convert between time and (frame) numbers using the <span class=\'code\'>as</span> operator. See also <a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Literal-Constants/Time-Literals.html\' title=\'\'>Time Literals</a>.</p>\n\
<p><strong>Literals</strong></p>\n\
<div class=\'codeBlock\'><pre>[-]{&lt;decimal_number&gt;[m | s | f | t]}+ \n\
</pre></div><p>minutes/sec/frames/<a href=\'#!/url=./developer/MAXScript-Introduction/General-MAXScript-Topics/Ticks.html\' title=\'\'>ticks</a></p>\n\
<div class=\'codeBlock\'><pre>[-]{&lt;digit&gt;}:{&lt;digit&gt;}[.{&lt;digit&gt;}]\n\
</pre></div><p>SMPTE mins:secs.frame</p>\n\
<p><strong>Example Literals</strong></p>\n\
<div class=\'codeBlock\'><pre>2.5s -- 2.5 seconds\n\
1m15s -- 1 minute 15 seconds\n\
2m30s5f2t -- 2 minutes 30 seconds 5 frames 2 ticks\n\
125f -- 125 frames\n\
17.25f -- 17.25 frames\n\
1f20t -- 1 frame 20 ticks\n\
2:10.0 -- 2 minutes 10 seconds 0 frames (SMPTE)\n\
0:0.29 -- 29 frames (SMPTE)\n\
\n\
</pre></div><p><strong>Constructor</strong></p>\n\
<div class=\'codeBlock\'><pre>normTime &lt;float&gt;\n\
</pre></div><p>Time from normal fraction based on the current scene animation range:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` animationRange --check out the current animation range: (interval 0f 100f) theHalfTime = normTime 0.5 --get the middle of the range: 50f animationRange = interval 42f 1024f --set new scene range: (interval 42f 1024f) theHalfTime = normTime 0.5 --get the middle of the new range: 533f theTenth = normTime 0.1 --get the frame at 1/10 of the range: 140.2f</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Properties</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;time&gt;.ticks\n\
</pre></div><p>Time as <a href=\'#!/url=./developer/MAXScript-Introduction/General-MAXScript-Topics/Ticks.html\' title=\'\'>ticks</a>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;time&gt;.frame\n\
</pre></div><p>Time as frames.</p>\n\
<div class=\'codeBlock\'><pre>&lt;time&gt;.normalized\n\
</pre></div><p>Time as normalized fraction of active segment (scene animation range):</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` animationRange --check out the current animation range: (interval 0f 100f) theHalfTime = 50f --the middle of the range: 50f normalizedTime = theHalfTime.normalized --the normalized time: 0.5</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>This is the inverse of the <span class=\'code\'>normTime</span> constructor described earlier.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;time&gt; + &lt;time&gt;\n\
</pre></div><p>Time values addition.</p>\n\
<div class=\'codeBlock\'><pre>&lt;time&gt; - &lt;time&gt;\n\
</pre></div><p>Time values subtraction.</p>\n\
<div class=\'codeBlock\'><pre>- &lt;time&gt;\n\
</pre></div><p>Invert time value</p>\n\
<div class=\'codeBlock\'><pre>&lt;time&gt; * &lt;number&gt;\n\
&lt;time&gt; / &lt;number&gt;\n\
</pre></div><p>Scale time</p>\n\
<div class=\'codeBlock\'><pre>&lt;time&gt; == &lt;time&gt;\n\
</pre></div><p>Compare time values for equality. Returns true if the two time values are equal, false if they are not.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` if sliderTime == 42f then &quot;It is time!&quot; else &quot;Not yet!&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;time&gt; != &lt;time&gt;\n\
</pre></div><p>Compare time values for non-equality. Returns true if the two time values are not equal, false if they are equal.</p>\n\
<div class=\'codeBlock\'><pre>&lt;time&gt; &gt; &lt;time&gt;\n\
</pre></div><p>Returns true if the first time value is greater than the second time value, false if it is less or equal to the second time value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;time&gt; &gt;= &lt;time&gt;\n\
</pre></div><p>Returns true if the first time value is greater or equal to the second time value, false if it is less than the second time value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;time&gt; &lt; &lt;time&gt;\n\
</pre></div><p>Returns true if the first time value is less than the second time value, false if it is greater than or equal to the second time value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;time&gt; &lt;= &lt;time&gt;\n\
</pre></div><p>Returns true if the first time value is less than or equal to the second time value, false if it is greater than the second time value.</p>\n\
<div class=\'codeBlock\'><pre>&lt;time&gt; as &lt;class&gt;\n\
</pre></div><p>You can coerce a time value to an Integer or Float number - you get the time in <a href=\'#!/url=./developer/MAXScript-Introduction/General-MAXScript-Topics/Ticks.html\' title=\'\'>ticks</a>:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` sliderTime = 35 35 currentTime 35f currentTime as integer 5600 currentTime as float 5600.0 (currentTime as integer)/TicksPerFrame 35 (currentTime as float)/TicksPerFrame 35.0</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note:</p>\n\
<p>To coerce a Time Value to Frames integer, you can use the <span class=\'code\'>.frame</span> property documented above:</p>\n\
<div class=\'codeBlock\'><pre>currentTime\n\
35f\n\
currentTime as integer\n\
5600\n\
currentTime.frame\n\
35\n\
\n\
</pre></div><p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>random &lt;time&gt; &lt;time&gt;\n\
</pre></div><p>Generates a random time value in the range defined by the two time values.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` random 10f 100f</p>\n\
<p>```</p>\n\
<p><strong>POSSIBLE OUTPUT VALUES:</strong></p>\n\
<p>``` 70.9813f 78.175f 59.225f ...</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note:</p>\n\
<p>To generate full frame random values, use Integers instead of Time Values instead. Integers are always assumed to represent full frames when used in place of Time Values.</p>\n\
<div class=\'codeBlock\'><pre>random 10 100\n\
abs &lt;time&gt;\n\
</pre></div><p>Returns the absolute value of the time value.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` theTime = -100f -100f abs theTime 100f</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Some of the examples above refer to system global variables. See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Reserved-Keywords-Symbols/3ds-Max-System-Globals.html\' title=\'\'>3ds Max System Globals</a> for more details.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";