var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Value Common Properties, Operators, and Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Value Common Properties, Operators, and Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"value-common-properties-operators-and-methods\"></a></div>\n\
<p>The <strong>Value</strong> class is the root class for all MAXScript classes. It supplies methods and operators that <strong>any</strong> class can use.</p>\n\
<p><strong>Operators</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;value&gt; == &lt;value&gt;\n\
</pre></div><p>compare if equal</p>\n\
<div class=\'codeBlock\'><pre>&lt;value&gt; != &lt;value&gt;\n\
</pre></div><p>compare if not equal</p>\n\
<div class=\'codeBlock\'><pre>&lt;value&gt; as &lt;class&gt;\n\
</pre></div><p>Converts the value to an instance of given class. See the description for each class for valid conversions. All values can be converted to class String, which yields a string with the printed representation of the value.</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>print &lt;value&gt; [ to:&lt;stream&gt; ] [#noMap] -- mappable\n\
</pre></div><p>where <span class=\'code\'>&lt;stream&gt;</span> is</p>\n\
<div class=\'codeBlock\'><pre>( &lt;filestream&gt; | &lt;stringstream&gt; | &lt;windowstream&gt; )\n\
</pre></div><p>Prints single value to Listener or optional <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/FileStream-Values.html\' title=\'\'>filestream</a>, <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/StringStream-Values.html\' title=\'\'>stringstream</a>, or <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Stream-Values/WindowStream-Values.html\' title=\'\'>windowstream</a>, followed by a line break. If the argument value is a <a href=\'#!/url=./developer/MAXScript-Language-Reference/Collections/Collections-1.html\' title=\'\'>Collection</a>, and <span class=\'code\'>#noMap</span> is not specified, each value in the collection is printed out on a separate line. If <span class=\'code\'>#noMap</span> is specified, the collection value is printed out on a single line. The printed form of all basic data value types, except for BigArray, are directly readable by the <span class=\'code\'>readValue()</span> and <span class=\'code\'>readExpr()</span> functions, making it simpler to read back in values printed to a file by MAXScript. If the pre-<strong>3ds Max</strong> R3 print forms are required for compatibility with existing scripts, you can set the system global variable <span class=\'code\'>options.oldPrintStyles</span> to <span class=\'code\'>true</span> .</p>\n\
<div class=\'codeBlock\'><pre>format &lt;format_string&gt; { &lt;value&gt; } [ to:&lt;stream&gt; ]\n\
</pre></div><p>Prints one or more values to Listener or optional filestream, stringstream, or windowstream, using the format string as a template. The format string is a string that can contain plain text to print interspersed with the <span class=\'code\'>&#39;%&#39;</span> (percent) metacharacter. Each occurrence of a <span class=\'code\'>&#39;%&#39;</span> is replaced by the printed representation of the successive argument values following the format string.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` format &quot;name:%, pos:%\\n&quot; obj.name obj.pos</p>\n\
<p>```</p>\n\
<p>generates something like:</p>\n\
<p>``` name: box01, pos: [0, 150.0, 0.5]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>format does not automatically append a line break to the output stream, so you can build up a line from several format calls and generally control layout better. An explicit &#39; <span class=\'code\'>\\\\n</span> &#39; newline escape character sequence is needed to place a line break in the output stream. Other escape character sequences are documented in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Literal-Constants/String-Literals.html\' title=\'\'>String Literals</a>.</p>\n\
<div class=\'codeBlock\'><pre>classOf &lt;value&gt;\n\
</pre></div><p>Returns the value&#39;s class. Each type of value has its own class. If the value is a Node value, <span class=\'code\'>classOf()</span> returns the class of the world state object (the state of the node at the top of its stack). See <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Node-MAXWrapper/Node-MAXWrapper-1.html\' title=\'\'>Node : MAXWrapper</a> for more information.</p>\n\
<p>Note: To avoid a conflict between a user class value in global variable named &#39;rollout&#39; and MAXScript reserved word &#39;rollout&#39; which always introduces a rollout definition the class variable name for a rollout is <span class=\'code\'>RolloutClass</span> . So, for a rollout foo you&#39;d now say &quot;if classOf foo == RolloutClass do ...&quot;</p>\n\
<div class=\'codeBlock\'><pre>superClassOf &lt;value&gt;\n\
</pre></div><p>Returns the value&#39;s superclass. A value&#39;s superclass is the class from which the value&#39;s class was derived.</p>\n\
<div class=\'codeBlock\'><pre>isKindOf &lt;value&gt; &lt;class&gt;\n\
</pre></div><p>Returns <span class=\'code\'>true</span> if value has given class or inherits from class.</p>\n\
<div class=\'codeBlock\'><pre>isStructDef &lt;value&gt;\n\
</pre></div><p>Returns true if the value is a structure definition</p>\n\
<div class=\'codeBlock\'><pre>isStruct &lt;value&gt;\n\
</pre></div><p>Returns true if the value is a structure instance</p>\n\
<div class=\'codeBlock\'><pre>isController &lt;value&gt;\n\
</pre></div><p>Returns true if the value is a controller</p>\n\
<div class=\'codeBlock\'><pre>isMSPlugin &lt;value&gt;\n\
</pre></div><p>Returns true if the value is a MAXScript scripted plugin.</p>\n\
<div class=\'codeBlock\'><pre>isMSPluginClass &lt;value&gt;\n\
</pre></div><p>Returns true if the value is a MAXScript scripted plugin class.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` b = box() --create a Box primitive --&gt;$Box:Box001 @ [0.000000,0.000000,0.000000] a = emptymodifier() --create an attribute holder modifier --&gt;EmptyModifier:Attribute Holder addModifier b a --add the modifier to the box --&gt;OK isMSPlugin a --see if the modifier is a scripted plugin? Yes! --&gt;true isMSPlugin b --see if the box is a scripted plugin? No! --&gt;false isMSPluginClass EmptyModifier --is the modifier class scripted? Yes! --&gt;true isMSPluginClassBox --is the object class scripted? No! --&gt;false</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>isMSCustAttrib &lt;value&gt;\n\
</pre></div><p>Returns true if the value is a MAXScript Custom Attribute.</p>\n\
<p>Note: Since Custom Attributes are a special case of a scripted plugin, <span class=\'code\'>isMSPlugin</span> will also return true.</p>\n\
<div class=\'codeBlock\'><pre>isMSCustAttribClass &lt;value&gt;\n\
</pre></div><p>Returns true if the value is a MAXScript Custom Attribute class.</p>\n\
<p>Note: Since Custom Attributes are a special case of a scripted plugin, <span class=\'code\'>isMSPluginClass</span> will also return true.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` weaponDataCA = attributes weaponData ( Parameters main ( ) ) b=box() custAttributes.add b weaponDataCA</p>\n\
<p>c=b.baseobject.custAttributes[1] d=classof c superclassof c isMSPluginClass d isMSCustAttribClass d isMSPluginClass b isMSCustAttribClass b</p>\n\
<p>```</p>\n\
<p><strong>RESULTS:</strong></p>\n\
<p>``` <attributedef:weapondata> $Box:Box03 @ [0.000000,0.000000,0.000000] true<p>\n\
<p>weaponDataCustAttrib:weaponData <attributedef:weapondata> CustAttrib true true false false<p>\n\
<p>```</p>\n\
</attributedef:weapondata></attributedef:weapondata></blockquote>\n\
<div class=\'codeBlock\'><pre>getHashValue &lt;value&gt; &lt;Integer oldHashValue&gt;\n\
</pre></div><p>If the value is one of the supported value types, returns an integer hash value that is a factor of the <span class=\'code\'>&lt;value&gt;</span> and <span class=\'code\'>&lt;oldHashValue&gt;</span>. If the value type is not supported, returns a value of <span class=\'code\'>undefined</span> .</p>\n\
<p>The supported value types are:</p>\n\
<ul>\n\
<li>Float</li>\n\
<li>Integer</li>\n\
<li>String</li>\n\
<li>BitArray</li>\n\
<li>Point3</li>\n\
<li>Ray</li>\n\
<li>Quat</li>\n\
<li>AngAxis</li>\n\
<li>EulerAngles</li>\n\
<li>Matrix3</li>\n\
<li>Point2</li>\n\
<li>Color</li>\n\
<li>Arrays containing any of the above value types</li>\n\
</ul>\n\
<p>Note: Since Custom Attributes are a special case of a scripted plugin, <span class=\'code\'>isMSPlugin</span> will also return true.</p>\n\
<div class=\'codeBlock\'><pre>deepCopy &lt;value&gt;\n\
</pre></div><p>Returns a deep copy of the value, which means all nested values are copies rather than references. The default implementation of this method is to call the copy() method. This method is only implemented for these value types:</p>\n\
<ul>\n\
<li>Array</li>\n\
<li>DataPair (in <strong>3ds Max 2019 and higher</strong>)</li>\n\
<li>Dictionary (in <strong>3ds Max 2019 and higher</strong>)</li>\n\
<li>Structure (in <strong>3ds Max 2019 and higher</strong>)</li>\n\
<li>MAXWrapper (in <strong>3ds Max 2019 and higher</strong>) - does not create a copy of the 3ds Max object, rather just returns the original value.</li>\n\
</ul>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";