var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>formattedprint</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>formattedprint</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"formattedprint\"></a></div>\n\
<p>The <strong>FormattedPrint</strong> method was added to MAXScript in <strong>3ds Max 9</strong>. It was previously available through the free <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>formattedPrint &lt;value&gt; format:&lt;string&gt; userLocale:&lt;boolean&gt;\n\
</pre></div><p>Returns a string representation of value based on the format specified.</p>\n\
<p>The format specified is applied for each component value for values that are comprised of more than a single value.</p>\n\
<p>For values or component values that are floating point numbers, the default format string is &quot;0.8g&quot;, for integers, &quot;%d&quot;.</p>\n\
<p>The value specified must be one of: float, double, integer, integer64, intptr, string, bool, ray, point2, point3, point4, quat, angleAxis, eulerAngle, matrix3, box2, color, time, or interval.</p>\n\
<p>Note: The <span class=\'code\'>formattedPrint()</span> function calls the c++ <span class=\'code\'>printf()</span> function with the corresponding value and format. There is no validation that the format is correct for the specified value type. It is up to the user to ensure that the format specified is correct for the value type. For example, using a format of &quot;04d&quot; for a float value will result in the string &quot;0000&quot;. See the <a href=\'https://docs.microsoft.com/en-us/cpp/c-runtime-library/format-specification-syntax-printf-and-wprintf-functions?view=vs-2019\' title=\'\' target=\'_blank\'>printf() format specification</a> for more information.</p>\n\
<p>The optional <span class=\'code\'>userLocal</span> parameter specifies whether to use the decimal character specified by the user&#39;s locale. If false (the default) a period (&quot;.&quot;) is used as the decimal character, regardless of locale. Available in <strong>3ds Max 2020.1 Update and higher</strong>.</p>\n\
<p>The optional <span class=\'code\'>format:</span> string is of the form:</p>\n\
<div class=\'codeBlock\'><pre>&quot;[Flags][Width][.Precision][SizePrefix]Type&quot;\n\
</pre></div><p>where</p>\n\
<p><strong>Flags</strong> is:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">Flag</th>\n\
<th align=\"left\">Meaning</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>-</span></td>\n\
<td align=\"left\">Left align the result within the given field width. Default is to right align.</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>+</span></td>\n\
<td align=\"left\">Prefix the output value with a sign (+ or -). Default is that sign appears only for negative signed values (-).</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>0</span></td>\n\
<td align=\"left\">If width is prefixed with 0, zeros are added until the minimum width is reached. If 0 and - appear, the 0 is ignored. If 0 is specified with an integer format (i, u, x, X, o, d) the 0 is ignored. Default is no padding.</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>Blank</span>(&#39; &#39;)</td>\n\
<td align=\"left\">Prefix the output value with a blank if the output value is signed and positive; the blank is ignored if both the blank and + flags appear. Default is no blank appears.</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#</span></td>\n\
<td align=\"left\">When used with the o, x, or X format, the # flag prefixes any nonzero output value with 0, 0x, or 0X, respectively. Default is no blank appears. When used with the e, E, or f format, the # flag forces the output value to contain a decimal point in all cases. Default is decimal point appears only if digits follow it. When used with the g or G format, the # flag forces the output value to contain a decimal point in all cases and prevents the truncation of trailing zeros. Default is decimal point appears only if digits follow it, and trailing zeros are truncated. Ignored when used with d, i, or u.</td>\n\
</tr>\n\
</table>\n\
<p><strong>Width</strong> is a non-negative decimal integer controlling the minimum number of characters printed. If the number of characters in the output value is less than the specified width, blanks are added to the left or the right of the values - depending on whether the - flag (for left alignment) is specified - until the minimum width is reached. If width is prefixed with 0, zeros are added until the minimum width is reached (not useful for left-aligned numbers). The width specification never causes a value to be truncated. If the number of characters in the output value is greater than the specified width, or if width is not given, all characters of the value are printed (subject to the precision specification).</p>\n\
<p><strong>Precision</strong> specifies a non-negative decimal integer, preceded by a period (.), which specifies the number of characters to be printed, the number of decimal places, or the number of significant digits. Unlike the width specification, the precision specification can cause either truncation of the output value or rounding of a floating-point value. If precision is specified as 0 and the value to be converted is 0, the result is no characters output.</p>\n\
<p>Note: Precision is always specified by a period (.) even if the locale specifies a different decimal character.</p>\n\
<p><strong>Type:d, i, u, o, x, X</strong> - The precision specifies the minimum number of digits to be printed. If the number of digits in the argument is less than precision, the output value is padded on the left with zeros. The value is not truncated when the number of digits exceeds precision. Default precision is 1.</p>\n\
<p><strong>Type:e, E</strong> - The precision specifies the number of digits to be printed after the decimal point. The last printed digit is rounded. Default precision is 6; if precision is 0 or the period (.) appears without a number following it, no decimal point is printed.</p>\n\
<p><strong>Type: f</strong> - The precision value specifies the number of digits after the decimal point. If a decimal point appears, at least one digit appears before it. The value is rounded to the appropriate number of digits. Default precision is 6; if precision is 0, or if the period (.) appears without a number following it, no decimal point is printed.</p>\n\
<p><strong>Type: g, G</strong> - The precision specifies the maximum number of significant digits printed. Six significant digits are printed, with any trailing zeros truncated.</p>\n\
<p><strong>Type: s</strong> - The precision specifies the minimum number of characters in the string, and left-pads the formatted string with space characters, if required.</p>\n\
<p>where <strong>Type</strong> character is the only required format field; it appears after any optional format fields.</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">Character</th>\n\
<th align=\"left\">Type</th>\n\
<th align=\"left\">Output Format</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>d, i </span></td>\n\
<td align=\"left\">int</td>\n\
<td align=\"left\">Signed decimal integer.</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>o</span></td>\n\
<td align=\"left\">int</td>\n\
<td align=\"left\">Unsigned octal integer.</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>u</span></td>\n\
<td align=\"left\">int</td>\n\
<td align=\"left\">Unsigned decimal integer.</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>x</span></td>\n\
<td align=\"left\">int</td>\n\
<td align=\"left\">Unsigned hexadecimal integer, using &quot;abcdef.&quot;</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>X</span></td>\n\
<td align=\"left\">int</td>\n\
<td align=\"left\">Unsigned hexadecimal integer, using &quot;ABCDEF.&quot;</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>e</span></td>\n\
<td align=\"left\">double</td>\n\
<td align=\"left\">Signed value having the form [ - ]d.dddd e [sign]ddd where d is a single decimal digit, dddd is one or more decimal digits, ddd is exactly three decimal digits, and sign is + or - ;.</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>E</span></td>\n\
<td align=\"left\">double</td>\n\
<td align=\"left\">Identical to the e format except that E rather than e introduces the exponent.</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>f</span></td>\n\
<td align=\"left\">double</td>\n\
<td align=\"left\">Signed value having the form [ - ]dddd.dddd, where dddd is one or more decimal digits. The number of digits before the decimal point depends on the magnitude of the number, and the number of digits after the decimal point depends on the requested precision.</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>g</span></td>\n\
<td align=\"left\">double</td>\n\
<td align=\"left\">Signed value printed in f or e format, whichever is more compact for the given value and precision. The e format is used only when the exponent of the value is less than -4 or greater than or equal to the precision argument. Trailing zeros are truncated, and the decimal point appears only if one or more digits follow it.</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>G</span></td>\n\
<td align=\"left\">double</td>\n\
<td align=\"left\">Identical to the g format, except that E, rather than e, introduces the exponent (where appropriate).</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>s</span></td>\n\
<td align=\"left\">string</td>\n\
<td align=\"left\">A string of characters.</td>\n\
</tr>\n\
</table>\n\
<p><strong>SizePrefix</strong> is:</p>\n\
<p>I - value being printed is an IntegerPtr</p>\n\
<p>I32 - value being printed is an Integer</p>\n\
<p>I64 - value being printed is an Integer64</p>\n\
<p>For Integer values, the default format is &quot;I32d&quot;</p>\n\
<blockquote>\n\
<p>``` v = 12611668 -- Integer formattedPrint v &quot;12611668&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>For Integer64 values, the default format is &quot;I64d&quot;</p>\n\
<blockquote>\n\
<p>``` v = 126116680000L -- Integer64 formattedPrint v &quot;126116680000&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>For IntegerPtr values, the default format is &quot;Id&quot;</p>\n\
<blockquote>\n\
<p>``` v = 12611668P -- IntegerPtr formattedPrint v &quot;12611668&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` formattedPrint pi &quot;3.1415927&quot;</p>\n\
<p>formattedPrint pi format:&quot;0 g&quot; &quot; 3.14159&quot;</p>\n\
<p>formattedPrint -pi format:&quot;0 g&quot; &quot;-3.14159&quot;</p>\n\
<p>formattedPrint pi format:&quot;12.8g&quot; &quot; 3.1415927&quot;</p>\n\
<p>-- when user locale uses &quot;,&quot; as the decimal separator: formattedPrint pi userLocale:true &quot;3,1415927&quot;</p>\n\
<p>formattedPrint yellow &quot;(color 255 255 0)&quot;</p>\n\
<p>m = matrix3 1 formattedPrint m &quot;(matrix3 [1,0,0] [0,1,0] [0,0,1])&quot;</p>\n\
<p>formattedPrint m format:&quot;#g&quot; &quot;(matrix3 [1.00000,0.000000,0.000000] [0.000000,1.00000,0.000000] [0.000000,0.000000,1.00000])&quot;</p>\n\
<p>formattedPrint 10 format:&quot;#o&quot; &quot;012&quot;</p>\n\
<p>formattedPrint 10 format:&quot;#x&quot; &quot;0xa&quot;</p>\n\
<p>formattedPrint v format:&quot;19.18g&quot; &quot; 1.2345678901234567&quot;</p>\n\
<p>formattedPrint &quot;abc&quot; format:&quot;15s&quot; &quot; abc&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";