var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>globalVars Structure</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>globalVars Structure</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"globalvars-structure\"></a></div>\n\
<p>The <strong>globalVars struct</strong> provides methods to collect, create, test and remove global variables.</p>\n\
<p>These methods are available in <strong>3ds Max 2008</strong> and higher.</p>\n\
<p>They were previously available in the <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>globalVars.get &lt;global var name&gt;     \n\
</pre></div><p>Returns the value of the specified global variable.</p>\n\
<p>The argument must be a MAXScript name value.</p>\n\
<p>The global variable name must exist, otherwise a runtime error will be generated.</p>\n\
<div class=\'codeBlock\'><pre>globalVars.set &lt;global var name&gt; &lt;value&gt;   \n\
</pre></div><p>Sets the value of the specified global variable.</p>\n\
<p>The argument must be a MAXScript name value.</p>\n\
<p>The global variable name must exist, otherwise a runtime error will be generated.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` globalVars.get #dontknow --try to get an undeclared variable -- Runtime error: Specified global variable does not exist: #dontknow global dontknow = &quot;Now I Know&quot; --declare the variable --&gt; &quot;Now I Know&quot; globalVars.get #dontknow --now we can get and set the value --&gt; &quot;Now I Know&quot; globalVars.set #dontknow &quot;I Still Know What You Did Last Siggraph&quot; --&gt; &quot;I Still Know What You Did Last Siggraph&quot; globalVars.set #reallydontknow &quot;MAXScript&quot; -- Runtime error: Specified global variable does not exist: #reallydontknow</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>globalVars.gather [filter:&lt;function&gt;] \n\
</pre></div><p>Returns an array of all global variable names declared in the current session.</p>\n\
<p>Available <strong>in 3ds Max 2017 and higher</strong>: The optional filter parameter is a two argument function that returns either true or false. The first argument is the global variable&#39;s name, and the second argument is the global variable&#39;s value. If the filter function returns true, the variable is gathered.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` ro_controls = globalvars.gather filter:(fn filterfn n v = (iskindof v rolloutcontrol))</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>globalVars.isglobal &lt;var name&gt; \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the specified variable name is global, false if it is not global or not declared.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE (CONTINUED FROM PREVIOUS EXAMPLE)</strong></p>\n\
<p>``` globalVars.isglobal #dontknow --declared in previous example --&gt; true globalVars.isglobal #reallydontknow --still notdeclared --&gt; false</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>globalVars.getTypeTag &lt;var name&gt; \n\
</pre></div><p>Returns the type of the global variable as an integer or name value.</p>\n\
<p>The specified global variable name must exist.</p>\n\
<p><strong>This method is mainly for internal testing</strong>.</p>\n\
<p>The primary type tag values are:</p>\n\
<p>10 - general global</p>\n\
<p>11 - constant global</p>\n\
<p>12 - system global</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE (CONTINUED FROM PREVIOUS EXAMPLE)</strong></p>\n\
<p>``` globalVars.getTypeTag #dontknow --declared in previous example --&gt; 10P globalVars. getTypeTag #reallydontknow --variable does not exist -- Runtime error: Specified global variable does not exist: #reallydontknow</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>globalVars.getValueTag &lt;var name&gt;       \n\
</pre></div><p>Returns the type of the value in the global variable as an integer or name value.</p>\n\
<p>The specified global variable name must exist.</p>\n\
<p><strong>This method is mainly for internal testing</strong>.</p>\n\
<p>Each value type has its own tag value.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` global aString = &quot;I Know Kung-Fu!&quot; --&gt; &quot;I Know Kung-Fu!&quot; global aFloat = 123.456 --&gt; 123.456 global anInt = 42 --&gt; 42 global aMatrix = matrix3 1 --&gt; (matrix3 [1,0,0] [0,1,0] [0,0,1] [0,0,0]) globalVars.getValueTag #aString --&gt; #String globalVars.getValueTag #aFloat --&gt; #float globalVars.getValueTag #anInt --&gt; #integer globalVars.getValueTag #aMatrix --&gt; #Matrix3 globalVars.getValueTag #reallydontknow -- Runtime error: Specified global variable does not exist: #reallydontknow</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>globalVars.remove &lt;var name&gt; \n\
</pre></div><p>Removes the specified variable name from the list of global variables.</p>\n\
<blockquote>\n\
<p>Warning: Use With Caution!</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";