var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Manual Garbage Collection</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Manual Garbage Collection</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"manual-garbage-collection\"></a></div>\n\
<p>The function <span class=\'code\'>gc()</span> invokes the garbage collector.</p>\n\
<p>Normally, the collector runs automatically when available memory runs low, so you don&#39;t normally need to call it explicitly.</p>\n\
<p>However, in some situations, it is useful to be able to force a collect to ensure a pause due to garbage collection will be delayed as long as possible.</p>\n\
<p>You can also invoke the collector to cause any unreferenced open files to be closed.</p>\n\
<p>In some situations, a file can be left open if a runtime error occurs while it is still open.</p>\n\
<p>If the file object was being held in a local variable at this point, it may not be possible to get at it from the Listener to force a close.</p>\n\
<p>Any subsequent attempts to open it may result in an &quot;already open&quot; error from the operating system.</p>\n\
<p>Running the collector will cause the file object to be reclaimed and this forces any open file associated with it to be closed.</p>\n\
<div class=\'codeBlock\'><pre>gc [light:false] [delayed:false]     \n\
</pre></div><p>This function returns the number of bytes free in the MAXScript heap after collection.</p>\n\
<p>Note that the collector may take many seconds to run if the heap is full of many small reclaimable objects.</p>\n\
<div class=\'section\'><a id=\"garbage-collection-light-option\"></a><h2 id=\"garbage-collection-light-option\">Garbage Collection light: option</h2></div>\n\
<p>When the optional <span class=\'code\'>light:</span> keyword argument is passed as <span class=\'code\'>true</span> , the undo buffer will not be flushed.</p>\n\
<p>If you are performing a lot of scene operations then it is recommended to call <span class=\'code\'>gc()</span> without any argument or pass <span class=\'code\'>light:false</span> , in which case the undo buffer will be flushed prior to the garbage collection.</p>\n\
<p>When <span class=\'code\'>light:true</span> is specified, any value that derives from MAXWrapper will not be collected.</p>\n\
<p>This covers all value types that could potentially be in the undo buffer.</p>\n\
<p>The result is that, for this case, less memory is released and <span class=\'code\'>gc</span> runs a bit slower, but you can&#39;t corrupt the undo stack.</p>\n\
<p>If <span class=\'code\'>light:true</span> is not specified, behavior and speed is same as before.</p>\n\
<p>What does get collected with <span class=\'code\'>light:true</span> includes rollouts, floaters, UI items, bitmaps, strings, arrays, and bitArrays.</p>\n\
<p>Those are all items that do not exist in the scene.</p>\n\
<div class=\'section\'><a id=\"automatic-garbage-collection-behavior-and-delayed-option\"></a><h2 id=\"automatic-garbage-collection-behavior-and-delayed-option\">Automatic Garbage Collection behavior and delayed: option</h2></div>\n\
<p>When MAXScript runs out of heap memory, it runs garbage collection to free unused memory.</p>\n\
<p>Since a value collected may be the last reference to a MAX object, we need to flush the undo system since it may contain a pointer to that object or one of its dependents.</p>\n\
<p>In <strong>3ds Max 5</strong>, the &#39;light&#39; keyword argument has been introduced for manual garbage collection where, if true, MAXWrapper-derived values are not garbage collected, thus no MAX objects are deleted, and no flush of the undo system is required.</p>\n\
<p>The change to MAXScript in <strong>3ds Max 6</strong> extended this to <strong>automatic garbage collection</strong>.</p>\n\
<p>When an automatic garbage collection is performed, and the undo system is not empty, an initial garbage collection is performed where MAXWrappers are not garbage collected, and a flag is set so that on the next undo system flush, a full garbage collection is performed.</p>\n\
<p>If this initial garbage collection does not free up sufficient memory to satisfy the memory request, or if the undo system is empty, a full garbage collection is performed where MAXWrappers are deleted and the undo system is flushed.</p>\n\
<p>With the recent improvements in MAXWrapper interning, undo system flushes due to MAXScript garbage collection should be a fairly rare event.</p>\n\
<p>To maintain current behavior, a manual garbage collection using &#39;gc()&#39; still flushes the undo system. <span class=\'code\'>gc light:true</span> will still not flush the undo system.</p>\n\
<p>The <span class=\'code\'>delayed:&lt;boolean&gt;</span> option will cause a full garbage collection at the next undo system flush.</p>\n\
<p>So you could say the following to match the behavior of an automatic garbage collection:</p>\n\
<blockquote>\n\
<p><span class=\'code\'>gc light:true delayed:true</span></p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";