var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Persistent Global Variables</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Persistent Global Variables</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"persistent-global-variables\"></a></div>\n\
<p>MAXScript supports a limited form of persistent global variables. You declare a particular global to be persistent and the value it contains is always saved to and restored from scene files as they are opened and closed. Therefore, you can keep direct references to objects in the scene in variables and those references will persist across scene save and reload.</p>\n\
<p>You declare a global variable as persistent by prefacing its declaration with the reserved word <span class=\'code\'>persistent</span> .</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p><span class=\'code\'>persistent global foo, baz, bar</span></p>\n\
</blockquote>\n\
<p>declares the variables <span class=\'code\'>foo</span> , <span class=\'code\'>baz</span> , and <span class=\'code\'>bar</span> to be persistent. From then on, the values in <span class=\'code\'>foo</span> , <span class=\'code\'>baz</span> , and <span class=\'code\'>bar</span> at the time of a scene save are stored in the .max scene file. When that file is reopened, the values in <span class=\'code\'>foo</span> , <span class=\'code\'>baz</span> , and <span class=\'code\'>bar</span> are restored, with an implicit declaration as persistent globals if they are not so already declared.</p>\n\
<p>The current limitation with persistent global variables is that only certain kinds of values are storable in a scene file, and only those types of values are saved and restored across scene saves and loads.</p>\n\
<p>The supported value classes are: AngleAxis, Array, Boolean, Color, DataPair, Double, Empty, EulerAngles, Float, Integer, Integer64, IntegerPtr, Interval, Matrix3, Name, OK, Point2, Point3, Point4, Quat, Ray, String, Struct, Time, Undefined, Unsupplied, and all the MAXWrapper classes (nodes, modifiers, controllers, materials, and so on). All other types of values restore as the value <span class=\'code\'>undefined</span> .</p>\n\
<p>In the case of Array, only those values in the array that are in the previous list are correctly saved and restored; others appear as <span class=\'code\'>undefined</span> in the restored array.</p>\n\
<p>IntegerPtr loading and saving support was added in <strong>3ds Max 2015</strong>. When saving to a previous 3ds Max version, IntegerPtr values will be stored as Integer64 values.</p>\n\
<p>DataPair loading and saving support was added in <strong>3ds Max 2017 Extension 1</strong>. When saving to a previous 3ds Max version, DataPair values will be stored as undefined.</p>\n\
<p>Persistent globals are removed from the persistent globals pool when a File &gt; Reset, File &gt; New, or File &gt; Open is performed, but they will remain in memory as ordinary, non-persistent global variables for that MAX session. Subsequently, persistent global variables declared during a MAX session do not &quot;stick around&quot; and get stored with every other file saved during that session.</p>\n\
<p>Note:</p>\n\
<p>When merging or XRef-ing in a file (scene/object XRefs are a special case of merge), when reading in persistent global variables,</p>\n\
<ul>\n\
<li><p>If the variable being read from the scene file already <strong>exists as a persistent global variable</strong>, the value of the persistent global is <strong>not overwritten</strong>. (It was overwritten in versions prior to <strong>3ds Max 8</strong>).</p></li>\n\
<li><p>If the variable exists as a non-persistent global variable, the global variable&#39;s value is overwritten.</p></li>\n\
<li><p>If the variable does not exist as a global variable, a non-persistent global variable will be created. The last 2 behaviors are the same as in previous versions of <strong>3ds Max</strong>.</p></li>\n\
</ul>\n\
<p>If needed, you can install persistent globals in each new file using a <span class=\'code\'>#filePreSave</span> callback. See <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism.html\' title=\'\'>General Event Callback Mechanism</a> for more information.</p>\n\
<p>However, this behavior also means that variables originally declared as persistent global variables may remain defined as ordinary global variables over multiple scenes while a script is being created or run, yet show up as undefined when these saved scenes are reopened in another MAX session.</p>\n\
<p>Below are two examples illustrating the use of callbacks to handle such situations:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE 1:</strong></p>\n\
<p>If a script requires that a certain critical variable carries its value into new and opened scenes and always exists as a persistent global, the following callbacks would ensure this during File &gt; Reset, File &gt; New and File &gt; Open events:</p>\n\
<p><span class=\'code\'>callbacks.addscript #systemPostNew &quot;persistent global myVar&quot; id:#myTools   callbacks.addscript #systemPostReset &quot;persistent global myVar&quot; id:#myTools   callbacks.addscript #filePostOpen &quot;persistent global myVar&quot; id:#myTools</span></p>\n\
</blockquote>\n\
<p>The critical variable is simply re-declared, leaving its value unaffected but ensuring that it is saved as a persistent global within the scene.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE 2:</strong></p>\n\
<p>Another case would be a script requiring that a certain critical variable always exist as a persistent global but never carry its current value into other scenes, instead either reverting to a default value for new and opened scenes that don&#39;t have the persistent global defined, or restoring the value from opened scenes that do have the persistent global defined. The following callbacks would assign default values to the variable during File &gt; Reset and File &gt; New events, but would only assign a default value during a File &gt; Open event if the persistent global was not already present in the opened file:</p>\n\
<p><span class=\'code\'>callbacks.addscript #systemPostReset &quot;persistent global myVar=0.0&quot; id:#myTools   callbacks.addscript #systemPostNew &quot;persistent global myVar=0.0&quot; id:#myTools   callbacks.addscript #filePreOpen &quot;myVar=undefined&quot; id:#myTools   callbacks.addscript #filePostOpen &quot;if myVar==undefined do (persistent global myVar=0.0)&quot; id:#myTools</span></p>\n\
</blockquote>\n\
<p>During File &gt; Reset and File &gt; New events the critical variable is re-declared and assigned a default value, but during a File &gt; Open event the variable first becomes undefined and is then tested after the file is opened. If that persistent global variable was already present and defined in the scene being opened, the variable would have already been restored as a persistent global variable with its old value. In that case, there&#39;s no need to re-declare it as a persistent global since it is already in the persistent global pool and will remain there forever until explicitly removed.</p>\n\
<p>Note:</p>\n\
<p>There is one potential problem with both of the above examples: the persistent globals will continue being created by the callbacks for the rest of the current MAX session. Unless this is the desired behavior, this should be avoided by having the created callbacks removed when the script is closed.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>if the script exists in a utility or dialog rollout then the associated close event handler should include a &quot;callbacks.removeScripts&quot; command to remove the callbacks.</p>\n\
<p><span class=\'code\'>on myToolsUtility close do (callbacks.removeScripts id:#myTools)</span></p>\n\
<p>This example also illustrates the advantage of using id: parameter whenever possible. This not only makes removal easy but specific as well, since it avoids accidentally removing callbacks that belong to other scripts.</p>\n\
<p>See <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism.html\' title=\'\'>General Event Callback Mechanism</a> and <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Utility-and-Rollout-Properties.html\' title=\'\'>Utility and Rollout Properties, Methods, and Event Handlers</a> for more information.</p>\n\
</blockquote>\n\
<p>For <strong>methods</strong> to <strong>create</strong>, <strong>collect</strong>, <strong>test</strong>, <strong>show</strong> and <strong>remove</strong> persistent global variables, see the topic <a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Global-and-Persistent-Global/Persistents-Structure.html\' title=\'\'>Persistents Structure</a>.</p>\n\
<p>Note: If a persistent global variable contains a <span class=\'code\'>MAXWrapper</span> value, but the class instance is <strong>not</strong> in the scene, that value is <strong>not</strong> stored/restored on a file save/load.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` -- persistents - node only persistent global global_array = #() global_array[1] = b= box() global_array[2] = bm= bend() global_array[3] = sm= standard() global_array[4] = fog() global_array[5] = area() global_array[6] = bezier_float() global_array[7] = br= bricks() global_array[8] = lookat() global_array[9] = blur() global_array[10] = MapScaler() --b.material=sm --addmodifier b bm --sm.diffusemap=br persistents.show() max hold max fetch persistents.show()</p>\n\
<p>```</p>\n\
<p><strong>REMARKS:</strong></p>\n\
<p>Only the box is in the array after running this script. If the commented lines are run, the material, modifier, and map are also in the array. MAXScript does not do a full reference-tree dump when it outputs its persistent variables, it just outputs RefIDs for MAX objects and so depends on them being dumped as references by the main file save code.</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";