var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Variable Assignment</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Variable Assignment</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"variable-assignment\"></a></div>\n\
<p>The syntax for general assignment, <span class=\'code\'>&lt;assignment&gt;</span> , is:</p>\n\
<div class=\'codeBlock\'><pre>&lt;destination&gt; = &lt;expr&gt;\n\
</pre></div><p>where <span class=\'code\'>&lt;destination&gt;</span> can be one of:</p>\n\
<div class=\'codeBlock\'><pre>&lt;var_name&gt;\n\
&lt;property&gt;\n\
&lt;array_index&gt;\n\
</pre></div><p>Each of these destination type is described below.</p>\n\
<p>MAXScript provides a <span class=\'code\'>swap()</span> method that takes two valid assignment destinations as arguments and swaps their values. Its syntax is:</p>\n\
<div class=\'codeBlock\'><pre>swap &lt;destination&gt; &lt;destination&gt;\n\
</pre></div><div class=\'section\'><a id=\"assignment-to-variables\"></a><h2 id=\"assignment-to-variables\">Assignment to Variables</h2></div>\n\
<p>A variable is identified with a MAXScript <span class=\'code\'>&lt;var_name&gt;</span> , as described in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Names-Literal-Constants-and/Names.html\' title=\'\'>Names</a>. If <span class=\'code\'>&lt;destination&gt;</span> is a <span class=\'code\'>var_name</span> , it identifies the variable to be assigned a value, as shown in the following examples:</p>\n\
<div class=\'codeBlock\'><pre>x = 2 + 2 * 3 -- assign to variable x\n\
y = [1, 2, 3] + pos -- assign to variable y\n\
z = #(1, 2,&quot;foo&quot;,&quot;bar&quot;) -- assign to variable z\n\
z = #oops -- oops, changed my mind\n\
\n\
</pre></div><div class=\'section\'><a id=\"assignment-to-accessors\"></a><h2 id=\"assignment-to-accessors\">Assignment to Accessors</h2></div>\n\
<p>If <span class=\'code\'>&lt;destination&gt;</span> is a <span class=\'code\'>&lt;property&gt;</span> or an <span class=\'code\'>&lt;array_index&gt;</span> , the assignment is to an accessor. Accessors are constructs used to access the components in compound values, such as arrays and 3D points. There are two kinds of accessors corresponding to the two kinds of <em>compound values</em> in MAXScript:</p>\n\
<ul>\n\
<li><p>The component values are arranged in an indexable sequence, as in arrays or strings.</p></li>\n\
<li><p>The compound value contains a fixed set of named components, as with 3D points and time intervals.</p></li>\n\
</ul>\n\
<p>All <strong>3ds Max</strong> objects, such as boxes, spheres, bend modifiers, or bitmap textures are treated as compound values in this sense. All their parameters, such as height and angle, or map file name, are accessed as named components. In MAXScript, these named components are referred to as <em>properties</em>. For more information, see <a href=\'#!/url=./developer/MAXScript-Introduction/Objects-and-Classes-in-Object/Properties-Methods-Operators-and.html\' title=\'\'>Properties, Methods, Operators, and Literals</a>.</p>\n\
<p>Accessors have one of two forms, an <span class=\'code\'>&lt;array_index&gt;</span> :</p>\n\
<div class=\'codeBlock\'><pre>&lt;operand&gt; [ &lt;expr&gt; ] -- an indexed element\n\
</pre></div><p>or a <span class=\'code\'>&lt;property&gt;</span> :</p>\n\
<div class=\'codeBlock\'><pre>&lt;operand&gt;.&lt;var_name&gt; -- a named property - property var_name of value in operand\n\
<blockquote>\n\
</blockquote></pre></div><p><strong>Examples of assignment to accessors are:</strong></p>\n\
<p>``` $box01.pos = baseObj.pos + (baseObj.radius*[0,0,1])</p>\n\
<p>```</p>\n\
<p>Set the position property of object <span class=\'code\'>box01</span> based on the position and radius properties of the object whose value is stored in variable <span class=\'code\'>baseObj</span> .</p>\n\
<p>``` z[2] = d.rotation as eulerangles</p>\n\
<p>```</p>\n\
<p>Convert the rotation property value of the value stored in variable <span class=\'code\'>d</span> to an <span class=\'code\'>eulerAngles</span> class value, and store this value in element 2 of the array stored in variable <span class=\'code\'>z</span> .</p>\n\
\n\
<p>The syntax definitions allow you to use any <span class=\'code\'>&lt;operand&gt;</span> before the <span class=\'code\'>.</span> or <span class=\'code\'>\\[\\]</span> . Because accessors are themselves operands, this definition is <em>recursive</em>, which means you can string accessors together to query nested arrays or properties:</p>\n\
<div class=\'codeBlock\'><pre>my_things[i][j]\n\
my_objects[i].target.position.x\n\
\n\
</pre></div><p>Accessors are evaluated left-to-right. The first example evaluates the i’th element of <span class=\'code\'>my_things</span> , which is presumably a nested array or an array of strings, before yielding the j&#39;th element of that element.</p>\n\
<p>The second example retrieves an object from an array of <span class=\'code\'>my_objects</span> , then its <span class=\'code\'>target</span> , then the <span class=\'code\'>position</span> of the target (a 3D point), and finally the <span class=\'code\'>x</span> coordinate of that point.</p>\n\
<p>An <span class=\'code\'>&lt;operand&gt;</span> can also be a block-expression, allowing you to compute the target object to be accessed.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>``` (instance myNode).pos=myNode.parent.pos</p>\n\
<p>```</p>\n\
<p>Create an instance of the node whose value is stored in variable <span class=\'code\'>myNode</span> , and set its position to the position of the <span class=\'code\'>myNode</span> ’s parent object.</p>\n\
<p>``` (find_table&quot;foo&quot;)[n - 2] = &quot;fred&quot;</p>\n\
<p>```</p>\n\
<p>Call function <span class=\'code\'>find_table</span> with a parameter value of <span class=\'code\'>&quot;foo&quot;</span> . The return value from the function is presumably an array. Set element <span class=\'code\'>n-2</span> of this array to the value <span class=\'code\'>&quot;fred&quot;</span> .</p>\n\
</blockquote>\n\
<p>The named properties defined for the MAXScript values and classes are documented with the value and class descriptions.</p>\n\
<div class=\'section\'><a id=\"order-of-evaluation\"></a><h2 id=\"order-of-evaluation\">Order of Evaluation</h2></div>\n\
<p>In an assignment, <span class=\'code\'>&lt;expr&gt;</span> is evaluated before <span class=\'code\'>&lt;destination&gt;,</span> as can be seen in the following example:</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` a=#() -- create an empty array to play with a[(print &quot;in <destination>&quot;;1)]=(print &quot;in <expr>&quot;;10)<p>\n\
<p>```</p>\n\
<p><strong>OUTPUT</strong></p>\n\
<p>``` #() -- result line 1 &quot;in <expr>&quot; -- output from <expr> side of assignment &quot;in <destination>&quot; -- output from <destination> side of assignment 10 -- result line 2<p>\n\
<p>```</p>\n\
</destination></destination></expr></expr></expr></destination></blockquote>\n\
<p>Assignment in MAXScript is itself an expression and yields the value just assigned. Therefore, you can use assignments inside other expressions or cascade assignments, as in:</p>\n\
<blockquote>\n\
<p>``` x = y = z = 0 #(1, 2, a = [0,0,1], 4)</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";