var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Change Handlers and When Constructs</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Change Handlers and When Constructs</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"change-handlers-and-when-constructs\"></a></div>\n\
<p>Change Handlers are used to detect when certain types of user events are performed on objects in a scene, allowing you to write scripts that respond to user operations like object moves, vertex edits, object deletions, name changes, and so on. Change Handlers are applied to individual MAXWrapper objects and specify an attribute to monitor for that object and an expression to evaluate when that attribute changes. Example attributes that can be monitored are geometry, name, transform, and parameters. Change Handlers are not stored in a <strong>3ds Max</strong> scene.</p>\n\
<p>The <span class=\'code\'>ChangeHandler : Value</span> class instances represent change handler setups. ChangeHandler values are created using the <span class=\'code\'>when</span> construct. Each time a <span class=\'code\'>when</span> construct is executed, it creates and returns a new ChangeHandler instance. You must store this ChangeHandler value in a variable or array so that you can dismiss the handler when it is appropriate to do so.</p>\n\
<p>The <span class=\'code\'>when</span> construct defines a change handler function for a certain type of event on one or more objects. The system then automatically calls this function whenever the event occurs.</p>\n\
<p>Note: Change events are only generated when the user changes the object. Events are not generated if the change is triggered by an animation.</p>\n\
<p>The syntax of the <span class=\'code\'>when</span> construct has two forms as follows:</p>\n\
<div class=\'codeBlock\'><pre>when &lt;attribute&gt; &lt;objects&gt; change[s] [ id:&lt;name&gt; ] \\ \n\
[handleAt: #redrawViews|#timeChange] \\ \n\
[ &lt;object_parameter&gt; ] do &lt;expr&gt;\n\
when &lt;objects&gt; deleted [ id:&lt;name&gt; ] \\ \n\
[handleAt:#redrawViews|#timeChange] \\\n\
[ &lt;object_parameter&gt; ] do &lt;expr&gt; \n\
</pre></div><p>In the first form, the <span class=\'code\'>&lt;attribute&gt;</span> can be one of:</p>\n\
<div class=\'codeBlock\'><pre> topology geometry name[s] transform select parameters subAnimStructure controller children\n\
</pre></div><p>These specify the attribute of the given object(s) to be tracked for change (see below for more details).</p>\n\
<p>The second form tracks object deletion by the user or other scripts. This is typically used if you have tables or other structures containing MAXScript object values and you want to remove deleted objects from them as the user modifies the scene.</p>\n\
<blockquote>\n\
<p><strong>NOTES:</strong></p>\n\
<p>The <span class=\'code\'>#selectedNodesPreDelete</span></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/GUID-F0CD0BD9-FC77-4881-8021-102B5837F7B2.html\' title=\'\'>general callback</a></p>\n\
<p>is the far superior method to use to catch node deletion by the user. It is called before <strong>anything</strong> happens to the nodes and will report the deletion of any node. In contrast, the <span class=\'code\'>when</span> construct operates only on nodes explicitly registered with the callback.</p>\n\
<p>``` mypot1 = teapot() --create a teapot fn whendeleted = --define a callback function ( local deletedobjects = callbacks.notificationParam() format &quot;Callback: %\\n&quot; deletedobjects -- This will printevery object that was deleted. -- By this point, the object isstillattached to it&#39;s parents -- and is still in groups etc... -- Nothing has been done to the nodeyet. ) when mypot1 deleted id:#foo obj do --define a when construct ( format &quot;When Construct:%\\n&quot; obj ) --unregisterany preDeletecallbacks callbacks.removeScripts #selectedNodesPreDelete --register the function as general callback callbacks.addscript #selectedNodesPreDelete &quot;whendeleted()&quot;</p>\n\
<p>```</p>\n\
<p>A regression in <strong>3ds Max 9</strong> caused a change in the way the <span class=\'code\'>when</span> construct was called. In releases prior to <strong>3ds Max 9</strong>, the <span class=\'code\'>when</span> construct was called before the actual deletion of the object. In <strong>3ds Max 9</strong>, the <strong>when</strong> callback in the above code would return <deleted scene=\"\" node=\"\"> instead.<p>\n\
<p>This behavior has been fixed in <strong>3ds Max 2008</strong>.</p>\n\
</deleted></blockquote>\n\
<p>In both forms, the <span class=\'code\'>&lt;objects&gt;</span> argument can be one of the following:</p>\n\
<ul>\n\
<li><p>a single <strong>3ds Max</strong> object such as, a scene node, controller, modifier, material, and so on.</p></li>\n\
<li><p>one of the object sets such as, &#39;selection&#39; or &#39;cameras&#39;.</p></li>\n\
<li><p>a wild-card pathname like $foo*.</p></li>\n\
<li><p>an array of <strong>3ds Max</strong> objects.</p></li>\n\
</ul>\n\
<p>If more than one object is specified, the handler is called each time the given attribute of any of the objects is signaled as changed by the <strong>3ds Max</strong> core.</p>\n\
<p>The optional <span class=\'code\'>id:</span> parameter specifies an ID for one or more handlers as a name literal. The ID name can later be used to delete the handler and if the same name is given to several handlers, they can be deleted as a group.</p>\n\
<p>The optional <span class=\'code\'>handleAt:</span> parameter signals that the change handler expression must <strong>not</strong> be executed immediately upon notification, but delayed until either the <strong>3ds Max</strong> viewports are redrawn ( <span class=\'code\'>#redrawViews</span> ) or current <strong>3ds Max</strong> animation time is changed ( <span class=\'code\'>#timeChange</span> ). Delaying the processing of the change handler expression is highly recommended, as described in the Caution section below. An example usage of the <span class=\'code\'>handleAt:</span> parameter is:when select $ changes id:#foo handleAt:#redrawViews do ...</p>\n\
<p>The optional <span class=\'code\'>&lt;object_parameter&gt;</span> lets you specify the name of a parameter variable that will be accessible in the do <span class=\'code\'>&lt;expr&gt;</span> and will hold the actual object that has changed. You typically specify this parameter name if the handler will respond to changes in many objects, so you can determine which one has changed. The <span class=\'code\'>&lt;expr&gt;</span> can be a single expression or block expression.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` b1 = box() b2 = box() b3 = box() when transform $box001 changes do $box002.pos = \\(box001.pos + delta  max select all  when names selection change obj do update_name_table obj  when #(\\)box001, $box002, $box003) deleted obj do ( messageBox &quot;Warning!&quot; deleteItem obj_table (findItem obj_table obj) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The change attributes are interpreted as follows:</p>\n\
<div class=\'codeBlock\'><pre>topology\n\
</pre></div><p>Signaled when the topology of an object changes in the Modify panel such as, using a mesh smooth, optimize, or vertex delete.</p>\n\
<div class=\'codeBlock\'><pre>geometry\n\
</pre></div><p>Signaled when the geometry of an object changes such as, by moving a vertex or using an animated modifier.</p>\n\
<div class=\'codeBlock\'><pre>name or names\n\
</pre></div><p>Signaled when the name of an object is changed if this occurs because a user edits the name in one of the <strong>3ds Max</strong> command panels. The handler is called repeatedly with each character that is changed.</p>\n\
<div class=\'codeBlock\'><pre>transform\n\
</pre></div><p>Signaled when the transform of an object is changed such as, by a move, rotate, or scale.</p>\n\
<div class=\'codeBlock\'><pre>select\n\
</pre></div><p>Signaled when a scene node moves into or out of the current selection set. You should interrogate the <span class=\'code\'>&lt;node&gt;.isSelected</span> property to determine the new state.</p>\n\
<div class=\'codeBlock\'><pre>parameters\n\
</pre></div><p>Signaled when any parameters are changed in the object. This is something of a catch all because the core signals this event in many situations.</p>\n\
<div class=\'codeBlock\'><pre>subAnimStructure\n\
</pre></div><p>Signaled when the dynamic subAnim structure changes such as, when a new vertex becomes animated in an editable mesh, or when a new controller is added to a list controller. Also called when subAnims are reassigned, for example, when a material is changed in an object.</p>\n\
<div class=\'codeBlock\'><pre>controller\n\
</pre></div><p>Signaled when a new controller is assigned to one of the object&#39;s tracks.</p>\n\
<div class=\'codeBlock\'><pre>children\n\
</pre></div><p>Signaled when an object has immediate children added or removed.</p>\n\
<div class=\'section\'><a id=\"deleting-change-handlers\"></a><h2 id=\"deleting-change-handlers\">Deleting Change Handlers</h2></div>\n\
<p>You can use the following two methods for deleting change handlers:</p>\n\
<div class=\'codeBlock\'><pre>deleteChangeHandler &lt;change_handler&gt;\n\
</pre></div><p>deletes specified change handler . <span class=\'code\'>change_handler</span> is the value returned by a <span class=\'code\'>when</span> construct.</p>\n\
<div class=\'codeBlock\'><pre>deleteAllChangeHandlers [ id:&lt;name&gt; ]\n\
</pre></div><p>If optional <span class=\'code\'>id:</span> parameter is not specified, deletes all change handlers. If optional <span class=\'code\'>id:</span> parameter is specified, deletes all change handlers with the specified id.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` deleteAllChangeHandlers id:#foo</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>For efficiency reasons, you do not want irrelevant change handlers running in the background, so it is essential that you delete those that you no longer need.</p>\n\
<p><strong>Special Considerations</strong></p>\n\
<ul>\n\
<li><p>If a runtime error occurs in the body of a change handler while it is being executed, an error message is displayed and that handler is permanently disabled.</p></li>\n\
<li><p>If all of the objects being tracked by a change handler are deleted, the change handler is also deleted.</p></li>\n\
<li><p>The <span class=\'code\'>do &lt;expr&gt;</span> change handler code is executed in a special context and not in the context of the code that created it. This means that the <span class=\'code\'>&lt;expr&gt;</span> code cannot contain references to local variables in outer code nestings surrounding the <span class=\'code\'>when</span> because those variables are on an execution stack that does not exist at the time the <span class=\'code\'>when</span> handler is called. The compiler detects any illegal references to outer locals and generates a compiler message. An important exception to this is utility and rollout panel locals such as, local functions, rollout variables, and nested rollouts. You can refer to them in change handler code inside rollout code as they are associated directly with their rollout or utility object.</p></li>\n\
<li><p>Change handlers are called only for user initiated events, and not for changes resulting from a change in controller values. For example, a change handler on the transform attribute of a node would be called when the user moves the node. If the position of the node is animated, and you play back the animation, the transform attribute change handler is not called.</p></li>\n\
<li><p>If you assign a change handler to an attribute on multiple objects, the change handler is called once per object if that object’s attribute changes.</p></li>\n\
</ul>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE, IF YOU SAY:</strong></p>\n\
<p>``` when select $ changes obj do update_modifier_list obj</p>\n\
<p>```</p>\n\
<p>The function <span class=\'code\'>update_modifier_list</span> is called whenever any object is selected or deselected. This is true even if you do an Edit / Select All. In this case, <span class=\'code\'>update_modifier_list</span> will be called once for each object currently selected (as the objects are deselected), and then once for all objects in the scene (as the objects are selected). If <span class=\'code\'>update_modifier_list</span> is at all processor-intensive, a significant system slowdown can occur.</p>\n\
</blockquote>\n\
<ul>\n\
<li><p>Change handlers are only applied to object already present in the scene. Change handlers are not automatically applied to newly created objects.</p></li>\n\
<li><p>If you have multiple change handlers defined, the order in which the change handlers are called is somewhat arbitrary.</p></li>\n\
<li><p>Due to the way that <strong>3ds Max</strong> internally processes notification signals, the <strong>\\(** form of accessing selected objects is not recommended in a select change handler. To access the selected objects, you must use the **selection** objectset. This is because **\\)</strong> relies on information that has not yet been set in the selection processing whereas <strong>selection</strong> uses a different method of accessing selections and the information it uses has been set up.</p></li>\n\
</ul>\n\
<blockquote>\n\
<p><strong>CAUTION</strong> <strong>!</strong></p>\n\
<p>The change handler system is based on <strong>3ds Max</strong>&#39;s internal notification system which essentially drives all animation and interactivity within <strong>3ds Max</strong>.</p>\n\
<p>There are cases when the core sends many signals for the same change, so setting up change handlers on many objects that do vast amounts of computing can significantly slow down the system.</p>\n\
<p>Strictly speaking, change handlers are supposed to be used to just set &quot;dirty flags&quot; in a lightweight, order-independent way, and then use Redraw Views or Time Change callbacks to actually cause the triggered processing.</p>\n\
<p>You must attempt to use change handlers judiciously, and not, for example, as a simple way to get scripted controllers.</p>\n\
<p>If you do find that a desired setup is being flooded with unnecessary signals, you must use the <span class=\'code\'>handleAt:</span> to delay the actual processing of the event handler script until a redrawViews or timeChange event occurs.</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";