var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>General Event Callback Mechanism</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>General Event Callback Mechanism</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"general-event-callback-mechanism\"></a></div>\n\
<p>MAXScript allows you to register callback scripts for all of the notification events supported by <strong>3ds Max</strong>, such as pre/post scene file open, new, reset, scene file save, pre/post render, selection change, etc.</p>\n\
<p>You can specify any number of callback scripts per notification event.</p>\n\
<p>Callback scripts can be bundled into sets with user-defined IDs and can be deleted by type, by ID or by both.</p>\n\
<p>Callback scripts can be specified as persistent so that they are saved and loaded with the currently open file.</p>\n\
<div class=\'section\'><a id=\"adding-callbacks\"></a><h2 id=\"adding-callbacks\">Adding Callbacks</h2></div>\n\
<p>The callbacks are added using the following syntax:</p>\n\
<div class=\'codeBlock\'><pre>callbacks.addScript &lt;callback_type_name&gt; (&lt;function&gt; | &lt;script_string&gt; | &lt;script_stringstream&gt; | fileName:&lt;filename_string&gt;) [id:&lt;name&gt;] [persistent:&lt;boolean&gt;]         \n\
</pre></div><p>This method is used to register a new callback script. Requires as the first argument a name that specifies which type of notify event this script is associated with. The list of valid <span class=\'code\'>callback_type_name</span> values is listed below.</p>\n\
<p><img src=\'developer/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> <a href=\'#!/url=./developer/What-is-New-in-MAXScript/What-s-New-in-MAXScript-in-3ds.html\' title=\'\'>NEW</a> <strong>in 3ds Max 2021:</strong>: The script is supplied as a MAXScript function. Any type of function may be supplied: global functions, struct methods, and plug-in methods. Only functions that do not take any parameters, or all parameters have default values, should be registered as callbacks. The <span class=\'code\'>addScript()</span> call will fail if you attempt to add a function that takes parameters. Functions passed as callbacks cannot be persisted, and attempting to call with <span class=\'code\'>persisted:true</span> will fail.</p>\n\
<p>Note: When a function is passed to <span class=\'code\'>addScript()</span>, it is effectively held as a unique instance. If the function is later re-defined, it does not change the code executed during the callback. To update the function, it needs to be removed and added again.</p>\n\
<p>The script can also be a direct String or StringStream value containing the text of the script to run, or as a <span class=\'code\'>fileName:</span> keyword argument, in which case the named file is loaded and run whenever the event notification callback occurs.</p>\n\
<p>The optional <span class=\'code\'>id:</span> parameter lets you tag one or a group of callbacks with a unique name so that you can remove them all as a group without interfering with other callbacks, perhaps registered by other scripted tools.</p>\n\
<p>The optional <span class=\'code\'>persistent:</span> parameter lets you control whether the script is saved permanently in the currently open scene file or is a global callback script that remains in place no matter what file opening and closing is performed. A <span class=\'code\'>true</span> value for the parameter specifies that the script should be stored in the current file and loaded and registered for callback whenever that file is opened again. Persistent callback scripts are always removed when a new file is loaded or a reset is performed so that persistent scripts in one file don&#39;t accidentally get copied to a later file. The default for this parameter is <span class=\'code\'>false</span> , indicating the script is a global script and is not persistent. Function-based callbacks cannot be persisted, and passing with <span class=\'code\'>persistent:true</span> will fail.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` callbacks.addScript #preRender &quot;setUpRenderGeom()&quot; id:#jbwRender</p>\n\
<p>```</p>\n\
<p>This registers a new callback script that will be called just before a render is performed. The script invokes a function (that has presumably already been set up). A unique ID has been assigned to the script for later selective removal.</p>\n\
<p><span class=\'code\'>-- in 3ds Max 2021 and higher   fn myCallback = print &quot;hello&quot;   callbacks.addScript #nodeCreated myCallback id:#myCallbacks</span></p>\n\
<p>This registers a new callback that is called whenever a node is created. The callback is a previously defined function.</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"removing-callbacks\"></a><h2 id=\"removing-callbacks\">Removing Callbacks</h2></div>\n\
<div class=\'codeBlock\'><pre>callbacks.removeScripts [&lt;callback_type_name&gt;] [id:&lt;name&gt;]   \n\
</pre></div><p>This method is used to unregister and remove one or more callback scripts.</p>\n\
<p>Specifying just a callback event type name removes all the callback scripts for that event type.</p>\n\
<p>Specifying just an <span class=\'code\'>id:</span> removes all callback scripts in all events with that ID.</p>\n\
<p>Specifying both limits the ID-based removal to the specified event type.</p>\n\
<div class=\'section\'><a id=\"inspecting-callbacks\"></a><h2 id=\"inspecting-callbacks\">Inspecting Callbacks</h2></div>\n\
<div class=\'codeBlock\'><pre>callbacks.show [&lt;callback_type_name&gt;] [id:&lt;name&gt;] [to:&lt;stream&gt;] \\\n\
  [asArray: &lt;boolean&gt;] \n\
</pre></div><p>This method lists out the current callback scripts or functions in the Listener window, or to an optional stream. Callbacks are listed with their ID, persistent setting, and whether they are loaded from a scene file. If the callback is defined in a string, stringStream or file, the script or filename in which they are defined is also listed. If the callback is defined as a function, the function name, including the struct or plugin it is defined in, is listed.</p>\n\
<p>If the optional callback type name argument is specified in <strong>3ds Max 2009 and higher</strong>, only callbacks of that type will be shown.</p>\n\
<p>If the optional keyword argument <span class=\'code\'>id:</span> is specified, only callbacks with that ID will be shown.</p>\n\
<p>If type name and ID are both specified, only callbacks of the type with the given ID will be shown.</p>\n\
<p>Available in <strong>3ds Max 2018.4 and higher</strong>: If the optional keyword argument <span class=\'code\'>to:</span> is specified, output from the method is sent to the specified stream.</p>\n\
<p>If the callback definition was loaded from a scene file they are listed as <span class=\'code\'>SceneFileEmbedded:true</span>, and considered embedded scripts. If the Safe Scene Script Execution feature is enabled these types of callbacks are inspected and potentially unsafe commands are blocked from execution. <strong>Available in 3ds Max 2021.3 Update and higher.</strong> If the optional keyword argument <span class=\'code\'>asArray:</span> is specified, the output is returned as an array, with an element for each callback. Available in <strong>3ds Max 2019.3 Update and higher</strong>. Each element is an array that contains information about the callback, in this order:</p>\n\
<p><span class=\'code\'>(callback type, callback ID, persistent, is filename, script name, scene file embedded)</span></p>\n\
<p><strong>Example</strong></p>\n\
<div class=\'codeBlock\'><pre>-- show callbacks of type #filePreOpen\n\
callbacks.show #filePreOpen\n\
-- output:\n\
filePreOpen:\n\
  id:#PhysXPlugin, persistent:false, SceneFileEmbedded:false, script:&quot;px_filePreOpen()&quot;\n\
  id:#ALC_SecurityTool, persistent:false, SceneFileEmbedded:false, script:&quot;::ALC_SecurityTool.scenePreOpen()&quot;\n\
  id:#ALC2_SecurityTool, persistent:false, SceneFileEmbedded:false, script:&quot;::ALC2_SecurityTool.scenePreOpen()&quot;\n\
  id:#CRP_SecurityTool, persistent:false, SceneFileEmbedded:false, script:&quot;::CRP_SecurityTool.m_in_file_open = true;::CRP_SecurityTool.register_post_load_check()&quot;\n\
  id:#ADSL_SecurityTool, persistent:false, SceneFileEmbedded:false, script:&quot;::ADSL_SecurityTool.m_in_file_open = true;::ADSL_SecurityTool.register_post_load_check()&quot;\n\
OK\n\
\n\
-- the same thing, but as an array:\n\
callbacks.show #filePreOpen asArray:true\n\
-- output:\n\
#(#(#filePreOpen, #PhysXPlugin, false, false, &quot;px_filePreOpen()&quot;, false), #(#filePreOpen, #ALC_SecurityTool, false, false, &quot;::ALC_SecurityTool.scenePreOpen()&quot;, false), #(#filePreOpen, #ALC2_SecurityTool, false, false, &quot;::ALC2_SecurityTool.scenePreOpen()&quot;, false), #(#filePreOpen, #CRP_SecurityTool, false, false, &quot;::CRP_SecurityTool.m_in_file_open = true;::CRP_SecurityTool.register_post_load_check()&quot;, false), #(#filePreOpen, #ADSL_SecurityTool, false, false, &quot;::ADSL_SecurityTool.m_in_file_open = true;::ADSL_SecurityTool.register_post_load_check()&quot;, false))\n\
\n\
\n\
-- function defined in a struct:\n\
callbacks.show #nodeCreated\n\
-- output:\n\
nodeCreated:\n\
  id:#myCallbacks, persistent:false, SceneFileEmbedded:false, script:&quot;myStruct.myCallback()&quot;\n\
\n\
callbacks.broadcastCallback &lt;callback_type_name&gt; \n\
</pre></div><p>This method provides a way for you to simulate one of the events and have all the callback scripts for it executed.</p>\n\
<p>Within <strong>3ds Max</strong>, the <span class=\'code\'>#preRenderFrame</span> and <span class=\'code\'>#postRenderFrame</span> callbacks can only be called by the renderer. These callbacks can not be called by using this method.</p>\n\
<div class=\'section\'><a id=\"additional-notification-information-on-the-callback\"></a><h2 id=\"additional-notification-information-on-the-callback\">Additional Notification Information on the Callback:</h2></div>\n\
<div class=\'codeBlock\'><pre>callbacks.notificationParam() \n\
</pre></div><p>This method can be called in a callback script to provide additional information on the callback. The value returned by this method varies based on the callback type. If no additional information was present for the callback, a value of &#39;undefined&#39; is returned.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` --Remove any existing callbacks with this ID. callbacks.removeScripts id:#MXSHelp --Add a new callback script which will call --callbacks.notificationParam() before selected nodes are deleted --and thus will print the deleted objects to the Listener: callbacks.addScript #selectedNodesPreDelete&quot; print (callbacks.notificationParam())&quot; id:#MXSHelp</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"callback-event-names-and-notificationparam-return-values\"></a><h2 id=\"callback-event-names-and-notificationparam-return-values\">Callback Event Names and notificationParam Return Values</h2></div>\n\
<p>These are all supported the Callback Event Names and the <span class=\'code\'>callbacks.notificationParam()</span> values typically returned. Depending on how the broadcast is generated, a value of &#39;undefined&#39; may be returned by this method instead of the value shown.</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/ActionItem-Notifications.html\' title=\'\'>ActionItem Notifications</a></td>\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Named-Selection-Set-Notification.html\' title=\'\'>Named Selection Set Notifications</a></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Animation-Notifications.html\' title=\'\'>Animation Notifications</a></td>\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Node-Related-Notifications.html\' title=\'\'>Node Related Notifications</a></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Direct3D-Device-Notification.html\' title=\'\'>Direct3D Device Notifications</a></td>\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Plug-in-Notifications.html\' title=\'\'>Plug-in Notifications</a></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/FileLink-Notifications.html\' title=\'\'>FileLink Notifications</a></td>\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Radiosity-Notifications.html\' title=\'\'>Radiosity Notifications</a></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/File-Notifications.html\' title=\'\'>File Notifications</a></td>\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Rendering-Notifications.html\' title=\'\'>Rendering Notifications</a></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Image-Viewer-Display.html\' title=\'\'>Image Viewer Display Notifications</a></td>\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Render-Dialog-and-Renderer.html\' title=\'\'>Render Dialog and Renderer Plugin Notifications</a></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Layer-System-Notifications.html\' title=\'\'>Layer System Notifications</a></td>\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Schematic-View-Notifications.html\' title=\'\'>Schematic Notifications</a></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Manipulate-Mode-Notifications.html\' title=\'\'>Manipulate Mode Notification</a></td>\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/System-Notifications.html\' title=\'\'>System Notifications</a></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Modifier-Panel-Notifications.html\' title=\'\'>Modifier Panel Notifications</a></td>\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Undo-System-Notifications.html\' title=\'\'>Undo System Notifications</a></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Modifier-Notifications.html\' title=\'\'>Modifier Notifications</a></td>\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Xrefs-Notifications.html\' title=\'\'>Xrefs Notifications</a></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Material-Library-Notifications.html\' title=\'\'>Material Library Notifications</a></td>\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Other-Notifications.html\' title=\'\'>Other Notifications</a></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks/General-Event-Callback-Mechanism/Material-Notifications.html\' title=\'\'>Material Notifications</a></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
</table>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";