var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Time Change Callback Mechanism</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Time Change Callback Mechanism</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"time-change-callback-mechanism\"></a></div>\n\
<p>You can register one or more functions to be called whenever the current <strong>3ds Max</strong> animation time is changed, such as when the user drags the time slider or plays the animation. The following methods let you register and unregister these callbacks:</p>\n\
<div class=\'codeBlock\'><pre>registerTimeCallback &lt;fn&gt;\n\
unRegisterTimeCallback &lt;fn&gt; | undefined )\n\
</pre></div><p>You can register as many functions as you like. Each one is individually called whenever the time changes. The functions you register must take no arguments. They can access the updated current time through the MAXScript system variable <span class=\'code\'>currentTime</span> .</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` fn time_p = print currentTime registerTimeCallback time_p</p>\n\
<p>```</p>\n\
<p>In the above example, the registered function causes the current time to be printed in the Listener window whenever the user moves the time slider or plays the animation.</p>\n\
</blockquote>\n\
<p>You can also enable or disable time change callbacks globally.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt; timeCallbacksEnabled()\n\
</pre></div><p>Returns whether time change callbacks are enabled. <strong>Available in 3ds Max 2021.1 Update and higher.</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt; enableTimeCallbacks()\n\
&lt;boolean&gt; disableTimeCallbacks()\n\
</pre></div><p>Enables or disables time change callbacks. These functions return the current time change callbacks enabled state. So, for example, calling <span class=\'code\'>disableTimeCallbacks()</span> when callbacks are already disabled will return <strong>false</strong>. <strong>Available in 3ds Max 2021.1 Update and higher.</strong></p>\n\
<div class=\'codeBlock\'><pre>showregisteredTimeCallbacks [to:stream] [asArray:&lt;boolean&gt;]\n\
</pre></div><p>Returns a list of registered time change callbacks, listing the function name, source file (if applicable) and line number in the source file where the function is defined. If the optional <strong>to</strong> argument is specified, the output is sent to that output stream. If the optional <strong>asArray</strong> argument is specified, the return value is formatted as an array of arrays, where for each registered callback function the first element is the callback function name, the second element is the source file name and line number where the callback function is defined (or an empty string if the function was not defined in a file), and the third element is the actual function value which can be used to de-register the callback.<br><strong>Special Considerations</strong></p>\n\
<ul>\n\
<li><p>If a runtime error occurs in a callback function while it is being executed, an error message is displayed and that callback function is permanently disabled.</p></li>\n\
<li><p>The time callback is <strong>not</strong> called during rendering, even if multiple frames are rendered.</p></li>\n\
<li><p>The registered function is executed in a special context and not in the context of the code that created it. This means that the function cannot contain references to local variables in outer code nestings surrounding the function definition since those variables are on an execution stack that does not exist at the time the function is called. An important exception to this is utility and rollout panel locals, such as local functions, rollout variables and nested rollouts. You can refer to them in change handler code inside rollout code as they are associated directly with their rollout or utility object.</p></li>\n\
<li><p>Note that it is the <strong>function value</strong> that is being registered, not the function name or global variable. This means that redefining the same-named function after registering it does <strong>not</strong> change the callback. You either need to unregister, re-define the function and then register it again, or make the registered function an intermediary which calls another function,</p></li>\n\
</ul>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` fn time_cb = print currentTime fn tcb = time_cb() registerTimeCallback tcb</p>\n\
<p>```</p>\n\
<p>In this case, the registered callback function, <span class=\'code\'>tcb</span> , calls the real call back, <span class=\'code\'>time_cb</span> , (by referencing the global variable it is defined in), meaning you can redefine <span class=\'code\'>time_cb()</span> as often as you need and the callback will always invoke the latest definition. This is a useful technique to employ while you are developing and debugging a callback.</p>\n\
</blockquote>\n\
<ul>\n\
<li>Callback functions remain registered after loading a new file or performing a <strong>3ds Max</strong> Reset.</li>\n\
</ul>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";