var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Defining Macro Scripts</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Defining Macro Scripts</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"defining-macro-scripts\"></a></div>\n\
<p><strong>MacroScripts</strong> are scripts that are associated with Customize User Interface ActionItems (toolbar buttons, Menu or QuadMenu items, and keyboard shortcuts) and are executed when the corresponding ActionItem is invoked.</p>\n\
<p>MacroScripts have to be defined with the <span class=\'code\'>macroScript</span> definition construct and can then be associated with a toolbar button by right-clicking a Shortcut toolbar or Tab and choosing Customize. The Customize User Interface dialog is displayed, which lets you choose from either Command shortcuts or MacroScripts. MacroScripts are essentially pieces of MAXScript code that have a name and category, and optionally a tooltip and icon.</p>\n\
<p>MacroScripts do not automatically create user interface items. If you want a MacroScript to display a dialog, you need to create a rollout floater window and rollout(s) as described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-Floater-Windows.html\' title=\'\'>Rollout Floater Windows</a>, and create and install the user-interface items in the rollout(s) as described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-User-Interface-Controls.html\' title=\'\'>Rollout User-Interface Controls</a>.</p>\n\
<p><strong>A MacroScript is defined using the following syntax:</strong></p>\n\
<div class=\'codeBlock\'><pre>macroScript &lt;name&gt; \n\
[category:&lt;string&gt;] \n\
[buttonText:&lt;string&gt;] \n\
[toolTip:&lt;string&gt;] \n\
[icon:#(&lt;string&gt;, &lt;index&gt;) | iconName:&lt;string&gt;] \n\
[silentErrors:&lt;boolean&gt;] \n\
[autoUndoEnabled:boolean&gt;] \n\
(&lt;macro_script_body&gt;)\n\
<blockquote>\n\
</blockquote></pre></div><p><strong>EXAMPLES:</strong></p>\n\
<p>``` macroScript Free_Camera category:&quot;Cameras&quot; tooltip:&quot;Free Camera&quot; Icon:#(&quot;Cameras&quot;,2) ( StartObjectCreation FreeCamera )</p>\n\
<p>```</p>\n\
<p>``` macroScript Target_Camera category:&quot;Cameras&quot; tooltip:&quot;Targeted Camera&quot; Icon:#(&quot;Cameras&quot;,1) ( StartObjectCreation TargetCamera )</p>\n\
<p>```</p>\n\
\n\
<p>Since <strong>3ds Max 2011</strong>, the strings defining the name properties of the MacroScript definition can be replaced with localized Resources strings whose definitions are enclosed in tildes. Please see the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts/Resource-String-Replacement.html\' title=\'\'>Resources String Replacement topic</a> for details.</p>\n\
<p>After MAXScript evaluates a <span class=\'code\'>macroScript</span> construct, the MacroScript definition shows up in the appropriate category list in the Customize User-Interface dialog. The following figure shows a Customize User Interface dialog containing the previous two MacroScripts.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-214A2746-EF3D-436C-8DE4-9F65752957AB-low.gif\' title=\'\'></div>\n\
<p>If a tooltip is specified, that tooltip is the name shown in the Customize User Interface dialog. If a tooltip is not specified, <span class=\'code\'>&lt;name&gt;</span> is the name shown. Unlike other similar constructs (Scripted Utilities, Functions, and right-click menus), <span class=\'code\'>macroScript</span> does not create a variable with this name. Rather, MacroScripts are stored as pointers into files, as described below.</p>\n\
<p>Note:</p>\n\
<p>You can use non-alpha numeric characters to define any of the argument strings. This includes support for escaped double quote characters: \\&quot;.</p>\n\
<p>The <span class=\'code\'>category:</span> argument specifies in which category of the Customize User-Interface dialog the MacroScript name is listed. The use of categories is intended to help you organize your MacroScripts into groupings so that the MacroScript names are less likely to clash. If you do not specify a category, a default category of &quot;unknown&quot; is used.</p>\n\
<p>The <span class=\'code\'>internalCategory</span> argument is intended to identify operations in <strong>.cui</strong>, <strong>.mnu</strong>, and <strong>.kbd</strong> files.</p>\n\
<p>The <span class=\'code\'>toolTip:</span> argument specifies the tooltip for the button. If no tooltip is specified, <span class=\'code\'>&lt;name&gt;</span> is displayed for the button.</p>\n\
<p>The <span class=\'code\'>buttonText:</span> argument specifies the text that appears in the button, and the <span class=\'code\'>icon:</span> argument specifies the icon that appears in the button. You can choose in the Customize User Interface dialog whether the <span class=\'code\'>buttonText</span> or <span class=\'code\'>icon</span> appears in the button. If no <span class=\'code\'>buttonText:</span> argument is specified, the MacroScript name is used as the <span class=\'code\'>buttonText</span> .</p>\n\
<p>The <span class=\'code\'>silentErrors:</span> parameter controls whether the MAXScript runtime error messages are displayed while executing the MacroScript. If this parameter is set to True , error messages are not displayed. This is useful for distributed MacroScripts that might confuse the user with MAXScript error messages. The default value is False.</p>\n\
<p>The <span class=\'code\'>autoUndoEnabled:</span> parameters controls whether the MacroScript body is automatically wrapped in a <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Miscellaneous-Functions/thehold.html\' title=\'\'>theHold</a> begin/accept calls internally.</p>\n\
<p>When set to False , the execution of the MacroScript body does not generate an undo record for the whole MacroScript.</p>\n\
<p>When set to True or not specified, the whole MacroScript body creates an undo record when executed.</p>\n\
<p>The default value is <span class=\'code\'>true</span> .</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` MacroScript MacroScript_autoUndoEnabled_test1 category:&quot;MacroScript_autoUndoEnabled_test&quot; buttontext:&quot;test1&quot; autoUndoEnabled:false ( format &quot;test1\\n&quot; format &quot;expecting theHold.holding == false, got: %\\n&quot; (theHold.holding()) format &quot;expecting theHold.IsSuspended == false, got: %\\n&quot; (theHold.IsSuspended()) format &quot;expecting theHold.Restoring == false, got: %\\n&quot; (theHold.Restoring()) format &quot;expecting theHold.Redoing == false, got: %\\n&quot; (theHold.Redoing()) format &quot;expecting theHold.RestoreOrRedoing == false, got: %\\n&quot; (theHold.RestoreOrRedoing()) format &quot;expecting theHold.SuperLevel == 0, got: %\\n&quot; (theHold.SuperLevel()) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"icons\"></a><h2 id=\"icons\">Icons</h2></div>\n\
<p>In <strong>3ds Max 2017</strong> a new method of loading icons was introduced to support high-DPI display scaling. The <span class=\'code\'>iconName:</span> argument uses this method. This argument can specify an icon in one of these locations:</p>\n\
<ol>\n\
<li>Baseline 3ds Max icons located in the compiled resource files IconsDark.rcc and IconsLight.rcc (for the dark and light themes, respectively), located under &lt;3ds Max&gt;\\UI_ln. See the <strong>Icon Reference Guide</strong> in the 3ds Max Developer&#39;s Guide for full paths to these icons. All icons are loaded by 3ds Max on startup, and are referred to by <internal\\_path>/<base\\_name>, where <span class=\'code\'>internal_path</span> is the path to the icon inside the rcc file (see the Icon Reference) and the <span class=\'code\'>base_name</span> is the icon name minus the _xx.png suffix, where **_xx** is the resolution of the icon. Typically 4 resolutions are supplied, and the system picks the best one for the current display resolution.</base\\_name></internal\\_path></li>\n\
<li>Custom icons compiled into .rcc resource files placed in &lt;3ds Max&gt;\\UI_ln\\Icons. Any .rcc file found in this location is loaded by 3ds Max on startup. These files must be compiled with the Qt resource compiler; see <a href=\'https://doc.qt.io/qt-5/resources.html\' title=\'\' target=\'_blank\'>The Qt Resource System</a>. You should include both light and dark versions to support both themes, and four resolutions to support high-DPI displays. As with baseline icons, these are referred to by <internal\\_path>/<base\\_name>. For more information on creating your own .rcc files, see the <strong>Using Multi-Res Icons in Max and Qt</strong> topic in the Developer&#39;s Guide.</base\\_name></internal\\_path></li>\n\
<li>PNG files from disk located in the &lt;3ds Max&gt;\\UI_ln\\Icons\\[Dark|Light] - depending on the active theme (you need a copy of the icon in each location). For example, an icon with four resolutions (my_icon_24.png, my_icon_30.png, my_icon_36.png, my_icon_48.png) placed in both &lt;3ds Max&gt;\\UI_ln\\Icons\\Dark\\MyIcons and &lt;3ds Max&gt;\\UI_ln\\Icons\\Light\\MyIcons would be referred to in the macroScript as <span class=\'code\'>iconName: &quot;MyIcons/my_icon&quot;</span>. <strong>Note:</strong> &lt;3ds Max&gt;\\UI_ln\\Icons\\[Dark|Light] do not exist by default, you will have to create these directories.</li>\n\
<li>The location pointed to by <span class=\'code\'>#userIcons</span>, and the current theme name under <span class=\'code\'>#userIcons</span>, a directory named &quot;Light&quot; or &quot;Dark&quot;. See <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/3ds-Max-System-Directories.html\' title=\'\'>3ds Max System Directories</a> for information about <span class=\'code\'>#userIcons</span>.</li>\n\
</ol>\n\
<p>Prior to <strong>3ds Max 2017</strong>, the <span class=\'code\'>icon:</span> argument is used.</p>\n\
<p><strong>Note</strong>: this is now considered a &quot;legacy&quot; method of specifying icons, and is supported for backwards compatibility. As of <strong>3ds Max 2017</strong>, this method no longer supports .bmp files, icons must be .png format.</p>\n\
<p>The <span class=\'code\'>icon:</span> argument specifies the icon bitmap file and the icon image within the icon bitmap file. The icon bitmap file must be located in the current <strong>3ds Max</strong> user-interface directory. Icon bitmap files have a base name such as, &quot;MyToolbar&quot;, followed by a suffix such as, &quot;_24i.bmp&quot; that specifies the individual icon size and icon bitmap file type. The <span class=\'code\'>icon:</span> argument string is just the base name with no extensions. This base name is the name shown in the Image Group list in the Customize User-Interface dialog. Each icon bitmap file can have any number of individual icons, lined up side-by-side in the file. If the icon bitmap file contains multiple icons, <span class=\'code\'>&lt;index&gt;</span> specifies which icon in the icon bitmap file to use. The left-most icon has an <span class=\'code\'>&lt;index&gt;</span> of 1. The <strong>3ds Max</strong> internal icons (Image Group Internal in the Customize User-Interface dialog) are not stored in an icon file, and are referenced by using an empty string as the <span class=\'code\'>icon:</span> argument.</p>\n\
<p>So, the <span class=\'code\'>icon:</span> argument is a two-element array containing the icon bitmap file’s base name as a string and the icon’s index in that file.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` macroScript Box category:&quot;Objects&quot; tooltip:&quot;Box&quot; icon:#(&quot;standard&quot;, 1) -- use first icon in standard ( StartObjectCreation Box )</p>\n\
<p>```</p>\n\
<p>``` macroScript Sphere category:&quot;Objects&quot; tooltip:&quot;Sphere&quot; icon:#(&quot;&quot;, 2) -- use second icon in internal icons ( StartObjectCreation Sphere )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>See <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Defining-Macro-Scripts/Creating-Icon-Bitmap-Files.html\' title=\'\'>Creating Icon Bitmap Files</a> for more information.</p>\n\
<p>The <span class=\'code\'>&lt;macro_script_body&gt;</span> can be one of two forms.</p>\n\
<p>The body can be either a single MAXScript expression, or a set of event handlers.</p>\n\
<p>An <span class=\'code\'>&lt;event_handler&gt;</span> is a special function definition local to the MacroScript that handles events generated by <strong>3ds Max</strong>.</p>\n\
<p>The valid <span class=\'code\'>&lt;event_name&gt;</span> are:</p>\n\
<div class=\'codeBlock\'><pre>on isChecked do &lt;expr&gt;   \n\
</pre></div><p>If <span class=\'code\'>&lt;expr&gt;</span> returns True and the MacroScript item is in a menu or quad menu, a check mark is placed next to the MacroScript item. If the MacroScript is a toolbar button, the button appears as &quot;pressed in&quot;. The <span class=\'code\'>do</span> is optional for this event handler. If this event handler is not specified, the item is not checked.</p>\n\
<div class=\'codeBlock\'><pre>on isIndeterminate do &lt;expr&gt;   \n\
</pre></div><p>If <span class=\'code\'>&lt;expr&gt;</span> returns True and the MacroScript item is in a menu or Quad menu, a horizontal dash symbol is placed next to the MacroScript item. If the MacroScript is a toolbar button, this handler has no effect. This handler is independent from the <span class=\'code\'>on isChecked do</span> handler and sets the Indeterminate symbol even if <span class=\'code\'>isChecked</span> returns False.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>on isEnabled do &lt;expr&gt; \n\
</pre></div><p>If <span class=\'code\'>&lt;expr&gt;</span> returns False and the macroscript item is in a menu or quad menu, the MacroScript item does not appear in the menu or quad menu. If the MacroScript is a toolbar button, the button is disabled. The <span class=\'code\'>do</span> is optional for this event handler. If this event handler is not specified, the item is enabled.</p>\n\
<div class=\'codeBlock\'><pre>on isVisible do &lt;expr&gt; \n\
</pre></div><p>If <span class=\'code\'>&lt;expr&gt;</span> returns False and the macroscript item is in a menu or quad menu, the MacroScript item does not appear in the menu or quad menu. If the MacroScript is a toolbar button, this handler has no affect. The <span class=\'code\'>do</span> is optional for this event handler. If this event handler is not specified, the item is visible.</p>\n\
<div class=\'codeBlock\'><pre>on execute do &lt;expr&gt; \n\
</pre></div><p>The expression evaluated when the menu or quad menu item is chosen, or the toolbar button clicked. A runtime error is generated if this event handler is not specified.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` macroScript Free_Camera category:&quot;Lights and Cameras&quot; internalcategory:&quot;Lights and Cameras&quot; tooltip:&quot;Free Camera&quot; buttontext:&quot;Free Camera&quot; Icon:#(&quot;Cameras&quot;,2) ( on execute do StartObjectCreation FreeCamera on isChecked return (mcrUtils.IsCreating FreeCamera) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` macroScript SubObject_Vertex buttonText:&quot;Vertex&quot; category:&quot;Modifier Stack&quot; internalCategory:&quot;Modifier Stack&quot; tooltip:&quot;Vertex Sub-object Mode&quot; icon:#(&quot;SubObjectIcons&quot;,1) ( on isChecked do (subObjectLevel == 1 and filters.canSwitchTo_Vertex()) on isEnabled do Filters.canSwitchTo_Vertex() on isVisible do Filters.canSwitchTo_Vertex() on execute do ( if subObjectLevel == undefined then max modify mode if subObjectLevel != 1 then subObjectLevel = 1 else subObjectLevel = 0 ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>on altExecute &lt;type&gt; do &lt;expr&gt; \n\
</pre></div><p>If a MacroScript implements the <span class=\'code\'>altExecute</span> event handler, then a mouse icon (with a dark click button) appears in the quad menu item that corresponds to the MacroScript. When the icon is clicked, the event handler is executed with <span class=\'code\'>&lt;type&gt;</span> being <span class=\'code\'>#default</span> .</p>\n\
<p>For example, the following adds alternative execute functionality to the standard &quot;Wire Parameters&quot; quad menu. When you click the icon, it pops the Param Wiring Editor instead of putting into the Wiring mode.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` macroScript paramWire category:&quot;Parameter Wire&quot; internalcategory:&quot;Parameter Wire&quot; buttonText:&quot;Wire Parameters&quot; tooltip:&quot;Start Parameter Wiring&quot; Icon:#(&quot;MAXScript&quot; ,1) ( on isEnabled return selection.count == 1 on execute do(paramWire.start()) on altExecute type do ( paramWire.OpenEditor() ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>on closeDialogs do &lt;expr&gt; \n\
</pre></div><p>The <span class=\'code\'>closeDialogs</span> handler is called instead of the <span class=\'code\'>on Execute</span> handler whenever the <span class=\'code\'>isChecked</span> handler returns True (the button/icon/item is checked). It can be used to TOGGLE back to the unchecked state. This handler must implement any cleanup code that closes any open dialogs and basically returns the MacroScript to a pre-executed state.</p>\n\
<p>Note: The <span class=\'code\'>closeDialogs</span> handler depends on the existence of the <span class=\'code\'>isChecked</span> handler. If an <span class=\'code\'>on closeDialogs</span> handler is defined without an <span class=\'code\'>isChecked</span> handler to be defined, a compile-time error is thrown.</p>\n\
<p>Here is a test for a MacroScript that toggles its rollout on and off:</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` macroScript testCloseDialogs category:&quot;MXS Help&quot; ( rollout testCloseRollout &quot;Test&quot; --define a rollout ( label lb_test &quot;testing CloseDialogs handler...&quot; ) on isChecked do testCloseRollout.open --return true if rollout is open --if isChecked returns false (the rollout is not open in a dialog), --the on execute handler will be called and will create the dialog.</p>\n\
<p>on execute do createDialog testCloseRollout</p>\n\
<div class=\'codeBlock\'><pre>--If isChecked returns true and the user pressed the button again, --instead of calling the on execute handler, the macroScript will call --the on closeDialogs handler and destroy the dialog.\n\
</pre></div><p>on closeDialogs do destroyDialog testCloseRollout )</p>\n\
<div class=\'codeBlock\'><pre>--If you drag the macroScript to a toolbar and click the button, --a dialog should appear and the button should be checked. --Click it again and the dialog will disappear. --Repeat as often as you want - the dialog will be toggled on and off! \n\
</pre></div><p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>on droppable &lt;window&gt; node:point:do... \n\
on drop &lt;window&gt; node:point:do... \n\
</pre></div><p>These optional MacroScript event handlers are used to define the so-called DropScripts that are used in conjunction with the i-Drop technology.</p>\n\
<p>The <span class=\'code\'>&lt;macro_script_body&gt;</span> can contain global and local variables, functions, and structure definitions. The <span class=\'code\'>&lt;macro_script_body&gt;</span> is compiled in its own local scope, and the locals are only visible inside the scope of the MacroScript. MacroScript locals are heap-based locals, which are slightly different from normal (stack-based) locals.</p>\n\
<p>Normal locals are visible in the current scope and have a lifetime of one execution of that scope. Heap-based locals are also visible only in the current scope, but have a lifetime equal to the lifetime of the top-level expression where they are defined. A MacroScript’s locals are created the first time you execute the MacroScript, initialized to a value of <span class=\'code\'>undefined</span> , or to their specified initialization value. These values are stored in a separate memory stack. On entry to each function (or top level script) in the MacroScript, a ’r;frame’ in the memory stack is marked and when the function (or top level script) exits, all of the values in the frame are freed from the memory.</p>\n\
<p>Because a MacroScript’s name is not created as a variable, you cannot access a MacroScript’s locals outside the scope of the MacroScript. So, for example, you can create a rollout in a MacroScript, and the rollout’s event handlers can access the locals defined in the MacroScript because the rollout is executing within the scope of the MacroScript. However, you cannot access the MacroScript’s locals from another utility or from the Listener because they are not executing within the scope of the MacroScript. See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Scope-of-Variables.html\' title=\'\'>Scope of Variables</a> for more information.</p>\n\
<p>When you execute a <span class=\'code\'>macroScript</span> definition, the return value is an integer MacroScript ID value. MAXScript internally stores information about each MacroScript in an array, and the returned MacroScript ID value is the array index for that MacroScript. The information stored for each MacroScript consists of the file in which that MacroScript is defined and a pointer into that file specifying where the MacroScript definition begins. The MacroScript definition is only compiled when you first press a toolbar button that contains the script, or execute the MacroScript using the <span class=\'code\'>macros.run()</span> method.</p>\n\
<div class=\'section\'><a id=\"there-are-five-ways-a-macroscript-can-be-defined\"></a><h2 id=\"there-are-five-ways-a-macroscript-can-be-defined\">There are five ways a MacroScript can be defined:</h2></div>\n\
<ul>\n\
<li><p>The default user-interface directory and its subdirectories are automatically scanned at startup for files of type .mcr, which are parsed for MacroScript definitions.</p></li>\n\
<li><p>A MacroScript definition is executed in an Editor window, in a script file that you execute, or in a startup script file.</p></li>\n\
<li><p>If you evaluate a MacroScript definition in the Listener window, a file is automatically created to contain the MacroScript definition. This file is stored in the MacroScripts directory under the current user-interface directory.</p></li>\n\
<li><p>MAXScript supports text drag onto toolbars to create MacroScript buttons. You can select and drag text from any text window such as, Listener window panes or Editor windows onto any visible toolbar. The cursor changes to an arrow with + sign when it is OK to drop the text. If you drop it, a MacroScript button is added to the toolbar with the dropped text as the body of the MacroScript. The classic case here is to drag some text from the Macro Recorder pane in the Listener window onto a toolbar to make a button that does the sequence of events just recorded. Remember that tabbed elements on the Shelf are toolbars and can accept dropped text. MAXScript automatically encloses the text in a MacroScript definition with a MacroScript name of <span class=\'code\'>DragAndDrop-MacroN</span> , where <span class=\'code\'>N</span> is a number that makes the MacroScript name unique. The category is DragAndDrop and no tooltip is specified. As with MacroScripts defined in the Listener window, a file is automatically created to contain the MacroScript definition. This file is stored in the MacroScripts directory under the current user-interface directory.</p></li>\n\
<li><p>A MacroScript can be defined using the <span class=\'code\'>macros.new()</span> method that is described next. As with MacroScripts defined in the Listener window, a file is automatically created to contain the MacroScript definition. This file is stored in the MacroScripts directory under the current user-interface directory.</p></li>\n\
</ul>\n\
<p>If you move or delete a file that contains a MacroScript definition that has been loaded, and try to execute the MacroScript, an error message appears. Further, if you edit a file containing MacroScript definitions, make sure to save and re-evaluate the entire file so that any other MacroScripts defined in the file have their file pointer updated. If you do not do this, you might get an error message indicating that the currently loaded definition no longer matches its file.</p>\n\
<p>If you reevaluate a MacroScript definition, any button using that MacroScript can see any changes that you make.</p>\n\
<p>Any macroScript definition evaluated in MAXScript or created by dropping text onto a toolbar has a separate definition .mcr file created in the MacroScripts directory under the current user-interface directory (typically UI\\MacroScripts). The name of the file is <span class=\'code\'>&lt;category_name&gt;-&lt;macro_name&gt;.mcr</span>.</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">FOR EXAMPLE:</th>\n\
<th align=\"left\"></th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">DragAndDrop-Macro12.mcr</td>\n\
<td align=\"left\">for macroScript Macro12 category:&quot;DragAndDrop&quot;</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">NURBS-Map_Updater.mcr</td>\n\
<td align=\"left\">for macroScript Map_Updater category:&quot;NURBS&quot;</td>\n\
</tr>\n\
</table>\n\
<p>If you evaluate a macroScript definition in the Listener or drop text on a toolbar, its recorded <strong>definition file</strong> is this backing file in UI\\MacroScripts. This definition file is the one that gets opened if you hit Edit MacroScript in the CUI customize menus or dialogs. For macroScript definitions evaluated in Listener, this means the same definition is updated each time you evaluate it, rather than having separate backing file for each evaluation.</p>\n\
<p>If you evaluate macroScript definitions in a .ms or .mcr file that does not already reside in the UI\\MacroScripts directory, a copy for each is placed in a separate file in UI\\MacroScripts, but the recorded definition file is the original source file, so that hitting Edit MacroScript goes to that file.</p>\n\
<p>This means that if any buttons containing such macroScript definitions are added to toolbars in the <strong>startup.cui</strong> file, the backing .mcr file in UI\\MacroScripts is used as its definition at the next <strong>3ds Max</strong> startup. When you start <strong>3ds Max</strong>, the macroScript definitions are taken from the backing files in UI\\MacroScripts. If these MacroScripts are also defined in MAXScript startup script files, they are re-defined at MAXScript startup and so the definition file of record is updated to point to the script file.</p>\n\
<div class=\'section\'><a id=\"macroscripts-access\"></a><h2 id=\"macroscripts-access\">MacroScripts Access:</h2></div>\n\
<p>MAXScript provides several methods that allow you to access and run MacroScripts from within a script. These MacroScript functions are in a structure package named <span class=\'code\'>macros</span> . For a description of the available methods, see the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Macro-Scripts/Macro-Scripts-1.html\' title=\'\'>Macro Scripts</a> topic.</p>\n\
<p>The following MacroScript allows you to render directly to the RAMPlayer. This MacroScript shows the use of rollouts and rollout floater windows in MacroScripts.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` -- MacroScript to Render to RamPlayer -- Author: Alexander Bicalho --<strong>************</strong>**** -- MODIFY THIS AT YOUR OWN RISK -- This utility will allow you to render directly to the RamPlayer</p>\n\
<p>MacroScript RAM_Render category:&quot;Tools&quot; tooltip:&quot;Render to Ram&quot; ( --declare local variables and define some functions local r_dialogue local get_names existFile function get_names name a = append a name function existFile fname = (getfiles fname).count != 0 --create the rollout definition rollout r_size&quot;Render Parameters&quot; ( local p = 95 local p2 = p+78 group &quot;Time Output&quot; ( radiobuttons r_time columns:1 align:#left labels:#(&quot;Single&quot;,&quot;Active Time Segment&quot;,&quot;Range:&quot; ) spinner nth &quot;Every Nth Frame:&quot; pos:[215,24] fieldwidth:50 type:#integer range:[0,10000,1] enabled:false spinner r_from fieldwidth:60 pos:[75,56] type:#integer range:[0,10000,1] enabled:false spinner r_to &quot;To:&quot; fieldwidth:60 pos:[152,56] type:#integer range:[0,10000,100] enabled:false ) group &quot;Render Size&quot; ( spinner rw &quot;Width &quot; fieldwidth:60 pos:[15,p+08] type:#integer range:[0,10000,320] spinner rh &quot;Height &quot; fieldwidth:60 pos:[12,p+32] type:#integer range:[0,10000,240] spinner aspect &quot;Aspect &quot; fieldwidth:60 pos:[10,p+56] type:#float range:[0,20,1.0] button s160 &quot;160x120&quot; pos:[125,p+06] width:75 height:19 button s256 &quot;256x243&quot; pos:[125,p+30] width:75 height:19 button s320 &quot;320x240&quot; pos:[205,p+06] width:75 height:19 button s512 &quot;512x486&quot; pos:[205,p+30] width:75 height:19 button s640 &quot;640x480&quot; pos:[285,p+06] width:75 height:19 button s720 &quot;720x486&quot; pos:[285,p+30] width:75 height:19 button conf_render &quot;Configure&quot; pos:[125,p+54] width:115 height:19 button wipe &quot;Purge Files&quot; pos:[245,p+54] width:115 height:19 button go &quot;Render&quot; pos:[125,p+78] width:235 height:19 ) label abt0 &quot;Render to RAM&quot; pos:[8,p2+31] label abt1 &quot;Version 0.2a&quot; pos:[8,p2+46] label abt2 &quot;Alexander Esppeschit Bicalho&quot; pos:[225,p2+31] label abt3 &quot;abicalho@brasilmail.com&quot; pos:[249,p2+46] --define the rollout event handlers on wipe pressed do ( local tempfilename_a = (getdir #image) + &quot;\\ramplayertemp_a.avi&quot; local tempfilename_b = (getdir #image) + &quot;\\ramplayertemp_b.avi&quot; if existfile tempfilename_a then deletefile tempfilename_a if existfile tempfilename_b then deletefile tempfilename_b ) on r_time changed state do ( case state of ( 1: nth.enabled = r_from.enabled = r_to.enabled = false 2: ( nth.enabled = true r_from.enabled = r_to.enabled = false ) 3: nth.enabled = r_from.enabled = r_to.enabled = true ) ) on s160 pressed do (rw.value=160; rh.value=120; aspect.value=1.0) on s320 pressed do (rw.value=320; rh.value=240; aspect.value=1.0) on s256 pressed do (rw.value=256; rh.value=243; aspect.value=1.266) on s512 pressed do (rw.value=512; rh.value=486; aspect.value=1.266) on s640 pressed do (rw.value=640; rh.value=480; aspect.value=1.0) on s720 pressed do (rw.value=720; rh.value=486; aspect.value=0.9) on conf_render pressed do (max render scene) on go pressed do ( local tempfilename_a = (getdir #image) + &quot;\\ramplayertemp_a.avi&quot; local tempfilename_b = (getdir #image) + &quot;\\ramplayertemp_b.avi&quot; if existfile tempfilename_b then ( deletefile tempfilename_a copyfile tempfilename_b tempfilename_a tempfilename = tempfilename_b ) else ( if existfile tempfilename_a then tempfilename = tempfilename_b else ( tempfilename = tempfilename_a tempfilename_b = &quot;&quot; ) ) case r_time.state of ( 1: ( render outputheight:rh.value outputwidth:rw.value pixelaspect:aspect.value outputfile:tempfilename vfb:off) 2: ( render outputheight:rh.value outputwidth:rw.value pixelaspect:aspect.value outputfile:tempfilename vfb:off nthframe:nth.value framerange:#active ) 3: ( render outputheight:rh.value outputwidth:rw.value pixelaspect:aspect.value outputfile:tempfilename vfb:off nthframe:nth.value fromframe:r_from.value toframe:r_to.value ) ) ramplayer tempfilename_a tempfilename_b closerolloutfloater r_dialogue )--end of on go pressed )--end of rollout r_size --close the old rollout floater if it exists try(closerolloutfloater r_dialogue)catch() --put up new rollout floater and add rollout to it. r_dialogue = newrolloutfloater &quot;Render to RAM&quot; 400 300 addrollout r_size r_dialogue --end of MacroScript, rollout takes over... )</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";