var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>RolloutCreator Functions</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>RolloutCreator Functions</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"rolloutcreator-functions\"></a></div>\n\
<p><strong>RolloutCreator</strong> is a structure of functions for dynamically creating rollouts. The functions are implemented by a script located under <strong>stdplugs\\stdscripts\\baseLib\\rolloutCreator.ms</strong></p>\n\
<p><strong>Here are the implemented functions and their usage:</strong></p>\n\
<div class=\'codeBlock\'><pre>rolloutCreator &lt;rollout_name&gt; &lt;rollout_caption&gt;      \n\
</pre></div><p>Creates an instance of rolloutCreator, assign it to a variable,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` rci = rolloutCreator &quot;myRollout&quot; &quot;My Rollout&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;rollout_creator&gt;.begin()   \n\
</pre></div><p>This function needs to be called immediately after the instance is created, this does the initialization</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout_creator&gt;.addControl &lt;control_type&gt; &lt;control_name&gt; &lt;control_caption&gt; [  paramStr:&lt;string&gt;] \n\
</pre></div><p>Adds a control to the rollout:</p>\n\
<div class=\'codeBlock\'><pre>&lt;control_type&gt; \n\
</pre></div><p>can be any of named rolloutControls eg: #button, #spinner, #activeXControl etc.</p>\n\
<div class=\'codeBlock\'><pre>&lt;control_name&gt; \n\
</pre></div><p>variable name of the control by which it is referred eg: #btnButton</p>\n\
<div class=\'codeBlock\'><pre>&lt;control_caption&gt; \n\
</pre></div><p>caption of the control &quot;My Button&quot;</p>\n\
<div class=\'codeBlock\'><pre>[paramStr:] \n\
</pre></div><p>an optional string representation of all the keyword parameters that needs to be passed to the control, for example: &quot;width:100 height:20 align:#right&quot;</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` rci.addControl #button #myButton &quot;My Button&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;rollout_creator&gt;.addHandler &lt;control_name&gt; &lt;event_type&gt; [paramStr:&lt;string&gt;] [codeStr:&lt;string&gt;] [filter:&lt;boolean&gt;] \n\
</pre></div><p>Adds an event handler for the controls previously added:</p>\n\
<div class=\'codeBlock\'><pre>&lt;control_name&gt; \n\
</pre></div><p>the variable passed during the control creation</p>\n\
<div class=\'codeBlock\'><pre>&lt;event_type&gt; \n\
</pre></div><p>any of the events supported by the control, eg: #changed, #pressed, #selected</p>\n\
<div class=\'codeBlock\'><pre>[paramStr:&lt;string&gt;] \n\
[codeStr:&lt;string&gt;] \n\
</pre></div><p>a string representation of the event handler code, if the string contains sub-strings, enclose them in two &#39;@&#39; characters and pass on\\true to the filter: parameter</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` rci.addHandler #myButton #pressed codeStr: &quot;MessageBox <span class=\"cite\" data-citation-ids=\"Hey\">@Hey</span>@&quot; filter:on</p>\n\
<p>```</p>\n\
<p>This will add an event handler for button named &quot;myButton&quot;. When the button is clicked, a messagebox pops up with the text &quot;hey&quot; in it. The final result inside the rollout definition will look like this:</p>\n\
<p>``` on myButton presseddoMessageBox &quot;Hey&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>ANOTHER EXAMPLE</strong></p>\n\
<p>``` rci.addHandler #myCheckbox #changed paramStr:&quot;val&quot; codeStr:&quot;myOtherCheckbox.state = not val&quot;</p>\n\
<p>```</p>\n\
<p>This will add an event handler for checkbox named &quot;myCheckbox&quot;. When the state of the checkbox is changed, the state of another previously defined checkbox called &quot;myOtherCheckbox&quot; will also be changed to the inverted boolean value of the argument variable &quot;val&quot; which is passed the actual state of &quot;myCheckbox&quot;. The final result inside the rollout definition will look like this:</p>\n\
<p>``` on myCheckbox changed val do myOtherCheckbox.state = not val</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;rollout_creator&gt;.end() \n\
</pre></div><p>This function has to be called whenever all the required controls and their event handlers are called. This function forms the rollout string, evaluates it and returns the definition which can be passed to createDialog and addRollout functions.</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout_creator&gt;.addLocal &lt;string&gt; [init:&lt;value&gt;] \n\
</pre></div><p>This function can be used to add local variables to the rollout definitions. The variable’s value can be initialized by passing the <span class=\'code\'>init:</span> value</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt; \n\
</pre></div><p>Name of local variable</p>\n\
<div class=\'codeBlock\'><pre>init: \n\
</pre></div><p>Specifies initialization value of local</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout_creator&gt;.addText &lt;string&gt; [filter:&lt;boolean&gt;] \n\
</pre></div><p>This function is useful for adding functions to the rollout definitions. If the string contains sub-strings, enclose them in two &#39;@&#39; characters and pass true to the <span class=\'code\'>filter</span> : parameter</p>\n\
<div class=\'codeBlock\'><pre>&lt;string&gt; \n\
</pre></div><p>String added to rollout definition.</p>\n\
<blockquote>\n\
<p><strong>COMPLETE EXAMPLE:</strong></p>\n\
<p>``` rci = rolloutCreator &quot;myRollout&quot; &quot;My Rollout&quot; rci.begin() rci.addControl #button #myButton &quot;My Button&quot; rci.addHandler #myButton #pressed filter:on codeStr:&quot;MessageBox <span class=\"cite\" data-citation-ids=\"Isn\">@Isn</span>&#39;t this cool@ title:<span class=\"cite\" data-citation-ids=\"Wow\">@Wow</span>@&quot; createDialog (rci.end())</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>ANOTHER EXAMPLE:</strong></p>\n\
<p>``` rfTest = rolloutCreator &quot;rfTestN&quot; &quot;rfTestC&quot; -- Start creating the rollout rfTest.begin() rfTest.addControl #button #myButton &quot;My Button&quot; -- add a button rfTest.addHandler #myButton #pressed filter:on codeStr:&quot;MessageBox <span class=\"cite\" data-citation-ids=\"Look\">@Look</span> to the @Light@ thing@&quot; rfTest.end() createDialog rfTest.def</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";