var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Scripted Mouse Tools</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Scripted Mouse Tools</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"scripted-mouse-tools\"></a></div>\n\
<p>Scripted Mouse Tools are used to perform a set of actions based on mouse clicks in the <strong>3ds Max</strong> viewports. Tools are useful for scripted object creation plug-ins, as described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/Scripted-Plug-ins-1.html\' title=\'\'>Scripted Plug-ins</a>.</p>\n\
<blockquote>\n\
<p><strong>HERE IS A SIMPLE EXAMPLE</strong></p>\n\
<p>``` tool foo ( local b on mousePoint clickno do if clickno == 1 then b = box pos:worldPoint else #stop on mouseMove clickno do b.pos = worldPoint )</p>\n\
<p>```</p>\n\
<p>This tool allows the user to click in a viewport at which point a box is created. Dragging the mouse positions the box and releasing the mouse button stops the tool.</p>\n\
<p><strong>YOU WOULD START THIS TOOL BY EXECUTING:</strong></p>\n\
<p>``` startTool foo</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The syntax for tools is similar to that for utility definition constructs. They have local variables, functions, and event handlers, but tools have no user-interface items.</p>\n\
<p>A tool is created using the <span class=\'code\'>tool</span> definition construct in MAXScript. The top-level syntax is as follows:</p>\n\
<div class=\'codeBlock\'><pre>tool &lt;tool_name&gt; [ prompt:&lt;string&gt; ] [ numPoints:&lt;number&gt; ]( &lt;tool_body&gt; )\n\
</pre></div><p>where <span class=\'code\'>&lt;tool_name&gt;</span> is the name of an automatically created variable to hold the value that represents the tool. The scope of this variable is the current MAXScript scope. This value is also returned as a result of the <span class=\'code\'>tool</span> declaration. The class of this value is <span class=\'code\'>MouseTool</span> .</p>\n\
<p>The optional <span class=\'code\'>prompt:</span> keyword argument specifies the prompt string displayed in the <strong>3ds Max</strong> Prompt Line while the tool is executing.</p>\n\
<p>The optional <span class=\'code\'>numPoints:</span> keyword argument specifies the maximum number of points (mouse clicks) the tool will use. If the tool is still executing when you reach the <span class=\'code\'>numPoints</span> number of mouse clicks, the tool will stop and return a value of <span class=\'code\'>#stop</span> .</p>\n\
<p><span class=\'code\'>&lt;tool_body&gt;</span> is enclosed in the required parentheses and is a sequence of clauses that define the functions and event handlers that process mouse clicks. These clauses are defined in detail in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Mouse-Tools/Mouse-Tool-Clauses.html\' title=\'\'>Mouse Tool Clauses</a>.</p>\n\
<p>The following method invokes a tool:</p>\n\
<div class=\'codeBlock\'><pre>startTool &lt;tool_name&gt; [prompt:&lt;string&gt;] [snap:#3D|#2D] [numPoints:&lt;number&gt;]\n\
</pre></div><p>where <span class=\'code\'>&lt;tool_name&gt;</span> is the tool name used in a tool definition.</p>\n\
<p>The optional <span class=\'code\'>prompt:</span> keyword argument specifies the prompt string displayed in the <strong>3ds Max</strong> Prompt Line while the tool is executing. If specified, this string overrides the prompt string specified in the tool definition.</p>\n\
<p>The optional <span class=\'code\'>snap:</span> keyword argument specifies the upper limit on snapping. Specifying a <span class=\'code\'>snap</span> parameter does not turn on snap, only the user can turn it on in the interface. When 2.5D or 3D snapping is turned on by the user, the <span class=\'code\'>snap</span> parameter restricts snapping to the specified level.</p>\n\
<p>The optional <span class=\'code\'>numPoints:</span> keyword argument specifies the maximum number of points (mouse clicks) the tool will use. If specified, this value overrides the number of points specified in the tool definition.</p>\n\
<p>The return value from <span class=\'code\'>startTool()</span> will be either <span class=\'code\'>#stop</span> if a called change handler returns the value <span class=\'code\'>#stop</span> or the <span class=\'code\'>numPoints</span> value is reached, or <span class=\'code\'>#abort</span> if the user aborts the tool using a right-click or presses the ESC key.</p>\n\
<p>A currently executing tool can also be aborted using the following method:</p>\n\
<div class=\'codeBlock\'><pre>stopTool &lt;tool_name&gt;\n\
</pre></div><p>where:</p>\n\
<p><span class=\'code\'>&lt;tool_name&gt;</span> is the tool name used in a tool definition.</p>\n\
<p>This method would typically be called in a callback function or change handler (see <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Change-Handlers-and-Callbacks.html\' title=\'\'>Change Handlers and Callbacks</a>), or in a timer event handler in a rollout (see <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-User-Interface-Controls/Rollout-User-Interface-Controls-3/Timer-UI-Control.html\' title=\'\'>Timer</a>).</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";