var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Mouse Tool Clauses</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Mouse Tool Clauses</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"mouse-tool-clauses\"></a></div>\n\
<p>The <span class=\'code\'>&lt;tool_body&gt;</span> of a mouse tool definition is made up of a sequence of tool clauses as follows:</p>\n\
<div class=\'codeBlock\'><pre>&lt;tool_body&gt; ::= { &lt;tool_clause&gt; }+\n\
</pre></div><p>Tool clauses define the components of a tool and can be one of two basic things:</p>\n\
<ul>\n\
<li><p><strong>Local variables, functions or structure definitions</strong> are variables, functions, and structures whose scope is the tool. The <span class=\'code\'>&lt;tool_body&gt;</span> is compiled in its own local scope and the locals are only visible inside the scope of the tool. Tool locals are heap-based locals, which are slightly different from normal (stack-based) locals. Normal locals are visible in the current scope and have a lifetime of one execution of that scope. Heap-based locals are also visible only in the current scope, but have a lifetime equal to the lifetime of the top-level expression where they are defined. A tool’s locals are created the first time you execute the tool and are kept permanently in the heap (unless and until you redefine the tool). This means things like rollouts created in a tool that live beyond the simple execution of the tool can refer to these locals and the locals will still exist. Each time you execute a tool, its local variables are initialized to a value of <span class=\'code\'>undefined</span> , or to their specified initialization value. For example, you can create a rollout in a tool, and the rollout’s event handlers can access the locals defined in the tool because the rollout is executing within the scope of the tool. You cannot access the tool’s locals from another utility or from Listener, because they are not executing within the scope of the tool. See <a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Scope-of-Variables.html\' title=\'\'>Scope of Variables</a> for more information.</p></li>\n\
<li><p><strong>Event handlers</strong> are special kinds of functions associated with particular events. Event handlers specify the processing you want to occur when a user clicks or moves a mouse, right-clicks, or starts or stops the tool. These actions generate named events and the optional event handler you supply for that event is called when the action occurs.</p></li>\n\
</ul>\n\
<p>Formally, the syntax of a <span class=\'code\'>&lt;tool_clause&gt;</span> is defined as follows:</p>\n\
<div class=\'codeBlock\'><pre>&lt;tool_clause&gt; ::= &lt;local_variable_decl&gt; | &lt;local_function_decl&gt; | &lt;local_struct_decl&gt; | &lt;event_handler&gt;\n\
</pre></div><p><strong>Locals</strong></p>\n\
<p>A <span class=\'code\'>&lt;local_variable_decl&gt;</span> , <span class=\'code\'>&lt;local_function_decl&gt;</span> , and <span class=\'code\'>&lt;local_struct_decl&gt;</span> are exactly the same as local variable, function, and structure definitions in MAXScript:</p>\n\
<div class=\'codeBlock\'><pre>&lt;local_variable_decl&gt; ::= local &lt;decl&gt; { , &lt;decl&gt; } \n\
&lt;decl&gt; ::= &lt;name&gt; [ = &lt;expr&gt; ] -- optional initial value\n\
&lt;local_function_decl&gt; ::= [ mapped ](function | fn ) &lt;name&gt; { &lt;argument&gt; } = &lt;expr&gt;\n\
&lt;local_struct_decl&gt; ::+ struct &lt;name&gt; ( &lt;member&gt; { , &lt;member&gt; } )\n\
&lt;member&gt; ::= ( &lt;name&gt; [ = &lt;expr&gt; ] | &lt;local_function_decl&gt; )\n\
</pre></div><p>Global variables cannot be declared as a tool clause, however they can be declared within event handler scripts. If you need to ensure a variable name references a global variable, declare the variable name as global immediately before defining the tool in your script.</p>\n\
<p>When writing scripts, it is good programming practice to explicitly declare your local and global variables. Implicit declaration is provided as a short-hand, typically used when working in the Listener interactively or developing short scripts. When developing extended scripts, explicitly declaring variables can reduce errors and improve readability of the code. It is also recommend that you declare as local all variables unless you really want them to be global variables. The reasons for this are described in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Scope-of-Variables.html\' title=\'\'>Scope of Variables</a>.</p>\n\
<p>Within the functions and event handlers of a tool, 13 pre-defined locals variables are always accessible. Each one holds a useful value relating to the mouse action that just occurred:</p>\n\
<div class=\'codeBlock\'><pre>viewPoint Point2\n\
</pre></div><p>The current mouse position in viewport pixel coordinates.</p>\n\
<div class=\'codeBlock\'><pre>worldPoint Point3\n\
</pre></div><p>The current mouse position projected on the active grid in world coordinates.</p>\n\
<div class=\'codeBlock\'><pre>worldDist Point3\n\
</pre></div><p>The distance in X, Y, and Z from the previous click point to the current click point in world coordinates.</p>\n\
<div class=\'codeBlock\'><pre>worldAngle Point3\n\
</pre></div><p>The angles around the world X, Y, and Z axes from the previous click point to the current click point in world coordinates.</p>\n\
<div class=\'codeBlock\'><pre>gridPoint Point3\n\
</pre></div><p>The current mouse position projected on the active grid in the coordinate system of the active grid. If the active grid is the home grid, the coordinate system is the home grid plane active in the current viewport (that is, the construction plane). See the discussion of grid versus world values below.</p>\n\
<div class=\'codeBlock\'><pre>gridDist Point3\n\
</pre></div><p>The distance in X, Y, and Z from the previous click point to the current click point in the coordinate system of the active grid. If the active grid is the home grid, the coordinate system is the home grid plane active in the current viewport (that is, the construction plane). See the discussion of grid versus world values below.</p>\n\
<div class=\'codeBlock\'><pre>gridAngle Point3\n\
</pre></div><p>The angles around the world X, Y, and Z axes from the previous click point to the current click point in the coordinate system of the active grid. If the active grid is the home grid, the coordinate system is the home grid plane active in the current viewport (that is, the construction plane). See the discussion of grid versus world values below.</p>\n\
<div class=\'codeBlock\'><pre>shiftKey Boolean\n\
</pre></div><p><span class=\'code\'>true</span> if <strong>SHIFT</strong> key was down.</p>\n\
<div class=\'codeBlock\'><pre>ctrlKey Boolean\n\
</pre></div><p><span class=\'code\'>true</span> if <strong>Ctrl</strong> key was down.</p>\n\
<div class=\'codeBlock\'><pre>altKey Boolean\n\
</pre></div><p><span class=\'code\'>true</span> if <strong>Alt</strong> key was down.</p>\n\
<div class=\'codeBlock\'><pre>lButton Boolean\n\
</pre></div><p><span class=\'code\'>true</span> if left mouse button was down.</p>\n\
<div class=\'codeBlock\'><pre>mButton Boolean\n\
</pre></div><p><span class=\'code\'>true</span> if middle mouse button was down.</p>\n\
<div class=\'codeBlock\'><pre>rButton Boolean\n\
</pre></div><p><span class=\'code\'>true</span> if right mouse button was down.</p>\n\
<p>When a create mouse tool is used in a level 5 scripted plug-in, an additional local variable is accessible:</p>\n\
<div class=\'codeBlock\'><pre>nodeTM Matrix3\n\
</pre></div><p>Provides read/write access to the transform of the node currently being created. This value is in the current grid coordinate system.</p>\n\
<p>See <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/Scripted-Plug-ins-1.html\' title=\'\'>Scripted Plug-ins</a> for more information.</p>\n\
<p>When writing SimpleObject scripted plug-ins, you should always use the <span class=\'code\'>gridPoint</span> , <span class=\'code\'>gridDist</span> , and <span class=\'code\'>gridAngle</span> values rather than corresponding world values, as object-creation in SimpleObject scripted plug-ins is managed in the active grid coordinate system.</p>\n\
<p>For <span class=\'code\'>gridDist</span> , the .X and .Y components are the delta X and Y between the previous clicked point and the current mouse point in the plane of the current grid. The .Z component is a projection from the current Y screen coordinates onto a Z-vector (in the grid coordinate system) based at the last point clicked on the grid, such that the .Z value is the projected height up the Z-vector. For non-orthogonal viewports this is as expected, but for orthogonal viewports (in which you are always dragging in the XY plane of the grid), this is always the same as <span class=\'code\'>gridDist.y</span> . If you are using the gridDist value to build the portion of an object on the grid, or determine the distance on the current grid from the last point, you want to use only the .X and .Y components.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` side1Len = gridDist.x side2Len = gridDist.y dist=length [gridDist.x,gridDist.y]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>If you are specifying the height off of the current grid, you would typically use the .Z component.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` height = gridDist.z</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>For <span class=\'code\'>worldDist</span> , the behavior is similar to that for <span class=\'code\'>gridDist</span> , however the projected component is dependent on the construction plane of the viewport. For the Top, Bottom, and non-orthogonal viewports, the projected height is contained in the .Z component. For Left and Right viewports, the projected height is contained in the .X component. For Front and Back viewports, the projected height is contained in the .Y component.</p>\n\
<p>When you create a node in the <strong>3ds Max</strong> user-interface, the local Z axis of the node is perpendicular to the construction plane. When you create a node using MAXScript, by default the local Z axis of the node points along the direction of the world Z axis. If you create a node in a tool (other than in a SimpleObject scripted plug-in), you must take into account the construction plane orientation if you want to duplicate <strong>3ds Max</strong>’s behavior when creating a node. The easiest way to do this is to create the node in a <span class=\'code\'>coordsys grid</span> context and specify the position of the node during creation in grid coordinate space. An example of this is shown in the following script.</p>\n\
<blockquote>\n\
<p><strong>POINT CREATOR</strong></p>\n\
<p>``` tool PointCreator ( local p, createpoint -- define a function to perform actual node creation. Setting coordsys to -- ’r;grid’ in order for the alignment of the node’s local Z axis to be -- perpendicular to the construction grid fn createpoint = in coordsys grid p=point pos:gridPoint -- -- set up so that a node is created on a mouse button down, move node -- drag, release node at mouse button up. -- -- if clickno == 1, then we are at first mouse click, which is a mouse -- button down. If clickno != 1, at following mouse button up. on mousePoint clickno do ( if clickno == 1 then createPoint() -- if p == undefined, then clicked twice without mouse movement -- (double clicked). No point object present, so just ignore this click. else if p != undefined do (p.pos=worldPoint;p=undefined) ) -- if p != undefined, we are moving a previously created node -- if p == undefined, and left mouse button is down, create a node on mouseMove clickno do ( if p != undefined then p.pos=worldPoint else if lbutton do createPoint() ) ) -- start the tool. No exit condition defined, so right-click to exit. startTool PointCreator</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Event Handlers</strong></p>\n\
<p>An <span class=\'code\'>&lt;event_handler&gt;</span> is a special function definition local to a tool that you provide to handle the processing you want to occur when a user clicks in a viewport, right-clicks, or starts or stops the tool. Each user action generates a named event and any event handler you supply for that event is called when the action occurs. The available event handlers are:</p>\n\
<div class=\'codeBlock\'><pre>on start do &lt;expr&gt;\n\
</pre></div><p>Called when the tool starts.</p>\n\
<div class=\'codeBlock\'><pre>on stop do &lt;expr&gt;\n\
</pre></div><p>Called when the tool ends.</p>\n\
<div class=\'codeBlock\'><pre>on freeMove do &lt;expr&gt;\n\
</pre></div><p>Called when the mouse moves prior to the first click.</p>\n\
<div class=\'codeBlock\'><pre>on mousePoint &lt;arg&gt; do &lt;expr&gt;\n\
</pre></div><p>Called for each mouse click, parameter <span class=\'code\'>arg</span> contains the number of the click.</p>\n\
<div class=\'codeBlock\'><pre>on mouseMove &lt;arg&gt; do &lt;expr&gt;\n\
</pre></div><p>Called when the mouse moves anytime after the first click.</p>\n\
<div class=\'codeBlock\'><pre>on mouseAbort &lt;arg&gt; do &lt;expr&gt;\n\
</pre></div><p>Called when the user right-clicks to cancel or presses the ESC key.</p>\n\
<p>The <span class=\'code\'>&lt;arg&gt;</span> parameter on each of the mouse event handlers lets you know which mouse click you are in. Mouse clicks are actually only the mouse click release, except for the initial mouse click. If you do a mouse click, drag, release, move, click, drag, and release, the <span class=\'code\'>on mousePoint</span> event handler is called three times: the first click, the first release, and the second release, with <span class=\'code\'>&lt;arg&gt;</span> values of 1, 2, and 3, respectively. The mouse click counter is incremented after processing the <span class=\'code\'>on mousePoint</span> event handler, so the <span class=\'code\'>&lt;arg&gt;</span> parameter for the <span class=\'code\'>mouseMove</span> and <span class=\'code\'>mouseAbort</span> event handlers specify the click count for the next mouse click. In the previous example, when you drag between the first click and first release, the <span class=\'code\'>&lt;arg&gt;</span> value for a <span class=\'code\'>mouseMove</span> event handler will have a value of 2. During the following move, click, and drag it will have a value of 3.</p>\n\
<p>In <strong>3ds Max 6 and higher,</strong> while running a mouse tool, if you click in a viewport where the construction plane is on edge, the tool will exit with a return value of <span class=\'code\'>#abort</span></p>\n\
<p>The following script simply demonstrates when the various event handlers are called. Simply run this script and drag in the viewports. Right-click or press the ESC key to stop the tool’s execution.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` tool foo ( on freeMove do print &quot;Free Moving&quot; on mousePoint clickno do format &quot;Point: %\\n&quot; clickno on mouseAbort clickno do format &quot;Abort: %\\n&quot; clickno on mouseMove clickno do format &quot;Moving: %\\n&quot; clickno on start do print &quot;Starting&quot; on end do print &quot;Ending&quot; ) startTool foo prompt:&quot;Hello!&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>All of the mouse action event handlers may return the special value <span class=\'code\'>#stop</span> which causes the tool to stop. In the following <span class=\'code\'>mousePoint</span> event handler example, the first click creates the box and the release (second click) terminates the tool.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` on mousePoint clickno do if clickno == 1 then b = box pos:worldPoint else #stop</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The following script implements the following functions: on mouse click three spot lights are created at the mouse point. While holding the mouse button down, drag the mouse to position the classical key, back and fill light positions. During this drag, holding down the SHIFT key will flip the fill light side. Release the mouse button and move the mouse to change the elevation of the lights. Click the mouse button when the lights are at the correct height. The back light is raised 1.5 times the key light’s height, and the fill light is raised 0.75 times the key light’s height.</p>\n\
<blockquote>\n\
<p><strong>TO START THIS TOOL, YOU WOULD SAY</strong></p>\n\
<p>``` startTool three_lights</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>and then drag in one of the viewports.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` tool three_lights ( local key, fill, back, targ on mousePoint click do coordsys grid ( if click == 1 then -- create key, back &amp; fill lights at mousedown ( targ = targetobject pos:gridPoint key = targetspot pos:gridPoint name:&quot;key&quot;target:targ back = targetspot pos:gridPoint name:&quot;back&quot;target:targ fill = targetspot pos:gridPoint name:&quot;fill&quot;target:targ ) if click == 3 then #stop ) on mouseMove click do ( if click == 2 then -- drag out &amp; round on x-y plane ( coordsys grid key.pos = gridPoint coordsys targ back.pos = - key.pos local p = if shiftKey then 90 else -90 coordsys targ fill.pos = key.pos * ((eulerangles 0 0 p) as quat) ) else if click == 3 then -- drag up to elevate lights ( in coordsys targ ( local Z = gridDist.z key.pos.z = Z back.pos.z = Z * 1.5 fill.pos.z = Z * 0.5 ) ) ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";