var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Scripted Camera Plug-ins</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Scripted Camera Plug-ins</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"scripted-camera-plug-ins\"></a></div>\n\
<p>Scripted camera plug-ins can be written in MAXScript. At present, you can write either extending camera plug-ins that extend the existing MAX cameras or temporary camera plug-ins that can be used to host create tools for a custom camera system.</p>\n\
<p>The plug-in superclass for cameras is &#39;camera&#39;.</p>\n\
<p><strong>Event Handlers</strong></p>\n\
<div class=\'codeBlock\'><pre>on renderApertureChanged val do ....\n\
</pre></div><p>This event handler is available to scripted cameras and gives access to the CameraObject:: <span class=\'code\'>renderApertureChanged</span> callbacks made by the rendering dialog to a camera when the user adjusts parameters that affect the render aperture.</p>\n\
<p>This handler is optional.</p>\n\
<p>The <span class=\'code\'>&#39;val&#39;</span> parameter contains the new render aperture value. This typically gets called when you select a new aperture in the Output Size dropdown in the render dialog or adjust a spinner when in Custom mode.</p>\n\
<p>There are several cases where this handler is called:</p>\n\
<ul>\n\
<li><p>In the Render Scene dialog, if Image Aspect is unlocked and you change the Width, Height, or Pixel Aspect</p></li>\n\
<li><p>In the Render Scene dialog, if you click on one of the output size preset buttons</p></li>\n\
<li><p>In the Render Scene dialog, if Image Aspect is locked and you change the Width, Height, or Pixel Aspect, or if you change Aperture Width, and then click on either Render or Close</p></li>\n\
</ul>\n\
<p>The value being passed into handler is the aperture width. You can get the remaining values using the <span class=\'code\'>renderWidth</span> , <span class=\'code\'>renderHeight</span> , and <span class=\'code\'>RenderPixelAspect</span> global variables. However, what you get for these values are typically the <strong>old</strong> value with the exception of the Aperture Width value. The call to the handler is coming from a &quot;InvalidateCameras&quot; method, which is called right before setting the new values. No broadcasts are made after the new values are set, and if safe frames are not turned on in any viewport, none of the viewports are redrawn.</p>\n\
<p>It is recommended that if a scripted camera uses this handler, it must cache the old Aperture Width value and test the incoming value against the cached value before proceeding.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` plugin Camera CamTest name:&quot;CamTest&quot; classID:#(0x47db14ff, 0x4e9b5f90) category:&quot;Standard&quot; extends:FreeCamera ( on renderApertureChanged val do format &quot;renderApertureChanged: %\\n&quot; val tool create ( on mousePoint click do #stop ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>The following handler was added in 3ds Max 7:</strong></p>\n\
<div class=\'codeBlock\'><pre>on getDisplayMesh do ....\n\
</pre></div><p>This event handler is available to scripted cameras and <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/Scripted-Helper-Plug-ins.html\' title=\'\'>helpers</a>, and lets the developer replace the viewport display mesh of the delegate with a custom display mesh.</p>\n\
<p>This handler is optional.</p>\n\
<p>Note: For <strong>performance</strong> reasons, it is <strong>critical</strong> to regenerate the returned mesh as little as possible. The handler is called often for display, bounds testing, and hit testing.</p>\n\
<p>The example below shows how to update the mesh in the handler only when the mesh has actually changed:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` plugin Camera CamTest_DisplayMesh name:&quot;CamTest&quot; classID:#(0x6ca13d13, 0x12afbfd4) category:&quot;Standard&quot; extends:FreeCamera ( local lastR1, lastR2, meshObj parameters pblock rollout:params ( radius1 type:#float animatable:true ui:r1_amount default:40.0 radius2 type:#float animatable:true ui:r2_amount default:20.0 ) rollout params &quot;CamTest Parameters&quot; ( Spinner r1_amount &quot;Radius 1:&quot; range:[0, 1e9, 40] Spinner r2_amount &quot;Radius 2:&quot; range:[0, 1e9, 20] ) on getDisplayMesh do ( if (meshObj == undefined) do ( meshObj = createInstance torus radius1:radius1 radius2:radius2 mapCoords:false lastR1 = radius1; lastR2 = radius2 ) if radius1 != lastR1 do (meshObj.radius1 = radius1; lastR1 = radius1) if radius2 != lastR2 do (meshObj.radius2 = radius2; lastR2 = radius2) meshObj.mesh )--end on getDisplayMesh tool create ( on mousePoint click do (nodeTM.translation = gridPoint;#stop ) )--end tool )--end plugin</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>on useWireColor do ....\n\
</pre></div><p>This <strong>optional</strong> event handler lets the developer specify whether to use the node&#39;s wire color when drawing the object in the viewport, or use the UI color for the object type (Camera Object for Cameras). If this handler returns true, the node&#39;s wire color is used, otherwise the UI color for the object type is used. If the event handler is not specified, the wire color is used. This handler is only applicable when a <span class=\'code\'>getDisplayMesh</span> handler is supplied. Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";