var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Scripted Manipulators</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Scripted Manipulators</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"scripted-manipulators\"></a></div>\n\
<p>Manipulators are a type of helper object designed to support direct manipulation of parameters in the 3D viewports. They can be set up to manipulate parameters on objects, modifiers, controllers and nodes.</p>\n\
<p>There is a &quot;Manipulate&quot; button on the main toolbar. When pressed, the system will show all the manipulators for selected objects. As the mouse passes over a manipulator, it turns red, and a tool tip pops up with the name of the current value of the parameter that is affected by that manipulator. To manipulate the value, you click down on the gizmo with the left mouse button and drag it. Most manipulators are designed so that the gizmo will track under the current mouse position, if possible.</p>\n\
<p>Note: &quot;Manipulate&quot; is <strong>not</strong> a separate mode - it <strong>modifies</strong> whatever mode you are currently in (select, move, create, etc.) to show manipulators and allow manipulation. If you are in move mode, for example, you can still move things around as usual. The only difference is that if you click down on a manipulator, you will manipulate, instead of move.</p>\n\
<p>There are two flavors of manipulators. The first are manipulators that are automatically created when you enter &quot;Manipulate&quot; mode. The hotspot manipulator is like that. The second kind is standalone objects, like the slider manipulator. These are usually used in conjunction with parameter wiring to get make them useful.</p>\n\
<p>To create a standalone manipulator, you go to the &quot;Helpers&quot; section of the create panel, and select &quot;Manipulators&quot; in the drop-down list.</p>\n\
<p>Standalone manipulators do not need to be selected in order to be manipulated. However, the automatically created manipulators, like the hotspot manipulator, are only displayed for selected objects.</p>\n\
<p>Manipulators support both 3d gizmos and 2d (screen space) gizmos. The hotspot manipulator is an example of a 3d gizmo, and the slider is an example of a 2d gizmo.</p>\n\
<div class=\'section\'><a id=\"scripted-manipulators-1\"></a><h2 id=\"scripted-manipulators-1\">Scripted Manipulators</h2></div>\n\
<p>Manipulators can be created either as standard MAX plug-ins in C++, or they can be implemented in MAXScript. In MAXScript, they are a type of <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/Scripted-Plug-ins-1.html\' title=\'\'>Scripted Plug-in object</a>, so if you want to write your own manipulator, it would be a good idea to read about <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/Scripted-Plug-ins-1.html\' title=\'\'>Scripted Plug-ins</a> first. They are very similar to scripted geometry objects.</p>\n\
<p>3 scripted manipulators that you can use as sample code can be found in the &quot;..\\stdplugs\\stdscripts&quot; folder.</p>\n\
<ul>\n\
<li><p>RadiusManip.ms -- Generic &quot;radius&quot; manipulator</p></li>\n\
<li><p>SliderManip.ms -- A 2d viewport slider. A standalone manipulator</p></li>\n\
<li><p>UVWManip.ms -- A set of manipulators for the UVW modifier</p></li>\n\
</ul>\n\
<div class=\'section\'><a id=\"radius-manipulator\"></a><h3 id=\"radius-manipulator\">Radius Manipulator</h3></div>\n\
<p>The radius manipulator is fairly simple, so it makes a good example to describe the scripted manipulator system.</p>\n\
<p>The code for the manipulator is included below, followed by a detailed description of how it works.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">```</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">-- Generic radius manipulator</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">-- Written by Scott Morrison</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">-- This manipulator sets the radius on any object or modifier with</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">-- a parameter named &quot;radius&quot;. It creates a circle gizmo of the appropriate</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">-- radius centered at the origin in the XY plane.</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">plugin simpleManipulator radiusManip</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">name:&quot;RadiusManip&quot;</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">invisible:true</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">(</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">-- Create the green and red colors for the gizmo</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">local g = [0, 1, 0], r = [1, 0, 0]</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">-- This manipulator manipulates any node with a &quot;radius&quot; property</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">on canManipulate target return (findItem (getPropNames target) #radius) != 0</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">-- Create the manipulator gizmo.</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">-- This is called initially and whenever the manipulator target changes</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">on updateGizmos do</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">(</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">-- Clear the current gizmo cache</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">this.clearGizmos()</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">-- Set the radius of circle gizmo a little bigger than the target radius</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">giz = manip.makeCircle [0,0,0] (target.radius * 1.01) 28</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">-- Add the circle to the manipulator</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">this.addGizmoShape giz 0 g r</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">-- return the ToolTip string</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">return node.name + &quot; radius = &quot; + target.radius as string</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">)</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">-- mouseMove is called on every mouse move when dragging the manip</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">-- It needs to convert the mouse position &#39;m&#39; into a new value for the radius</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">on mouseMove m which do</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">(</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">-- Create the XY plane.</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">-- manip.makePlaneFromNormal takes a normal vector and a point</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">-- and creates a plane passing through the point with the given normal</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">local pl = manip.makePlaneFromNormal z_axis [0, 0, 0],</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">projectedPoint = [0,0,0]</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">-- Compute the hit-ray in local coordinates</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">viewRay = this.getLocalViewRay m</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">-- Intersect the plane with the view ray</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">res = pl.intersect viewRay &amp;projectedPoint</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">-- If the intersection worked, set the radius</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">if (res) then target.radius = (length projectedPoint) / 1.01</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">)</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">)</td>\n\
</tr>\n\
</table>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>The header:</strong></p>\n\
<blockquote>\n\
<p>``` plugin simpleManipulator radiusManip name:&quot;RadiusManip&quot; invisible:true</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Indicates to MAXScript that this is a scripted manipulator plug-in called &quot;RadiusManip&quot;. The &quot;invisible:true&quot; tells the system not to make a creation button for the manipulator in the create panel.</p>\n\
<p><strong>The body:</strong></p>\n\
<p>A set of handlers for various events.</p>\n\
<blockquote>\n\
<p><span class=\'code\'>on canManipulate target return (findItem (getPropNames target) #radius) != 0</span></p>\n\
</blockquote>\n\
<p>&quot; <span class=\'code\'>canManipulate</span> &quot; is called on every manipulator, for every node that is selected when the &quot;Manipulate&quot; button is pressed. The &quot; <span class=\'code\'>target</span> &quot; parameter is the object that we might potentially manipulate. It is called on the base object, all the modifiers on the object, and transform controllers on the object&#39;s node. Also, if the transform controller is a PRS controller, it calls &quot; <span class=\'code\'>canManipulate</span> &quot; on the position, rotation and scale controllers.</p>\n\
<p>In the case of the radius manipulator, it can manipulate any object that has a property named &quot; <span class=\'code\'>radius</span> &quot;.</p>\n\
<p>If you want to create a manipulator that works on a specific object type, say a sphere, you can say:</p>\n\
<blockquote>\n\
<p><span class=\'code\'>on canManipulate target return classOf target == sphere</span></p>\n\
</blockquote>\n\
<p>There is an alternative handler that may be needed in some cases called &quot; <span class=\'code\'>canManipulateNode n</span> &quot;. This is called passing in the each selected node to the handler. This is not normally needed, but available if your manipulator wants to manipulate property of a node other than the ones that are passed as the &quot; <span class=\'code\'>target</span> &quot; to &quot; <span class=\'code\'>canManipulate</span> &quot;.</p>\n\
<p>Note:</p>\n\
<p>While a Scripted Manipulator Plug-in could implement both handlers at the same time, the resulting behavior could confuse the user. It is a good idea to implement only the one handler that suits your needs.</p>\n\
<p>The next handler is called &quot; <span class=\'code\'>updateGizmos</span> &quot;, and this is called whenever a manipulator need to build its gizmos. This happens when the manipulator is created, and whenever the target that it is manipulating changes.</p>\n\
<p>When MAXScript creates a manipulator, it sets up some variables that are available inside the calls to its handlers. One of these is called &quot; <span class=\'code\'>target</span> &quot; and it is the object, modifier or controller that is being manipulated. Another is called &quot; <span class=\'code\'>this</span> &quot; and it is the manipulator itself. It also sets up some constant values that can be used as flags on gizmos. These will be described later. There is also a &quot; <span class=\'code\'>node</span> &quot; value available which is the node that owns the target.</p>\n\
<p>The first thing every manipulator must to in the &quot; <span class=\'code\'>updateGizmos</span> &quot; handler is call &quot; <span class=\'code\'>this.clearGizmos()</span> &quot;. This clears any currently cached gizmos.</p>\n\
<p>Next it creates a set of gizmos that will be displayed in the viewport. In the case of the radius manipulator, it creates a single circle that represents the radius being manipulated.</p>\n\
<blockquote>\n\
<p><span class=\'code\'>giz =manip.makeCircle [0,0,0] (target.radius * 1.01) 28</span></p>\n\
</blockquote>\n\
<p>&quot; <span class=\'code\'>manip</span> &quot; is a exported set of utility interface functions that manipulators can use. See the &quot;<strong>Reference</strong>&quot; section below for full details. In this case we are creating a circle, centered at the origin, with radius 1.01 times the radius we are manipulating, and 28 segments. The &quot;1.01&quot; factor was added so that the gizmo will stick out a little bit from the object it is manipulating. If we used the radius directly, then it might not be visible in the viewport, because it co-exists with the object it is manipulating.</p>\n\
<p>Note that 3d gizmos are defined in the local coordinate system of the node that owns the manipulator target. The system will automatically compensate if the node is moved, rotated or scaled when displaying or hit-testing the manipulator.</p>\n\
<p>Next, we add the gizmo to the manipulator:</p>\n\
<blockquote>\n\
<p><span class=\'code\'>this.addGizmoShapegiz 0 g r</span></p>\n\
</blockquote>\n\
<p>This tells the manipulator to add the shape gizmo to the manipulator, with no special flags values ie. the &quot;0&quot;. All of the flags will be described below. Additionally, the command indicates to use green (&quot;g&quot;) as the unselected color and red (&quot;r&quot;) as the selected color. The selected color is used when the mouse passes over it, and the unselected color is used when the mouse isn&#39;t over it.</p>\n\
<p>Finally, this method returns a string value that will be used as the tool tip when the mouse passes over the gizmo.</p>\n\
<p>In general, gizmos can be made from meshes, shapes (wire frame), text and markers. The details are covered in the reference section below.</p>\n\
<p>The next handler is called &quot; <span class=\'code\'>mouseMove m which</span> &quot;. This is called on every mouse movement when the target is being manipulated. The &quot; <span class=\'code\'>m</span> &quot; parameter holds the screen coordinates of the mouse location, and the &quot; <span class=\'code\'>which</span> &quot; parameter is an index that indicates which gizmo is being dragged. The gizmos are numbered in the order of their creation in &quot; <span class=\'code\'>updateGizmos</span> &quot;, starting at 0.</p>\n\
<p>The <span class=\'code\'>mouseMove</span> handler is usually the trickiest part of the manipulator to implement. It needs to update the value of the parameter being manipulated in such a way that the manipulator gizmo tracks under the mouse, if possible.</p>\n\
<p>For manipulators that exist in 3d space, this is normally done by computing a &quot; <span class=\'code\'>hit-ray</span> &quot;, which is a ray in 3d space that passes through the mouse position, and travels in the direction of the view.</p>\n\
<p>This is computed as follows:</p>\n\
<blockquote>\n\
<p><span class=\'code\'>viewRay = this.getLocalViewRaym</span></p>\n\
</blockquote>\n\
<p>This view ray is then intersected with some plane, and the new parameter value is computed using the intersection point.</p>\n\
<p>In the case of the radius manipulator, the plane we use is the XY plane, because the radius circle lies on the XY plane, in local coordinate space.</p>\n\
<p>This plane is computed as follows:</p>\n\
<blockquote>\n\
<p><span class=\'code\'>local pl = manip.makePlaneFromNormalz_axis [0, 0, 0],</span></p>\n\
</blockquote>\n\
<p>This create &quot;pl&quot; which is a plane whose normal is the Z axis, and which passes through the origin ([0,0,0]).</p>\n\
<p>To intersect this with the view ray, we use the &quot;intersect&quot; operation on planes:</p>\n\
<blockquote>\n\
<p><span class=\'code\'>projectedPoint= [0,0,0]   res =pl.intersect viewRay &amp;projectedPoint</span></p>\n\
</blockquote>\n\
<p>We set up &quot; <span class=\'code\'>projectedPoint</span> &quot; first at the holder of the result of the intersection. The return value &quot; <span class=\'code\'>res</span> &quot; is a boolean value that tells us if the intersection worked or not. If it returns true, the intersection worked, if it returns false, it failed. It can fail if the plane is parallel to the view ray.</p>\n\
<p>Once we have the intersection point, in &quot; <span class=\'code\'>projectedPoint</span> &quot;, then we use that to determine a new value for the radius. In this case we use the distance from the origin (&quot; <span class=\'code\'>length projectedPoint</span> &quot;) as the new radius. We scale it by dividing by 1.01 to compensate for the fact that we made the gizmo 1.01 time bigger than the actual radius being manipulated.</p>\n\
<p>That&#39;s it! Generally, you will need to use some trigonometry and linear algebra in your &quot;mouseMove&quot; handler. The idea behind direct manipulation is that the gizmo should track directly under the mouse.</p>\n\
<p>For a more complicated example of a 3d manipulator, check the code in <span class=\'code\'>UVWManip.ms</span> .</p>\n\
<div class=\'section\'><a id=\"standalone-manipulators\"></a><h2 id=\"standalone-manipulators\">Standalone Manipulators</h2></div>\n\
<p>Standalone manipulators, like the 2d slider, require a bit more work.</p>\n\
<p>The code in SliderManip.ms will be used for this discussion.</p>\n\
<p>The header has a bit more information:</p>\n\
<blockquote>\n\
<p>``` plugins simpleManipulator sliderManipulator name:&quot;Slider&quot; classID:#(0x47db14ef, 0x4e9b5990) category:&quot;Manipulators&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Since standalone manipulators can be saved in the MAX file, it needs a <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/The-Super-Class-ID-and-the-Class.html\' title=\'\'>class ID</a>. See the MAXScript reference for more information about that. It also does not include the &quot; <span class=\'code\'>invisible:true</span> &quot; line, which means that the system will create a button for it in the &quot; <span class=\'code\'>Create</span> &quot; panel. It will be placed in the &quot; <span class=\'code\'>Manipulators</span> &quot; section of the helper create panel.</p>\n\
<p>We also need to define a parameter block and rollout UI for the object. This is done in the same way as other scripted plug-ins.</p>\n\
<p>Standalone manipulators manipulate themselves, so the &quot; <span class=\'code\'>canManipulate</span> &quot; handler looks like this:</p>\n\
<blockquote>\n\
<p><span class=\'code\'>on canManipulate target return (classOf target) == sliderManipulator</span></p>\n\
</blockquote>\n\
<p>We also need to provide a creation tool that handles mouse interaction when creating the manipulator. This is handle exactly like other scripted plug-ins.</p>\n\
<p>A standalone manipulator also needs some special code in its &quot; <span class=\'code\'>updateGizmos</span> &quot; handler. For the slider this looks like:</p>\n\
<blockquote>\n\
<p>``` -- If this is not a standalone manip, get values from the manip target if (target != undefined) then ( this.value = target.value this.minVal = target.minVal this.maxVal = target.maxVal this.xPos = target.xPos this.yPos = target.yPos this.width = target.width this.hide = target.hide this.sldName = target.sldName this.snapToggle = target.snapToggle this.snapVal = target.snapVal unselColor = greenColor ) else ( unselColor = yellowColor )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The test of &quot; <span class=\'code\'>target != undefined</span> &quot; is to see if this if this is a manipulator, or standalone object. When the object is standalone, the value of &quot; <span class=\'code\'>target</span> &quot; is undefined, and it uses the value of the parameters from its own parameter block. It target is defined, then this means it is manipulating. In that case, we want to copy the values of the parameters from the target that we are manipulating.</p>\n\
<div class=\'section\'><a id=\"reference\"></a><h2 id=\"reference\">Reference</h2></div>\n\
<p>Scripted manipulators can have the following handlers:</p>\n\
<div class=\'codeBlock\'><pre>on canManipulate target\n\
</pre></div><p>This returns a value that says whether this manipulator manipulate the given target.</p>\n\
<div class=\'codeBlock\'><pre>on canManipulateNode n\n\
</pre></div><p>This returns a value that says whether this manipulator manipulate the given node.</p>\n\
<p>Note:</p>\n\
<p>A manipulator should only implement one of these handlers.</p>\n\
<div class=\'codeBlock\'><pre>on updateGizmos\n\
</pre></div><p>This is called whenever the manipulator needs to build its gizmos. It returns a string value that is used for the tool tip. If it returns an empty string, no tool tip is displayed.</p>\n\
<div class=\'codeBlock\'><pre>on mouseMove m which\n\
</pre></div><p>This is called when the user has grabbed a gizmo and is dragging it.</p>\n\
<p>The &quot; <span class=\'code\'>m</span> &quot; parameter hold the current screen coordinates of the mouse, and the &quot;which&quot; parameter indicates the 0-based index of the gizmo that is being dragged. This is what handles that actual manipulation.</p>\n\
<p>Note:</p>\n\
<p>Normally this will set a value of a parameter of the manipulation target based on the mouse location.</p>\n\
<div class=\'codeBlock\'><pre>on mouseDown m which\n\
</pre></div><p>Called when the user first clicks the mouse down on the gizmo.</p>\n\
<div class=\'codeBlock\'><pre>on mouseUp m which\n\
</pre></div><p>Called when the user releases the mouse after manipulation is done.</p>\n\
<div class=\'section\'><a id=\"helper-functions\"></a><h3 id=\"helper-functions\">Helper Functions</h3></div>\n\
<p>There are some built-in functions that manipulators support, and a couple of helper packages with utility functions.</p>\n\
<p>The simpleManipulator type itself has these functions available:</p>\n\
<div class=\'codeBlock\'><pre>this.clearGizmos()\n\
</pre></div><p>This must be called at the beginning of the &quot;updateGizmos&quot; handler in order to clear the current gizmo cache.</p>\n\
<div class=\'codeBlock\'><pre>this.addGizmoMesh mesh flags unselColor selColor\n\
</pre></div><p>This creates a gizmo from a mesh (or geometry in MAX lingo). The mesh can be any arbitrary MAX mesh, and created with the tools in MAXScript for creating meshes. One convenient way to do this is to create an instance of a primitive and get the mesh from it.</p>\n\
<p>The flags can be 0, or one or more of these value. If you want more than one flag to apply, then you add the values together.</p>\n\
<p>Here are all the flags, and whether that can be used with addGizmoText, addGizmoMarker, addGizmoShape and addGizmoMesh:</p>\n\
<div class=\'codeBlock\'><pre>gizmoDontDisplay\n\
</pre></div><p>Tells the system to not display the gizmo. It will be hit-tested, but not displayed, applies to all.</p>\n\
<div class=\'codeBlock\'><pre>gizmoDontHitTest\n\
</pre></div><p>Tells the system to not hit-test the gizmo. It will be displayed, but not hit-tested, applies to all.</p>\n\
<div class=\'codeBlock\'><pre>gizmoActiveViewportOnly\n\
</pre></div><p>Tells the system to only display and hit-test this gizmo in the active viewport, applies to all.</p>\n\
<div class=\'codeBlock\'><pre>this.addGizmoShapegizmo Shape flags unselColor selColor\n\
</pre></div><p>This creates a gizmo from a shape object. The gizmoShape can be created using functions from the &quot;manip&quot; package, described below.</p>\n\
<p>The flags can take on the same value as for &quot;addGizmoMesh&quot;, with two new values supported:</p>\n\
<div class=\'codeBlock\'><pre>gizmoUseScreenSpace\n\
</pre></div><p>This tells the system to interpret the coordinates of the shape as device coordinates in the viewport, not as 3d values. The values are still specified as 3d points, but the &quot;Z&quot; coordinate is ignored, applies to all but addGizmoMesh.</p>\n\
<div class=\'codeBlock\'><pre>gizmoUseRelativeScreenSpace\n\
</pre></div><p>This is like gizmoUseScreenSpace, but the coordinates are specified as values from 0.0 to 1.0, and interpreted in each viewport as a percentage of the width or height of the viewport, applies to all but addGizmoMesh.</p>\n\
<div class=\'codeBlock\'><pre>addGizmoMarker markerType position flags unselColor selColor\n\
</pre></div><p>The creates a gizmo using a marker. The value of the &quot;markerType&quot; parameter can be:</p>\n\
<div class=\'codeBlock\'><pre>#point #hollowBox #plusSign #asterisk #xMarker #bigBox #circle #triangle #diamond #smallHollowBox #smallCircle #smallTriangle #smallDiamond #dot #smallDot\n\
</pre></div><p>The position is a point in 3d space, or 2d screen space. The flags are the same ones supported by addGizmoShape.</p>\n\
<div class=\'codeBlock\'><pre>addGizmoText text position flags unselColor selColor\n\
</pre></div><p>This creates a gizmo that is text on the screen. Note that text cannot be hit-tested or grabbed by the mouse. It is used for display purposes only.</p>\n\
<div class=\'codeBlock\'><pre>getLocalViewRay m\n\
</pre></div><p>This function takes a mouse position and returns the ray that passes through that mouse position in the direction of the view. It is returned in the local coordinates of the node that owns the manipulator target.</p>\n\
<div class=\'section\'><a id=\"the-manip-package\"></a><h2 id=\"the-manip-package\">The &quot;manip&quot; package</h2></div>\n\
<p>&quot;manip&quot; is a value in MAXScript that contains a set of useful interface functions for manipulators. The functions it exports are:</p>\n\
<div class=\'codeBlock\'><pre>manip.makeSphere position radius segments\n\
</pre></div><p>This returns a mesh sphere with the given position, radius, and segments.</p>\n\
<div class=\'codeBlock\'><pre>manip.makeTorus position radius1 radius2 segments sides\n\
</pre></div><p>Create a torus mesh with the given values.</p>\n\
<div class=\'codeBlock\'><pre>manip.makeBox position length width height lengthSegs widthSegs heightSegs\n\
</pre></div><p>Creates a box mesh with the given parameters.</p>\n\
<div class=\'codeBlock\'><pre>manip.makePlaneFromNormal normal point\n\
</pre></div><p>Creates a Plane object with the given normal that passes through the given point.</p>\n\
<div class=\'codeBlock\'><pre>manip.makeCircle center radius segments\n\
</pre></div><p>Creates a circle shape in the XY plane with the given parameters.</p>\n\
<div class=\'codeBlock\'><pre>manip.makeGizmoShape()\n\
</pre></div><p>Creates an empty gizmo shape. See the details of &quot;GizmoShape&quot; below for how to use this.</p>\n\
<div class=\'section\'><a id=\"plane-objects\"></a><h3 id=\"plane-objects\">Plane objects</h3></div>\n\
<p>The plane objects returned from &quot;manip.makePlaneFromNormal&quot; have the following functions available:</p>\n\
<div class=\'codeBlock\'><pre>intersectionPoint= [0,0,0]\n\
plane.intersect ray &amp;intersectionPoint\n\
</pre></div><p>This intersects the given ray with the plane. It returns true, if it succeeds, and false if it doesn&#39;t If it works, then the intersection point is set in the &quot;intersectionPoint&quot; value, which must be initialized to a Point3 value in advance.</p>\n\
<div class=\'codeBlock\'><pre>plane.mostOrthogonal ray otherPlane\n\
</pre></div><p>This returns the plane that is most orthogonal to the given ray. This means the plane that is most &quot;square&quot; to the view direction.</p>\n\
<p>Sometimes a manipulator might choose between two different planes on which to project a ray. It is usually best to project it to the plane which faces the view ray most directly, and this function determines that. See &quot;UVWManip.ms&quot; for an example of how to use this.</p>\n\
<div class=\'codeBlock\'><pre>plane.getNormal()\n\
</pre></div><p>Returns the normal of a plane.</p>\n\
<div class=\'codeBlock\'><pre>plane.getPoint()\n\
</pre></div><p>Return the point that the plane passes through.</p>\n\
<div class=\'codeBlock\'><pre>plane.getPlaneConstant()\n\
</pre></div><p>Return the value of the plane constant. This is the value of &quot;D&quot; in the equation that defines the plane:</p>\n\
<p><span class=\'code\'>Ax + By +Cz + D = 0</span></p>\n\
<div class=\'section\'><a id=\"gizmoshape-objects\"></a><h3 id=\"gizmoshape-objects\">GizmoShape objects</h3></div>\n\
<p>A GizmoShape is a shape object that you can use to construct wire-frame gizmos. You can get an empty GizmoShape as follows:</p>\n\
<div class=\'codeBlock\'><pre>local giz = manip.makeGizmoShape()\n\
</pre></div><p>The functions available are:</p>\n\
<div class=\'codeBlock\'><pre>giz.addPoint point\n\
</pre></div><p>This adds a new point to the shape. The points are connected by line segments in order to create the wireframe. If you want a closed shape, you have to add the first point again as the last point.</p>\n\
<div class=\'codeBlock\'><pre>giz.startNewLine()\n\
</pre></div><p>This begins a new line segment in the shape.</p>\n\
<div class=\'codeBlock\'><pre>giz.transform matrix\n\
</pre></div><p>This transforms the gizmo by the given Matrix3 transform.</p>\n\
<p>Note: See <span class=\'code\'>UVWManip.ms</span> for an example of creating 3D gizmos with GizmoShape.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";