var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Scripted Plug-in Clauses</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Scripted Plug-in Clauses</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"scripted-plug-in-clauses\"></a></div>\n\
<p>The various optional clauses inside the plug-in body are similar to those for scripted utilities and tools.</p>\n\
<p>There is an additional scripted plug-in specific clause <span class=\'code\'>&lt;parameters&gt;</span> for defining scene-savable and Track View visible parameters for the plug-in.</p>\n\
<p>The <span class=\'code\'>&lt;plugin_body&gt;</span> of a scripted plug-in definition is made up of a sequence of plug-in clauses as follows:</p>\n\
<div class=\'codeBlock\'><pre>&lt;plugin_body&gt; ::= { &lt;plugin_clause&gt; }+\n\
</pre></div><p>Plug-in clauses define the components of a scripted plug-in and can be one of these five basic things:</p>\n\
<ul>\n\
<li><p><strong>Local variables, functions, or structure definitions</strong> - They are variables, functions, and structures whose scope is the plug-in. These locals will exist as long as the instance of the plug-in exists. The visibility of locals and accessing scripted plug-in locals from external code are described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Visibility-of-Locals-Functions.html\' title=\'\'>Visibility of Locals, Functions, Structures, and User-Interface Items in Rollout Code</a> and <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Accessing-Locals-and-Other-Items.html\' title=\'\'>Accessing Locals and Other Items in a Rollout from External Code</a>.</p></li>\n\
<li><p><strong>Parameter blocks</strong> - They define a set of parameters for the plug-in, which are like plug-in local variables, but are directly animatable and are saved to and restored from scene files. You can also associate each parameter with appropriate user-interface elements in one of the plug-ins rollouts. When associated in this way, the parameters are &quot;wired&quot; to their spinners, checkboxes, and others. Both update automatically as the other changes, so you do not have to write any user-interface event handlers for them. These parameters correspond to the visible parameters you see in other <strong>3ds Max</strong> plug-ins.</p></li>\n\
<li><p><strong>Mouse tools</strong> - They are used to perform a set of actions based on mouse clicks in the <strong>3ds Max</strong> viewports and are described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Mouse-Tools.html\' title=\'\'>Scripted Mouse Tools</a>.</p></li>\n\
<li><p><strong>Rollouts</strong> - They can be displayed for the scripted plug-in. For scripted plug-ins that extend an existing plug-in, these rollouts can be displayed in addition to or replace the existing plug-in’s rollouts. Rollout definitions are described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Utility-Clauses.html\' title=\'\'>Utility Clauses</a>.</p></li>\n\
<li><p><strong>Event handlers</strong> - They are special kinds of functions associated with particular events. Event handlers specify the processing that must occur when a user creates an instance of the scripted plug-in or when <strong>3ds Max</strong> calls the scripted plug-in. These actions generate named events and the optional event handler you supply for that event is called when the action occurs.</p></li>\n\
</ul>\n\
<p>Formally, the syntax of a <span class=\'code\'>&lt;plugin_clause&gt;</span> is defined as follows:</p>\n\
<div class=\'codeBlock\'><pre>&lt;plugin_clause&gt; ::= &lt;local_variable_decl&gt; | \n\
&lt;local_function_decl&gt; | \n\
&lt;local_struct_decl&gt; | \n\
&lt;parameters&gt; | \n\
&lt;tools&gt; | \n\
&lt;rollouts&gt; | \n\
&lt;event_handler&gt;\n\
\n\
</pre></div><div class=\'section\'><a id=\"topic-navigation\"></a><h2 id=\"topic-navigation\">Topic Navigation</h2></div>\n\
<p>{{toc}}</p>\n\
<div class=\'section\'><a id=\"locals\"></a><h2 id=\"locals\">Locals</h2></div>\n\
<p>The <span class=\'code\'>&lt;local_variable_decl&gt;</span>, <span class=\'code\'>&lt;local_function_decl&gt;</span>, and <span class=\'code\'>&lt;local_struct_decl&gt;</span> are exactly the same as local variable, function, and structure definitions in MAXScript:</p>\n\
<div class=\'codeBlock\'><pre>&lt;local_variable_decl&gt; ::= local &lt;decl&gt; { , &lt;decl&gt; }\n\
&lt;decl&gt; ::= &lt;name&gt; [ = &lt;expr&gt; ] -- optional initial value\n\
&lt;local_function_decl&gt; ::= [ mapped ](function | fn) &lt;name&gt; { &lt;argument&gt; } = &lt;expr&gt;\n\
&lt;local_struct_decl&gt; ::= struct &lt;name&gt; ( &lt;member&gt; { , &lt;member&gt; } )\n\
&lt;member&gt; ::= ( &lt;name&gt; [ = &lt;expr&gt; ] | &lt;local_function_decl&gt; )\n\
</pre></div><p>Global variables cannot be declared as a plug-in clause. However, they can be declared within event handler scripts. If you need to ensure a variable name references a global variable, declare the variable name as global immediately before defining the plug-in in your script.</p>\n\
<p>When writing scripts, it is good programming practice to explicitly declare your local and global variables. Implicit declaration is provided as a short-hand, typically used when working in the Listener interactively or developing short scripts. When developing extended scripts, explicitly declaring variables can reduce errors and improve readability of the code. It is also recommended that you declare as local all variables unless you really want them to be global variables. The reasons for this are described in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Scope-of-Variables.html\' title=\'\'>Scope of Variables</a>.</p>\n\
<p>Plug-in locals are attached to plug-in objects and each new instance of the scripted plug-in has its own local storage area. When you reference a plug-in local in a plug-in function or handler, it accesses the local storage of the currently active object. For example, the object currently open in the command panel. Plug-in local storage is not permanent across scene saves and loads (unlike <span class=\'code\'>&lt;parameters&gt;</span> ). You can provide initial values for locals, as elsewhere in MAXScript, and the locals are re-initialized when a saved scripted plug-in object is loaded again as part of a scene file open. You can also do this by hand in a <span class=\'code\'>create</span> event handler if you supply one in the plug-in.</p>\n\
<p>Plug-in locals are accessible to script code outside a plug-in as a normal property on the object, but note that they might be hidden by parameters or other common object properties if they have the same name. When accessing a property on a scripted plug-in object, MAXScript first looks in the common properties (such as, <span class=\'code\'>.pos</span> , <span class=\'code\'>.scale</span> , <span class=\'code\'>.parent</span> , and others on a node), then in the parameters, and then in the locals for a property name match.</p>\n\
<div class=\'section\'><a id=\"there-are-four-local-variables-accessible-in-all-scripted-plug-ins\"></a><h2 id=\"there-are-four-local-variables-accessible-in-all-scripted-plug-ins\">There are four local variables accessible in all scripted plug-ins:</h2></div>\n\
<div class=\'codeBlock\'><pre>version\n\
</pre></div><p>Yields the current version of the object as an Integer value.</p>\n\
<div class=\'codeBlock\'><pre>this\n\
</pre></div><p>Yields the instance of the scripted plug-in.</p>\n\
<div class=\'codeBlock\'><pre>delegate\n\
</pre></div><p>Yields the instance of the plug-in you are extending in an <span class=\'code\'>extends:</span> plug-in.</p>\n\
<div class=\'codeBlock\'><pre>loading\n\
</pre></div><p>In <strong>3ds Max6 and higher,</strong> yields True while the plug-in instance is in the process of being loaded.</p>\n\
<p>The <span class=\'code\'>version</span> local variable contains the version number specified in the scripted plug-in definition. See <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/Updating-Scripted-Plug-ins.html\' title=\'\'>Updating Scripted Plug-ins</a> for more information on this variable.</p>\n\
<p>The <span class=\'code\'>this</span> local variable always contains the MAXScript value corresponding to the current instance of the scripted plug-in. This variable provides a guaranteed way of accessing parameters on the new object within plug-in code (in case there are locals or globals with the same name), and it is a way of referencing the plug-in in case you want to store it to a variable.</p>\n\
<p>The <span class=\'code\'>delegate</span> local variable contains the MAXScript value corresponding to the instance of the plug-in being extended. To access common properties or subAnim properties in the instance of the plug-in being extended, you need to do so using the <span class=\'code\'>delegate</span> local variable.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` delegate.width = thisWidth</p>\n\
<p>```</p>\n\
<p>inside a plug-in function or handler will set the <span class=\'code\'>.width</span> property in the instance of the plug-in being extended. The delegate local variable in a scripted plug-in that creates a scene object does not contain the node itself, but the BaseObject of that node. As such, you can not access the node level properties of the object being created. An exception to this is the node’s transform, which is exposed to the scripted plug-in through a local variable called <span class=\'code\'>nodeTM</span> . This variable is described in the applicable scripted plug-in type topics.</p>\n\
</blockquote>\n\
<p>If the <span class=\'code\'>extends:</span> parameter is not supplied for a plug-in, <span class=\'code\'>delegate</span> returns <span class=\'code\'>undefined</span> .</p>\n\
<p>As well as local variables, you can define local functions and local structures, just as you can with scripted utilities and rollouts.</p>\n\
<div class=\'section\'><a id=\"parameters\"></a><h2 id=\"parameters\">Parameters</h2></div>\n\
<p>You can define one or more parameter blocks in a scripted plug-in.</p>\n\
<p>A parameter block has the form:</p>\n\
<div class=\'codeBlock\'><pre>parameters &lt;name&gt; [type:#class] [rollout:&lt;name&gt;] ( \n\
{ &lt;param_defs&gt; }+ \n\
{ &lt;event_handler&gt; } \n\
) \n\
</pre></div><p>A parameter block defines a set of parameters for the plug-in, which are like plug-in local variables, but are directly animatable and are saved to and restored from scene files. You can also associate each parameter with appropriate user-interface elements in one of the plug-ins rollouts. When associated in this way, the parameters are &quot;wired&quot; to their spinners, checkboxes, and others. Both update automatically as the other changes, so you do not have to write any user-interface event handlers for them. These parameters correspond to the visible parameters you see in other <strong>3ds Max</strong> plug-ins. Parameters in the parameter block do not participate in <strong>3ds Max</strong>’s undo system, therefore changes to the parameter values are not undoable.</p>\n\
<p>The <span class=\'code\'>&lt;name&gt;</span> you give to a parameter block becomes permanently associated with the parameter block and is used by MAXScript to connect to the right parameter block in a plug-in object that is being loaded from a scene file. This becomes important as you modify a plug-in script and yet there are still objects corresponding to the old definition in other files. When the old-version object is loaded, MAXScript attempts to convert it to the new definition using the current parameter block definition as a guide. To properly do this, each parameter in a parameter block is also given a permanent name. So, if you have existing objects of your plug-in in other files, do not change the parameter block names randomly or they will not be loadable.</p>\n\
<p>The optional <span class=\'code\'>type:&lt;#class&gt;</span> specifies that the parameters in the parameter block are &quot;class&quot; parameters. This means that there is one copy of each parameter for *all* the objects of this plug-in class; they all share the parameter. Examples of existing class parameters are the creation type and type-in parameters in a typical geometry primitive.</p>\n\
<p>The optional <span class=\'code\'>rollout:&lt;name&gt;</span> specifies a rollout definition elsewhere in the plug-in body to use as the user-interface rollout for the parameter block&#39;s parameters. A limitation of the internal parameter block mechanism requires that each parameter block be associated with a separate rollout and each rollout be associated with only one parameter block. This means that each rollout you want to have in the plug-ins user interface must have its own separate parameter block.</p>\n\
<p>The <span class=\'code\'>&lt;param_defs&gt;</span> are definitions for each parameter in the parameter block.</p>\n\
<p>They have the form:</p>\n\
<div class=\'codeBlock\'><pre>&lt;name&gt; type:&lt;#name&gt; [localizedName:&lt;string&gt;] [nonLocalizedName:&lt;string&gt;] [tabSize:&lt;integer&gt;] \n\
[tabSizeVariable:&lt;boolean&gt;] [default:&lt;operand&gt;] [animatable:&lt;boolean&gt;] \n\
[subAnim:&lt;boolean&gt;] [ui:&lt;ui_def&gt;] [assettype:&lt;asset_type&gt;] \n\
[invisibleInTV:&lt;boolean&gt;] [showAllInTV:&lt;boolean&gt;]\n\
[readOnly:&lt;boolean&gt;] [readOnlyAsset:&lt;boolean&gt;] [enumAsAsset:&lt;boolean&gt;]\n\
[useNodeOsValidity:&lt;boolean&gt;] [useNodeTmValidity:&lt;boolean&gt;]\n\
</pre></div><p>The <span class=\'code\'>&lt;name&gt;</span> is permanently associated with the parameter in the same sense as parameter block names. They are used to connect to the right parameter when loading objects of the scripted plug-in and allow you to make certain changes to a script and still be able to load old version objects. So, as with parameter block names, do not change or re-use parameter names if you have scene files with old version objects you want to get at.</p>\n\
<p>The optional <span class=\'code\'>localizedName:&lt;string&gt;</span> specifies a localized string that is used when 3ds Max attempts to display the parameter&#39;s localized name. This localized name is shown in places such as <strong>TrackView</strong> when the parameter type is animatable, or holds a material or texturemap; in the <strong>Material Editor</strong> when displaying the UI for a subMaterial or subTexture; or in the <strong>Slate Material Editor</strong> when displaying slot names. This localized name is returned from the MAXScript <span class=\'code\'>getSubAnimName()</span>, <span class=\'code\'>getSubAnimNames()</span>, <span class=\'code\'>getSubMtlSlotName()</span> and <span class=\'code\'>getSubTexmapSlotName()</span> methods. When not specified, the parameter&#39;s <span class=\'code\'>name</span> property is displayed. <strong>Available in 3ds Max 2021 and higher.</strong></p>\n\
<p><img src=\'developer/images/GUID-21C87158-BBA7-4B63-B8F7-CB9BA17CA2CA-low.gif\' title=\'\'> <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/What-s-New-in-MAXScript-in-3ds.html\' title=\'\'>NEW</a> <strong>in 3ds Max 2022:</strong> The optional <span class=\'code\'>nonLocalizedName:&lt;string&gt;</span> specifies a nonlocalized (ENU) string that is used when an attempt is made to access the parameter in a script. This option should be specified if the parameter&#39;s name property is not the same as the <span class=\'code\'>localizedName</span> option when 3ds Max is running in the <strong>en-US</strong> locale. The nonlocalized name is returned from the MAXScript <span class=\'code\'>getSubAnimName()</span>, <span class=\'code\'>getSubAnimNames()</span>, <span class=\'code\'>getSubMtlSlotName()</span> and <span class=\'code\'>getSubTexmapSlotName()</span> methods when they are called with the localizedName/localizedNames options set to false. When not specified, the parameter&#39;s name property is returned instead.</p>\n\
<p>The <span class=\'code\'>type:&lt;#name&gt;</span> parameter is required and defines the parameter type. It can be one of the following:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#float</span></td>\n\
<td align=\"left\">animatable</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#integer</span></td>\n\
<td align=\"left\">animatable</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#index</span></td>\n\
<td align=\"left\">animatable</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#color</span></td>\n\
<td align=\"left\">animatable</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#rgb</span></td>\n\
<td align=\"left\">animatable, alias of <span class=\'code\'>#color</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#frgba</span></td>\n\
<td align=\"left\">animatable, available since 3ds Max 6</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#point3</span></td>\n\
<td align=\"left\">animatable</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#point4</span></td>\n\
<td align=\"left\">animatable, available since 3ds Max 6</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#boolean</span></td>\n\
<td align=\"left\">animatable</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#angle</span></td>\n\
<td align=\"left\">animatable</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#percent</span></td>\n\
<td align=\"left\">animatable</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#worldUnits</span></td>\n\
<td align=\"left\">animatable</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#matrix3</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#string</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#filename</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#colorChannel</span></td>\n\
<td align=\"left\">animatable</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#time</span></td>\n\
<td align=\"left\">animatable</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#radiobtnIndex</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#material</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#texturemap</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#bitmap</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#node</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#maxObject</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#paramBlock2</span></td>\n\
<td align=\"left\">available since 3ds Max 2018</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#point2</span></td>\n\
<td align=\"left\">available since 3ds Max 2018</td>\n\
</tr>\n\
</table>\n\
<p>or one of the following types which are arrays of the above base types:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#floatTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#intTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#indexTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#colorTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#rgbTab</span></td>\n\
<td align=\"left\">Alias of <span class=\'code\'>#colorTab</span></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#frgbaTab</span></td>\n\
<td align=\"left\">Available since 3ds Max 6</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#point3Tab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#point4Tab</span></td>\n\
<td align=\"left\">Available since 3ds Max 6</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#boolTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#angleTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#percentTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#worldUnitsTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#matrix3Tab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#stringTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#filenameTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#colorChannelTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#timeTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#radiobtnIndexTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#materialTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#texturemapTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#bitmapTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#nodeTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#maxObjectTab</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
</table>\n\
<p>In <strong>3ds Max 2010 and higher</strong>, when the parameter is of type <strong><span class=\'code\'>#filename</span></strong> , to handle the parameter as an asset you also need to specify <span class=\'code\'>assettype:&lt;asset_type&gt;</span> where argument is one of the following enums:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#Other</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#Bitmap</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#XRef</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#Photometric</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#Animation</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#VideoPost</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#BatchRender</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#ExternalLink</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#RenderOutput</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#PreRenderScript</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#PostRenderScript</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#Sound</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#Container</span></td>\n\
<td align=\"left\"></td>\n\
</tr>\n\
</table>\n\
<p>TYPE_INDEX, TYPE_INDEX_TAB, TYPE_MATRIX3, and TYPE_MATRIX3_TAB have been added as supported PB2 data types in MAXScript. TYPE_INDEX is used for parameters that are 0-based, but are exposed in MAXScript as 1-based, for example, a vertex index.</p>\n\
<p>The above data types are also available in scripted parameter blocks with types of <span class=\'code\'>#index</span> , <span class=\'code\'>#indexTab</span> , <span class=\'code\'>#matrix3</span> , and <span class=\'code\'>#matrix3Tab</span> respectively.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` height1 type:#index animatable:true default:1 ui:height1 height3 type:#indexTab tabSizeVariable:true m3a type:#matrix3 default:(matrix3 [1,0,0] [0,0,1] [0,-1,0] [53.1187,-6.50834e-007,14.8893]) m3b type:#matrix3tab tabSizeVariable:true</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><span class=\'code\'>type:#index</span> is animatable, and <span class=\'code\'>#matrix3</span> is not.</p>\n\
<p><span class=\'code\'>type:#index</span> must behave in the same manner as <span class=\'code\'>type:#int</span> , except the data value stored is 0-based, but is seen by MAXScript as 1-based. So, if you had an object using an animated height1 property (as defined above),</p>\n\
<blockquote>\n\
<p><strong>YOU WILL SEE SOMETHING LIKE</strong></p>\n\
<p>``` $.height1 15 $.height1.controller.value 14.0</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The <span class=\'code\'>type:#integer</span> parameters can be associated with dropDownList, ComboBox, and ListBox user interface controls using the UI: option in the parameter definition. The value in the parameter corresponds to the 1-based index of the currently selected item in the user interface control.</p>\n\
<p>ListBox user interface controls were not supported for integer parameter association in releases prior to <strong>3ds Max 7</strong>.</p>\n\
<p>Typically, you would populate this list with names or strings, and the value in the associate parameter effectively becomes a code number for these names or strings. Setting the value of the parameter using a script will automatically cause the corresponding item in the dropDownList to be selected if the UI for that object is currently open.</p>\n\
<p><span class=\'code\'>#worldUnits</span> and <span class=\'code\'>#worldUnitsTab</span> specify that a parameter holds a world distance value that is kept internally as a system units float.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` parameters main rollout:params ( height type:#worldUnits ui:heightSpin )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note that this does not cause any spinner display to be automatically shown in current display units. You also need to specify <span class=\'code\'>type:#worldUnits</span> on the associated rollout spinner definition.</p>\n\
<p><span class=\'code\'>#node</span> and <span class=\'code\'>#nodeTab</span> are used to store references to nodes. The nodes stored in these parameters cannot create a circular dependency. For example, if you were creating a scripted helper, and set the helper as a target or parent of a camera, you cannot store the camera node in a <span class=\'code\'>#node</span> or <span class=\'code\'>#nodeTab</span> parameter. Likewise, if you created a scripted modifier or material, and store a node in a <span class=\'code\'>#node</span> or <span class=\'code\'>#nodeTab</span> parameter, you cannot apply the modifier or material to that node.</p>\n\
<p><span class=\'code\'>#node</span> and <span class=\'code\'>#nodeTab</span> can take these flags, which affect whether the plugin is re-evaluated if the node is animated:</p>\n\
<ul>\n\
<li><span class=\'code\'>useNodeTmValidity</span> - set to true to cause the scripted plugin to take into account the node&#39;s transform validity.</li>\n\
<li><span class=\'code\'>useNodeOsValidity</span> - set to true to cause the scripted plugin to take into account the node&#39;s object space / geometry pipeline validity.</li>\n\
</ul>\n\
<p>The various <span class=\'code\'>xxTab</span> parameter types allow you to store an array of values having the corresponding type. The initial size of the array is specified using the <span class=\'code\'>tabSize:</span> specifier. If <span class=\'code\'>tabSizeVariable:true</span> is specified, the size of the array will be automatically expanded when you assign to an higher array index.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` parameters main rollout:params ( mapAmounts type:#floatTab tabSize:4 tabSizeVariable:true ui:(map1Amount, map2Amount, map3Amount, map4Amount) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>defines an array parameter containing four float elements (defined by the <span class=\'code\'>tabSize:</span> parameter).</p>\n\
<blockquote>\n\
<p>Warning: The number of UI items must match the tabSize. If the user increases the tab size using a script, new UI elements are not created for the new items. If the user decreases the number to less than the UI element count, this will lead to a crash.</p>\n\
</blockquote>\n\
<p>You can associate a separate rollout element with each array parameter element. These parameters appear as arrays when accessed in the plug-in handler code.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` a = mapAmounts[i]</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Because <span class=\'code\'>tabSizeVariable:true</span> was specified, the following will automatically increase the array size to 10:</p>\n\
<div class=\'codeBlock\'><pre>mapAmounts[10] = a\n\
\n\
</pre></div><p>You can also increase or decrease the array size by assigning a value to the <span class=\'code\'>.count</span> property.</p>\n\
<p>Each element in an array parameter whose base type is a number of some kind ( <span class=\'code\'>floatTab</span> , <span class=\'code\'>intTab</span> , <span class=\'code\'>percentTab</span> , and so on) is independently and automatically animatable unless you specify <span class=\'code\'>animatable:false</span> . You can get at and assign individual controllers using the <span class=\'code\'>.controller</span> property.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` c = mapAmounts[i].controller</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The optional parameter <span class=\'code\'>default:&lt;operand&gt;</span> specifies an initial default value for the parameter. The <span class=\'code\'>&lt;operand&gt;</span> expression has to be convertible by MAXScript to the base type of the parameter.</p>\n\
<p>The optional parameter <span class=\'code\'>animatable:&lt;boolean&gt;</span> specifies whether the parameter is animatable and hence visible in the track view. Only those base types marked as animatable in the above type list can be specified as animatable. Defaults to <span class=\'code\'>true</span> .</p>\n\
<p>The optional parameter <span class=\'code\'>subAnim:&lt;boolean&gt;</span> can be specified for the <strong>3ds Max</strong> object types: <span class=\'code\'>#node</span> , <span class=\'code\'>#material</span> , <span class=\'code\'>#textureMap</span> , and <span class=\'code\'>#maxObject</span> . If specified as <span class=\'code\'>true</span> , the <strong>3ds Max</strong> object is made visible as a sub-object track in track view. Defaults to <span class=\'code\'>false</span> .</p>\n\
<p>The optional parameter <span class=\'code\'>ui:&lt;ui_def&gt;</span> is used to specify which user-interface element in the parameter block&#39;s associated rollout is to be linked to this parameter. When linked, the handling of user actions for these elements are automatic and they also update automatically to follow any changes to the parameter caused by animation, scripts, and others. For example, in the following, the parameter block named <span class=\'code\'>main</span> is associated with the rollout named <span class=\'code\'>params</span> . The parameters <span class=\'code\'>height</span> and <span class=\'code\'>spread</span> are then linked with the spinners named <span class=\'code\'>height</span> and <span class=\'code\'>spread</span> in that rollout:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` parameters main rollout:params ( key type:#node subAnim:true fill type:#node subAnim:true back type:#node subAnim:true height type:#float animatable:true default:10 ui:height spread type:#float animatable:true default:10 ui:spread on height set val do ( key.pos.z = val back.pos.z = val * 1.5 fill.pos.z = val * 0.5 ) ) rollout params &quot;Light Parameters&quot; ( spinner height &quot;Height&quot; spinner spread &quot;Spread&quot; )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>After this is done, the parameter and spinner are linked and changes in one are reflected immediately and automatically in the other. Further, if the parameter is animated, the spinner will show red keyframe highlights when the time slider is positioned at a keyframe for that parameter as with other <strong>3ds Max</strong> plug-ins. The kinds of user-interface items that can be linked to particular parameter types is limited to the following sensible combinations:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">Parameter type</th>\n\
<th align=\"left\">Rollout user-interface item</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#integer</span></td>\n\
<td align=\"left\">spinner, slider, radioButtons, checkbox, checkbutton</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#float</span></td>\n\
<td align=\"left\">spinner, slider</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#time</span></td>\n\
<td align=\"left\">spinner, slider</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#color</span></td>\n\
<td align=\"left\">colorpicker</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#angle</span></td>\n\
<td align=\"left\">spinner, slider</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#percent</span></td>\n\
<td align=\"left\">spinner, slider</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#colorChannel</span></td>\n\
<td align=\"left\">spinner, slider</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#boolean</span></td>\n\
<td align=\"left\">checkbox, checkbutton</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#node</span></td>\n\
<td align=\"left\">pickButton</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#textureMap</span></td>\n\
<td align=\"left\">mapButton</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"><span class=\'code\'>#material</span></td>\n\
<td align=\"left\">materialButton</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"><span class=\'code\'>#worldUnits</span></td>\n\
<td align=\"left\">spinner, slider</td>\n\
</tr>\n\
</table>\n\
<p>The optional parameter <span class=\'code\'>invisibleInTV:&lt;boolean&gt;</span> if set to <strong>true</strong> hides the parameter in TrackView. This only applies to parameters that are subAnim or animatable normally shown in TrackView. The default is <strong>false</strong>.</p>\n\
<p>The optional parameter <span class=\'code\'>showAllInTV:&lt;boolean&gt;</span> if set to <strong>true</strong>, and the parameter is subAnim or animatable normally shown in TrackView, and the parameter is also a Tab type parameter, then all of the tab elements are shown in TrackView. The default is <strong>false</strong>.</p>\n\
<p>The optional parameter <span class=\'code\'>readOnly:&lt;boolean&gt;</span> if set to true, means the parameter&#39;s value cannot be set using MAXScript, it can only be changed in the user interface. Similarly, the optional <span class=\'code\'>readOnlyAsset:&lt;boolean&gt;</span> parameter applies to asset type parameters, and when true, the parameter&#39;s value cannot be set using the Asset Tracker or MAXScript. It can only be changed using the user interface.</p>\n\
<p>The optional parameter <span class=\'code\'>enumAsAsset:&lt;boolean&gt;</span> if set to true for asset type parameters, specifies that the asset held by the parameter is reported when performing scene asset enumeration.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` t=teapot() bitmap_holder = attributes &quot;bitmap_holder&quot; ( parameters main ( thebitmap type:#filename assetType:#bitmap enumAsAsset:true ) ) custattributes.add t.baseobject bitmap_holder t.baseobject.thebitmap = &quot;fir1.tga&quot;</p>\n\
<p>function get_names name a = append a name files = #() enumerateFiles t.baseobject get_names files enumerateFiles t.baseobject get_names files #missing files</p>\n\
<p>--&gt; #(&quot;fir1.tga&quot;)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"parameter-event-handlers\"></a><h2 id=\"parameter-event-handlers\">Parameter Event Handlers</h2></div>\n\
<p>The following event handlers are associated with parameters. These handlers are called when a parameter is assigned a value, or when the parameter value is retrieved.</p>\n\
<p>Note: <strong>preSet</strong> replaces <strong>set</strong> in most situations; see below.</p>\n\
<div class=\'codeBlock\'><pre>on &lt;name&gt; set &lt;arg&gt; do &lt;expr&gt;\n\
on &lt;name&gt; preSet &lt;arg1&gt; do &lt;expr&gt;\n\
on &lt;name&gt; postSet &lt;arg1&gt; do &lt;expr&gt;\n\
</pre></div><p>A <span class=\'code\'>set</span> handler can be supplied for any of the parameters in the block and it will be called whenever the parameter is updated, either through an associated rollout user-interface item or directly, especially using the MAXScript property assignment. In general, the way you code change handlers is to supply <span class=\'code\'>set</span> handlers for parameters, rather than <span class=\'code\'>on &lt;item&gt;</span> change handlers for spinners, checkboxes, and others in the rollout definition. A <span class=\'code\'>set</span> handler in used in the previous example to update the light positions when the height parameter value changes.</p>\n\
<p>The <span class=\'code\'>set</span> handlers are also called when an instance is created or loaded so that common dependent actions can be taken such as, setting up other dependent system object or delegate properties.</p>\n\
<p>Note: If the param is of a <strong>tab</strong> type, the <span class=\'code\'>set</span> handler is <strong>not</strong> called on create or load.</p>\n\
<p>Available since <strong>3ds Max 2018</strong>: The <strong>preSet</strong> and <strong>postSet</strong> handlers guarantee the state of the parameter value. In most situations you should use <strong>preSet</strong> instead of <strong>set</strong>, as the parameter value is guaranteed to be the original value, while the <span class=\'code\'>&lt;arg&gt;</span> passed through is the new value. To alter the <span class=\'code\'>&lt;arg&gt;</span> value passing through, do not change <span class=\'code\'>&lt;arg&gt;</span>, but rather return a new value from the handler. MAXScript will set the parameter to this returned value.</p>\n\
<p>In situations where you do not need to alter the value passing through, or do not care about the original parameter value (for example, when you are updating a UI element), use <strong>postSet</strong>.</p>\n\
<div class=\'codeBlock\'><pre>on &lt;name&gt; get &lt;arg&gt; do &lt;expr&gt;\n\
</pre></div><p>A <span class=\'code\'>get</span> handler can be supplied for any of the parameters in the block and it will be called whenever the parameter value is retrieved. This will occur when the user interface updates itself or a script accesses the parameter. It will also occur when a viewport is redrawn or a render occurs if a script (including the scripted plugin itself) accesses the parameter as part of the redraw or render. In all these cases, the animated value is retrieved one or more times. The <span class=\'code\'>get</span> handler is called with a single argument which is the current value stored in the paramblock (or underlying controller if the parameter is animated). The <span class=\'code\'>currentTime</span> variable is set to the time at which the value is being retrieved and not necessarily the current slider time, since you can ask a parameter for its value for any specified time. If you implement the <span class=\'code\'>get</span> handler, you must return a value, and that value is returned as the value of the parameter to the value requester. If you do not want to modify the value, but just monitor accesses, return the argument. You can also compute and return any value of the appropriate type.</p>\n\
<div class=\'codeBlock\'><pre>on &lt;name&gt; set &lt;arg1&gt; [&lt;arg2&gt;] do &lt;expr&gt;\n\
\n\
on &lt;name&gt; get &lt;arg1&gt; [&lt;arg2&gt;] do &lt;expr&gt;\n\
</pre></div><p>For both get and set handlers, if the parameter is of <strong>tab</strong> type, a second argument can be specified for the handlers. The tab index will be placed in the second argument.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` plugin helper getsetHandlerTest name:&quot;DummyEx&quot; classID:#(1453456,5432110) category:&quot;Scripted Primitives&quot; extends:dummy ( parameters main rollout:params ( nodeTab type:#nodetab tabSizeVariable:true on nodeTab set val index do format &quot;set nodeTab: % : %\\n&quot; val index on nodeTab get val index do (format &quot;get nodeTab: % : %\\n&quot; val index;val) intTab type:#inttab tabSizeVariable:true on intTab set val index do format &quot;set intTab: % : %\\n&quot; val index on intTab get val index do (format &quot;get intTab: % : %\\n&quot; val index;val) point3Tab type:#point3tab tabSizeVariable:true on point3Tab set val index do format &quot;set point3Tab: % : %\\n&quot; val index on point3Tab get val index do (format &quot;get point3Tab: % : %\\n&quot; val index;val) intVal type:#integer on intVal set val do format &quot;set intVal: %\\n&quot; val on intVal get val do (format &quot;get intVal: %\\n&quot; val;val) ) rollout params &quot;Parameters&quot; ( ) ) ---------------------------------- --Test the Get and Set Handlers:-- ---------------------------------- x=getsetHandlerTest() --create an instance of the above Helper b=box() s=sphere() x.nodeTab[1] = b x.nodeTab[2] = s x.nodeTab[1] x.nodeTab[2] x.intTab[1] = 9 x.intTab[2] = 20 x.intTab[1] x.intTab[2] x.point3Tab[1] = [pi,pi,pi] x.point3Tab[2] = [e,e,e] x.point3Tab[1] x.point3Tab[2] x.intVal = 20 x.intVal with animate on at time 100 x.intVal = 120</p>\n\
<p>```</p>\n\
<p><strong>OUTPUT:</strong></p>\n\
<p>``` getsetHandlerTest set intVal: 0 $DummyEx:DummyEx01 @ [0.000000,0.000000,0.000000] $Box:Box01 @ [0.000000,0.000000,0.000000] $Sphere:Sphere01 @ [0.000000,0.000000,0.000000] set nodeTab: $Box:Box01 @ [0.000000,0.000000,0.000000] : 1 $Box:Box01 @ [0.000000,0.000000,0.000000] set nodeTab: $Sphere:Sphere01 @ [0.000000,0.000000,0.000000] : 2 $Sphere:Sphere01 @ [0.000000,0.000000,0.000000] get nodeTab: $Box:Box01 @ [0.000000,0.000000,0.000000] : 1 $Box:Box01 @ [0.000000,0.000000,0.000000] get nodeTab: $Sphere:Sphere01 @ [0.000000,0.000000,0.000000] : 2 $Sphere:Sphere01 @ [0.000000,0.000000,0.000000] set intTab: 9 : 1 9 set intTab: 20 : 2 20 get intTab: 9 : 1 9 get intTab: 20 : 2 20 set point3Tab: [3.14159,3.14159,3.14159] : 1 [3.14159,3.14159,3.14159] set point3Tab: [2.71828,2.71828,2.71828] : 2 [2.71828,2.71828,2.71828] get point3Tab: [3.14159,3.14159,3.14159] : 1 [3.14159,3.14159,3.14159] get point3Tab: [2.71828,2.71828,2.71828] : 2 [2.71828,2.71828,2.71828] set intVal: 20 20 get intVal: 20 20 set intVal: 120 120 OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>on &lt;name&gt; tabChanged &lt;arg1&gt; &lt;arg2&gt; &lt;arg3&gt; do &lt;expr&gt;\n\
</pre></div><p>A <span class=\'code\'>tabChanged</span> handler can be supplied for any Tab parameters in the block and will be called when an operation is performed on the tab itself. The arguments are:</p>\n\
<p><span class=\'code\'>arg1</span> - The type of change. Will be one of: # <span class=\'code\'>insert</span> , # <span class=\'code\'>append</span> , # <span class=\'code\'>delete</span> , # <span class=\'code\'>refDeleted</span> , # <span class=\'code\'>setCount</span> , or # <span class=\'code\'>sort</span> . All are pretty evident except for # <span class=\'code\'>refDeleted</span> . This type will occur when a MAXWrapper stored in the tab is deleted.</p>\n\
<p><span class=\'code\'>arg2</span> - The tabIndex associated with the operation. If not applicable, it will have a value of 0.</p>\n\
<p><span class=\'code\'>arg3</span> - The count associated with the operation. If not applicable, it will have a value of -1.</p>\n\
<p>For example, if you append an item to a tab that already contains one member, you will get a call to this handler with arguments of: #append 2 1. The set handler is not called, so you must handle this message in the same way as the set handler.</p>\n\
<div class=\'section\'><a id=\"tools\"></a><h2 id=\"tools\">Tools</h2></div>\n\
<p>Plug-ins can define local mouse tools. Although, you can have any number of local tools and start them as needed, you typically supply a single tool with the reserved name <span class=\'code\'>create</span> . This is taken to be the create tool for objects created in the Create panel and is invoked automatically when you create scripted plug-in objects. Tool definitions are described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Mouse-Tools.html\' title=\'\'>Scripted Mouse Tools</a>.</p>\n\
<p>Creatable scene scripted plug-ins (scripted plug-ins that are not invisible, temporary, or extend another plug-in) require a <span class=\'code\'>create</span> tool. A <span class=\'code\'>create</span> tool, if present on a non-temporary extending plug-in will override the delegate&#39;s create tool. The animate state is implicitly turned off while the <span class=\'code\'>create</span> tool is executed.</p>\n\
<p>A local variable <span class=\'code\'>WS73099cc142f487553098682e12ac2fc2bc7-722e</span> is accessible within the <span class=\'code\'>create</span> tool. This variable contains a Matrix3 value. This value is in the active grid coordinate system. This variable allows the <span class=\'code\'>create</span> tool to set the transform of the node currently being created. Also, within the <span class=\'code\'>create</span> tool you must use the <span class=\'code\'>gridX</span> values rather than <span class=\'code\'>worldX</span> values in all cases because object-creation is managed in the active grid coordinate system.</p>\n\
<div class=\'section\'><a id=\"rollouts-and-related-event-handlers\"></a><h2 id=\"rollouts-and-related-event-handlers\">Rollouts and related Event Handlers</h2></div>\n\
<p>Plug-ins can define local rollouts. These have the same syntax as local rollouts in scripted utilities. Unlike utility local rollouts, these rollouts are automatically opened as appropriate for the plug-in type (in the command panel, Material Editor, and others).</p>\n\
<p>Note: Rollout local variables only live as long as the rollout is open in the user interface. It gets opened and closed each time it is displayed, so the rollout open and close events are signalled at this time. If you want to load any spinners or other user-interface elements from the currently editing plug-in object, supply an <span class=\'code\'>on &lt;rollout&gt; open</span> event handler to pick up these values. Rollout definitions are described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Utility-Clauses.html\' title=\'\'>Utility Clauses</a>.</p>\n\
<div class=\'codeBlock\'><pre>on &lt;rollout&gt; reload do ...\n\
</pre></div><p>This event handler is defined for rollouts in scripted plug-ins. This handler is called in a scripted material, environment, or render effect whenever an instance of the plug-in is open in the Material Editor or render effects dialog, and another instance of the same plug-in class is selected. In this situation, the existing rollout is not closed and re-opened, but rather left open and &#39;loaded&#39; with the new instance. The &#39;reload&#39; handler is called after the new instance is installed in the rollout and can be used in place of <span class=\'code\'>on &lt;rollout&gt; open do ...</span> handler to update the rollout. The open handler is not called in this case. The reload event handler is not called if the scripted object has custom attributes associated with it, rather the existing rollout is closed and a new rollout opened.</p>\n\
<div class=\'codeBlock\'><pre>on &lt;rollout&gt; setTime &lt;val&gt; do ...\n\
</pre></div><p>This event handler is defined for rollups in scripted materials and texturemaps. This handler is called whenever the time slider is changed while the rollout is displayed. <span class=\'code\'>&lt;val&gt;</span> is the slider time.</p>\n\
<div class=\'section\'><a id=\"event-handlers\"></a><h2 id=\"event-handlers\">Event Handlers</h2></div>\n\
<p>As with mouse tools, scripted plug-ins respond to certain actions in <strong>3ds Max</strong> by implementing handler functions. All types of scripted plug-ins support the following event handlers. You can use these event handlers to perform any extra initialization needed such as, loading up plug-in local variables or initializing properties of the plug-in’s delegate.</p>\n\
<div class=\'codeBlock\'><pre>on create do &lt;expr&gt;\n\
</pre></div><p>The <span class=\'code\'>create</span> event handler is called whenever an instance of a scripted plug-in is created in a scene file. The animate state is implicitly turned off while the <span class=\'code\'>create</span> event handler expression is executed.</p>\n\
<div class=\'codeBlock\'><pre>on postCreate do &lt;expr&gt;\n\
</pre></div><p>When a scripted plugin is created, its create handler is called, the set handler for all paramBlock items are called, and then the postCreate handler is called. Available in <strong>3ds Max 6 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>on load do &lt;expr&gt;\n\
</pre></div><p>The <span class=\'code\'>load</span> event handler that is called whenever an instance of a scripted plug-in is loaded from a scene file. The animate state is implicitly turned off while the <span class=\'code\'>load</span> event handler expression is executed.</p>\n\
<div class=\'codeBlock\'><pre>on postLoad do &lt;expr&gt;\n\
</pre></div><p>When a scripted plugin is loaded, its update handler is called if necessary, the load handler is called, the set handler for all param block items are called, and then the postLoad handler is called. In most cases, you do not want to perform any action in the param block item set handlers when they are called during a load. You can make processing with the set handlers conditional using the &#39;loading&#39; automatic variable.</p>\n\
<p>Available in <strong>3ds Max 6 and higher</strong>.</p>\n\
<blockquote>\n\
<p>Warning: It is recommended that MAX objects not be deleted in the load or postload handlers, or in the param block item set handlers when they are called during a load. These calls occur much later in the scene load than the update handler, and deleting objects will most likely not cause a failure. However, this can not be guaranteed.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>on update do &lt;nodeVar&gt;\n\
</pre></div><p>The <span class=\'code\'>update</span> event handler that is called whenever an instance of a scripted plug-in is present in the scene file, and the definition of the scripted plug-in is changed (if you define a scripted plug-in, create an instance of the plug-in object in the scene, and then change and execute the script defining the scripted plug-in, the update event handler defined in the new definition of the scripted plug-in script is called for each instance of the plug-in object in the scene). See the Updating Scripted Plug-ins topic for more information.</p>\n\
<blockquote>\n\
<p>Warning: You must not cause a MAX object to be deleted in an update handler. The file is not done loading when the update handler is called and deleting an object might cause a crash when 3ds Max tries to finish loading the now deleted object.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>on attachedToNode &lt;nodeVar&gt; do ...\n\
</pre></div><p>Called whenever a scripted plug-in scene object (geometry, camera, light, helper, shape) is bound to a node in the scene such as, during create mode. The node that the current plug-in instance is being attached to is given as the first argument. In the event of scene node instancing, this handler might be called several times, whenever the base object is instanced to a node. Note that, in most cases, this will be called in the middle of a create mode and consequently actions such as, creating other nodes in the handler body are forbidden as they are generally in &#39;on create&#39; handlers.</p>\n\
<div class=\'codeBlock\'><pre>on detachedFromNode &lt;node&gt; do ...\n\
</pre></div><p>This is a handler to scene object scripted plug-ins. It is called whenever a node that references a plug-in instance is deleted in the scene. Note that in the presence of instancing, there might still be other nodes referencing the base object instance.</p>\n\
<div class=\'codeBlock\'><pre>on deleted do...\n\
</pre></div><p>Called whenever the scripted plug-in object is finally deleted. This might not occur immediately such as, when a scene node containing a scripted base object is deleted because the object is held onto by the undo stack in case the node delete is undone by the user. The delete might occur when the undo stack is cleared such as, a file new or reset.</p>\n\
<div class=\'codeBlock\'><pre>on clone &lt;original&gt; do ...\n\
</pre></div><p>Called whenever an instance of a scripted plug-in is cloned. This event handler is called on the newly created scripted plugin instance and the argument passed in is the plugin instance that was cloned.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` plugin material MyMaterial name:&quot;MyMaterial&quot; classID:#(0x69fedc0d, 0x7c79a4d2) extends:Standard replaceUI:true ( parameters hardwareShaders rollout:shaderRoll ( ) rollout shaderRoll &quot;Hardware Shaders&quot; width:328 height:189 ( label l1 &quot;AA&quot; ) on create do format &quot;created: %\\n&quot;this on clone orig do format &quot;cloned: % : % : % : %\\n&quot; this orig(this == orig) (delegate == orig.delegate) ) a=mymaterial() b=copy a</p>\n\
<p>```</p>\n\
<p><strong>RESULTS:</strong></p>\n\
<p>``` MyMaterial created: (null):MyMaterial MyMaterial:MyMaterial cloned: MyMaterial:MyMaterial : MyMaterial:MyMaterial : false : false MyMaterial:MyMaterial</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Specific classes of scripted plug-ins implement additional event handlers and are described with description of the scripted plug-in type.</p>\n\
<p>Runtime errors in certain event handlers cause the plug-in to be disabled until it is re-defined. When disabled, none of the plug-in event handlers are called. For example, errors in the <span class=\'code\'>map</span> event handler expression in <span class=\'code\'>SimpleMods</span> and the <span class=\'code\'>buildMesh</span> event handler expression in <span class=\'code\'>SimpleObject</span> disable the plug-in because they are called so frequently. You will need to correct any problems and re-evaluate the plug-in definition again to re-enable the plug-in event handlers.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";