var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Scripted Plug-in Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Scripted Plug-in Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"scripted-plug-in-methods\"></a></div>\n\
<p>The <span class=\'code\'>addPluginRollouts()</span> is used within scripted plug-in create tools, specifically for level 1 plug-ins that don&#39;t create instances of themselves in the scene but might create other objects within their create tool. This method lets you install rollouts for a specified object in the Create panel, typically one of the objects being created in the create tool, so that its parameters can be adjusted directly during creation.</p>\n\
<p>The form is:</p>\n\
<div class=\'codeBlock\'><pre>addPluginRollouts &lt;obj&gt;\n\
</pre></div><p>In the following example, a variation of the three light mouse tool example presented in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Mouse-Tools/Mouse-Tool-Clauses.html\' title=\'\'>Mouse Tool Clauses</a> is set into permanent, editable classes. It defines two new classes. The helper class <span class=\'code\'>lightMaster</span> is used as a master object for the light system. The light class <span class=\'code\'>threeLights</span> is what you create to layout the initial system. It also creates a <span class=\'code\'>lightMaster</span> and sets its parameters to point at the lights. The <span class=\'code\'>lightMaster</span> rollout allows subsequent editing of the system in the Modifier panel, and storing the lights in a parameter block makes the setup persistent over scene saves and loads.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` plugin helper lightMaster name:&quot;Light Master&quot; classID:#(12345,54321) extends:Dummy replaceUI:true invisible:true ( parameters main rollout:params ( key type:#node subAnim:true fill type:#node subAnim:true back type:#node subAnim:true height type:#worldUnits default:0 ui:height spread type:#worldUnits default:0 ui:spread angle type:#angle default:90 ui:angle -- check value of key since lights don&#39;t exist at initial creation on height set val do if key != undefined then coordsys key.target ( key.pos.z = val back.pos.z = val * 1.5 fill.pos.z = val * 0.5 ) on spread set val do if key != undefined then coordsys key.target ( -- compute normal vector pointing at key in the target&#39;s XY plane -- (kuv) and reposition everything based on that and the current -- spread and angle values local kuv = normalize ([key.pos.x, key.pos.y, 0]) key.pos = [kuv.x * spread, kuv.y * spread, height] back.pos = [kuv.x * -spread, kuv.y * -spread, height * 1.5] -- position fill by placing it under the key and then rotating in -- about the target fill.pos = [kuv.x * spread, kuv.y * spread, height * 0.5] about key.target rotate fill angle z_axis ) on angle set val do if key != undefined then coordsys key.target ( fill.pos = [key.pos.x, key.pos.y, height * 0.5] about key.target rotate fill angle z_axis ) ) rollout params &quot;Light Parameters&quot; ( spinner height &quot;Height&quot; type:#worldUnits range:[-1e32, 1e32, 0] spinner spread &quot;Spread&quot; type:#worldUnits range:[0, 1e32, 0] spinner angle &quot;Angle&quot; range:[-180, 180, 30] on params open do flagForeGround #(key, back, fill) true on params close do if key != undefined and back != undefined and fill != undefined then flagForeGround #(key, back, fill) false ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` plugin light searchlights name:&quot;Three Lights&quot; ( local master tool create ( on mousePoint click do ( if click == 1 then -- create key, back &amp; fill lights at mousedown ( coordsys grid ( master = lightMaster pos:gridPoint master.dummy.boxsize = [10,10,10] in master ( local targObj=targetobject pos:gridPoint master.key = targetspot pos:gridPoint name:&quot;key&quot;<br> target:targObj master.back = targetspot pos:gridPoint name:&quot;back&quot;<br> target:targObj master.fill = targetspot pos:gridPoint name:&quot;fill&quot;<br> target:targObj ) ) addPluginRollouts master ) if click == 3 then ( select master master = undefined #stop ) ) on mouseMove click do ( if click == 2 then -- drag out &amp; round on x-y plane ( -- place the key on the grid then set the spread and the -- &#39;on set spread&#39; handler will -- move the lights to the correct heights master.key.pos = worldPoint master.spread = distance master.key master.key.target ) else if click == 3 then -- drag up to elevate lights master.height = gridDist.z ) on mouseAbort click do ( if master != undefined then ( if master.fill != undefined then delete master.fill if master.back != undefined then delete master.back if master.key != undefined then delete master.key delete master ) ) ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"parameter-type-convenience-functions\"></a><h2 id=\"parameter-type-convenience-functions\">Parameter Type Convenience Functions</h2></div>\n\
<p>The following functions allow you to convert parameter type names to their corresponding integer values used in the C++ API, or from an integer value to the corresponding name value. The integer values correspond to the values for <span class=\'code\'>ParamType</span> and <span class=\'code\'>ParamType2</span> enums found in the maxsdk/include/paramtype.h header file. <strong>Available in 3ds Max 2021 and higher.</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;type_name&gt; ParamTypeToTypeName &lt;int&gt;\n\
</pre></div><p>Returns the name value corresponding to the specified integer.</p>\n\
<div class=\'codeBlock\'><pre>&lt;int&gt; TypeNameToParamType &lt;type_name&gt;\n\
</pre></div><p>Returns the integer value for the enum corresponding to the specified type name.</p>\n\
<div class=\'section\'><a id=\"for-example\"></a><h3 id=\"for-example\">For Example</h3></div>\n\
<div class=\'codeBlock\'><pre>ParamTypeToTypeName 4\n\
--&gt; #boolean\n\
\n\
TypeNameToParamType #filename\n\
--&gt; 9\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";