var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Scripted Plug-ins</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Scripted Plug-ins</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"scripted-plug-ins\"></a></div>\n\
<p>MAXScript supports several levels of scripted plug-ins, as follows:</p>\n\
<div class=\'section\'><a id=\"level-1-scripted-plug-in\"></a><h2 id=\"level-1-scripted-plug-in\">Level 1 Scripted Plug-in</h2></div>\n\
<p>The scripted plug-in appears in the user interface as a new class but does not allow instances of itself in the scene. It lets you define a mouse tool that creates other objects in the scene, but once you&#39;ve finished creation, there is no instance of the class left in the scene to modify or save. Examples of this currently in <strong>3ds Max</strong> are the System classes such as RingArray.</p>\n\
<div class=\'section\'><a id=\"level-2-scripted-plug-in\"></a><h2 id=\"level-2-scripted-plug-in\">Level 2 Scripted Plug-in</h2></div>\n\
<p>The scripted plug-in extends an existing plug-in, either adding to or replacing the command panel parameter rollouts for the existing plug-in. For example, you might create a new &quot;glass&quot; material which extends StandardMaterial and provides a custom, presumably smaller, Material Editor rollout that just has glass parameters which set up and modify various properties in the underlying material plug-in as appropriate. Or, you want to create a new light type that is actually a system of coordinated lights, that also has a &quot;controlling&quot; dummy object created. This controlling dummy keeps track of the lights in the system and has a Create/Modify panel rollout that allows coordinated manipulation of the system. In this case, you&#39;d create a new helper plug-in that extends Dummy, has locals to store the lights, and define a rollout. You would also create a new light plug-in with a create tool that builds the system.</p>\n\
<div class=\'section\'><a id=\"level-3-scripted-plug-in\"></a><h2 id=\"level-3-scripted-plug-in\">Level 3 Scripted Plug-in</h2></div>\n\
<p>The scripted plug-in is given a unique and permanent class ID value by the script writer and so can be instanced in the scene and stored in scene files. All <strong>3ds Max</strong> plug-ins have a unique class ID and <strong>3ds Max</strong> uses this class ID to associate stored scene objects with the code that handles them each time you open a scene file, hence it has to be unique and permanent. In the level 1 scripted plug-in above, MAXScript allocates a temporary class ID that is not permanent across executions of <strong>3ds Max</strong> and thus prevents instancing in the scene.</p>\n\
<div class=\'section\'><a id=\"level-4-scripted-plug-in\"></a><h2 id=\"level-4-scripted-plug-in\">Level 4 Scripted Plug-in</h2></div>\n\
<p>The scripted plug-in defines one or more <strong>parameter blocks</strong>, containing directly animatable parameters that are saved to and restored from scene files. These are the permanent parameters for the plug-in and are distinct from the local variables in the example above which only live during creation.</p>\n\
<div class=\'section\'><a id=\"level-5-scripted-plug-in\"></a><h2 id=\"level-5-scripted-plug-in\">Level 5 Scripted Plug-in</h2></div>\n\
<p>A parameter block can be associated with a rollout in the scripted plug-in that provides a user interface for the parameters in the parameter block. When associated in this way, the parameters are &quot;wired&quot; to their spinners and checkboxes, etc., and both update automatically as the other changes.</p>\n\
<p>The general form for a scripted plug-in is:</p>\n\
<div class=\'codeBlock\'><pre>plugin &lt;superclass&gt; &lt;varname&gt; {keyword:val}( &lt;plugin_body&gt; )\n\
</pre></div><p>where:</p>\n\
<p><span class=\'code\'>&lt;superclass&gt;</span> is one of the currently supported plug-in superclasses:</p>\n\
<div class=\'codeBlock\'><pre>Geometry SimpleObject Shape Light Camera Helper Modifier SimpleMod TrackViewUtility Material TextureMap RenderEffect Atmospheric simpleManipulator simpleMeshMod floatController point3Controller point4Controller colorController positionController rotationController scaleController transformController simpleSpline*\n\
</pre></div><p>Note: the <span class=\'code\'>simpleSpline</span> superclass is exposed for MCG support, and cannot be created in MAXScript.</p>\n\
<p><span class=\'code\'>&lt;varname&gt;</span> is the name that will be given to the global variable that contains this plug-in class. This class value is just like a normal plug-in class (like box, sphere, etc.) and you can create an instance of the plug-in in MAXScript by applying the class value.</p>\n\
<p><span class=\'code\'>{keyword:val}</span> is an optional sequence of keyword/value pairs defining options for the plug-in. These pairs are:</p>\n\
<div class=\'codeBlock\'><pre>name:&lt;string&gt;\n\
</pre></div><p>The optional <span class=\'code\'>name:</span> parameter specifies the name of the plug-in as seen in the <strong>3ds Max</strong> user-interface. For example, if the superclass of the plug-in is <span class=\'code\'>geometry</span> or <span class=\'code\'>light</span> , this name would be displayed on the plug-in’s button in the Create panel; if the superclass of the plug-in is <span class=\'code\'>modifier</span> , this name would be displayed on the plug-in’s button in the Modify panel; and if the superclass of the plug-in is <span class=\'code\'>material</span> or <span class=\'code\'>textureMap</span> , this name would be displayed in the Material/Map Browser. The default name is the plug-in’s <span class=\'code\'>&lt;varname&gt;</span>.</p>\n\
<p>In versions prior to <strong>3ds Max 2014</strong>, the <span class=\'code\'>name:</span> parameter was used to define the naming of class instances and scene objects. This changed in <strong>3ds Max 2014</strong> - the <span class=\'code\'>&lt;varname&gt;</span> will be used to define the name of class instances and scene objects, the <span class=\'code\'>name:</span> parameter will be used only for the (localizable) creation buttons/entries in the UI.</p>\n\
<p>For example, a scripted geometry plugin with <span class=\'code\'>&lt;varname&gt;</span> myCuboid and name:&quot;Supa Cuboid&quot; will display &quot;Supa Cuboid&quot; on its creation button, but the Modifier Stack will show a base object called &quot;myCuboid&quot; and the scene node will be named &quot;myCuboid001&quot;. In earlier versions of <strong>3ds Max</strong>, the Modifier Stack was showing &quot;Supa Cuboid&quot;, and the scene node was named &quot;Supa Cuboid001&quot;.</p>\n\
<div class=\'codeBlock\'><pre>category:&lt;string&gt;\n\
</pre></div><p>The optional <span class=\'code\'>category:</span> parameter specifies in which object category (access via the object category list) the plug-in will appear in. This parameter is applicable only to plug-ins that appear in the Create panel. The default category in &quot;Standard&quot;. Note that there is a fixed number of buttons available in the Create panel for each category. If a button for your plug-in does not show up in the appropriate Create panel, you may need to make a new category for it.</p>\n\
<div class=\'codeBlock\'><pre>classID:#(&lt;integer&gt;,&lt;integer&gt;)\n\
</pre></div><p>You supply the <span class=\'code\'>classID:#(`&lt;integer&gt;,&lt;integer&gt;`)</span> parameter if you want the plug-in to be creatable and storable in the scene. This ID becomes the permanent ID for the class and is used by <strong>3ds Max</strong> to identify objects as they are saved and loaded in the scene. You don&#39;t need to supply a class ID value if the plug-in is to be like a System object that only creates other types of objects in the scene. The class ID is basically a pair of numbers, chosen randomly so that (hopefully) they won’t conflict with another plug-in. MAXScript provides a method to generate a fresh random class ID each time you run it:</p>\n\
<div class=\'codeBlock\'><pre>genClassID [returnValue:&lt;boolean&gt;]\n\
</pre></div><p>This method generates a random class ID similar to #(0x9b7ea231, 0xb6db86ef), and prints it by default to Listener. You can cut and paste this class ID into your script to use the generated ID.</p>\n\
<p>In <strong>3ds Max6 and higher,</strong> if <span class=\'code\'>returnValueL</span> is <span class=\'code\'>true</span> , the classid is not printed to the Listener, rather a 2 element array containing the 2 parts of the class ID is returned.</p>\n\
<div class=\'codeBlock\'><pre>extends:&lt;maxClass&gt;\n\
</pre></div><p>The <span class=\'code\'>extends:&lt;maxClass&gt;</span> parameter is supplied if you want to base your plug-in on an existing plug-in. This basically lets you add a new class that works internally exactly like the one you are extending, but with an expanded or replaced user interface. The class you specify must have the same superclass as specified in the scripted plug-in header. Current limitations prevent certain plug-ins from being extended, in particular those with custom creation managers. These include target lights and cameras and all the System plug-ins. You can tell if a plug-in is not extendable if your new rollouts do not appear.</p>\n\
<p>When you create an object of scripted plug-in that extends another, MAXScript also creates an internal object of the <span class=\'code\'>extends:</span> plug-in and passes most of <strong>3ds Max</strong>&#39;s interaction with your plug-in onto the internal object. This is called <strong>delegation</strong> and the internal <span class=\'code\'>extends:</span> plug-in object is the <strong>delegate</strong>. The delegate is visible in your plug-in&#39;s objects in Track View and you can access the delegate in your scripts to control it as needed. See the locals section below for more information. The delegate <strong>is not shown</strong> in TV if replaceUI:true is specified.</p>\n\
<div class=\'codeBlock\'><pre>replaceUI:&lt;boolean&gt;\n\
</pre></div><p>The <span class=\'code\'>replaceUI:</span> parameter is used only when <span class=\'code\'>extends:</span> is supplied to indicate whether the rollouts in your plug-in should add-to or replace the extended plug-ins rollouts. The default is <span class=\'code\'>false</span> , which means your rollouts will be appended at the end of the extended plug-in&#39;s. Another current limitation when extending plug-ins whose objects are created in the Create panel only allows user interface replacement in the Modifier panel; the original plug-in&#39;s rollouts are always displayed along with the scripted rollouts in the Create panel.</p>\n\
<div class=\'codeBlock\'><pre>version:&lt;integer&gt;\n\
</pre></div><p>The optional <span class=\'code\'>version:</span> parameter specifies the version number of the scripted plug-in. The value assigned to this parameter is used when updating the scripted plug-in definition. The default value for this parameter is 1. See <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/Updating-Scripted-Plug-ins.html\' title=\'\'>Updating Scripted Plug-ins</a> for more information on this parameter.</p>\n\
<div class=\'codeBlock\'><pre>invisible:&lt;boolean&gt;\n\
</pre></div><p>The optional <span class=\'code\'>invisible:</span> parameter gives control over whether the plug-in is visible in the Create panel Object Type rollout or in the Material/Map Browser, etc. This is useful for component or controlling objects created as part of a group, say in a System-style plug-in that should not be creatable on their own. Set this parameter to <span class=\'code\'>true</span> to hide the plug-in.</p>\n\
<div class=\'codeBlock\'><pre>silentErrors:&lt;boolean&gt;\n\
</pre></div><p>The optional <span class=\'code\'>silentErrors:</span> parameter gives control over whether MAXScript run-time error messages are displayed when executing handlers in the scripted plug-in. If this parameter is set to <span class=\'code\'>true</span> , error messages will not be displayed. This may be useful for distributed scripted plug-ins that may confuse the user with MAXScript error messages.</p>\n\
<div class=\'codeBlock\'><pre>usePBValidity:&lt;boolean&gt; \n\
</pre></div><p>The optional <span class=\'code\'>usePBValidity:</span> parameter is applicable to scripted plug-ins that extend an existing class. If usePBValidity is false (the default, which matches the original behavior), the validity interval of the scripted plug-in does not include the validity of controllers in the scripted plug-in, only the validity of the delegate that is used. If true, the validity interval is the intersection of delegate&#39;s validity interval and the validity interval of any parameter blocks defined in a scripted plug-in.</p>\n\
<p>Available in <strong>3ds Max 6 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>initialRollupState:&lt;0xnnnnn&gt;\n\
</pre></div><p>The argument is an integer whose 32 bits are used to initialize the rollouts&#39; rollup state in both the create and the modify panel. The semantics are different, however for these two cases. Whenever the rollups are created in the create tab, their state will be that specified by this value. In the modify tab, the first time an object of this type is modified, the state will be that of this value, after that it will remain what it was last set to. The bits of this value indicate the corresponding rollout page is rolled up (closed). The zero bit corresponds to the plug-ins first rollout, the first bit is the second rollout, etc. The default value of 0x7fffffff is used so the command panel can detect that this value is not being overridden, and just leave the rollouts as is. For example, a value of 0x07 would result in the first 3 rollouts being rolled up, and the remaining rollouts open.</p>\n\
<div class=\'codeBlock\'><pre>autoPromoteDelegateProps:&lt;boolean&gt;\n\
</pre></div><p>In <strong>3ds Max 6 and higher</strong>, the optional <span class=\'code\'>autoPromoteDelegateProps</span> : parameter gives control over whether the delegate’s properties are automatically searched if a property access is performed on the plug-in, but the property is not defined by the plug-in. Defaults to <span class=\'code\'>false</span> .</p>\n\
<div class=\'codeBlock\'><pre>remap:#(&lt; old param names array&gt;, &lt;new param names array&gt;)\n\
</pre></div><p>This keyword allows parameter names in the definitions to be changed when updating existing definitions.</p>\n\
<p>The keyword takes as an argument a 2 element array, where each element contains an array of string literal or name values. The size of the 2 arrays must be the same.</p>\n\
<p>The names in the first array are the existing parameter names, the names in the second array are the new parameter names. As parameter names are read in while migrating existing plugin instances, the parameter names are searched for in the first array. If the name is found, the data associated with that parameter is moved to the parameter name in the corresponding location in the second array. If a parameter name is not found in the first array, the parameter name is not remapped. If the parameter name in the second array does not match a parameter name in the new definition, the parameter data is not moved to the new definition.</p>\n\
<p><span class=\'code\'>&lt;plugin_body&gt;</span> is enclosed in the required parentheses and is a sequence of clauses that define the local variables and functions, parameters, user-interface items, and event handlers that define the plug-in. These clauses are defined in detail in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/Scripted-Plug-in-Clauses.html\' title=\'\'>Scripted Plug-in Clauses</a>.</p>\n\
<p>If you load a scene file that uses a level 3 or higher scripted plug-in, and you have not defined that scripted plug-in, a Missing DLL dialog will be displayed after the load, indicating the definition for the scripted plug-in is missing. The file will then load using a standin for the object with the missing definition, just as it would for other objects missing their DLL definitions. <strong>3ds Max</strong> treats scripted plug-ins as it does C++ plugins, requiring the definition to be in place, either in a script file in the plugins directory when <strong>3ds Max</strong> starts, or having been defined by running some script prior to loading the file.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";