var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Scripted RenderEffect Plug-ins</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Scripted RenderEffect Plug-ins</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"scripted-rendereffect-plug-ins\"></a></div>\n\
<p>A scriptable RenderEffect plug-in can be declared by specifying the <span class=\'code\'>&lt;superclass&gt;</span> as <span class=\'code\'>RenderEffect</span> and by declaring an <span class=\'code\'>apply</span> event handler. When declared, the render effect can be seen in Render Effects &gt; Add dialog.</p>\n\
<p><strong>Event Handlers:</strong></p>\n\
<div class=\'codeBlock\'><pre>on apply &lt;bitmap&gt; do &lt;expr&gt; \n\
</pre></div><p>When the scripted effect is added as one of the rendering effects and &quot;Update Scene&quot; or &quot;Update Effect&quot; buttons are pressed, the <span class=\'code\'>apply</span> event handler is called and passed a bitmap which can be modified with any changes the render effect wants to make. The bitmap you are given is the current rendered image that has had all of the prior effects in the render effects list applied to it. You modify this bitmap in place, typically by using the <span class=\'code\'>getPixel()</span> and <span class=\'code\'>setPixel()</span> functions. This modified bitmap is then passed onto the next render effect in the list or to the render output if it is the last effect.</p>\n\
<p>To allow scripted Effects to take advantage of the g-buffer channel access, the following handlers are present:</p>\n\
<div class=\'codeBlock\'><pre>on channelsRequired do &lt;expr&gt; \n\
</pre></div><p>The handler expression must evaluate to an array of the g-buffer channel names that are required. The g-buffer channel names are:</p>\n\
<div class=\'codeBlock\'><pre>#zDepth #matID #objectID #UVCoords #normal #unClamped #coverage #mask #node #shaderColor #shaderTransparency #velocity #weight \n\
on preApply &lt;bitmap&gt; do &lt;expr&gt; \n\
</pre></div><p>The <span class=\'code\'>preApply</span> handler allows the scripted effect to analyze the incoming render bitmap and its channels to precondition the delegate&#39;s effect processing.</p>\n\
<p>So, you might add an <span class=\'code\'>on channelsRequired do</span> to add <span class=\'code\'>#node</span> and <span class=\'code\'>#coverage</span> channels to the renderer’s bitmap, and an <span class=\'code\'>on preApply bm do</span> to get the <span class=\'code\'>#node</span> channel out as a mask and then set it into a delegate’s mask parameter to limit an effect to a given object.</p>\n\
<p>The <span class=\'code\'>render()</span> function can be called re-entrantly within scripted renderEffect. In releases prior to <strong>3ds Max 4</strong>, attempting to do this caused a runtime error indicating that the renderer cannot be called while a render is already under way.</p>\n\
<p>Here is a simple example that extends the Blur effect to add another rollout that has a node picker button. If you pick a node, it generates a channel mask and uses that to limit the blur to that object:</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` plugin RenderEffect myBlurFX name:&quot;Super Blur FX&quot; classID:#(6545,456581) extends:Blur version:1 ( local tx, cm, g_channels local tx = bitmaptexture () local g_channels = #(#node, #coverage) rollout params &quot;SupaFX Parameters&quot; ( label nn align:#center pickbutton nodepick &quot;Pick Node&quot; ) parameters main rollout:params ( thenode type:#node ui:nodepick on thenode set nd do params.nn.text = if nd == undefined then &quot;&quot; else nd.name ) on channelsRequired do g_channels on preApply map do if theNode != undefined then ( if cm == undefined then ( cm = getChannelAsMask map #node node:theNode<br> fileName:(scriptsPath + &quot;__fxtmp.bmp&quot;) save cm tx.bitmap = cm ) else getChannelAsMask map #node node:theNode to:cm ) on create do ( delegate.selMaskActive = true delegate.selImageActive = false delegate.selMaskMap = tx ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` plugin renderEffect myColorBalanceFx name:&quot;Super Color Balance FX&quot; classID:#(64425,45761) extends:Color_Balance version:1 ( parameters main rollout:params ( redness type:#integer animatable:true ui:redness default:0.0 on redness set val do delegate.red = val ) rollout params &quot;Super Color Balance Parameters&quot; ( spinner redness &quot;Redness: &quot; type:#integer range:[-100,100,0] ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` plugin renderEffect myNegative name:&quot;myNegative&quot; classID:#(0xb7aa794c, 0xc3bd78ab) ( parameters main rollout:params ( Color type:#color default:blue ui:Color ) rollout params &quot;Negative Parameters&quot; ( colorpicker Color &quot;Base color: &quot; align:#center ) on apply bmp do ( for h=0 to (bmp.height-1) do ( local sline = getPixels bmp [0,h] bmp.width for i=1 to sline.count do sline[i] = Color - sline[i] setPixels bmp [0,h] sline ) ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";