var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Scripted SimpleMod Plug-ins</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Scripted SimpleMod Plug-ins</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"scripted-simplemod-plug-ins\"></a></div>\n\
<p>A SimpleMod plug-in is a deformation-type modifier that moves vertices around, but does not change the topology (adding or deleting vertices, faces, surfaces, lines, and so on).</p>\n\
<p>Examples of similar <strong>3ds Max</strong> modifiers are Bend, Stretch, and Taper.</p>\n\
<p>These kinds of modifiers require only a single <span class=\'code\'>map</span> handler to be provided for moving vertices around and they automatically supply 3D box deformation gizmo and center sub-objects.</p>\n\
<p>A scripted Simple Modifier plug-in is declared by specifying the <span class=\'code\'>&lt;superclass&gt;</span> as <span class=\'code\'>simpleMod</span> .</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` plugin simpleMod saddle name:&quot;SaddleDeform&quot; classID:#(685325,452281) version:1 ( parameters main rollout:params ( amount type:#integer ui:amtSpin default:20 ) rollout params &quot;Saddle Parameters&quot; ( spinner amtSpin &quot;Amount: &quot; type:#integer range:[0,1000,20] ) on map i p do ( p.z += amount * sin((p.x * 22.5/extent.x) * (p.y * 22.5/extent.y)) p ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>This script defines a new SimpleMod plug-in named SaddleDeform. It applies a saddle-type deformation to an object, curving up two opposite corners, and curving down the other two opposite corners (try it on a plane object to see this best). There is a single parameter spinner, <span class=\'code\'>amount</span> that specifies how much deformation to apply. The key component of a SimpleMod plug-in is the <span class=\'code\'>map</span> handler.</p>\n\
<p><strong>Its form is:</strong></p>\n\
<div class=\'codeBlock\'><pre>on map &lt;index&gt; &lt;point&gt;  do &lt;expr&gt;    \n\
</pre></div><p>This event handler is called once for every point in the object (or current point selection in the object) being modified. These points might be mesh vertices, spline vertices, NURBS CVs, and so on. The <span class=\'code\'>&lt;index&gt;</span> argument gives the number of the point, but this index might not correspond to a vertex number in a mesh or a spline. The <span class=\'code\'>&lt;point&gt;</span> argument supplied to the <span class=\'code\'>map</span> handler gives the current object-space coordinates of the point as a Point3. The function must modify the supplied point value as appropriate and return it as the result of the <span class=\'code\'>map</span> handler call. In the example above, the <span class=\'code\'>map</span> handler applies a Z-coordinate deformation using the equation <span class=\'code\'>z = sin(x * y)</span> , so all the points retain their X and Y coordinates and the Z is moved up or down to follow the saddle function. Note that all coordinates are object-local.</p>\n\
<p>The <span class=\'code\'>&lt;index&gt;</span> value is 1-based. However, the scripted plug-in is called with an <span class=\'code\'>&lt;index&gt;</span> value of 0 to signal that this particular map call is being used by the gizmo bounding box drawing code to compute points in the gizmo box to draw. This hit testing is performed on the object the SimpleMod modifier is applied to and the gizmo bounding box is displayed. This will be the case if the object is selected, the Modifier panel is active, and the SimpleMod modifier is selected in the object’s modifier stack.</p>\n\
<p>It is basically up to the object being modified to decide what index value to pass. For example, for meshes it is the actual mesh vertex index. For patches, it is the control points first all in one sequence, followed by the in and out vectors for each control point in control point order. For splines, it is the control point, in vector, and out vector in control point sequence within the curve sequence. This ordering might change in later versions of <strong>3ds Max</strong>.</p>\n\
<p>Because the <span class=\'code\'>map</span> handler can be called many times, even on simple objects, it is highly recommended that you minimize the number of values created in the <span class=\'code\'>map</span> handler. This will reduce the need for garbage collection to be run. If you need several local variables in the map handler, it is recommended that you declare one or more Point2 or Point3 values in the scripted plug-in definition, and then store values to the component values of the Point2 or Point3 values. This will prevent new local variables from being allocated in the <span class=\'code\'>map</span> handler.</p>\n\
<p>You must not try to access the object being modified from within the <span class=\'code\'>map</span> handler as this will attempt to evaluate the scripted modifier again. This will result in an infinite loop and hang <strong>3ds Max</strong>.</p>\n\
<p>There are also three pre-defined plug-in locals you can access in the <span class=\'code\'>map</span> handler as follows:</p>\n\
<div class=\'codeBlock\'><pre>min -- the modifier context&#39;s bounding box min coordinate    \n\
max -- the modifier context&#39;s bounding box max coordinate    \n\
center -- the modifier context&#39;s bounding box center coordinate      \n\
extent -- the modifier context&#39;s bounding box extent or size   \n\
</pre></div><p>In the example above, the map handler uses the <span class=\'code\'>extent</span> pre-defined local variable to compute a scaling for the saddle function, so that it gets a 1/8th cycle of the function (22.5 degrees) across the whole object. These bounding box locals relate to the modifier&#39;s context, either the whole object or group of objects if applied to a scene node selection, or sub-object selection if there is a sub-object selection modifier below it on the stack (such as, a Mesh Select).</p>\n\
<p>You can also use some other built-in capabilities of SimpleMod to implement modifier limits display. To do this, implement handlers for the following (you must implement all if you implement any):</p>\n\
<div class=\'codeBlock\'><pre>on modLimitZMin do &lt;expr&gt;   \n\
on modLimitZMax do &lt;expr&gt;   \n\
on modLimitAxis do &lt;expr&gt; \n\
</pre></div><p>If called, the <span class=\'code\'>on modLimitZMin</span> and <span class=\'code\'>on modLimitZMax</span> handler expressions must evaluate to float values corresponding to the minimum and maximum limits and the <span class=\'code\'>on modLimitAxis</span> handler expression must return <span class=\'code\'>#x</span> , <span class=\'code\'>#y</span> , or <span class=\'code\'>#z</span> to specify the limit axis. The MAXScript global variable <span class=\'code\'>currentTime</span> contains the time at which these values must be computed. Generally, simple access to parameter values will yield the correct <span class=\'code\'>currentTime</span> value automatically. The simplest way to implement these handlers is to maintain limit parameters and associated spinners and checkboxes, and simply pass these parameter values back.</p>\n\
<p>Note that these handlers do not implement the actual limiting of the effect to the limit values, only the gizmo display of the limits. To actually apply the limits, you must provide the necessary logic and calculations within the <strong><span class=\'code\'>on map ... do()</span></strong> event handler.</p>\n\
<p>The following example implements a radial Bulge effect relative to the Z axis, and provides limits expressed as Percentage of the bounding box Z height. When enabled, the p.z coordinate normalized by the height of the bounding box is compared to the lower and upper limits and the effect is only applied if the value is between the limits. As the effect and limits are always applied using the Z axis, the on modLimitAxis do() handler always returns #z.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` plugin simpleMod bulgeZ name:&quot;BulgeZ&quot; classID:#(0xa4741be, 0x953eaf3) version:1 ( parameters main rollout:params ( amplitude type:#float ui:spn_amplitude default:1 wavecount type:#float ui:spn_wavecount default:1 phase type:#float ui:spn_phase default:0 limit type:#boolean ui:chk_limit default:false maxLimit type:#float ui:spn_maxLimit default:100 minLimit type:#float ui:spn_minLimit default:0 ) rollout params &quot;BulgeZ Parameters&quot; ( spinner spn_amplitude &quot;Amplitude: &quot; type:#float range:[0,1000,1] spinner spn_wavecount &quot;Wave Count: &quot; type:#float range:[0,1000,1] spinner spn_phase &quot;Phase:&quot; type:#float range:[-100000,100000,0] scale:0.01 group &quot;Limits&quot; ( checkbox chk_limit &quot;Limit Effect&quot; align:#right offset:[8,-5] spinner spn_maxLimit &quot;Upper Limit %:&quot; range:[-1000,1000,100] spinner spn_minLimit &quot;Lower Limit %:&quot; range:[-1000,1000,0] ) ) on map i p do ( local v = normalize [p.x-center.x, p.y-center.y,0] local pzn = p.z/(max.z-min.z) if not limit or (pzn &gt;= minLimit<em>0.01 and pzn &lt;= maxLimit</em>0.01) do p += v<em>amplitude</em>(cos (360<em>(pzn-phase)</em>wavecount)) p ) on modLimitZMin do if limit then minLimit<em>0.01</em>(max.z-min.z) else 0.0 on modLimitZMax do if limit then maxLimit<em>0.01</em>(max.z-min.z) else 0.0 on modLimitAxis do #z )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The Modify panel actually creates a fresh instance of every modifier when it is to be shown in the Modifier list or the buttons in the Modifiers rollout. This will cause the <span class=\'code\'>create</span> handler to be called for a scripted SimpleMod plug-in. No special handling in the <span class=\'code\'>create</span> handler is required for this case.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";