var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Scripted SimpleObject Plug-ins</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Scripted SimpleObject Plug-ins</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"scripted-simpleobject-plug-ins\"></a></div>\n\
<p>A SimpleObject is a kind of geometry primitive that is defined by a tri-mesh such as, a box, sphere, cone, and so on. In other words, a simpleObject plugin is similar to all the Standard and Extended primitives in <strong>3ds Max</strong>.</p>\n\
<p>In scripting a SimpleObject plug-in, you need to supply a handler for building this mesh and <strong>3ds Max</strong> automatically handles the scene display, hit-testing, ray intersection, rendering, modifier applicability, and others.</p>\n\
<p>A scripted SimpleObject plug-in is declared by specifying the <span class=\'code\'>&lt;superclass&gt;</span> as <span class=\'code\'>simpleObject</span> .</p>\n\
<p>Scripted SimpleObject plug-ins <strong>require</strong> a <span class=\'code\'>create</span> tool.</p>\n\
<p>A SimpleObject plug-in must not perform any scene related actions such as, creating scene nodes or building modifier stacks. It must only adjust its parameters in the mouse tool handlers and construct a mesh in the <span class=\'code\'>buildMesh</span> handler. Attempting to create scene nodes or applying modifiers in a SimpleObject plug-in will cause all kinds off strange interactions with the in-progress scene node creation.</p>\n\
<p>A SimpleObject plug-in has a predefined local variable <span class=\'code\'>mesh</span> . This variable contains the underlying mesh of the object being created. The <span class=\'code\'>mesh</span> local variable is accessible in any of the plug-in&#39;s handlers, but is typically only built in the <span class=\'code\'>buildMesh</span> handler. You can either modify the existing TriMesh value in place using the TriMesh methods, or construct a new TriMesh value and assign it to the <span class=\'code\'>mesh</span> plug-in local variable. The TriMesh methods and properties are described in <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Editable-Meshes-Splines-Patches/Editable_Mesh-and-TriMesh/Editable_Mesh-GeometryClass-and.html\' title=\'\'>Editable Mesh</a>.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` plugin simpleObject tower_plugin_def name:&quot;Tower&quot; classID:#(145345,543211) category:&quot;Scripted Primitives&quot; ( parameters main rollout:params ( height type:#worldUnits ui:height default:0 width type:#worldUnits ui:width default:0 depth type:#worldUnits ui:depth default:0 ) rollout params &quot;Two Faces Parameters&quot; ( spinner height &quot;Height&quot; type:#worldunits range:[-1000,1000,0] spinner width &quot;Width&quot; type:#worldunits range:[-1000,1000,0] spinner depth &quot;Depth&quot; type:#worldunits range:[-1000,1000,0] ) on buildMesh do ( setMesh mesh<br> verts:#([0,0,0],[width,0,0],[width,depth,0],[0,depth,0])<br> faces:#([3,2,1], [1,4,3]) extrudeFace mesh #(1,2) (height * 0.5) 40 dir:#common extrudeFace mesh #(1,2) (height * 0.5) 50 dir:#common ) tool create ( on mousePoint click do case click of ( 1: nodeTM.translation = gridPoint 3: #stop ) on mouseMove click do case click of ( 2: (width = gridDist.x; depth = gridDist.y) 3: height = gridDist.z ) ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In this script a new primitive called Tower is defined. It constructs a very simple tower form; the first drag sets the base and the second drag sets the height. It contains three animatable rollout parameters: <span class=\'code\'>height</span> , <span class=\'code\'>width</span> , and <span class=\'code\'>depth</span> , which set the object&#39;s basic bounds. The key components here are the <span class=\'code\'>create</span> tool and the <span class=\'code\'>on buildMesh</span> handler, and they work together in a simple way. The <span class=\'code\'>create</span> tool sets the values of the parameters and the <span class=\'code\'>on buildMesh</span> handler constructs a mesh based on the parameter values.</p>\n\
<p>The <span class=\'code\'>create</span> tool can also access and set the position of the node that is being created to contain the new object through the Matrix3 value in the pre-defined mouse tool local variable <span class=\'code\'>nodeTM</span> . In this case, the position portion of the node&#39;s TM is set to the initial mouse down world position. The <span class=\'code\'>on mouseMove</span> handler sets the width and depth during click 2 and the height during click 3.</p>\n\
<p>The <span class=\'code\'>on buildMesh</span> handler constructs the desired mesh in the TriMesh value in the pre-defined plug-in local variable <span class=\'code\'>mesh</span> . Typically, it does this by building the mesh from scratch each time the handler is called. In the above example, the mesh is initially set to a simple two-face rectangular plane (using <span class=\'code\'>setMesh()</span> ), and then the two faces are extruded up and scaled-down twice to get the simple tower.</p>\n\
<p>The <span class=\'code\'>mesh</span> plug-in local variable is accessible in any of the plug-in&#39;s handlers, but is typically built only in the <span class=\'code\'>on buildMesh</span> handler. You can either modify the existing TriMesh value in place using the TriMesh methods, or construct a new TriMesh value and assign it to the <span class=\'code\'>mesh</span> plug-in local variable. The TriMesh created must be valid or a <strong>3ds Max</strong> crash might occur. All face, vertex, material ID, and texture vertex arrays allocated must be filled in the handler.</p>\n\
<p>There are three additional event handlers that might be implemented for a scripted SimpleObject:</p>\n\
<div class=\'codeBlock\'><pre>on OKtoDisplay do &lt;boolean_expr&gt;\n\
</pre></div><p>If the <span class=\'code\'>OKtoDisplay</span> event handler is implemented, <span class=\'code\'>&lt;boolean_expr&gt;</span> must return <span class=\'code\'>true</span> or <span class=\'code\'>false</span> depending on whether it is OK to display the current mesh. This is useful in situations where a mesh might be in some degenerate state for certain parameter settings and must not be displayed in the viewports. The default implementation is <span class=\'code\'>true</span> . Note that empty meshes are OK to display.</p>\n\
<div class=\'codeBlock\'><pre>on hasUVW do &lt;boolean_expr&gt;\n\
</pre></div><p>If the <span class=\'code\'>hasUVW</span> event handler is implemented, <span class=\'code\'>&lt;boolean_expr&gt;</span> must return <span class=\'code\'>true</span> or <span class=\'code\'>false</span> depending on whether UVW coordinates are present on the mesh. In many primitive objects, a Generate Mapping Coords checkbox is provided for the user to control UVW coordinate generation and the <span class=\'code\'>hasUVW</span> handler expression returns the state of this checkbox. The default implementation returns <span class=\'code\'>true</span> or <span class=\'code\'>false</span> depending on whether the mesh has texture vertices or not. At present, only a single map channel is supported.</p>\n\
<div class=\'codeBlock\'><pre>on setGenUVW &lt;onOff&gt; do &lt;expr&gt;\n\
</pre></div><p>The <span class=\'code\'>setGenUVW</span> event handler is called when <strong>3ds Max</strong> wants the plug-in to automatically generate mapping coordinates. This happens when you first render an object that has a material applied, but not mapping coordinates. It is called with a switch argument <span class=\'code\'>&lt;onOff&gt;</span> , which is <span class=\'code\'>true</span> or <span class=\'code\'>false</span> to turn on or turn off the mapping coordinates. If your plug-in is managing mapping coordinates, it must implement this handler and generate mapping coordinates when called with a <span class=\'code\'>true</span> argument.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` plugin simpleObject TexturePlane name:&quot;TexturePlane&quot; classID:#(0x19a75166, 0x83e3a1c7) category:&quot;MAXScript Examples&quot; ( parameters main rollout:params ( Size type:#worldUnits ui:size default:0 genMapCoords type:#boolean ui:gen_Map_Coords default:false animatable:false u_tile type:#float default:1.0 ui:u_step v_tile type:#float default:1.0 ui:v_step ) rollout params &quot;TexturePlane&quot; ( group &quot;Geometry&quot; ( spinner size &quot;Size:&quot; type:#worldunits range:[0,1000,1] ) group &quot;Mapping&quot; ( spinner u_step &quot;U Tiling&quot; scale:0.01 spinner v_step &quot;V Tiling&quot; scale:0.01 checkbox gen_Map_Coords &quot;Generate Mapping Coords.&quot; ) ) --end roll</p>\n\
<p>--When Max wants to know whether the object has UV coords, --return the value stored in genMapCoords to inform it of --the current UV sate of the plug-in.</p>\n\
<p>on hasUVW do genMapCoords</p>\n\
<p>--When 3ds Max tells the plug-in to turn on UV coordinates --(for example when applying a texture --with &quot;Show Map In Viewport&quot; checked), --this handler will automagically check the checkbutton --connected to our parameter called genMapCoords. --Also, when the user changes the checkbox, --the variable will tell the builMesh to generate coordinates. --Note that the handler will override the manual settings, --for example if a texture has &quot;Show Map In Viewport&quot; enabled, --you cannot actually uncheck the &quot;Generate Mapping Coords.&quot; --checkbox with the mouse!</p>\n\
<p>on setGenUVW bool do genMapCoords = bool</p>\n\
<p>on buildMesh do ( --Generate a simple Quad local vertex_array = #() append vertex_array [-size/2,-size/2,0] append vertex_array [size/2,-size/2,0] append vertex_array [size/2,size/2,0] append vertex_array [-size/2,size/2,0] face_array = #( [1,2,3], [1,3,4] ) setMesh mesh verts:vertex_array faces:face_array --If the checkbox was enabled and we want --coordinates to be generated...</p>\n\
<div class=\'codeBlock\'><pre>if genMapCoords then ( --define the texture vertices \n\
  local uvw_array = #() append uvw_array [0.0,0.0,0.0] append uvw_array [u_tile ,0.0,0.0] append uvw_array [u_tile ,v_tile ,0.0] append uvw_array [0.0,v_tile ,0.0] \n\
  --set the number of vertices \n\
  setNumTVerts mesh uvw_array.count \n\
  --set all vertices \n\
  for v = 1 to uvw_array.count do setTVert mesh v uvw_array[v] \n\
  --build texture faces \n\
  buildTVFaces mesh false \n\
  --set all texture faces (in this case using the mesh faces \n\
  --since we happen to have a one-to-one correspondence \n\
  --between vertices and texture vertices.) \n\
  --This is not always the case though... \n\
  for f = 1 to face_array.count do setTVFace mesh f face_array[f] ) \n\
</pre></div><p>)--end on buildMesh tool create ( on mousePoint click do case click of ( 1: ( nodeTM.translation = gridPoint ) 2: ( #stop) ) on mouseMove click do case click of ( 2: (Size= abs gridDist.x) ) ) )--end plugin</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Here is another example that creates a mesh by first building other temporary objects and using mesh booleans to build the final mesh:</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` plugin simpleObject squareTube name:&quot;SquareTube&quot; classID:#(63445,55332) category:&quot;Scripted Primitives&quot; ( local box1, box2 parameters main rollout:params ( length type:#worldUnits ui:length default:1E-3 width type:#worldUnits ui:width default:1E-3 height type:#worldUnits ui:height default:1E-3 ) rollout params &quot;SquareTube&quot; ( spinner height &quot;Height&quot; type:#worldUnits range:[1E-3,1E9,1E-3] spinner width &quot;Width&quot; type:#worldUnits range:[1E-3,1E9,1E-3] spinner length &quot;Length&quot; type:#worldUnits range:[-1E9,1E9,1E-3] ) on buildMesh do ( if box1 == undefined do (box1 = createInstance box; box2 = createInstance box) box1.height = height; box2.height = height box1.width = width; box2.width = width * 2 box1.length = length; box2.length = length * 2 mesh = box2.mesh - box1.mesh ) tool create ( on mousePoint click do case click of ( 1: nodeTM.translation = gridPoint 3: #stop ) on mouseMove click do case click of ( 2: (width = abs gridDist.x; length = abs gridDist.y) 3: height = gridDist.z ) ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In this example, the parameters and rollouts are handled in a similar manner to the first example, but the <span class=\'code\'>buildMesh</span> handler generates the mesh in an indirect way. The final object is in the form of a rectangular pipe, a box with a box hole through the middle. Two plug-in locals ( <span class=\'code\'>box1</span> and <span class=\'code\'>box2</span> ) are made to contain Box base objects whose size parameters are set according to the plug-in&#39;s parameters ( <span class=\'code\'>box2</span> is the outer box and <span class=\'code\'>box1</span> is the hole). The final mesh is made by boolean subtraction of <span class=\'code\'>box1</span> from <span class=\'code\'>box2</span> . In this case, a separate new mesh is created and assigned to the <span class=\'code\'>mesh</span> plug-in local variable, in contrast to the first example that modified the object&#39;s original mesh directly. Either method is okay.</p>\n\
<p>The <span class=\'code\'>createInstance()</span> method is used to directly create the box base objects. This method creates the geometry associated with the specified object, but does not create a node. This method is used since SimpleObject plug-in must not perform any scene related actions such as, creating scene nodes or building modifier stacks.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";