var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>RCMenu Clauses</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>RCMenu Clauses</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"rcmenu-clauses\"></a></div>\n\
<p>The <span class=\'code\'>&lt;rcmenu_body&gt;</span> of a right-click menu definition is made up of a sequence of scripted right-click menu clauses as follows:</p>\n\
<div class=\'codeBlock\'><pre>&lt;rcmenu_body&gt; ::= { &lt;rcmenu_clause&gt; }+\n\
</pre></div><p>Scripted right-click menu clauses define the components of a scripted right-click menu and can be one of three basic things:</p>\n\
<ul>\n\
<li><p><strong>Local variables, functions or structure definitions</strong> are variables, functions, and structures whose scope is the scripted right-click menu. These locals will exist as long as the scripted right-click menu value exists. The scripted right-click menu value will exist until the scripted right-click menu value is redefined or deleted. Local variables are particularly useful for storing working data associated with the right-click menu such as picked objects.</p></li>\n\
<li><p><strong>User-interface items</strong> are displayed in the right-click menu, such as menu items, separators, and submenus.</p></li>\n\
<li><p><strong>Event handlers</strong> are special kinds of functions that are associated with particular user-interface items. Event handlers specify the processing you want to occur when a user interacts with an user-interface item, for example pressing a menu item or opening a submenu. These user actions generate named <strong>events</strong> and the optional event handler you supply for that event is called when the user action occurs.</p></li>\n\
</ul>\n\
<p>The visibility of locals, and accessing scripted right-click menu locals from external code, are the same as described for utility rollouts, and described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Visibility-of-Locals-Functions.html\' title=\'\'>Visibility of Locals, Functions, Structures, and User-Interface Items in Rollout Code</a> and <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Accessing-Locals-and-Other-Items.html\' title=\'\'>Accessing Locals and Other Items in a Rollout from External Code</a>. In both utility rollouts and scripted right-click menus, the name given to a user-interface item is used to name an automatically constructed local variable that will hold the value representing the item. It is also used to associate event handler functions with the item. One difference between the scooping of these variables is that they are local to the rollout in utility rollouts, and local to the scripted right-click menu in scripted right-click menus. This means that all user-interface items in a scripted right-click menu must have a unique name within the scripted right-click menu, even for those items present in a <span class=\'code\'>subMenu</span> .</p>\n\
<p>Formally, the syntax of a <span class=\'code\'>&lt;rcmenu_clause&gt;</span> is defined as follows:</p>\n\
<div class=\'codeBlock\'><pre>&lt;rcmenu_clause&gt; ::= &lt;local_variable_decl&gt; | &lt;local_function_decl&gt; | &lt;local_struct_decl&gt; | &lt;user_interface_item&gt; | &lt;event_handler&gt;\n\
</pre></div><div class=\'section\'><a id=\"locals\"></a><h2 id=\"locals\">Locals</h2></div>\n\
<p>A <span class=\'code\'>&lt;local_variable_decl&gt;</span> , <span class=\'code\'>&lt;local_function_decl&gt;</span> , and <span class=\'code\'>&lt;local_struct_decl&gt;</span> are exactly the same as local variable, function, and structure definitions in MAXScript:</p>\n\
<div class=\'codeBlock\'><pre>&lt;local_variable_decl&gt; ::= local &lt;decl&gt; { , &lt;decl&gt; } \n\
&lt;decl&gt; ::= &lt;name&gt; [ = &lt;expr&gt; ] -- optional initial value\n\
&lt;local_function_decl&gt; ::= [ mapped ](function | fn) &lt;name&gt; { &lt;argument&gt; } = &lt;expr&gt;\n\
&lt;local_struct_decl&gt; ::= struct &lt;name&gt; ( &lt;member&gt; { , &lt;member&gt; })&lt;member&gt; ::= ( &lt;name&gt; [ = &lt;expr&gt; ] | &lt;local_function_decl&gt; )\n\
<blockquote>\n\
</blockquote></pre></div><p><strong>EXAMPLES OF THE ABOVE (IN ORDER) ARE:</strong></p>\n\
<p>``` local numSelected</p>\n\
<p>```</p>\n\
<p>``` local numSelected = 0</p>\n\
<p>```</p>\n\
<p>``` fn onlyOneSelected = selection.count == 1</p>\n\
<p>```</p>\n\
<p>``` struct parents (mother=&quot;&quot;,father=&quot;&quot;)</p>\n\
<p>```</p>\n\
\n\
<p>Global variables cannot be declared as a scripted right-click menu clause, however they can be declared within event-handler scripts. If you need to ensure that a variable name references a global variable, declare the variable name as global immediately before defining the right-click menu in your script.</p>\n\
<p>When writing scripts, it is good programming practice to explicitly declare your local and global variables. Implicit declaration is provided as a short-hand, typically used when working in the Listener interactively or developing short scripts. When developing extended scripts, explicitly declaring variables can reduce errors and improve readability of the code. It is also recommend that you declare as local all variables unless you really want them to be global variables. The reasons for this are described in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Scope-of-Variables.html\' title=\'\'>Scope of Variables</a>.</p>\n\
<div class=\'section\'><a id=\"user-interface-items\"></a><h2 id=\"user-interface-items\">User-Interface Items</h2></div>\n\
<p>A <span class=\'code\'>&lt;user_interface_item&gt;</span> defines an individual menu item, separator, or submenu user-interface item that will appear in the right-click menu. These user-interface items are described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Right-Click-Menus/RCMenu-User-Interface-Items.html\' title=\'\'>RCMenu User-Interface Items</a>.</p>\n\
<div class=\'section\'><a id=\"event-handlers\"></a><h2 id=\"event-handlers\">Event Handlers</h2></div>\n\
<p>An <span class=\'code\'>&lt;event_handler&gt;</span> is a special function definition local to a scripted right-click menu that you provide to handle the processing you want to occur when a user clicks on a menu item. This user action generates a named event and any event handler you supply for that event is called when the action occurs. The syntax for defining a handler is as follows:</p>\n\
<div class=\'codeBlock\'><pre>on &lt;item_name&gt; &lt;event_name&gt; do &lt;expr&gt;\n\
</pre></div><p>The <span class=\'code\'>&lt;item_name&gt;</span> specifies the name of the item for which this handler is connected. The <span class=\'code\'>&lt;event_name&gt;</span> specifies the type of event to be handled.</p>\n\
<p>There is only one type of user-interface item event:</p>\n\
<div class=\'codeBlock\'><pre>picked\n\
</pre></div><p>The <span class=\'code\'>picked</span> handler expression is executed when a menu item is picked from the right-click menu. Any MAXScript action like creating a object, adding a modifier, and so on can be performed in this expression.</p>\n\
<p>In addition to the event handlers you specify for particular menu items in a right-click menu, you can define a handler function that is called when the entire right-click menu is first opened by the user. This event handler is useful for initialization code. The syntax for this event handler is as follows:</p>\n\
<div class=\'codeBlock\'><pre>on &lt;rcmenu&gt; open do &lt;expr&gt;\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";