var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Scripted Utilities and Rollouts</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Scripted Utilities and Rollouts</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"scripted-utilities-and-rollouts\"></a></div>\n\
<p>MAXScript provides a set of classes and functions and some special syntax to allow you to construct custom rollouts that can be incorporated into the existing <strong>3ds Max</strong> user interface. You typically use custom rollouts to provide a point-and-click interface to a tool that you have written or want to write in MAXScript, so users of your tool don&#39;t have to work with it at the script level.</p>\n\
<p>There are several places in the <strong>3ds Max</strong> user interface where you can install scripted rollouts:</p>\n\
<ul>\n\
<li><p>In the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Scripted-Utility-Panels.html\' title=\'\'>Utilities panel</a>.Use the <span class=\'code\'>utility</span> definition construct in MAXScript to define and install scripted utilities. Once installed, they appear in the Utilities list at the bottom of the MAXScript rollout. If the user selects a utility in this list, its rollout(s) appear below the MAXScript rollout and functions just like a plug-in utility. This was the original way of creating scripted utilities when MAXScript was first introduced in <strong>3ds Max 2</strong>. The main benefit of using a scripted utility is that it can be created very fast and does not require much management code to add rollouts and perform operations onto the scene so it is a good way to start into scripting. The main drawback is that the Utilities rollout is narrow and rather hidden and cannot be open at the same time as the Create and Modify tabs of the Command Panel.</p></li>\n\
<li><p>In special modeless <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-Floater-Windows.html\' title=\'\'>rollout floater windows</a> that you can create with the <span class=\'code\'>newRolloutFloater()</span> function. These windows appear on the desktop and function in a way similar to the Material Editor and the Selection floater in <strong>3ds Max</strong>. You can click to alternate between them and the main <strong>3ds Max</strong> user interface. You create individual rollout(s) for these windows using the <strong>rollout</strong> definition construct in MAXScript and install them in a rollout floater window using the <span class=\'code\'>addRollout()</span> function.</p></li>\n\
<li><p>In floating <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Dialogs/CreateDialog.html\' title=\'\'>scripted Dialogs</a>. Dialogs are not a holder for rollouts but a special display form of an existing rollout. They can be created out of a rollout using the <span class=\'code\'>createDialog()</span> function.</p></li>\n\
<li><p>In <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/Scripted-Plug-ins-1.html\' title=\'\'>scripted plugins</a>. Scripted plugins can contain one or more rollouts which will be displayed inside the Command Panel&#39;s Create and Modify tabs and can be linked to Parameter Blocks for automatic animation track management.</p></li>\n\
<li><p>In <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Custom-Attributes/Scripted-Custom-Attributes.html\' title=\'\'>Custom Attributes</a> added to scene objects or modifiers. Custom Attributes are a special form of a Parameter Block that can be attached to other objects.</p></li>\n\
</ul>\n\
<p>Choosing which place is best for your scripted rollouts depends on a number of factors. It is best to keep them in the Utilities panel if possible, as that maximizes the use of the screen and is consistent with the <strong>3ds Max</strong> user interface conventions. However sometimes it is useful to have them in a modeless window if the user of your tool needs to move between the various command panels while using the tool. In some cases, you might want to provide a &quot;float me&quot; button on a scripted Utility rollout, similar to the Color Clipboard utility, so the user can choose to display the rollouts in a rollout floater window or in the Utilities panel.</p>\n\
<p>The following topics provide information about scripting utility panels and rollout floater windows:</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Scripted-Utility-Panels.html\' title=\'\'>Scripted Utility Panels</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Utility-Clauses.html\' title=\'\'>Utility Clauses</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Managing-Multiple-Rollouts-in-a.html\' title=\'\'>Managing Multiple Rollouts in a Scripted Utility</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-Clauses.html\' title=\'\'>Rollout Clauses</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Utility-and-Rollout-Properties.html\' title=\'\'>Utility and Rollout Properties, Methods, and Event Handlers</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-User-Interface-Controls.html\' title=\'\'>Rollout User-Interface Controls</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Visibility-of-Locals-Functions.html\' title=\'\'>Visibility of Locals, Functions, Structures, and User-Interface Items in Rollout Code</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Accessing-Locals-and-Other-Items.html\' title=\'\'>Accessing Locals and Other Items in a Rollout from External Code</a></p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-Floater-Windows.html\' title=\'\'>Rollout Floater Windows</a></p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";