var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Managing Multiple Rollouts in a Scripted Utility</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Managing Multiple Rollouts in a Scripted Utility</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"managing-multiple-rollouts-in-a-scripted-utility\"></a></div>\n\
<p>MAXScript includes support for managing multiple rollouts in one utility, which is useful in large scripted utilities that are unwieldy in one rollout. There is one main rollout defined by the user-interface items in the utility definition. The other rollouts are defined as nested rollouts within the body of the utility definition. These other rollouts can be added to and removed from the Utilities panel under script control.</p>\n\
<p>You can define extra rollouts with the <span class=\'code\'>rollout</span> clause inside a utility definition:</p>\n\
<div class=\'codeBlock\'><pre>utility foo &quot;name&quot;\n\
(\n\
local ...\n\
spinner ...\n\
...\n\
rollout baz &quot;name&quot;\n\
(\n\
local ...\n\
checkbox ..\n\
on ...\n\
)\n\
...\n\
)\n\
\n\
</pre></div><p>Such nested rollouts can contain anything that a utility definition can contain with the exception of further nested rollouts. Nested rollouts are not automatically opened or closed when the parent utility rollout opens and closes. You need to explicitly do this in the open and close handlers, or other handlers or functions in the utility.</p>\n\
<p>There are two functions for this:</p>\n\
<div class=\'codeBlock\'><pre>addRollout &lt;rollout&gt; [ rolledUp:&lt;boolean&gt; ] removeRollout &lt;rollout&gt;\n\
</pre></div><p>The <span class=\'code\'>rolledUp:</span> parameter on the <span class=\'code\'>addRollout()</span> function specifies whether the rollout is added in a rolled-up state. This defaults to <span class=\'code\'>false</span> , so the rollout is added fully opened. The nested rollouts are arranged in the order of <span class=\'code\'>addRollout()</span> calls, so take care in sequencing these to ensure the order you want.</p>\n\
<p>The nested rollouts do not automatically get removed when the main utility rollout is closed. You must make sure they are explicitly removed, typically in the close handler for the main utility.</p>\n\
<p>To always open and close extra rollouts when the main utility is opened and closed, place <span class=\'code\'>addRollout()</span> and <span class=\'code\'>removeRollout()</span> calls in the main utility open and close handlers.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` on foo open do ( ... addRollout panel_1 addRollout panel_2 rolledUp:true ... ) on foo close do ( ... removeRollout panel_1 removeRollout panel_2 ... )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Calling <span class=\'code\'>removeRollout()</span> on an already closed rollout is OK and does nothing. If during utility development, you forget to close a nested rollout, closing the entire MAXScript utility will remove any remaining open scripted rollouts.</p>\n\
<p>Because these rollout definitions are nested within a utility, all the locals, functions, and other items in the utility are visible to nested rollouts, following the standard nested scoping in MAXScript. This means you can &quot;reach out&quot; and access the utility’s locals, user-interface control items, and functions.</p>\n\
<p>Conversely, user-interface control items and locals in nested rollouts are exposed as properties of that rollout, so code in the main utility or other rollouts can &quot;reach in&quot; and access them. In the following example, the spinner <span class=\'code\'>bar</span> change handler looks at the state of a check box in the nested rollout <span class=\'code\'>baz</span> :</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` utility foo &quot;name&quot; ( local ... local ... spinner bar ... ... rollout baz &quot;name&quot; ( local ... checkbox baz_enable ... on ... ) ... on bar changed val do if baz.baz_enable.checked == true then...</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>You can control the grouping of rollouts by supplying a <span class=\'code\'>category:&lt;integer&gt;</span> header parameter before the opening parenthesis of the rollout body. The category numbers order the rollouts. In the following example, the rollouts are defined and added in a certain order, but displayed in another based on their category number:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` ( rollout first_rollout &quot;1st Rollout&quot; category:2 ( label rights &quot;First&quot; ) rollout second_rollout &quot;2nd Rollout&quot; category:1 ( label second &quot;Second&quot; ) rf = newRolloutFloater &quot;Rollout Order Test&quot; 200 140 addRollout first_rollout rf addRollout second_rollout rf )</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";