var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Rollout Clauses</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Rollout Clauses</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"rollout-clauses\"></a></div>\n\
<p>Rollout clauses define the components of a rollout (utilities are considered a special case of rollouts) and can be one of these four basic things:</p>\n\
<ul>\n\
<li><p><strong>Local variables, functions, or structure definitions</strong> are variables, functions, and structures whose scope is the rollout. These locals will exist as long as the rollout value exists. The rollout value will exist until a new value is assigned to the rollout’s variable name. Local variables are particularly useful for storing the working data associated with the rollout such as, picked objects or arrays of generated objects. The visibility of locals and accessing rollout locals from external code are described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Visibility-of-Locals-Functions.html\' title=\'\'>Visibility of Locals, Functions, Structures, and User-Interface Items in Rollout Code</a> and <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Accessing-Locals-and-Other-Items.html\' title=\'\'>Accessing Locals and Other Items in a Rollout from External Code</a>.</p></li>\n\
<li><p><strong>Mouse tools</strong> are used to perform a set of actions based on mouse clicks in the <strong>3ds Max</strong> viewports and are described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Mouse-Tools.html\' title=\'\'>Scripted Mouse Tools</a>.</p></li>\n\
<li><p><strong>User-interface control items</strong> are elements displayed in the rollout such as, buttons, spinners, and list boxes.</p></li>\n\
<li><p><strong>Event handlers</strong> are special functions associated with certain user-interface control items. Event handlers specify the processing that must occur when a user interacts with a user-interface item. For example, pressing a button or adjusting a spinner. These user actions generate named events and the optional event handler you supply for that event is called when the user action occurs. For example, if you press a button named <strong>DoIt</strong>, the <strong>on DoIt pressed</strong> event handler expression is executed.</p></li>\n\
</ul>\n\
<p>Formally, the syntax of a <span class=\'code\'>&lt;rollout_clause&gt;</span> is defined as follows:</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout_clause&gt; ::= &lt;local_variable_decl&gt; | &lt;local_function_decl&gt; | &lt;local_struct_decl&gt; | &lt;global_variable_decl&gt; | &lt;mousetool&gt; | &lt;user_interface_item&gt; | &lt;item_group&gt; | &lt;event_handler&gt;\n\
</pre></div><p><strong>Locals</strong></p>\n\
<p>A <span class=\'code\'>&lt;local_variable_decl&gt;</span> , <span class=\'code\'>&lt;global_variable_decl&gt;</span> , <span class=\'code\'>&lt;local_function_decl&gt;</span> , and <span class=\'code\'>&lt;local_struct_decl&gt;</span> are exactly the same as local and global variable, local function, and local structure definitions in MAXScript:</p>\n\
<div class=\'codeBlock\'><pre>&lt;local_variable_decl&gt; ::= local &lt;decl&gt; { , &lt;decl&gt; } \n\
&lt;decl&gt; ::= &lt;name&gt; [ = &lt;expr&gt; ] -- optional initial value\n\
&lt;global_variable_decl&gt; ::= global &lt;decl&gt; { , &lt;decl&gt; } \n\
&lt;decl&gt; ::= &lt;name&gt; [ = &lt;expr&gt; ] -- optional initial value\n\
&lt;local_function_decl&gt; ::= [ mapped ](function | fn) &lt;name&gt; { &lt;argument&gt; } = &lt;expr&gt;\n\
&lt;local_struct_decl&gt; ::= struct &lt;name&gt; ( &lt;member&gt; { , &lt;member&gt; } )\n\
&lt;member&gt; ::= ( &lt;name&gt; [ =&lt;expr&gt; ] | &lt;local_function_decl&gt; )\n\
</pre></div><p>Examples of the previous (in order) are:</p>\n\
<div class=\'codeBlock\'><pre>local numSelected\n\
global foo\n\
local numSelected = 0\n\
fn onlyOneSelected = (selection.count == 1)\n\
struct parents (mother=&quot;&quot;, father=&quot;&quot;)\n\
\n\
</pre></div><p>When writing scripts, it is a good programming practice to explicitly declare your local and global variables. Implicit declaration is provided as a short-hand, typically used when working in the Listener interactively or developing short scripts. When developing extended scripts, explicitly declaring variables can reduce errors and improve readability of the code. It is also recommend to declare all variables as local unless you really want them to be global variables. The reasons for this are described in <a href=\'#!/url=./developer/MAXScript-Language-Reference/Variables-Assignment-and-Scope/Scope-of-Variables.html\' title=\'\'>Scope of Variables</a>.</p>\n\
<p><strong>User-Interface Items</strong></p>\n\
<p>A <span class=\'code\'>&lt;user_interface_item&gt;</span> defines an individual button, check box, spinner, or other user-interface control item that will appear in the rollout. These user-interface control items are described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-User-Interface-Controls.html\' title=\'\'>Rollout User-Interface Controls</a>.</p>\n\
<p>An <span class=\'code\'>&lt;item_group&gt;</span> is used to place a sequence of user-interface items in a labeled box in the rollout, so you can organize large rollouts into meaningful groups.</p>\n\
<p><strong>Its syntax is:</strong></p>\n\
<div class=\'codeBlock\'><pre>group &lt;group_label_string&gt; \n\
( \n\
{ &lt;user_interface_item&gt; } \n\
) \n\
</pre></div><p>The use of <span class=\'code\'>group</span> is shown in the following script:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` utility Infinity &quot;Game Utilities&quot; ( group &quot;Lighting&quot; ( label label1d &quot;Number of Day lights:&quot; across:2 offset:[10,0] label label2d &quot;0&quot; offset:[10,0] label label1n &quot;Number of Night lights:&quot; across:2 offset:[13,0] label label2n &quot;0&quot; offset:[10,0] label label3 Radiobuttons WhichOn &quot;Active Lights:&quot; labels:#(&quot;Day&quot;,&quot;Night&quot;) ) group &quot;Scene Data Dump&quot; ( Button scenedump &quot;Dump Scene Data&quot; ) group &quot;Exclusions/Inclusions&quot; ( Button DispExcl &quot;Unhide Exclusions&amp;Inclusions&quot; ) group &quot;Camera Mattes&quot; ( radiobuttons CamMatte labels:#(&quot;None&quot;,&quot;1&quot;,&quot;2&quot;,&quot;3&quot;,&quot;4&quot;) columns:3 ) Button resetb &quot;Reset&quot; ) createDialog infinity</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The Utilities panel rollout that the previous script generates looks like the following figure.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-E0CDD9A7-9855-440A-A567-A0AB1C53AEE3-low.gif\' title=\'\'></div>\n\
<p><strong>Game Utilities rollout using group user-interface item</strong></p>\n\
<p>Note: A group is technically not an user-interface control. If you want to use a group that is an interface control, consider the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-User-Interface-Controls/Rollout-User-Interface-Controls-3/GroupBox-UI-Control.html\' title=\'\'>GroupBox</a> user-interface control.</p>\n\
<p>Internally, a group is implemented as two controls of <span class=\'code\'>GroupStartControl</span> and <span class=\'code\'>GroupEndControl</span> classes, enclosing the grouped user-interface controls like brackets.</p>\n\
<p>In <strong>3ds Max 8 and higher</strong>, you can access and change the <span class=\'code\'>.caption</span> property of either controls if you access them using the <span class=\'code\'>.controls</span> property of a rollout. This was not possible in the previous versions.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` rollout test &quot;Test&quot; ( group &quot;Group&quot; ( button pressme &quot;Press Me&quot; ) ) createDialog test test.controls test.controls[1].caption = &quot;XXX&quot; --this is the GroupStartControl test.controls[3].caption = &quot;Test me&quot; --this is the GroupEndControl --Both change the group&#39;s caption!</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In <strong>3ds Max 2010 and higher</strong>, user Interface controls&#39; event handlers can be included inside a Group&#39;s body. In previous versions of <strong>3ds Max</strong>, including an even handler inside the group caused a Syntax Error.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` rollout test &quot;Test&quot; ( group &quot;Group&quot; ( button pressme &quot;Press Me&quot; --In versions prior to 3ds Max 2010, --this would have caused a Syntax Error: on pressme pressed do print &quot;Pressed!&quot; ) --because the handler is inside the group&#39;s body.Now allowed. ) createDialog test</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Event Handlers</strong></p>\n\
<p>An <span class=\'code\'>&lt;event_handler&gt;</span> is a special function definition local to a utility or rollout that you provide to handle the processing that must occur when a user performs an action on a user-interface item. For example, event handlers are called when the user presses a button or adjusts a spinner, opens or closes the utility or rollout, or resizes or moves a rollout floater window. These user actions generate named events and any event handler you supply for that event is called when the action occurs. The syntax for defining an event handler is as follows:</p>\n\
<div class=\'codeBlock\'><pre>on &lt;item_name&gt; &lt;event_name&gt; [ &lt;argument&gt; ] do &lt;expr&gt;\n\
</pre></div><p>The <span class=\'code\'>&lt;item_name&gt;</span> specifies the name of the item to which this handler is connected. The <span class=\'code\'>&lt;event_name&gt;</span> specifies the type of event to be handled and the optional <span class=\'code\'>&lt;argument&gt;</span> is used to pass various values to the handler. The possible events you can specify depend on the item type. These events include:</p>\n\
<div class=\'codeBlock\'><pre>pressed changed picked entered selected resized moved open close\n\
</pre></div><p>The available events and passed arguments are defined in the description for each user-interface item type, as listed in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-User-Interface-Controls.html\' title=\'\'>Rollout User-Interface Controls</a>. The available events and passed arguments for utilities and rollouts are described in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Utility-and-Rollout-Properties.html\' title=\'\'>Utility and Rollout Properties, Methods, and Event Handlers</a>.</p>\n\
<p>You can access and invoke the event handler functions in a scripted rollout by referring to the handlers as properties on the user-interface items. The event handler functions are accessed as sub-properties of the item using the event name as the sub-property name. For example, if a scripted rollout has a check box item named <span class=\'code\'>foo</span> , and an <span class=\'code\'>on foo changed</span> event handler is defined, you can invoke the handler as follows:</p>\n\
<div class=\'codeBlock\'><pre>foo.changed true -- call foo&#39;s &#39;changed&#39; handler function, passing argument of true\n\
</pre></div><p>Or, if a scripted rollout has a button item named <span class=\'code\'>apply</span> , and an <span class=\'code\'>on apply pressed</span> event handler is defined, you can invoke the handler as follows:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` apply.pressed() -- call apply’s &#39;pressed&#39; handler function, no argument.</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>You can access an event handler function as a sub-property of the item.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` ApplyPressedEH = apply.pressed</p>\n\
<p>```</p>\n\
<p>stores a copy of the <span class=\'code\'>on apply pressed</span> event handler function value to variable <span class=\'code\'>ApplyPressedEH</span> . The event handler functions can only be <strong>read</strong>. You <strong>cannot set</strong> the handler function to another user-defined function.</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";