var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Checkbutton UI Control</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Checkbutton UI Control</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"checkbutton-ui-control\"></a></div>\n\
<p>A <strong>checkbutton control</strong> is used to place a press button on the rollout that has two states, on and off, just like a check box. The user can click to successively switch between states.</p>\n\
<p><strong>The syntax is</strong>:</p>\n\
<div class=\'codeBlock\'><pre>checkbutton &lt;name&gt; [&lt;caption&gt;] [ highlightColor:&lt;color&gt; ] \\ \n\
[ toolTip:&lt;string&gt; ] [ checked:&lt;boolean&gt; ] [ images:&lt;image_spec_array&gt; ] \\ \n\
[ border:&lt;boolean&gt; ]\n\
</pre></div><p>The default alignment of <span class=\'code\'>checkbutton</span> items is <span class=\'code\'>#center</span> .</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p><span class=\'code\'>rollout test &quot;Test&quot;   (   checkbutton setup &quot;Setup&quot; checked:true tooltip:&quot;Opens setup panels&quot;   on setup changed state do   if state == on then     openRollout setup_pan   else     closeRollout setup_pan   )</span></p>\n\
</blockquote>\n\
<p><strong>Parameters:</strong></p>\n\
<div class=\'codeBlock\'><pre>checked:\n\
</pre></div><p>Initial state of the check button, defaults to <span class=\'code\'>off</span> .</p>\n\
<div class=\'codeBlock\'><pre>highlightColor:\n\
</pre></div><p>The background color of the check button in its pressed (or on) state, defaults to a light-gray wash in keeping with <strong>3ds Max</strong> user-interface conventions.</p>\n\
<div class=\'codeBlock\'><pre>toolTip:\n\
</pre></div><p>Provides text for a tooltip for the check button (no tooltip if unsupplied).</p>\n\
<div class=\'codeBlock\'><pre>images:\n\
</pre></div><p>An image-specification array for providing bitmap images for the check button. If this is specified, the <span class=\'code\'>&lt;label&gt;</span> is ignored and the contents of the check button are replaced with the bitmaps.</p>\n\
<p>The form is:</p>\n\
<div class=\'codeBlock\'><pre>images:#(&lt;image&gt;, &lt;maskImage&gt;, &lt;count_integer&gt;, &lt;enabled_out_image_index&gt;, &lt;enabled_in_image_index&gt;, &lt;disabled_out_image_index&gt;, &lt;disabled_in_image_index&gt;)\n\
</pre></div><p>where <span class=\'code\'>&lt;image&gt;</span> and <span class=\'code\'>&lt;maskImage&gt;</span> can be either a bitmap file-name string or a MAXScript bitmap value. <span class=\'code\'>&lt;count_integer&gt;</span> specifies the number of sub-images in the bitmaps, and the <span class=\'code\'>image_index</span> values specify which sub-image in the bitmaps is to be used for each of the four check button states.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` bm1 = render camera:$cam01 outputSize:[80,60] ... checkbutton foo images:#(bm1, undefined, 1, 1, 1, 1, 1)</p>\n\
<p>```</p>\n\
<p>would use a rendering as the check button image, and</p>\n\
<p>``` checkbutton decay images:#(&quot;dcybtns.bmp&quot;,&quot;dcymask.bmp&quot;, 6, 1, 4, 1, 4)</p>\n\
<p>```</p>\n\
<p>would use sub-images 1 and 4 of bitmaps <span class=\'code\'>dcybtns.bmp</span> and <span class=\'code\'>dcymask.bmp</span> for the out and in states of the check button, respectively.</p>\n\
<p>See also <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-User-Interface-Controls/Image-Buttons.html\' title=\'\'>Image Buttons</a>.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>border:\n\
</pre></div><p>When set to true or not specified, the checkbutton will be drawn with a border. This was the default behavior prior to <strong>3ds Max 2009</strong>.</p>\n\
<p>When set to false, the checkbutton will be drawn without a border, making it one with the UI background. If the checkbutton is enabled, the border will appear when the checkbutton is pressed, checked, if its <span class=\'code\'>.checked</span> property is set to true and upon mouseover.</p>\n\
<p>Available in <strong>3ds Max 2009 and higher</strong>.</p>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;checkbutton&gt;.checkedBoolean\n\
</pre></div><p>The state of the check button, on ( <span class=\'code\'>true</span> ) or off ( <span class=\'code\'>false</span> ).</p>\n\
<div class=\'codeBlock\'><pre>&lt;checkbutton&gt;.state Boolean\n\
</pre></div><p>Synonym for <span class=\'code\'>.checked</span></p>\n\
<div class=\'codeBlock\'><pre>&lt;checkbutton&gt;.images Array\n\
</pre></div><p>Sets the image-specification array for the check button. This property is <strong>write-only</strong>.</p>\n\
<p>Setting the value to <span class=\'code\'>undefined</span> will set the control back to displaying its caption rather than images in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;checkbutton&gt;.width Integer\n\
</pre></div><p>Gets or sets the checkbutton&#39;s width, in pixels. Available in <strong>3ds Max 2019 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;checkbutton&gt;.height Integer\n\
</pre></div><p>Gets or sets the checkbutton&#39;s height, in pixels. Available in <strong>3ds Max 2019 and higher</strong>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` -- re-render, update button bm1 = render() foo.images = #(bm1, undefined, 1, 1, 1, 1, 1)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;checkbutton&gt;. String \n\
                tooltip\n\
</pre></div><p>Get/set the tooltip string of the checkbutton.</p>\n\
<p>Available in <strong>3ds Max 9</strong> and higher.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` --Evaluate this script, then roll over the checkbutton to read the tooltip. --Check the checkbutton, roll over again to see the new tooltip. --Uncheck the checkbutton and roll over once again to see the new tooltip. ( rollout test &quot;Test&quot; ( checkbutton chk_test &quot;Check Me!&quot; tooltip:&quot;This is a tooltip&quot; on chk_test changed state do chk_test.tooltip = if state then &quot;I am checked!&quot; else &quot;I am unchecked!&quot; ) createDialog test )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Events:</strong></p>\n\
<div class=\'codeBlock\'><pre>on &lt;checkbutton&gt; changed &lt;arg&gt; do &lt;expr&gt;\n\
</pre></div><p>Called when the user clicks the check button to change its state. The <span class=\'code\'>&lt;arg&gt;</span> argument will contain the new state of the check button, on ( <span class=\'code\'>true</span> ) or off ( <span class=\'code\'>false</span> ).</p>\n\
<p>Note: The <span class=\'code\'>&lt;arg&gt;</span> is a local variable in the context of the event handler - you can use it inside the handler to act according to the new state of the checkbutton.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` utility testCheckButton &quot;Test The CheckButton&quot; ( checkbutton myCheckButton &quot;Check Me!&quot; -- theState is a user variable name that will contain the state -- of the checkbox whenever the change handler is executed on myCheckButton changed theState do ( if theState == true then myCheckButton.text = &quot;Uncheck Me!&quot; else myCheckButton.text = &quot;Check Me!&quot; ) )--end utility</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>on &lt;checkbutton&gt; rightclick do &lt;expr&gt;\n\
</pre></div><p>Called when the right mouse button is released over the button. Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";