var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Listbox UI Control</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Listbox UI Control</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"listbox-ui-control\"></a></div>\n\
<p>A <strong>Listbox control</strong> is used to place a list box in the rollout.</p>\n\
<p>This is another variant of the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-User-Interface-Controls/Rollout-User-Interface-Controls-3/Dropdownlist-UI-Control.html\' title=\'\'>drop-down list</a> in which the list is always fully displayed in the rollout.</p>\n\
<p>Unlike <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Rollout-User-Interface-Controls/Rollout-User-Interface-Controls-3/Combobox-UI-Control.html\' title=\'\'>Combobox</a> it has no edit-text field at the top and it is just a simple scrollable list. The user can scroll the list or click to select an item.</p>\n\
<p><strong>The syntax is:</strong></p>\n\
<div class=\'codeBlock\'><pre>listbox &lt;name&gt; [&lt;caption&gt;] [items:&lt;array_of_strings&gt;] [selection:&lt;number&gt;] [height:&lt;number&gt;] [readOnly:&lt;boolean&gt;] [toolTip:&lt;string&gt;]     \n\
</pre></div><p>The default alignment of <span class=\'code\'>listbox</span> items is <span class=\'code\'>#left</span> .</p>\n\
<p><strong>Parameters:</strong></p>\n\
<div class=\'codeBlock\'><pre>items:   \n\
</pre></div><p>The array of text strings that are the items in the list.</p>\n\
<div class=\'codeBlock\'><pre>selection: \n\
</pre></div><p>The 1-based number of the currently selected item in the list. The default selection value is 1.</p>\n\
<div class=\'codeBlock\'><pre>height: \n\
</pre></div><p>The overall height of the <span class=\'code\'>listbox</span> in number of item lines. Defaults to 10 lines. To have a <span class=\'code\'>listBox</span> display exactly <span class=\'code\'>N</span> items, set height to <span class=\'code\'>N</span> .</p>\n\
<p>The minimum height value is clamped to 1 line.</p>\n\
<div class=\'codeBlock\'><pre>readOnly: \n\
</pre></div><p>When set to true, the user cannot pick items from the list. When false or not specified, the user can pick items from the list.</p>\n\
<div class=\'codeBlock\'><pre>toolTip:\n\
</pre></div><p>Provides text for a tooltip for the <span class=\'code\'>listbox</span>; no tooltip if unsupplied. Available in <strong>in 3ds Max 2017 and higher</strong>.</p>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;listbox&gt;.items Array Of Strings \n\
</pre></div><p>The item string array.</p>\n\
<div class=\'codeBlock\'><pre>&lt;listbox&gt;.selection Integer \n\
</pre></div><p>The currently selected item number, 1-based. If the items list is an empty array, this value is 0.</p>\n\
<div class=\'codeBlock\'><pre>&lt;listbox&gt;.selected String \n\
</pre></div><p>The text of the currently selected item. Can be used to replace individual items with resetting the entire <span class=\'code\'>items</span> array. If the items list is an empty array, this value is <span class=\'code\'>undefined</span> .</p>\n\
<div class=\'codeBlock\'><pre>&lt;listbox&gt;.readOnly \n\
</pre></div><p>When set to <span class=\'code\'>true</span> , the user cannot pick items from the list. When <span class=\'code\'>false</span> , the user can pick items from the list.</p>\n\
<div class=\'codeBlock\'><pre>&lt;listbox&gt;.width Integer \n\
</pre></div><p>Get/set the width of the listbox list window in pixels.</p>\n\
<div class=\'codeBlock\'><pre>&lt;listbox&gt;.height Integer \n\
</pre></div><p>Get/set the height of the listbox list window in pixels.</p>\n\
<p>Note: As constructor parameter, <span class=\'code\'>height:</span> specifies the height <strong>in lines of text</strong>, while the <span class=\'code\'>.height</span> property specifies the <strong>height in pixels</strong>!</p>\n\
<p><strong>Events</strong></p>\n\
<div class=\'codeBlock\'><pre>on &lt;listbox&gt; selected &lt;arg&gt; do &lt;expr&gt; \n\
</pre></div><p>Called when the user selects an item in the list. The <span class=\'code\'>&lt;arg&gt;</span> argument contains the new current selection item number.</p>\n\
<div class=\'codeBlock\'><pre>on &lt;listbox&gt; doubleClicked &lt;arg&gt; do &lt;expr&gt; \n\
</pre></div><p>Called when the user double-clicks on an item in the list. Note that the <span class=\'code\'>on selected</span> handler is always called on single clicks and on the first click of a double-click. The <span class=\'code\'>&lt;arg&gt;</span> argument contains the number of the item double-clicked.</p>\n\
<div class=\'codeBlock\'><pre>on &lt;listbox&gt; rightClick [&lt;arg&gt;] do &lt;expr&gt; \n\
</pre></div><p>Called when the user right-clicks an item in the list.</p>\n\
<p>If the optional <span class=\'code\'>&lt;arg&gt;</span> argument is specified, it will contain the index of the right-clicked item.</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<blockquote>\n\
<p><strong>LISTBOX EXAMPLE:</strong></p>\n\
<p>``` rollout objectKiller &quot;Object Killer&quot; ( --Define a list box, collect the names of all scene objects and --assign them to the items array listbox objectToKill &quot;Objects:&quot; items:(for o in objects collect o.name) --If the user clicked a name on the list, --get the name from the .items array by index --then get the node by name and select it. --COMPARE to the doubleClicked handler below which performs a --similar task using a slightly different approach. --Both ways are valid! on objectToKill selected nameIndex do select (getNodeByName objectToKill.items[nameIndex]) on objectToKill doubleClicked itm do ( --Get node using its name from the .selected property and delete it: delete (getNodeByName objectToKill.selected) --Get the items into a temporary array: temp = objectToKill.items --Delete the doubleckicked item by index --the local variable itm contains the index! deleteItem temp itm --Assign the result back to the items array: objectToKill.items = temp ) ) createDialog objectKiller--create a dialog from the rolloutParameters</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-B268B6B1-BF39-4C81-BD71-69FDC4DCADE6-low.gif\' title=\'\'></div>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";