var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Slider UI Control</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Slider UI Control</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"slider-ui-control\"></a></div>\n\
<p>A <strong>slider control</strong> is used to place a slider on the rollout, as an alternative to a spinner. The user can drag the slider&#39;s pointer around to set its value.</p>\n\
<p><strong>The syntax is:</strong></p>\n\
<div class=\'codeBlock\'><pre>slider &lt;name&gt; [&lt;caption&gt;] [range:[min,max,val]] [type:&lt;#float | #integer&gt;] [ticks:10][orient:&lt;#horizontal | #vertical&gt;] [height:80] [controller:(&lt;controller&gt;)] [toolTip:&lt;string&gt;]   \n\
</pre></div><p>The default alignment of <span class=\'code\'>slider</span> items is <span class=\'code\'>#center</span> .</p>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<div class=\'codeBlock\'><pre>slider tilt &quot;Head tilt&quot; orient:#vertical ticks:0 range:[-30,30,0] \n\
on tilt changed val do $head.bend.angle = val\n\
\n\
</pre></div><p><strong>Parameters:</strong></p>\n\
<div class=\'codeBlock\'><pre>range:   \n\
</pre></div><p>A Point3 value containing the minimum, maximum and initial values for the slider in the x, y, and z components, respectively. Defaults to [0,100,0].</p>\n\
<div class=\'codeBlock\'><pre>type: \n\
</pre></div><p>The type of the slider, <span class=\'code\'>#float</span> or <span class=\'code\'>#integer</span> . Defaults to <span class=\'code\'>#float</span> .</p>\n\
<div class=\'codeBlock\'><pre>orient: \n\
</pre></div><p>The layout orientation of the slider in the rollout, either <span class=\'code\'>#vertical</span> or <span class=\'code\'>#horizontal</span> . Defaults to <span class=\'code\'>#horizontal</span> .</p>\n\
<div class=\'codeBlock\'><pre>height:\n\
</pre></div><p>Specifies the slider height when <span class=\'code\'>orient:#vertical</span> is specified.</p>\n\
<div class=\'codeBlock\'><pre>ticks: \n\
</pre></div><p>Specifies how many ticks to place along the slider bar. No ticks are drawn if you specify <span class=\'code\'>ticks:0</span> . Defaults to 10.</p>\n\
<div class=\'codeBlock\'><pre>controller: \n\
</pre></div><p>Links the slider to the specified controller. This can be a new controller or &#39;undefined&#39; to disconnect. This lets you establish a direct link between the slider and the controller. Changes to the slider will automatically update the controller (and its controlled objects). Changes to the controller automatically update the slider. This feature was previously available for spinner controls only. Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>tooltip: \n\
</pre></div><p>Specifies the tooltip text to be displayed when the mouse hovers over the slider.</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;slider&gt;.range Point3 \n\
</pre></div><p>The current range and value for the slider, as a Point3 like the <span class=\'code\'>range:</span> parameter.</p>\n\
<div class=\'codeBlock\'><pre>&lt;slider&gt;.value (Float | Integer)\n\
</pre></div><p>The current value of the slider. The type of the value returned depends on the type of the slider when it was created, either #integer or #float.</p>\n\
<div class=\'codeBlock\'><pre>&lt;slider&gt;.ticks Integer \n\
</pre></div><p>The number of ticks along the slider.</p>\n\
<div class=\'codeBlock\'><pre>&lt;slider&gt;.tooltip String \n\
</pre></div><p>Get/set the tooltip text to be displayed when the mouse hovers over the slider.</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<p><strong>Events</strong></p>\n\
<div class=\'codeBlock\'><pre>on &lt;slider&gt; changed &lt;arg&gt; do &lt;expr&gt; \n\
</pre></div><p>Called when the user moves the slider pointer. The <span class=\'code\'>&lt;arg&gt;</span> argument contains the new value of the slider. The type of the value returned depends on the type of the slider when it was created, either #integer or #float.</p>\n\
<div class=\'codeBlock\'><pre>on &lt;slider&gt; rightClick do &lt;expr&gt; \n\
</pre></div><p>Called when the Slider control is right-clicked.</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>on &lt;slider&gt; buttondown do &lt;expr&gt; \n\
</pre></div><p>Called when the user first clicks the slider.</p>\n\
<div class=\'codeBlock\'><pre>on &lt;slider&gt; buttonup do &lt;expr&gt; \n\
</pre></div><p>Called when the user releases the slider.</p>\n\
<p>The <span class=\'code\'>buttonDown</span> and <span class=\'code\'>buttonUp</span> events effectively notify you of the start and end of a slider &quot;twiddle&quot;, allowing you to perform some setup for the adjustment. A typical use for this is to bring scene nodes that are being modified in the <span class=\'code\'>on &lt;slider&gt; changed</span> handler into the foreground plane to speed up screen redraw.</p>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<div class=\'codeBlock\'><pre>slider foo &quot;height: &quot;\n\
on foo buttonDown do flagForeground $baz...* true\n\
on foo buttonUp do flagForeground $baz...* false\n\
\n\
</pre></div><p>Note: If you are using a slider to interactive adjust a property of an on-screen object, you can improve the interactive speed by moving the object to the foreground plane. Objects placed in the foreground plane are redrawn individually and so interactive changes to them are <strong>much</strong> faster. An object is moved to the foreground or background plane using the <span class=\'code\'>flagForeground()</span> method described below:</p>\n\
<div class=\'codeBlock\'><pre>flagForeground &lt;node&gt; &lt;boolean&gt; -- mapped \n\
</pre></div><p>The boolean argument puts the scene node(s) into the foreground plane if <span class=\'code\'>true</span> , or into the background plane if <span class=\'code\'>false</span> .</p>\n\
<p>You should be judicious in putting objects in the foreground plane, because putting too many objects in the foreground plane reduces the foreground plane&#39;s effectiveness. Remember to return objects to the background plane when you don&#39;t need to interactively control them any more.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";