var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Spinner UI Control</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Spinner UI Control</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"spinner-ui-control\"></a></div>\n\
<p>A <strong>spinner control</strong> is used to place a <strong>3ds Max</strong> value spinner in a rollout. The user can drag the spinner arrows or type values into the spinner edit field.</p>\n\
<p><strong>The syntax is:</strong></p>\n\
<div class=\'codeBlock\'><pre>spinner &lt;name&gt; [&lt;caption&gt;] [range:[min,max,val]] [type:&lt;name&gt;] [scale:&lt;float&gt;] [fieldWidth:&lt;integer&gt;] [toolTip:&lt;string&gt;] [indeterminate:&lt;boolean&gt;] [controller:(&lt;controller&gt;)] [setKeyBrackets:&lt;boolean&gt;]    \n\
</pre></div><p>The default alignment of <span class=\'code\'>spinner</span> items is <span class=\'code\'>#right</span> .</p>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<div class=\'codeBlock\'><pre>spinner frab_amt &quot;Frab %:&quot; range:[0,100,10] type:#integer\n\
spinner ball_radius &quot;Ball radius&quot; controller:($ball.radius.controller)\n\
on frab_amt changed val do frabulate selection val\n\
\n\
</pre></div><p><strong>Parameters:</strong></p>\n\
<div class=\'codeBlock\'><pre>range:   \n\
</pre></div><p>A Point3 value containing the minimum, maximum, and initial values for the spinner in the x, y, and z components, respectively. Defaults to [0,100,0].</p>\n\
<div class=\'codeBlock\'><pre>type: \n\
</pre></div><p>The type of the spinner: <span class=\'code\'>#float</span> , <span class=\'code\'>#integer</span> , or <span class=\'code\'>#worldunits</span> . Defaults to <span class=\'code\'>#float.</span> If type is <span class=\'code\'>#worldunits</span> , the value is displayed in the current <strong>3ds Max</strong> display units, but the value is always in internal system units.</p>\n\
<div class=\'codeBlock\'><pre>scale: \n\
</pre></div><p>The scale of the spinner specifies the smallest value increment. Defaults to 0.1 for floats, 1 for integers.</p>\n\
<div class=\'codeBlock\'><pre>fieldwidth: \n\
</pre></div><p>The width in pixels of the spinner text-edit field. By default, the spinner is placed so the left edge of the edit field is exactly in the center of the rollout and right edge is placed at the right margin. You can control how wide the field is using this parameter.</p>\n\
<div class=\'codeBlock\'><pre>tooltip: \n\
</pre></div><p>Specifies the tooltip text to be displayed when the mouse hovers over the spinner.</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>Indeterminate: \n\
</pre></div><p>When set to <span class=\'code\'>true</span> , the spinner edit field is blank.</p>\n\
<div class=\'codeBlock\'><pre>controller: \n\
</pre></div><p>Links the spinner to the specified controller. This can be a new controller or &#39;undefined&#39; to disconnect. This lets you establish a direct link between the spinner and the controller. Changes to the spinner will automatically update the controller (and its controlled objects). Changes to the controller automatically update the spinner. For example, say you have a sphere called $ball with a float controller already assigned to its radius, then the following code:</p>\n\
<div class=\'codeBlock\'><pre>utility foo &quot;foo&quot;\n\
(\n\
spinner ball_radius &quot;Ball radius&quot; range:[0,1000,1] \\\n\
controller:($ball.radius.controller)\n\
)\n\
\n\
</pre></div><p>sets up a spinner that automatically affects and tracks the radius of the scene node $ball. Any changes to the spinner update $ball&#39;s radius. Any other changes to $ball&#39;s radius, say in the Modify panel or because of animation, will update the spinner. Note that this links to controllers, so the specified controller must already exist before creating the spinner user-interface item. You can either specify a controller already assigned to the parameter you want to link to, or you can create the controller in your script and then assign that controller to the parameter of interest.</p>\n\
<div class=\'codeBlock\'><pre>setKeyBrackets: \n\
</pre></div><p>When set to <span class=\'code\'>true</span> (on) or <span class=\'code\'>false</span> (off), it will turn on and off the red keyframe brackets that signal a keyframe is present for animated parameters. This allows you to simulate keyframe notification in scripted rollouts by setting this spinner property on or off, most likely in a time change callback function.</p>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<div class=\'codeBlock\'><pre>utility foo &quot;foo&quot;\n\
(\n\
local myController=bezier_float()\n\
spinner ball_radius &quot;Ball radius&quot; range:[0,1000,1] \\\n\
controller:myController\n\
button apply &quot;Apply Radius Controller&quot;\n\
on apply pressed do\n\
(\n\
animate off at time 0 $ball.radius=myController.value\n\
$ball.radius.controller=myController\n\
)\n\
)\n\
\n\
</pre></div><p><strong>Properties:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;spinner&gt;.range Point3 \n\
</pre></div><p>The current range and value for the spinner, as a Point3 like the <span class=\'code\'>range:</span> parameter.</p>\n\
<div class=\'codeBlock\'><pre>&lt;spinner&gt;.value (Float | Integer)\n\
</pre></div><p>The current value of the spinner. The type of the value returned depends on the type of the spinner when it was created, either #integer or #float.</p>\n\
<div class=\'codeBlock\'><pre>&lt;spinner&gt;.setKeyBrackets Boolean \n\
</pre></div><p>When set to true (on) or false (off), it will turn on and off the red keyframe brackets that signal a keyframe is present for animated parameters. This allows you to simulate keyframe notification in scripted rollouts by setting this spinner property on or off, most likely in a time change callback function.</p>\n\
<div class=\'codeBlock\'><pre>&lt;spinner&gt;.indeterminate Boolean \n\
</pre></div><p>When set to <span class=\'code\'>true</span> , the spinner edit field is blank. The value of the spinner is unchanged and remains accessible when a spinner is set to indeterminate. Setting the spinner&#39;s value sets <span class=\'code\'>indeterminate</span> to <span class=\'code\'>false</span> .</p>\n\
<div class=\'codeBlock\'><pre>&lt;spinner&gt;.tooltip String \n\
</pre></div><p>Get/set the tooltip text to be displayed when the mouse hovers over the spinner.</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<p><strong>Events</strong></p>\n\
<div class=\'codeBlock\'><pre>on &lt;spinner&gt; changed &lt;arg&gt; [&lt;inSpin_arg&gt;] do &lt;expr&gt; \n\
</pre></div><p>Called when the user spins the spinner, or when the user enters a value in the spinner field then presses ENTER or presses TAB to move the cursor out of the field. The <span class=\'code\'>&lt;arg&gt;</span> argument will contain the new value of the spinner. The type of the value returned depends on the type of the spinner when it was created, either #integer or #float.</p>\n\
<p>The optional &lt; <span class=\'code\'>inSpin_arg</span> &gt; argument will contain <span class=\'code\'>true</span> if the value was changed by spinning using the mouse and the arrows and <span class=\'code\'>false</span> if the value was entered using the keyboard and the value field. Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>on &lt;spinner&gt; entered [&lt;inSpin_arg&gt;] [&lt;inCancel_arg&gt;] do &lt;expr&gt; \n\
</pre></div><p>Called when the user types a number into a spinners edit field and then presses ENTER or presses TAB to move the cursor out of the field. Also called when the spinner is released. The <span class=\'code\'>on &lt;spinner&gt; changed</span> and <span class=\'code\'>&lt;spinner&gt; buttonUp</span> handlers, if supplied, have already been called at this point and the spinner&#39;s value property is up to date.</p>\n\
<p>The optional first &lt; <span class=\'code\'>inSpin_arg</span> &gt; argument will contain <span class=\'code\'>true</span> if the value was entered by spinning the arrows and releasing the mouse and <span class=\'code\'>false</span> if the value was entered using the keyboard and the value field. Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<p>The optional second &lt; <span class=\'code\'>inCancel_arg</span> &gt; argument will contain <span class=\'code\'>true</span> if the value change was canceled with a mouse right-click and <span class=\'code\'>false</span> if no cancel was performed. Available in <strong>3ds Max 8 and higher.</strong></p>\n\
<div class=\'codeBlock\'><pre>on &lt;spinner&gt; buttondown do &lt;expr&gt; \n\
</pre></div><p>Called when the user first clicks the spinner.</p>\n\
<div class=\'codeBlock\'><pre>on &lt;spinner&gt; buttonup [&lt;inCancel_arg&gt;] do &lt;expr&gt; \n\
</pre></div><p>Called when the user releases the spinner.</p>\n\
<p>The optional &lt; <span class=\'code\'>inCancel_arg</span> &gt; argument will contain <span class=\'code\'>true</span> if the value change was canceled with a mouse right-click and <span class=\'code\'>false</span> if no cancel was performed. Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<p>Note:</p>\n\
<p>The <span class=\'code\'>buttonDown</span> and <span class=\'code\'>buttonUp</span> events effectively notify you of the start and end of a spinner &quot;twiddle&quot;, allowing you to perform some setup for the adjustment. A typical use for this is to bring scene nodes that are being modified in the <span class=\'code\'>on &lt;spinner&gt; changed</span> handler into the foreground plane to speed up screen redraw.</p>\n\
<p>If you are using a spinner to interactive adjust a property of an on-screen object, you can improve the interactive speed by moving the object to the foreground plane. Objects placed in the foreground plane are redrawn individually and so interactive changes to them are <strong>much</strong> faster. An object is moved to the foreground or background plane using the <span class=\'code\'>flagForeground()</span> method described below:</p>\n\
<div class=\'codeBlock\'><pre>flagForeground &lt;node&gt; &lt;boolean&gt; -- mapped \n\
</pre></div><p>The boolean argument puts the scene node(s) into the foreground plane if <span class=\'code\'>true</span> , or into the background plane if <span class=\'code\'>false</span> .</p>\n\
<p>You should be judicious in putting objects in the foreground plane, because putting too many objects in the foreground plane reduces the foreground plane&#39;s effectiveness. Remember to return objects to the background plane when you don&#39;t need to interactively control them any more.</p>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<div class=\'codeBlock\'><pre>spinner foo &quot;height: &quot;\n\
on foo buttonDown do flagForeground $baz...* true\n\
on foo buttonUp do flagForeground $baz...* false\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";