var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Utility and Rollout Properties, Methods, and Event Handlers</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Utility and Rollout Properties, Methods, and Event Handlers</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"utility-and-rollout-properties-methods-and-event-handlers\"></a></div>\n\
<p><strong>Properties</strong></p>\n\
<p>Several properties are available for scripted utilities and rollouts that provide access to the current state of the rollout.</p>\n\
<div class=\'section\'><a id=\"rollout-properties\"></a><h2 id=\"rollout-properties\">Rollout Properties:</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;rollout&gt;.name String, read-only\n\
</pre></div><p>The name of the rollout.</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout&gt;.title String\n\
</pre></div><p>Title of rollout.</p>\n\
<p>Note:</p>\n\
<p>You cannot change the title of a rollout or rollout floater registered as a dialog bar.</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout&gt;.open Boolean\n\
</pre></div><p>If <span class=\'code\'>true</span> , the rollout is open, <span class=\'code\'>false</span> it is rolled up. You can assign <span class=\'code\'>true</span> or <span class=\'code\'>false</span> to this property to open or roll up the rollout.</p>\n\
<p>Note: Setting does nothing if the rollout is a Dialog, dialogBar, or is in an extended viewport. Will always be <span class=\'code\'>true</span> in these cases.</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout&gt;.scrollPos Integer\n\
</pre></div><p>Scroll position of panel the rollout is in.</p>\n\
<p>Note:</p>\n\
<p>Setting this property does nothing if the rollout is a Dialog, dialogBar, or is in an extended viewport. Will always be 0 in these cases.</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout&gt;.height Integer\n\
</pre></div><p>Gets/sets the Height of the rollout in pixels.</p>\n\
<p>Note: If the rollout is in an extended viewport, the <span class=\'code\'>.width</span> and <span class=\'code\'>.height</span> properties report the width and height of the viewport. The properties cannot be set for this case.</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout&gt;.width Integer\n\
</pre></div><p>Gets/sets the Width of the rollout.</p>\n\
<p>Note:</p>\n\
<p>Setting this property does nothing if the rollout is in a rolloutfloater, subRollout, or a command panel.</p>\n\
<p>If the rollout is in an extended viewport, the <span class=\'code\'>.width</span> and <span class=\'code\'>.height</span> properties report the width and height of the viewport. The properties cannot be set for this case.</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout&gt;.controls Array of ui elements, read-only\n\
</pre></div><p>Returns an array of all controls in the rollout.</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout&gt;.inViewport Boolean, read-only\n\
</pre></div><p>Returns <span class=\'code\'>True</span> when the rollout is in extended viewport.</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout&gt;.dialogBar Boolean, read-only\n\
</pre></div><p>Returns <span class=\'code\'>True</span> when the rollout is registered as a dialog bar.</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout&gt;.inDialog Boolean, read-only\n\
</pre></div><p>Returns <span class=\'code\'>True</span> when the rollout is currently displayed in a dialog created using <span class=\'code\'>createDialog &lt;rollout&gt;.</span> Always valid.</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout&gt;.isDisplayed Boolean, read-only\n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the rollout is currently displayed, <span class=\'code\'>false</span> otherwise.</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout&gt;.visible Boolean\n\
</pre></div><p>Gets or sets the visibility of a rollout if it is displayed in a dialog. If <span class=\'code\'>true</span> (the default), the rollout is visible in the UI. If <span class=\'code\'>false</span> , the rollout is hidden in the UI, but is still accessible via MAXScript. <strong>Available in 3ds Max 2021 and higher.</strong> Note: This property does not affect rollout visibility in a rollout floater, only in a dialog created with <span class=\'code\'>createDialog()</span>.</p>\n\
<p>For Example:</p>\n\
<div class=\'codeBlock\'><pre>rollout test &quot;Test&quot; (\n\
    button bt_test &quot;Show/Hide Rollout&quot;\n\
    on bt_test pressed  do  test.visible = not test.visible\n\
)\n\
\n\
createDialog test \n\
&lt;rollout&gt;.owner Object, read-only\n\
</pre></div><p>If the rollout is being displayed by a scripted plugin or a Custom Attribute, the property will contain the scripted plugin or CA instance. This property was added in <strong>3ds Max 8</strong> to make it easier to access the variables in a scripted plugin or CA instance when a debugger break occurs in a rollout event handler. In this case, the owner of the event handler is the rollout, so you can access the scripted plugin or CA instance using <span class=\'code\'>getVar owner.owner</span> .</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout&gt;.hwnd Integer, read-only\n\
</pre></div><p>Contains the Window HWND handle of the rollout if the rollout is open, or 0 if it is closed.</p>\n\
<p>Available in <strong>3ds Max 2011 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout&gt;.rolloutFloater RolloutFloater, read-only\n\
</pre></div><p>Contains the rollout floater the rollout is in, or undefined if the rollout is not in a floater. Available in <strong>3ds Max 2019 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;rollout&gt;.autoLayoutOnResize Boolean\n\
</pre></div><p>True if auto layout on resize is enabled for the rollout. Available in <strong>3ds Max 2019 and higher</strong>.</p>\n\
<div class=\'section\'><a id=\"rollout-methods\"></a><h2 id=\"rollout-methods\">Rollout Methods:</h2></div>\n\
<p>Several methods are available for opening and closing utilities, and adding and removing rollouts in the Utilities panel. These methods are:</p>\n\
<div class=\'codeBlock\'><pre>openUtility &lt;utility&gt;\n\
</pre></div><p>Opens the utility’s main rollout in the Utilities panel. This is equivalent to selecting the utility from the Utilities list in the MAXScript’s Utilities panel rollout.</p>\n\
<div class=\'codeBlock\'><pre>closeUtility &lt;utility&gt;\n\
</pre></div><p>Closes the utility’s main rollout in the Utilities panel. This is equivalent to clicking the Close button in this rollout.</p>\n\
<div class=\'codeBlock\'><pre>addRollout &lt;rollout&gt; [ rolledUp:&lt;boolean&gt; ]\n\
</pre></div><p>Adds the rollout to the Utilities panel. The <span class=\'code\'>rolledUp:</span> parameter on the <span class=\'code\'>addRollout()</span> function specifies whether the rollout is added in a rolled-up state. This defaults to <span class=\'code\'>false</span> , so the rollout is added fully opened. The extra rollouts are arranged in the order of <span class=\'code\'>addRollout()</span> calls, so take care in sequencing these to ensure the order you want.</p>\n\
<div class=\'codeBlock\'><pre>removeRollout &lt;rollout&gt;\n\
</pre></div><p>Removes the rollout from the Utilities panel.</p>\n\
<p>See <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Utilities-and-Rollouts/Managing-Multiple-Rollouts-in-a.html\' title=\'\'>Managing Multiple Rollouts in a Scripted Utility</a> for more information on the <span class=\'code\'>addRollout()</span> and <span class=\'code\'>removeRollout()</span> methods.</p>\n\
<div class=\'codeBlock\'><pre>updateRolloutLayout (&lt;rollout_floater&gt; | &lt;rollout&gt;) forceUpdate:&lt;boolean&gt;\n\
</pre></div><p>Updates the layout of rollouts in the specified rollout floater or rollout in a dialog, unless both the rolloutfloater and rollout have their <strong>autoLayoutOnResize</strong> properties set to false, and the <strong>forceUpdate</strong> parameter to the method is false or not specified (the default is false). Available in <strong>3ds Max 2019 and higher</strong>. If <strong>forceUpdate</strong> is true, the layout is updated regardless of <strong>autoLayoutOnResize</strong> settings.</p>\n\
<p><strong>Event Handlers</strong></p>\n\
<p>In addition to the event handlers you specify for particular user-interface items in a rollout, you can define handler functions that are called when an entire rollout is first opened ( <span class=\'code\'>open</span> ) or explicitly closed ( <span class=\'code\'>close</span> ) by the user. These event handlers are useful for initialization code or for cleaning up when a rollout closes, and are necessary when managing multiple rollouts in one scripted utility. If a rollout floater window is resized or moved, an event handler ( <span class=\'code\'>resized</span> or <span class=\'code\'>moved</span>, respectively) is called on the first rollout in the rollout floater window. An additional event handler ( <span class=\'code\'>oktoclose</span> ) is called to verify that it is OK to close a rollout.</p>\n\
<p><strong>The syntax is as follows:</strong></p>\n\
<div class=\'codeBlock\'><pre>on &lt;rollout_or_utility&gt; open do &lt;expr&gt;\n\
</pre></div><p>Called when the rollout or utility is opened.</p>\n\
<div class=\'codeBlock\'><pre>on &lt;rollout_or_utility&gt; close do &lt;expr&gt;\n\
</pre></div><p>Called when the rollout or utility is closed.</p>\n\
<div class=\'codeBlock\'><pre>on &lt;rollout_or_utility&gt; oktoclose do &lt;expr&gt;\n\
</pre></div><p>Called when the user clicks the rollout’s Close button so the script writer can decide whether to allow the close to proceed. If the expression evaluates to the value <span class=\'code\'>true</span> , the rollout is allowed to close. If the expression evaluates to the value <span class=\'code\'>false</span> , the action attempting the close is ignored and the rollout or utility is left open.</p>\n\
<p>In the following example the utility will not close unless the &quot;OK To Close&quot; check button is pressed:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` utility ui_oktoclose &quot;OKToClose Test&quot; ( checkbutton a2 &quot;OK To Close&quot; on ui_oktoclose oktoclose do a2.state )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>on &lt;rollout_or_utility&gt; help do &lt;expr&gt;\n\
</pre></div><p>Called when dialog/rollout floater/rollout has focus and F1 is pressed.</p>\n\
<p>If a rollout or a rollout control in a rollout has focus, the code looks to see if a &#39;help&#39; event handler is defined for that rollout.</p>\n\
<p>If not, if the rollout is in a rollout floater, the floater will get the message and will check for the &#39;help&#39; event handler on the first rollout in the floater, and if present will call it.</p>\n\
<p>If the rollout is in a subrollout, MAXScript explicitly performs the same check and calls the handler on the first rollout in the subrollout.</p>\n\
<p>If no &#39;help&#39; event handler is found, the message ends up in the 3ds Max window and the 3ds Max help will be called.</p>\n\
<div class=\'codeBlock\'><pre>on &lt;rollout_or_utility&gt; rolledUp &lt;arg&gt; do &lt;expr&gt;\n\
</pre></div><p>Called when the rollout or utility is rolled up or down. The argument will contain <span class=\'code\'>true</span> when the rollout is rolled down (open) and <span class=\'code\'>false</span> when the rollout is rolled up (closed).</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` rollout test &quot;Test&quot; ( button btn_test &quot;Press Me&quot; on test rolledUp state do if state then print &quot;Rolled Down!&quot; else print &quot;Rolled Up!&quot; ) nf = newRolloutFloater &quot;Test&quot; 200 200 addRollout test nf</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>on &lt;rollout&gt; resized &lt;arg&gt; do &lt;expr&gt;\n\
</pre></div><p>Called on first rollout in a rollout floater window when it is resized either by the user or by a script changing the <span class=\'code\'>size</span> property of the rollout floater window. Changing the rollout floater window size in the <span class=\'code\'>resized</span> event handler expression will not cause the <span class=\'code\'>resized</span> event handler to be called again. The value of &lt; <span class=\'code\'>arg</span> &gt; is the current width and height of the rollout floater window.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` global my_rof_size ... on my_rollout resized size do ( my_rof_size = size -- save the new window size )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>on &lt;rollout&gt; moved &lt;arg&gt; do &lt;expr&gt;\n\
</pre></div><p>Called on first rollout in a rollout floater window when it is moved either by the user or by a script changing the <span class=\'code\'>pos</span> property of the rollout floater window. The value of &lt; <span class=\'code\'>arg</span> &gt; is the current position of the rollout floater window on the screen in pixels.</p>\n\
<p>The following example keeps a log file of its actions, and uses the rollout open and close handlers to open and close the log file:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` utility frab &quot;Optimal Frabulator&quot; ( local log spinner frab_x ... button do_it &quot;Enfrabulate now&quot; ... on do_it pressed do ( frabulate selection format &quot;selection frabbed at %\\n&quot; localTime to:log ) on frab open do log = createFile &quot;frabulator.log&quot; on frab close do close log )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In the following example, the <span class=\'code\'>on resized</span> event handler is called when the rollout floater window is resized. Because the event is generated only for the first rollout in a rollout floater window, the <span class=\'code\'>on b resized</span> event handler is never called.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` rollout a &quot;Rollout A&quot; ( button a1 &quot;a1&quot; on a resized val do (format &quot;A: %\\n&quot; val) ) -- rollout b &quot;Rollout B&quot; ( button b1 &quot;b1&quot; on b resized val do (format &quot;B: %\\n&quot; val) ) -- rof=newrolloutfloater &quot;test&quot; 200 200 addrollout a rof addrollout b rof rof.size=[300,300]</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";