var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Visibility of Locals, Functions, Structures and User-Interface Items in Rollout Code</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Visibility of Locals, Functions, Structures and User-Interface Items in Rollout Code</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"visibility-of-locals-functions-structures-and-user-interface-items-in-rollout-code\"></a></div>\n\
<p>The ordering of user-interface items and functions and sub-rollouts in a utility is important when referencing other items and rollouts in handler or local function code. Specifically, you can only reference a user-interface item or rollout or function in a handler or other function if that item or rollout or function has been defined earlier in the utility.</p>\n\
<p>A recommended ordering can help ensure this:</p>\n\
<ol>\n\
<li>local variables</li>\n\
<li>structs</li>\n\
<li>user-interface items</li>\n\
<li>nested rollouts</li>\n\
<li>functions</li>\n\
<li>event handlers</li>\n\
</ol>\n\
<p>In some situations, cross-referencing means there&#39;s no way to order definitions and still pre-define everything. To remedy this, MAXScript lets you pre-declare local rollouts and functions, so code that comes before the function or rollout definition will see the correct object. You do this by declaring such rollouts and functions as uninitialized locals. In the following example, there are two rollouts, <span class=\'code\'>ro1</span> and <span class=\'code\'>ro2</span> , that each want to reference items within the other. By pre-declaring them as locals in the main utility, this cross-referencing is possible:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` ( local ro1, ro2 -- pre-declare local rollouts rollout ro1 &quot;Rollout 01&quot; ( checkbox chk_checkbox &quot;Check The Box In Rollout 02&quot; enabled:false on chk_checkbox changed state do ro2.chk_checkbox.checked = state ) rollout ro2 &quot;Rollout 02&quot; ( checkbox chk_checkbox &quot;Enable The Checkbox In Rollout 01&quot; on chk_checkbox changed state do ro1.chk_checkbox.enabled = state ) theFloater = newRolloutFloater &quot;Test Local Visibility&quot; 250 110 addRollout ro1 theFloater addRollout ro2 theFloater ) --end script</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>As a general rule, it is recommended that all local variable names be explicitly declared as locals at their outermost scope. This will prevent any conflicts from occurring if another script has declared the same variable name as a global variable. While functions, structures definitions, and rollouts will always be local to the utility they are defined in (even if they have the same name as a global variable), declaring these as local will ensure the variables are defined, even if the order in which they are defined is changed. Here&#39;s an example showing these declarations:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` utility foo &quot;Object Frabulator&quot; ( -- local variables local target_obj -- local functions local prop_name -- local rollouts local setup fn prop_name obj name = for c in obj.children do c.name = name + &quot;_&quot; + c.name checkbutton setup_btn &quot;Setup&quot; edittext name_box &quot;New name:&quot; -- use a checkbutton to dynamically control presence of panels on setup_btn changed state do if state then addRollout setup else removeRollout setup on foo close do removeRollout setup -- always close rollouts rollout setup &quot;Setup fraber&quot; -- local panel ( label hello pickbutton pick_tgt &quot;Pick object&quot; on pick_tgt picked obj do ( target_obj = obj -- access utility local name_box.text = obj.name -- access utility item prop_name obj obj.name -- call utility local fn ) ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";