var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>3ds Max File Loading and Saving</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>3ds Max File Loading and Saving</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"ds-max-file-loading-and-saving\"></a></div>\n\
<p>The following System Globals and Methods are used to access the file name and path and load, save, merge, import, and export <strong>3ds Max</strong> scenes.</p>\n\
<p>{{toc}}</p>\n\
<p><strong>System Globals:</strong></p>\n\
<div class=\'section\'><a id=\"scene-file-path-and-name\"></a><h2 id=\"scene-file-path-and-name\">Scene File Path and Name</h2></div>\n\
<div class=\'codeBlock\'><pre>maxFileName \n\
</pre></div><p>Contains a String value that defines the file name for the currently open scene.</p>\n\
<p>This variable is read-only.</p>\n\
<p>It will be set automatically when the scene is loaded or saved using the <span class=\'code\'>loadMaxFile()</span> and <span class=\'code\'>saveMaxFile()</span> methods described below.</p>\n\
<p>See also the <a href=\'#!/url=./developer/Frequently-Asked-Questions/MAXScript-Syntax-and-Terminology/How-do-I-get-the-file-name-of.html\' title=\'\'>How do I get the file name of the current scene?</a> FAQ entry.</p>\n\
<div class=\'codeBlock\'><pre>maxFilePath \n\
</pre></div><p>Contains a String value that defines the directory path for the currently open scene.</p>\n\
<p>This variable is read-only.</p>\n\
<p>It will be set automatically when the scene is loaded or saved using the <span class=\'code\'>loadMaxFile()</span> and <span class=\'code\'>saveMaxFile()</span> methods described below.</p>\n\
<p>See also the <a href=\'#!/url=./developer/Frequently-Asked-Questions/MAXScript-Syntax-and-Terminology/How-do-I-get-the-file-name-of.html\' title=\'\'>How do I get the file name of the current scene?</a> FAQ entry.</p>\n\
<p><strong>Methods:</strong></p>\n\
<p>The following methods are used to load, save, merge, import, and export <strong>3ds Max</strong> scenes.</p>\n\
<div class=\'section\'><a id=\"loading-max-files\"></a><h2 id=\"loading-max-files\">Loading MAX Files</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;loadMaxFile &lt;filename_string&gt; [useFileUnits:&lt;boolean&gt;] [quiet:&lt;boolean&gt;] [allowPrompts:&lt;boolean&gt;]\n\
    [missingExtFilesAction: (#logmsg|#logToFile|#abort|&lt;int&gt;)] [missingExtFilesList:&lt;&amp;var array of strings&gt;]\n\
    [missingDLLsAction: (#logmsg|#logToFile|#abort|&lt;int&gt;)] [missingDLLsList:&lt;&amp;var array of strings&gt;]\n\
    [missingXRefsAction:(#logmsg|#logToFile|#abort|&lt;int&gt;)] [missingXRefsList:&lt;&amp;var array of strings&gt;]\n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the file was found and loaded successfully, false otherwise.</p>\n\
<p>The <span class=\'code\'>useFileUnits</span> parameter specifies whether to adopt the file&#39;s unit scale (if true) or the current System&#39;s unit scale (if false, the default). This option will apply regardless of the Respect System Units in Files option setting in the System Units Setup dialog. Loading a file with <span class=\'code\'>useFileUnits:true</span> will not change the system units setting in the <strong>3dsmax.ini</strong> file.</p>\n\
<p>For details on the <span class=\'code\'>quiet:</span> and <span class=\'code\'>missing*</span> parameters, see <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Network-Render-Interface/Quiet-Mode.html\' title=\'\'>Quiet Mode</a>.</p>\n\
<p>The <span class=\'code\'>allowPrompts</span> parameter specifies whether to allow dialogs to appear during the file loading process; the default is false.</p>\n\
<blockquote>\n\
<p>Warning: <span class=\'code\'>loadMaxFile()</span> will replace the current scene content with the file content without warning!The <strong>&quot;The scene has been modified. Do you want to save your changes&quot;</strong> prompt will <strong>not</strong> be issued when using this method, even when supplying <span class=\'code\'>quiet:false</span>. See <a href=$13ds-Max-File-Loading-and-Saving.html#check-for-save\' title=\'\'><span class=\'code\'>checkForSave()</span></a> and <a href=$13ds-Max-File-Loading-and-Saving.html#save-max-file\' title=\'\'><span class=\'code\'>saveMaxFile()</span></a> further on this page to ensure the current content of the scene is not lost if it requires saving.</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"scene-file-path-resolution\"></a><h3 id=\"scene-file-path-resolution\">Scene File Path Resolution</h3></div>\n\
<p>3ds Max searches for the file specified by <span class=\'code\'>filename_string</span> in the following places:</p>\n\
<ul>\n\
<li>The 3ds Max install directory</li>\n\
<li>The current .mzp file, If the script is running in zip-file script package, and the file path is relative</li>\n\
<li>The current working directory (which you can get or set using <span class=\'code\'>sysinfo.currentdir</span>)</li>\n\
<li>The Windows directory, and the system directories (<span class=\'code\'>system</span> and <span class=\'code\'>system32</span>)</li>\n\
<li>The directories in the <span class=\'code\'>PATH</span> environment variable.</li>\n\
</ul>\n\
<div class=\'section\'><a id=\"merging-max-files\"></a><h2 id=\"merging-max-files\">Merging MAX Files</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;mergeMAXFile &lt;filename_string&gt; [&lt;name_array&gt;] [#prompt] \\ \n\
[ [ #select ] #noRedraw ] \\ \n\
[ #deleteOldDups | #mergeDups | #skipDups | #promptDups | #autoRenameDups ] \\\n\
[ #promptMtlDups | #useMergedMtlDups | #useSceneMtlDups | #renameMtlDups ]\\\n\
[ #promptReparent | #alwaysReparent | #neverReparent ] \\\n\
[ quiet:&lt;boolean&gt; ] \\ \n\
[ missingExtFilesAction: &lt;actions&gt; ] [ missingExtFilesList: &lt;&amp;variable&gt; ] \\ \n\
[ missingDLLsAction: &lt;actions&gt;] [ missingDLLsList: &lt;&amp;variable&gt;]\n\
[ missingXRefsAction: &lt;actions&gt; ] [ missingXRefsList: &lt;&amp;variable&gt; ] \\\n\
[ mergedNodes: &lt;&amp;variable&gt; | includeFullGroup: &lt;boolean&gt;\n\
</pre></div><p>All arguments are optional except the initial file name. The flag arguments can be specified in any order.</p>\n\
<p>The arguments details are as follows:</p>\n\
<div class=\'codeBlock\'><pre>&lt;filename_string&gt;\n\
</pre></div><p>The scene file to merge. For information about where 3ds Max looks for the specified <span class=\'code\'>&lt;filename_string&gt;</span>, see <a href=$13ds-Max-File-Loading-and-Saving.html#scene-file-path-resolution\' title=\'\'>Scene File Path Resolution</a>, above.</p>\n\
<div class=\'codeBlock\'><pre>&lt;name_array&gt; \n\
</pre></div><p>An optional array of names or strings identifying the objects in the source scene file to be merged; all objects are merged if not specified.</p>\n\
<div class=\'codeBlock\'><pre>#prompt \n\
</pre></div><p>If specified causes the standard merge dialog to be opened.</p>\n\
<div class=\'codeBlock\'><pre>#select \n\
</pre></div><p>If specified causes the newly merged objects to be selected when merged.</p>\n\
<div class=\'codeBlock\'><pre>#noRedraw \n\
</pre></div><p>If specified causes the screen redraw to be delayed in case you want to call <span class=\'code\'>mergeMAXFile()</span> several times and delay the redraw until after the last file merge.</p>\n\
<div class=\'codeBlock\'><pre>#deleteOldDups \n\
</pre></div><p>Deletes existing scene objects with the same names as incoming objects.</p>\n\
<div class=\'codeBlock\'><pre>#mergeDups \n\
</pre></div><p>Ignore name conflicts, merge anyway resulting in possibly duplicated names.</p>\n\
<div class=\'codeBlock\'><pre>#skipDups \n\
</pre></div><p>Don&#39;t merge objects with duplicated names.</p>\n\
<div class=\'codeBlock\'><pre>#promptDups \n\
</pre></div><p>Throw up the duplicates resolution dialog for the user to choose.</p>\n\
<div class=\'codeBlock\'><pre>#AutoRenameDups \n\
</pre></div><p>Auto-renames the incoming objects that have names that already exist in the current scene. No dialog will pop up. Available in <strong>3ds Max 2011 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>#promptMtlDups \n\
</pre></div><p>Default, prompt the user when duplicated materials are found.</p>\n\
<div class=\'codeBlock\'><pre>#useMergedMtlDups \n\
</pre></div><p>Merge using the incoming materials.</p>\n\
<div class=\'codeBlock\'><pre>#useSceneMtlDups \n\
</pre></div><p>Merge using the scene materials.</p>\n\
<div class=\'codeBlock\'><pre>#renameMtlDups \n\
</pre></div><p>Merge and rename duplicated incoming materials.</p>\n\
<div class=\'codeBlock\'><pre>#promptReparent \n\
</pre></div><p>Default, prompt the user.</p>\n\
<div class=\'codeBlock\'><pre>#alwaysReparent \n\
</pre></div><p>Don&#39;t ask the user, always reparent.</p>\n\
<div class=\'codeBlock\'><pre>#neverReparent \n\
</pre></div><p>Don&#39;t ask the user, never reparent.</p>\n\
<p>For details on the <span class=\'code\'>quiet:</span> and <span class=\'code\'>missing*</span> parameters, see <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Network-Render-Interface/Quiet-Mode.html\' title=\'\'>Quiet Mode</a></p>\n\
<p><span class=\'code\'>mergeMAXFile</span> returns <span class=\'code\'>true</span> if the file was found and loaded successfully. Returns <span class=\'code\'>false</span> when the argument is a file with .DRF extension.</p>\n\
<div class=\'codeBlock\'><pre>mergedNodes &lt;&amp;variable&gt;\n\
</pre></div><p>On a successful merge, the specified variable will contain an array of merged nodes.</p>\n\
<div class=\'codeBlock\'><pre>includeFullGroup: &lt;boolean&gt;\n\
</pre></div><p>When <strong>true</strong>, if a an imported node is part of a group, all the nodes in that group are also imported. The default is <strong>false</strong>.</p>\n\
<p>Available in <strong>3ds Max 2020 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;nodes array&gt;getLastMergedNodes()\n\
\n\
</pre></div><p>Available <strong>in 3ds Max 2017 and higher</strong>: Returns an array of the nodes merged in the last merge operation.</p>\n\
<p>Returns an empty array #() if no merge operations have been performed in the current scene.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` resetMaxFile #noPrompt --reset the scene --&gt; OK</p>\n\
<p>getLastMergedNodes() --get the last merged nodes - returns an empty array, because nothing has been merged yet --&gt; #()</p>\n\
<p>t = teapot() --create a teapot --&gt; $Teapot:Teapot001 @ [0.000000,0.000000,0.000000]</p>\n\
<p>s = sphere pos:[100,0,0] --create a sphere to the right of the teapot --&gt; $Sphere:Sphere001 @ [100.000000,0.000000,0.000000]</p>\n\
<p>b = box pos:[-50,0,0] --create a box to the left of the teapot --&gt; $Box:Box001 @ [-50.000000,0.000000,0.000000]</p>\n\
<p>theFile = (GetDir #temp + @&quot;\\teapotAndSphere.max&quot;) --define a temp file to save --&gt; &quot;C:\\Users\\YOURNAME\\AppData\\Local\\Autodesk\\3dsMax\\2017 - 64bit\\ENU\\temp\\teapotAndSphere.max&quot;</p>\n\
<p>saveNodes #(t,s,b) theFile --save the three objects to the file --&gt; OK</p>\n\
<p>resetMaxFile #noPrompt --reset the scene again --&gt; OK</p>\n\
<p>mergeMAXFile theFile #(&quot;Teapot001&quot;) --attempt to merge two teapots --&gt; true m1 = getLastMergedNodes() --check to see what was merged - only one teapot actually exists in the file --&gt; #($Teapot:Teapot001 @ [0.000000,0.000000,0.000000])</p>\n\
<p>mergeMAXFile theFile #mergeDups #autoRenameDups --merge all objects, allowing duplicates to be renamed --&gt; true m2 = getLastMergedNodes() --see what got merged... --&gt; #($Teapot:Teapot002 @ [0.000000,0.000000,0.000000], $Sphere:Sphere001 @ [100.000000,0.000000,0.000000], $Box:Box001 @ [-50.000000,0.000000,0.000000])</p>\n\
<p>move m2 [0,100,0] --move the objects merged in the second attempt 100 units along Y --&gt; OK select m1 --and select the object from the first merge --&gt; OK</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"ds-max-load-and-save-dialogs\"></a><h2 id=\"ds-max-load-and-save-dialogs\">3ds Max Load and Save Dialogs</h2></div>\n\
<div class=\'codeBlock\'><pre>getMAXSaveFileName [filename:&lt;seed_filename_string&gt;] \n\
</pre></div><p>Displays the standard <strong>3ds Max</strong> file save dialog, returns the file name selected by the user, or the value &#39;undefined&#39; if canceled.</p>\n\
<p>If the optional <span class=\'code\'>filename:</span> string argument is specified and it contains only a file name pattern, only the files matching the pattern will be displayed. If it also contains a file path, the content of the directory matching the pattern will be displayed.</p>\n\
<p>No actual file saving will be performed, only the name of the selected file will be returned. You can perform the saving by passing the result of this function (as long as it is not &#39;undefined&#39;) as argument to <span class=\'code\'>saveMaxFile()</span> documented further on this page.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` --Open the dialog at the current path (can be found or set via sysinfo.currentdir): theName = getMAXSaveFileName()</p>\n\
<p>--Open the dialog at &quot;c:\\temp&quot; and filter by pattern &quot;test<em>.max&quot; --The user must click a specific file if the pattern contains wildcards theName = getMAXSaveFileName filename:&quot;c:\\temp\\test</em>.max&quot;</p>\n\
<p>--Open the dialog at &quot;c:\\temp&quot; and set the file name to &quot;test.max&quot; --The user can click the Open button to get the specified file name if it exists, --otherwise a prompt will show up saying the file does not exist... theName = getMAXSaveFileName filename:&quot;c:\\temp\\test.max&quot; --If the result is not undefined, we can actually save the file: if theName != undefined do saveMaxFile theName</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>getMAXOpenFileName [filename:&lt;seed_filename_string&gt;] [dir:&lt;seed_directory_string&gt;] \n\
</pre></div><p>Displays the standard <strong>3ds Max</strong> file open dialog, returns the file name selected by the user, or the value &#39;undefined&#39; if canceled.</p>\n\
<p>If the optional <span class=\'code\'>filename:</span> string argument is specified and it contains only a file name pattern, only the files matching the pattern will be displayed. If it also contains a file path, the content of the directory matching the pattern will be displayed.</p>\n\
<p>If the optional <span class=\'code\'>dir:</span> string is specified, the dialog will open at the specified path and the File name field will be set to the current scene file name (found in the <span class=\'code\'>maxFileName</span> global variable), or will be empty if the scene is still Untitled.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong>.</p>\n\
<p>``` --Open the dialog at the current path (sysinfo.currentdir): theName = getMAXOpenFileName()</p>\n\
<p>--Open the dialog at c:\\temp and use current file name theName = getMAXOpenFileName dir:&quot;c:\\temp&quot;</p>\n\
<p>--Open the dialog at &quot;c:\\temp&quot; and filter by pattern &quot;test<em>.max&quot; --The user must click a specific file if the pattern contains wildcards theName = getMAXOpenFileName filename:&quot;c:\\temp\\test</em>.max&quot;</p>\n\
<p>--Open the dialog at &quot;c:\\temp&quot; and set the file name to &quot;test.max&quot; --The user can click the Open button to get the specified file name if it exists. theName = getMAXOpenFileName filename:&quot;c:\\temp\\test.max&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"max-file-object-names\"></a><h2 id=\"max-file-object-names\">MAX File Object Names</h2></div>\n\
<div class=\'codeBlock\'><pre>getMAXFileObjectNames &lt;max_filename_string&gt; [quiet:&lt;boolean&gt;] \\\n\
  [missingDLLsAction: (#logmsg|#logToFile|#abort|&lt;int&gt;)] [missingDLLsList:&lt;&amp;var array of strings&gt;]\n\
</pre></div><p>Returns an array of <strong>strings</strong>, one for each of the names of the objects in the given <strong>3ds Max</strong> file. For information about where 3ds Max looks for the specified <span class=\'code\'>&lt;filename_string&gt;</span>, see <a href=$13ds-Max-File-Loading-and-Saving.html#scene-file-path-resolution\' title=\'\'>Scene File Path Resolution</a>, above.</p>\n\
<p>This provides a way to get a preview list of the objects in another scene file (by name) to set up user selection of the objects to be merged under script control using the <span class=\'code\'>mergeMAXFile()</span> function,</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong>.</p>\n\
<p>``` p=[1000,1000,1000] for i = 1 to 5 do box pos:(random p -p) -- create some boxes savemaxfile &quot;mergetest.max&quot; -- save to file for obj in objects do obj.name = &quot;_&quot;+obj.name -- rename the boxes objects.pos += [0,-1000,0] -- move them off to the side fobj_names = getmaxfileobjectnames &quot;mergetest.max&quot; -- get the object names from the file deleteitem fobj_names 3 -- delete the third name from the array mergemaxfile &quot;mergetest.max&quot; fobj_names #select -- merge in the objects and select them selection.count -- should be 4 objects.count -- should be 9</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><span class=\'code\'>getMAXFileObjectNames</span> returns an empty array when the argument is a file with .DRF extension.</p>\n\
<p>For details on the <span class=\'code\'>quiet:</span> and <span class=\'code\'>missing*</span> parameters, see <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Network-Render-Interface/Quiet-Mode.html\' title=\'\'>Quiet Mode</a></p>\n\
<p><span class=\'code\'>getMAXFileObjectNames</span> in <strong>3ds Max 7 and higher</strong> returns an array of string values, rather than the array of name values in previous <strong>3ds Max</strong> versions. The object names used by <span class=\'code\'>mergeMaxFile</span> are case sensitive, and name values are not guaranteed to maintain the case of the string they wrap.</p>\n\
<div class=\'section\'><a id=\"save-max-file\"></a><h2 id=\"save-max-file\">Save MAX File</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;saveMaxFile &lt;filename_string&gt; [saveAsVersion:&lt;integer&gt;] [clearNeedSaveFlag:&lt;boolean&gt;] [useNewFile:&lt;boolean&gt;] [quiet:&lt;boolean&gt;] \n\
</pre></div><p>Saves the scene to the current <strong>3ds Max</strong> scene directory if there is no explicit directory path on the supplied file name. If no filename extension is specified, &quot;.max&quot; is automatically appended to the filename.</p>\n\
<blockquote>\n\
<p>Warning: <span class=\'code\'>saveMaxFile()</span> will overwrite existing files with the same name without warning! See <span class=\'code\'>CheckForSave()</span> and <span class=\'code\'>doesFileExist()</span> further on this page!</p>\n\
</blockquote>\n\
<p>The optional keywords are true by default to match the existing behavior prior to <strong>3ds Max 6</strong>, except when saving as a previous version in 3ds Max 2011 and higher where the <span class=\'code\'>useNewFile:</span> is assumed <span class=\'code\'>false</span> to prevent the previous version file from becoming the current file.</p>\n\
<p>In <strong>3ds Max 2011 and higher</strong>, if a <strong>valid previous version</strong> is specified using <span class=\'code\'>saveAsVersion:</span> , the scene will be saved in the file format of the specified previous version. In <strong>3ds Max 2011</strong> the valid value is 2010. In <strong>3ds Max 2012</strong>, the valid values are 2010 and 2011. Any other value will save using the current version&#39;s format.</p>\n\
<p>If <span class=\'code\'>clearNeedSaveFlag:</span> is set to <span class=\'code\'>false</span> , the file is saved, but the need save flag will not be cleared and <strong>3ds Max</strong> will still consider the scene as changed and requiring saving.</p>\n\
<p>If <span class=\'code\'>useNewFile:</span> is <span class=\'code\'>false</span> , the saved file is not set as the current scene file and the file is not put in the Most Recently Used list. This lets you save a backup file of the scene to a different name without the name becoming the current one or appearing on the list of recent files.</p>\n\
<p>For details on the <span class=\'code\'>quiet:</span> option which was added to this method in <strong>3ds Max 8</strong>, see <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Network-Render-Interface/Quiet-Mode.html\' title=\'\'>Quiet Mode</a>.</p>\n\
<p>The method will return true on success or false if the saving failed (for example if attempting to overwrite an existing read-only file) in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'section\'><a id=\"archive-max-file\"></a><h2 id=\"archive-max-file\">Archive MAX File</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt; archiveMAXFile &lt;filename_string&gt; [quiet:&lt;boolean&gt;] [saveAsVersion: &lt;integer&gt;] \n\
    [missingExtFilesAction: (#logmsg|#logToFile|#abort|&lt;int&gt;)] [missingExtFilesList:&lt;&amp;var array of strings&gt;]\n\
</pre></div><p>Archives the current scene file and all of its related texture maps to a ZIP archive with the specified filename string. Available in <strong>3ds Max 2019.1 Update and higher</strong>.</p>\n\
<p>If <strong>quiet</strong> is true, the <strong>Missing Asset</strong> dialog will not be displayed if assets are missing.</p>\n\
<p>The <strong>saveAsVersion</strong> parameter specifies the version of 3ds Max for which the saved archive is compatible. If not specified, the current 3ds Max version is used.</p>\n\
<p>The missingExtFilesAction and missingExtFilesList parameters determine the behavior when assets are missing. For details on the <span class=\'code\'>quiet</span> and <span class=\'code\'>missing*</span> parameters, see <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Network-Render-Interface/Quiet-Mode.html\' title=\'\'>Quiet Mode</a>.</p>\n\
<div class=\'section\'><a id=\"hold-and-fetch\"></a><h2 id=\"hold-and-fetch\">Hold and Fetch</h2></div>\n\
<div class=\'codeBlock\'><pre>holdMaxFile() \n\
</pre></div><p>Equivalent to the <strong>3ds Max</strong> Edit &gt; Hold operation.</p>\n\
<div class=\'codeBlock\'><pre>fetchMaxFile [quiet:&lt;boolean&gt;] \n\
    arc\n\
    [missingDLLsAction: (#logmsg|#logToFile|#abort|&lt;int&gt;)] [missingDLLsList:&lt;&amp;var array of strings&gt;]\n\
    [missingXRefsAction:(#logmsg|#logToFile|#abort|&lt;int&gt;)] [missingXRefsList:&lt;&amp;var array of strings&gt;]\n\
</pre></div><p>Equivalent to the <strong>3ds Max</strong> Edit &gt; Fetch operation. For details on the <span class=\'code\'>quiet</span> and <span class=\'code\'>missing*</span> parameters, see <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Network-Render-Interface/Quiet-Mode.html\' title=\'\'>Quiet Mode</a>.</p>\n\
<div class=\'section\'><a id=\"checking-for-max-file\"></a><h2 id=\"checking-for-max-file\">Checking For MAX File</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;isMaxFile &lt;filename_string&gt; \n\
</pre></div><p>Returns true if the specified file is a MAX file.</p>\n\
<p>This method tests the internal structure of the file to see if it is consistent with a MAX file.</p>\n\
<p>Returns false if the file is not a MAX file or if the specified file does not exist.</p>\n\
<p>For information about where 3ds Max looks for the specified <span class=\'code\'>&lt;filename_string&gt;</span>, see <a href=$13ds-Max-File-Loading-and-Saving.html#scene-file-path-resolution\' title=\'\'>Scene File Path Resolution</a>, above.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` isMaxFile &quot;\\(scenes/ca_test1.max&quot; --returns true if file exists  isMaxFile &quot;\\)max/autoback/maxhold.mx&quot; --returns true if file exists isMaxFile &quot;$matlibs/Nature.mat&quot; --returns true if file exists isMaxFile (maxFilePath + maxFileName) --returns true unless the scene is Untitled</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"importing-files\"></a><h2 id=\"importing-files\">Importing Files</h2></div>\n\
<div class=\'codeBlock\'><pre>importFile &lt;filename_string&gt; [#noPrompt] [using:&lt;maxclass&gt;] \n\
</pre></div><p>Lets you import files using any of the import plug-ins that are available. The kind of file imported is determined by the file name suffix such as DXF for <span class=\'code\'>.dxf</span> , 3DS DOS for <span class=\'code\'>.3ds</span> , etc.</p>\n\
<p>The way 3ds Max looks for the specified <span class=\'code\'>&lt;filename_string&gt;</span> is the same as for loading scene files. For more information, see <a href=$13ds-Max-File-Loading-and-Saving.html#scene-file-path-resolution\' title=\'\'>Scene File Path Resolution</a>, above.</p>\n\
<p>The <span class=\'code\'>#noPrompt</span> flag prevents any configuration or control dialogs from being displayed in which case the default configuration is used.</p>\n\
<p>If the optional keyword argument <span class=\'code\'>using:</span> is supplied, the respective I/O class will be used to perform the import. This can be useful when multiple plug-ins support the same file format extension. Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<p>To see all available importer plug-in classes, you can access the <span class=\'code\'>.classes</span> property of the <span class=\'code\'>importerPlugin</span> value - it returns an array of all installed importer plug-ins:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES:</strong></p>\n\
<p>``` print importerPlugin.classes</p>\n\
<p>```</p>\n\
<p><strong>RESULT:</strong></p>\n\
<p>``` 3D_Studio 3D_Studio_Shape Adobe_Illustrator_Shape AutoCADImport FBXIMP DAEIMP STL_Import ATF_Solidworks_importer Revit_importer FileLinkAsDwgImporter ObjImp Alembic_Import VrmlImp ImportTRC XMLImp2 FltImport ATF_ProE_importer ImportHTR InventorImport LandXML___DEM_Model_Import sketchUp ATF_STEP_importer SATImport ATF_IGES_importer ATF_Alias_importer ATF_CATIA_V4_importer ATF_CATIA_V5_importer ATF_UG_NX_importer ATF_JT_importer</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>See also the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Import-and-Export-Filters/InventorImport-ImporterPlugin.html\' title=\'\'>Import and Export Filters</a> topic for MAXScript access to the settings of some Importer and Exporter plugins.</p>\n\
<div class=\'section\'><a id=\"exporting-files\"></a><h2 id=\"exporting-files\">Exporting Files</h2></div>\n\
<div class=\'codeBlock\'><pre>exportFile &lt;filename_string&gt; [#noPrompt] [selectedOnly:&lt;boolean&gt;] [using:&lt;maxclass&gt;] \n\
</pre></div><p>Lets you export files using any of the export plug-ins that are available.</p>\n\
<p>The kind of file exported is determined by the file name suffix such as DFX for <span class=\'code\'>.dxf</span> , 3DS DOS for <span class=\'code\'>.3ds</span> , etc.</p>\n\
<p>The <span class=\'code\'>#noPrompt</span> flag prevents any configuration or control dialogs from being displayed in which case the default configuration is used.</p>\n\
<p>If the <span class=\'code\'>selectedOnly</span> keyword parameter is set to <span class=\'code\'>true</span> , only selected nodes are exported. Defaults to <span class=\'code\'>false</span> .</p>\n\
<p>If the optional <span class=\'code\'>using:</span> keyword argument is supplied, the respective I/O class will be used to perform the export. This can be useful when multiple plug-ins support the same file format extension. Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<p>To get an array of all available exporter plug-in classes, you can access the <span class=\'code\'>.classes</span> property of the <span class=\'code\'>exporterPlugin</span> value:</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>``` theClasses =exporterPlugin.classes --&gt;#(3D_StudioExporterPlugin, Adobe_Illustrator, DWG_ExportExporterPlugin, DWG_Export, STL_Export, -- Alembic_Export, ACIS_SAT, PhysX_and_APEX_Exporter, FBXEXP, DAEEXP, IGES_Export, OpenFltExport, -- ArnoldSceneSourceExport, ObjExp, ExportHTR, AsciiExp, SvfExporter, VRBL_Export, DWF_Exporter)</p>\n\
<p>exportFile (GetDir #scene + &quot;/exportTest&quot; ) using:theClasses[1]</p>\n\
<p>```</p>\n\
<p>In the example above, the export will use the first plug-in found in the array, which is by default the <span class=\'code\'>3D_StudioExporterPlugin</span>.</p>\n\
</blockquote>\n\
<p>See also the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Import-and-Export-Filters/InventorImport-ImporterPlugin.html\' title=\'\'>Import and Export Filters</a> topic for MAXScript access to the settings of some Importer and Exporter plugins.</p>\n\
<div class=\'section\'><a id=\"saving-nodes\"></a><h2 id=\"saving-nodes\">Saving Nodes</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;saveNodes &lt;node_collection&gt; &lt;filename_string&gt; [saveAsVersion: &lt;integer&gt;] [quiet:&lt;boolean&gt;] \n\
</pre></div><p>Creates a new .max scene file with the given name and stores the node collection to it.</p>\n\
<p>The <span class=\'code\'>&lt;node_collection&gt;</span> argument can be a single node, an array of nodes you gathered, a wild-card path name, one of the built-in objects sets such as <span class=\'code\'>selection</span> or <span class=\'code\'>lights</span> , or a <span class=\'code\'>&lt;node&gt;.children</span> array.</p>\n\
<p>If no filename extension is specified, &quot;.max&quot; is automatically appended to the filename.</p>\n\
<p>Available in <strong>3ds Max 2011 and higher:</strong> If <span class=\'code\'>saveAsVersion:</span> provides a value of 2010, the resulting file will be saved in the specified version&#39;s file format. Versions prior to 3ds Max 2010 are not supported. If any other value is specified, or if not specified at all, the current version&#39;s file format will be used.</p>\n\
<p>For details on the <span class=\'code\'>quiet:</span> option which was added to this method in <strong>3ds Max 8</strong>, see <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Network-Render-Interface/Quiet-Mode.html\' title=\'\'>Quiet Mode</a>.</p>\n\
<p>The method will return true on success or false if the saving failed (for example if attempting to overwrite an existing read-only file) in <strong>3ds Max 8 and higher</strong>.</p>\n\
<blockquote>\n\
<p>Warning: <span class=\'code\'>saveNodes()</span> will overwrite existing files with the same name without warning! See <span class=\'code\'>CheckForSave()</span> and <span class=\'code\'>doesFileExist()</span> below for solution.</p>\n\
</blockquote>\n\
<div class=\'section\'><a id=\"check-for-save\"></a><h2 id=\"check-for-save\">Check For Save</h2></div>\n\
<div class=\'codeBlock\'><pre>checkForSave() \n\
</pre></div><p>If the scene has been modified since the last file save (if any), calling this function displays the message box prompting the user that the scene has been modified and requests to save.</p>\n\
<p>The function returns <span class=\'code\'>false</span> if the user selects &quot;Cancel&quot;, <span class=\'code\'>true</span> if the user selects to save and the scene was successfully saved, the user selects &quot;Don&#39;t Save&quot;, or if the scene does not need to be saved. The function also returns true if 3ds Max is running in quiet mode. The file is saved if the user selects &quot;Save&quot;.</p>\n\
<p>See also <span class=\'code\'>getSaveRequired()</span> in <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Miscellaneous-Functions/Exiting-and-Resetting-3ds-Max.html\' title=\'\'>Exiting and Resetting3ds Max</a>.</p>\n\
<blockquote>\n\
<p>Warning:</p>\n\
<p><span class=\'code\'>saveNodes()</span> and <span class=\'code\'>saveMaxFile()</span> will overwrite existing files with the same name without warning!</p>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<div class=\'codeBlock\'><pre>b = box()\n\
saveNodes b &quot;foo.max&quot;\n\
saveNodes b &quot;foo.max&quot;\n\
saveMaxFile &quot;foo.max&quot;\n\
--All these calls will overwrite the file &quot;foo.max&quot;\n\
--without notice.\n\
\n\
</pre></div></blockquote>\n\
<p>You should always use <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/External-Files-Access/File-Name-Parsing.html\' title=\'\'>doesFileExist()</a> to make sure the target file does not exist and prompt if it does.</p>\n\
<p>Here are two examples of using <span class=\'code\'>doesFileExist()</span> for these cases:</p>\n\
<blockquote>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` b = box() -- if filename exists, ask user if ok to overwrite -- function returns true if file was saved, false otherwise fn maybe_saveNodes nodeArray filename = ( if getFilenamePath filename == &quot;&quot; do filename = getdir #scene + &quot;\\&quot; + filename if (not (doesfileexist filename)) or querybox (&quot;filename: &quot;+filename + &quot;\\nexists. Overwrite?&quot;) then ( saveNodes nodeArray filename true ) else false )</p>\n\
<p>```</p>\n\
<p><strong>SCRIPT:</strong></p>\n\
<p>``` fn maybe_saveMaxFile filename = ( if getFilenamePath filename == &quot;&quot; do filename = getdir #scene + &quot;\\&quot; + filename if (not (doesfileexist filename)) or querybox (&quot;filename: &quot;+filename + &quot;\\nexists. Overwrite?&quot;) then ( saveMaxFile filename true ) else false )</p>\n\
<p>```</p>\n\
<p><strong>USING THE ABOVE FUNCTIONS:</strong></p>\n\
<p>``` maybe_saveNodes b &quot;foo.max&quot; maybe_saveNodes b &quot;foo.max&quot; maybe_saveMaxFile &quot;foo.max&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";