var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Bitmap Files</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Bitmap Files</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"bitmap-files\"></a></div>\n\
<p>The following method is used to collect a list of the bitmap files used in a scene.</p>\n\
<p>For the properties and methods associated with bitmap values, including reading and writing bitmap files, see <a href=\'#!/url=./developer/MAXScript-Language-Reference/Values/Bitmap-Values/Bitmap-Values-1.html\' title=\'\'>Bitmap Values</a>.</p>\n\
<div class=\'codeBlock\'><pre>enumerateFiles [ &lt;maxwrapper_obj&gt; ] &lt;function&gt; [ &lt;arg&gt; ] \\\n\
 [#inactive] [#videoPost] [#render] [#missing] \\\n\
 [#localOnly ] [#skipCustAttributes ] [#skipVPRender] [#firstSubOnly] \\\n\
 [#skipSubFiles] [#visitOnce] [#useEnumAccessor]     \n\
</pre></div><p>Lets you run through all the bitmap files currently used in the scene or in an individual object. You can filter this so it just gives you those for video post or the renderer or the ones that are inactive or missing.</p>\n\
<p>The enumerator works by calling a function you give it once for each of the file names it finds corresponding to the filters switches and other arguments you set.</p>\n\
<p>The only required argument is the <span class=\'code\'>&lt;function&gt;</span> argument.</p>\n\
<p>The details are:</p>\n\
<div class=\'codeBlock\'><pre>&lt;maxwrapper_obj&gt;\n\
</pre></div><p>An optional <strong>3ds Max</strong> object, such as a node or a material. Supplying this argument causes the enumerator to only consider files associated with this object. See the <span class=\'code\'>#localOnly</span> switch for more info.</p>\n\
<div class=\'codeBlock\'><pre>&lt;function&gt; \n\
</pre></div><p>The function to be called for each file found. It should be a function of one or two arguments, the first one is the string file name supplied by the enumerator. See example below.</p>\n\
<div class=\'codeBlock\'><pre>&lt;arg&gt; \n\
</pre></div><p>If specified is passed to the <span class=\'code\'>&lt;function&gt;</span> as its second argument by the enumerator. This is useful if you have a general purpose enumerator function that can be conditioned by the argument you pass in on a particular enumeration, or if you want to pass in an array that the found names should be appended to.</p>\n\
<div class=\'codeBlock\'><pre>#inactive \n\
</pre></div><p>Include the inactive files.</p>\n\
<div class=\'codeBlock\'><pre>#videoPost \n\
</pre></div><p>Include the files used in video post.</p>\n\
<div class=\'codeBlock\'><pre>#render \n\
</pre></div><p>Include the files used during rendering.</p>\n\
<div class=\'codeBlock\'><pre>#missing \n\
</pre></div><p>Include files that are missing in the file system</p>\n\
<p>If you don&#39;t specify any of the above filter flags, <strong>all</strong> the files are enumerated.</p>\n\
<div class=\'codeBlock\'><pre>#localOnly \n\
</pre></div><p>Use in conjunction with the <span class=\'code\'>&lt;maxwrapper_obj&gt;</span> argument. If specified, limits the enumeration to those files used directly in the object, if not then any referenced objects are scanned.</p>\n\
<div class=\'codeBlock\'><pre>#skipCustAttributes \n\
</pre></div><p>Don&#39;t enumerate into custom attributes</p>\n\
<div class=\'codeBlock\'><pre>#skipVPRender \n\
</pre></div><p>Don&#39;t include viewport rendering only required files.</p>\n\
<div class=\'codeBlock\'><pre>#firstSubOnly \n\
</pre></div><p>Stop checking after the first missing sub file is found when checking for missing files. This applies to objects that use sub files for their assets, for example the bitmap files specified in an .ifl file, or per-frame cache files used by the point cache modifier.</p>\n\
<div class=\'codeBlock\'><pre>#skipSubFiles \n\
</pre></div><p>Skip asset sub files. This applies to objects that use sub files for their assets, for example the bitmap files specified in an .ifl file, or per-frame cache files used by point cache modifier.</p>\n\
<div class=\'codeBlock\'><pre>#visitOnce \n\
</pre></div><p>Use in conjunction with the <span class=\'code\'>&lt;maxwrapper_obj&gt;</span> argument. If specified, any references held by the object are scanned once. In large scenes, using this option can be an expensive operation.</p>\n\
<div class=\'codeBlock\'><pre>#useEnumAccessor \n\
</pre></div><p>Use an alternative means of recording of assets that is used by the <strong>Asset Tracking</strong> dialog. This is primarily exposed for testing of the object <span class=\'code\'>EnumAuxFiles</span> methods. The handling of sub files is different when using this option. The first sub file is always recorded, and only missing sub files after that first sub file are recorded.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` function get_names name a = append a name files = #() enumerateFiles get_names files #missing</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The following script will print out a sorted list of all the bitmap files used in the current scene file:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` ( local mapfiles=#() fn addmap mapfile = ( local mapfileN=mapfile as name local index=finditem mapfiles mapfileN if index == 0 do append mapfiles mapfileN ) enumeratefiles addmap --line 9 sort mapfiles for mapfile in mapfiles do print (mapfile as string) )</p>\n\
<p>```</p>\n\
<p>By replacing line 9 with</p>\n\
<p>``` enumeratefiles addmap #missing</p>\n\
<p>```</p>\n\
<p>only the missing bitmap files will be printed.</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";