var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>MAX Scene File Properties</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>MAX Scene File Properties</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"max-scene-file-properties\"></a></div>\n\
<p>The <strong>File Properties</strong> can be accessed in MAXScript using the methods described in this topic.</p>\n\
<p>The File Properties are organized into three sets. These sets correspond to the three pages in the Main Menu &gt; File &gt; File Properties dialog:</p>\n\
<div class=\'codeBlock\'><pre>#summary \n\
</pre></div><p>This set contains the Title, Subject, Author, Keywords, Comments fields from the Summary page.</p>\n\
<div class=\'codeBlock\'><pre>#contents \n\
</pre></div><p>This set contains the Manager, Company, Category and an array of all headers from the Contents page like General, Mesh Totals etc. Note that the Contents page contents are only update when the file is saved. You can perform a <span class=\'code\'>max hold</span> to perform a scene hold, which causes the file to be saved and the Contents page contents to be updated.</p>\n\
<div class=\'codeBlock\'><pre>#custom \n\
</pre></div><p>This set contains all the fields from the Custom page.</p>\n\
<p>The following methods are used to access the above sets. <span class=\'code\'>&lt;set_name&gt;</span> can be any of the values from above.</p>\n\
<div class=\'codeBlock\'><pre>fileProperties.getNumProperties &lt;set_name&gt; \n\
</pre></div><p>Returns the number of properties in the given set.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` numProps=fileProperties.getNumProperties #summary</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>fileProperties.getPropertyName &lt;set_name&gt; &lt;index&gt; \n\
</pre></div><p>Returns as a string the property name of the given index. The index is 1-based.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` nameProp=fileProperties.getPropertyName #summary 1</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>fileProperties.getPropertyValue &lt;set_name&gt; &lt;index&gt; \n\
</pre></div><p>Returns the property value of given index. The value type can be one of the following types of values currently supported by <strong>3ds Max</strong> in the File Properties dialog. The values in bracket are the MAXScript equivalent value type.</p>\n\
<p>Property Value Types:</p>\n\
<div class=\'codeBlock\'><pre>Text [String]\n\
Date [String] - contains the date eg:&quot;03/23/99&quot;\n\
Number [Integer or Float based on actual value]\n\
Yes or No [Boolean]\n\
Headers [Array of strings]\n\
</pre></div><p>Headers are items like General, Mesh Totals, etc. that appear in contents page.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>an array of headers from contents page obtained using:</p>\n\
<p>``` fileproperties.getPropertyValue #contents 1</p>\n\
<p>```</p>\n\
<p>will return</p>\n\
<p>``` #(&quot;General&quot;, &quot;Mesh Totals&quot;,...)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>fileProperties.getItems &lt;header_string&gt; \n\
</pre></div><p>Returns an array of strings containing all the items under the given header.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>an array of headers from contents page obtained using:</p>\n\
<p>``` fileProperties.getItems &quot;Mesh Totals&quot;</p>\n\
<p>```</p>\n\
<p>might return</p>\n\
<p>``` #(&quot;Vertices: 488&quot;, &quot;Faces: 968&quot;)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>fileProperties.findProperty &lt;set_name&gt; &lt;prop_name_string&gt; \n\
</pre></div><p>Given the set name and property name string, will return the index of the property if found, 0 if not found.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` fileProperties.findProperty #custom &quot;BoolVal&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>fileProperties.addProperty &lt;set_name&gt; &lt;prop_name_string&gt; &lt;prop_value&gt; [#date] \n\
</pre></div><p>Adds a new property with the property name and property value to the specified set.</p>\n\
<p>The property values can be any of the types previously described except an Array as you cannot add anything to contents page.</p>\n\
<p>If string containing a date is passed then the optional <span class=\'code\'>#date</span> argument has to be passed for it to be added as a date value.</p>\n\
<p>Adding to an existing property name will replace the existing value and act as a setter function - this is why <strong>there is no</strong> <span class=\'code\'>fileProperties.setProperty()</span> method.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE:</strong></p>\n\
<p>``` fileProperties.addProperty #custom &quot;DateVal&quot; &quot;03/23/99&quot; #date</p>\n\
<p>```</p>\n\
<p>will add a date property named <span class=\'code\'>DateVal</span> to the custom page.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>fileProperties.deleteProperty &lt;set_name&gt; &lt;prop_name_string&gt; \n\
</pre></div><p>Delete the property indicated by <span class=\'code\'>&lt;prop_name_string&gt;</span> in the specified set.</p>\n\
<p>Following is an example of printing all the File Properties in an hierarchical fashion for the current scene.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` -- Add some properties fileProperties.addProperty #summary &quot;Title&quot; &quot;H2G2&quot; fileProperties.addProperty #summary &quot;Subject&quot; &quot;Earth&quot; fileProperties.addProperty #summary &quot;Author&quot; &quot;Ford Prefect&quot;</p>\n\
<p>fileProperties.addProperty #contents &quot;Manager&quot; &quot;Zarniwoop&quot; fileProperties.addProperty #contents &quot;Company&quot; &quot;Megadodo Publishing&quot; fileProperties.addProperty #contents &quot;Category&quot; &quot;Mostly Harmless&quot;</p>\n\
<p>fileProperties.addProperty #custom &quot;IntVal&quot; 42 fileProperties.addProperty #custom &quot;FloatVal&quot; 1.234 fileProperties.addProperty #custom &quot;BoolVal&quot; true fileProperties.addProperty #custom &quot;DateVal&quot; &quot;05/11/2001&quot; #date -- -- Perform a scene hold to update the Contents set. max hold -- -- Get all properties pages = #( #summary, #contents, #custom) for pg in pages do ( format &quot;--- % ---\\n&quot; (pg as string) for i=1 to (fileProperties.getNumProperties pg) do ( local pname = (fileProperties.getPropertyName pg i) local pval = (fileProperties.getPropertyValue pg i) format &quot;\\t% : &quot; pname if (pname ==&quot;Headers&quot;) then ( format &quot;\\n&quot; for hdr in pval do ( format &quot;\\t\\t%\\n&quot; hdr local docs = fileProperties.getItems hdr if docs != undefined then for d in docs do format &quot;\\t\\t\\t%\\n&quot;d ) ) else format &quot; %\\n&quot; pval ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";