var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Character Encoding</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Character Encoding</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"character-encoding\"></a></div>\n\
<p><strong>3ds Max 2013 and higher</strong> provide support for multi-lingual character support in text files.</p>\n\
<p>While the majority of the changes are transparent to the user, there are several aspects of this new functionality that affect MAXScript files or are exposed to MAXScript for advanced user control.</p>\n\
<p>The following topic discusses the various encoding standards and provides links to the affected features.</p>\n\
<div class=\'section\'><a id=\"character-encoding-overview\"></a><h2 id=\"character-encoding-overview\">Character Encoding Overview</h2></div>\n\
<p>In the early days of computing, text files were encoded using the <strong>ASCII</strong> (<strong>A</strong>merican <strong>S</strong>tandard <strong>C</strong>ode for <strong>I</strong>nformation <strong>I</strong>nterchange) specification. The ASCII originally used 7-bit encoding and represented only the English alphabet, the digits from 0 to 9 and punctuation characters.</p>\n\
<p>Later, ASCII was extended to 8-bit with international and special characters added in the upper half of the table (ASCII code above 127). Only 128 additional characters could be active at a time, so it wasn&#39;t possible to support both Cyrillic and German characters at the same time, for example. The extended ASCII used in Microsoft Windows is known as Windows-1252 or ANSI encoding.</p>\n\
<p>To solve this problem and allow each character to be stored with its unique code, a Unicode standard was introduced in the early 90s. Various Unicode-based encodings implement the Unicode standard. These include UTF-8, UTF-16, UTF-32/UCS-4. They all go beyond 8-bit encoding and support almost every language on the planet. UTF-8 is the dominant Unicode encoding, esp. on the World Wide Web.</p>\n\
<div class=\'section\'><a id=\"utf-8\"></a><h3 id=\"utf-8\">UTF-8</h3></div>\n\
<p><strong>UTF-8</strong> stands for &quot;<strong>U</strong>CS <strong>T</strong>ransformation <strong>F</strong>ormat&quot;, where <strong>UCS</strong> stands for &quot;<strong>U</strong>niversal <strong>C</strong>haracter <strong>S</strong>et&quot;. <strong>UCS</strong> is an <strong>International ISO/IEC standard</strong>.</p>\n\
<p><strong>UTF-8</strong> is a variable-width encoding - it uses one to four 8-bit bytes (called octets in the Unicode Standard) to represent each of the 1,112,064 unique characters of the Unicode Character Set.</p>\n\
<p>Characters with lower numerical values which are used more often in practice are encoded using less bytes, somewhat improving efficiency.</p>\n\
<p>In particular, the first 128 characters of the Unicode Character Set correspond one-to-one to the ASCII character set, and UTF-8 also encodes them with one byte. This makes ASCII text valid UTF-8-encoded Unicode text as well.</p>\n\
<p>A side effect of this is that some foreign languages require more bytes to represent their characters - for example Cyrillic and Greek characters require mostly two bytes, other languages can take 3 or even 4 bytes for their characters, thus producing larger text files.</p>\n\
<div class=\'section\'><a id=\"utf-16\"></a><h3 id=\"utf-16\">UTF-16</h3></div>\n\
<p><strong>UTF-16</strong> is similar to <strong>UTF-8</strong> in the amount of characters it can encode, but it uses two 16-bit bytes instead of four 8-bit bytes to encode the Unicode Character Set.</p>\n\
<p>Since the WIndows API supports only <strong>ANSI</strong> and <strong>UTF-16</strong>, <strong>3ds Max 2013</strong> uses <strong>UTF-16</strong> internally for Unicode representation, including text streams inside the scene file, INI files saving and loading etc.</p>\n\
<div class=\'section\'><a id=\"bom-byte-order-mark\"></a><h3 id=\"bom-byte-order-mark\">BOM (Byte-Order Mark)</h3></div>\n\
<p>Some Windows programs add the bytes 0xEF, 0xBB, 0xBF to the beginning of an UTF-8 file. This is the UTF-8 encoding of the Unicode Byte-Order Mark and is commonly referred to as <strong>UTF-8 BOM</strong>, even though it is not relevant to the actual byte order. Most modern text editors will strip these bytes, but some older programs might not.</p>\n\
<p>If compatibility with other programs is not important, the BOM bytes could be used to identify the file as UTF-8 encoding as opposed to ASCII encoding. For example, saving an .MS file with BOM will allow <strong>3ds Max 2012</strong> and earlier to open the script without losing international characters.</p>\n\
<p>In general, if compatibility with older software is not an issue, it is recommended not to use UTF-8 BOM and leave the determination of the encoding to the program (by checking if the file is valid UTF-8).</p>\n\
<div class=\'section\'><a id=\"character-encoding-defaults-in-3ds-max\"></a><h2 id=\"character-encoding-defaults-in-3ds-max\">Character Encoding Defaults in 3ds Max</h2></div>\n\
<p>The default Character Encoding of non-scene files is controlled by the <strong>Customize &gt; Preferences &gt; File tab &gt; File String Data Handling</strong> group of controls.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-B7B1A1EF-BE89-41A5-B0C4-19BDA596B0CE-low.png\' title=\'\'></div>\n\
<p><strong>Override language data specified in scene file</strong></p>\n\
<p>When unchecked, the language data stored in the .MAX scene file will be respected.</p>\n\
<p>When checked, the language data will be overridden.</p>\n\
<p><strong>Save strings in legacy non-scene files using UTF8</strong></p>\n\
<p>When unchecked, text files will be saved as ASCII for compatibility.</p>\n\
<p>When checked, text files will be saved using <strong>UTF-8 with BOM</strong> encoding.</p>\n\
<div class=\'section\'><a id=\"character-encoding-and-maxscript\"></a><h2 id=\"character-encoding-and-maxscript\">Character Encoding and MAXScript</h2></div>\n\
<div class=\'section\'><a id=\"maxscript-editor-and-script-files\"></a><h3 id=\"maxscript-editor-and-script-files\">MAXScript Editor and Script Files</h3></div>\n\
<p>The most obvious area affected by the ability of 3ds Max to write text files using different character encoding is the MAXScript Tabbed Editor (also known as MAXScript Pro Editor) introduced in <strong>3ds Max 2008</strong>.</p>\n\
<p><strong>3ds Max 2013</strong> added the ability to control the encoding of the saved script file via a drop-down list in the <strong>Save File...</strong> dialog of the MAXScript Editor.</p>\n\
<p>The default setting of the drop-down list for new files is <strong>&quot;Default Code Page&quot;</strong>.</p>\n\
<p>The setting of the drop-down list for existing files will depend on the encoding of the file, so resaving will preserve the encoding unless changed explicitly.</p>\n\
<p>The default behavior of <strong>3ds Max</strong> when saving <strong>&quot;Default Code Page&quot;</strong> is to NOT use <strong>UTF-8 with BOM</strong>. This can be changed in the Preferences dialog (see previous section) to enforce saving as <strong>UTF-8 with BOM</strong>.</p>\n\
<p>In versions <strong>prior to 3ds Max 2013</strong>, the MAXScript Editor saved script files implicitly as <strong>UTF-8 BOM</strong>.</p>\n\
<p>The Editor in previous versions of <strong>3ds Max</strong> will also load <strong>UTF-8 with BOM</strong> files correctly, but does not support all other flavors including Unicode, Unicode BigEndian and UTF-8 without BOM.</p>\n\
<p>Thus, script files saved from previous versions of <strong>3ds Max</strong> will load correctly in <strong>3ds Max 2013 and higher</strong>, but files saved from <strong>3ds Max 2013 or higher</strong> will only load international characters correctly if saved as <strong>UTF-8 with BOM</strong>. Otherwise, international characters will be replaced with a ? symbol.</p>\n\
<p><strong>For Example</strong></p>\n\
<p>The following script contains three string definitions in three languages - English, German and Bulgarian.</p>\n\
<p>After entering the text in the MAXScript Editor of <strong>3ds Max 2013 or higher</strong>, the script was saved as Default Code Page, Unicode, Unicode BigEndian, UTF-8 BOM and UTF-8.</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-6EE9557E-2A19-424D-8668-35A2B1D14724-low.png\' title=\'\'></div>\n\
<p>After saving the text using all supported encoding standards, the resulting script files were opened again in the MAXScript Editor of <strong>3ds Max 2013</strong>:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-85B51E68-F826-4FE4-BB8C-607605F01120-low.png\' title=\'\'></div>\n\
<p>As you can see, all files except for the Default Code Page one reproduce the original multi-lingual content correctly.</p>\n\
<p>Now let&#39;s take a look at the same files loading in the MAXScript Editor of <strong>3ds Max 2012</strong>:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-7ED26076-C6D5-4238-AB24-FFD7FBAB0512-low.png\' title=\'\'></div>\n\
<p>As you can see, only the UTF-8 BOM encoding was interpreted correctly. The UTF-8 contains the German characters, but completely lost the Bulgarian text. The Unicode is not recognized at all.</p>\n\
<p>Note that re-saving the UTF-8 BOM encoded file from <strong>3ds Max 2012</strong> opens it correctly in <strong>3ds Max 2013</strong>:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-E5108EB1-58AE-4EBB-A572-82FDB59029BB-low.png\' title=\'\'></div>\n\
<div class=\'section\'><a id=\"encoding-and-user-interface-text\"></a><h3 id=\"encoding-and-user-interface-text\">Encoding and User Interface Text</h3></div>\n\
<p>Creating a test rollout with three edit text controls and putting each of the three strings in a text field produces correct encoding in <strong>3ds Max 2013</strong>, but not in <strong>3ds Max 2012</strong>:</p>\n\
<p><img src=\'developer/images/GUID-8163E21D-AD10-47B4-BBB8-32CCFD70983C-low.png\' title=\'\'> <img src=\'developer/images/GUID-52727A07-E6F4-4D9D-9800-366AAEB67D48-low.png\' title=\'\'></p>\n\
<p>In other words, although the MAXScript Editor in previous versions of <strong>3ds Max</strong> is able to read UTF-8 BOM encoded files, <strong>3ds Max</strong> itself was not able to represent the international characters correctly.</p>\n\
<p>Starting with <strong>3ds Max 2013</strong>, the complete application is Unicode-aware and international characters will be displayed correctly.</p>\n\
<div class=\'section\'><a id=\"filestream-text-files-input-and-output\"></a><h3 id=\"filestream-text-files-input-and-output\">FileStream Text Files Input and Output</h3></div>\n\
<p>The saving and loading of text files using the FileStream methods will support the current character encoding settings.</p>\n\
<p>For example, if the Preferences dialog is set to not override the encoding to UTF-8, using the following script will produce a text file with missing international characters:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` theString1 = &quot;This is some English text.&quot; theString2 = &quot;Das wäre auf Deutsch, so daß man die Unterschiede sehen könnte...&quot; theString3 = &quot;Най-сетне повод да вмъкна малко Български в документацията!&quot;</p>\n\
<p>theFileName = (GetDir #temp + &quot;\\testencoding.txt&quot;) theFile = createFile theFileName format &quot;%\\n&quot; theString1 to:theFile format &quot;%\\n&quot; theString2 to:theFile format &quot;%\\n&quot; theString3 to:theFile close theFile edit theFileName ```</p>\n\
</blockquote>\n\
<p>Switching the Preferences to &quot;Save strings in legacy non-scene files using UTF8&quot; will save the file as UTF-8 and the Bulgarian text will be saved and loaded correctly.</p>\n\
<div class=\'section\'><a id=\"ini-files-saving-and-loading\"></a><h3 id=\"ini-files-saving-and-loading\">INI Files Saving and Loading</h3></div>\n\
<p>The <span class=\'code\'>setIniSetting()</span> method uses its own defaults settings independent from the Preferences settings of <strong>3ds Max</strong>.</p>\n\
<p>By default, <span class=\'code\'>setIniSetting()</span> will default to UTF-16 encoding.</p>\n\
<p>A <span class=\'code\'>setIniForceUTF16Default()</span> method can set the temporary default of the encoding (valid only for the current <strong>3ds Max</strong> session).</p>\n\
<p>The user can specify the encoding explicitly using the optional keyword argument <span class=\'code\'>forceUTF16:</span></p>\n\
<p>For details, please see the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/External-Files-Access/Accessing-INI-File-Keys.html\' title=\'\'><span class=\'code\'>setINISetting()</span></a> documentation.</p>\n\
<div class=\'section\'><a id=\"memstreammgr-parsing\"></a><h3 id=\"memstreammgr-parsing\">MemStreamMgr Parsing</h3></div>\n\
<p>The <strong><span class=\'code\'>[MemStreamMgr](../../3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/M/Interface-MemStream.html).openFile()</span></strong> method now provides two optional keyword arguments to control the encoding and code page.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";