var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Accessing INI File Keys</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Accessing INI File Keys</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"accessing-ini-file-keys\"></a></div>\n\
<p>An INI File is a pure ASCII Text file typically used to store settings of User Interface states or any arbitrary information. The data is organized in Categories containing any number of Keys and corresponding Values.</p>\n\
<p>MAXScript provides a very error-tolerant set of functions to manage INI Files. For example, setting a new category and key in an non-existent INI file will automatically generate a new file without the need for any additional management function calls. Getting a non-existent key value from an existing file or even from a non-existent file will return an empty string without causing an error and so on.</p>\n\
<p>Note: The <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/External-Files-Access/3ds-Max-Configuration-File.html\' title=\'\'>cfgMgr</a> struct contains functions to operate specifically on the 3ds Max configuration file, 3dsmax.ini.</p>\n\
<div class=\'section\'><a id=\"the-following-methods-provide-read-and-write-access-to-categories-keys-and-values-in-ini-files\"></a><h3 id=\"the-following-methods-provide-read-and-write-access-to-categories-keys-and-values-in-ini-files\">The following methods provide read and write access to Categories, Keys and Values in INI files:</h3></div>\n\
<div class=\'codeBlock\'><pre>getINISetting &lt;filename_string&gt; &lt;section_string&gt; &lt;key_string&gt;       \n\
</pre></div><p>Reads an INI setting from the specified file. Within the file, the section identified by <span class=\'code\'>&lt;section_string&gt;</span> is located, and then the key specified by the <span class=\'code\'>&lt;key_string&gt;</span> is located.</p>\n\
<p>The value assigned to this key is then returned as a string.</p>\n\
<p>If the specified file, section, or key is not found, an empty string &quot;&quot; is returned.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` getINISetting &quot;c:/temp/test.ini&quot; &quot;Directories&quot; &quot;Scenes&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>In <strong>3ds Max 6 and higher</strong>, if only the .ini file is specified, the method will return an <strong>array of the sections</strong> in the .ini file.</p>\n\
<p>In <strong>3ds Max 6 and higher</strong>, if only the .ini file and section are specified, the method will return an <strong>array of the keys</strong> in the section.</p>\n\
<p>In <strong>3ds Max 2017 Update 1</strong> and higher, the return value can be up to 32,767 characters in length. In previous versions, values would be truncated at about 8000 characters.</p>\n\
<div class=\'codeBlock\'><pre>setINISetting &lt;filename_string&gt; &lt;section_string&gt; &lt;key_string&gt; &lt;key_value_string&gt; [ forceUTF16:&lt;boolean&gt; ]\n\
</pre></div><p>Sets an INI setting in the specified file.</p>\n\
<p>Returns a value of true if the key value was written to the file, false if the key was not written.</p>\n\
<p>Within the file, the section identified by <span class=\'code\'>&lt;section_string&gt;</span> is located, and then the key specified by the <span class=\'code\'>&lt;key_string&gt;</span> is located.</p>\n\
<p>The <span class=\'code\'>&lt;key_value_string&gt;</span> is then assigned to this key.</p>\n\
<p>If the specified file, section, or key is not found, a <strong>new file, section, or key</strong> is created.</p>\n\
<p>If the specified file is read-only, or the file is open in MAXScript, the key value is not written to the file.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` setINISetting &quot;c:/temp/test.ini&quot; &quot;Directories&quot; &quot;Scenes&quot; &quot;c:/3dsmax/scenes&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>The optional <span class=\'code\'>forceUTF16:</span> keyword argument available in <strong>3ds Max 2013 and higher</strong> controls whether the value is written using UTF16 encoding or as ASCII text.</p>\n\
<p>By default, when the optional keyword argument is not supplied, or is supplied as true, UTF16 encoding will be used.</p>\n\
<p>If the optional keyword is provided as false, the value will be written as ASCII text.</p>\n\
<p>An additional <strong>method</strong> available in <strong>3ds Max 2013 and higher</strong> controls the default behavior of the <span class=\'code\'>forceUTF16:</span> optional keyword argument when it is not supplied:</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;setIniForceUTF16Default &lt;boolean&gt;\n\
</pre></div><p>After a fresh start, the <span class=\'code\'>forceUTF16:</span> keyword argument&#39;s default value is true.</p>\n\
<p>Calling <span class=\'code\'>setIniForceUTF16Default false</span> will set the default encoding of the <span class=\'code\'>setINISetting()</span> method to ASCII.</p>\n\
<p>Calling <span class=\'code\'>setIniForceUTF16Default true</span> will set the default encoding of the <span class=\'code\'>setINISetting()</span> method to UTF16.</p>\n\
<p>The default behavior is not sticky between sessions, after a restart it will revert back to <span class=\'code\'>forceUTF16:</span> default encoding.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES</strong></p>\n\
<p>``` setINISetting &quot;c:/temp/deleteme.ini&quot; &quot;Hello&quot; &quot;World&quot; &quot;10&quot; --utf16 encoding by default setINISetting &quot;c:/temp/deleteme.ini&quot; &quot;Hello&quot; &quot;World&quot; &quot;10&quot; forceUTF16:false --force ASCII setIniForceUTF16Default false --switch default behavior when keyword argument unsupplied setINISetting &quot;c:/temp/deleteme.ini&quot; &quot;Hello&quot; &quot;World&quot; &quot;10&quot; --ASCII by default setINISetting &quot;c:/temp/deleteme.ini&quot; &quot;Hello&quot; &quot;World&quot; &quot;10&quot; forceUTF16:true --force utf16 encoding setIniForceUTF16Default true --switch back to startup default</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>delIniSetting &lt;filename_string&gt; &lt;section_string&gt; &lt;key_string&gt;   \n\
</pre></div><p>Deletes the specified key from the supplied section of the given INI file.</p>\n\
<div class=\'codeBlock\'><pre>delIniSetting &lt;filename_string&gt; &lt;section_string&gt; \n\
</pre></div><p>Deletes the section and all keys in the section of the given INI file.</p>\n\
<div class=\'codeBlock\'><pre>hasINISetting &lt;filename_string&gt; &lt;section_string&gt; [&lt;key_string&gt;] \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the INI setting exists in the specified file.</p>\n\
<p>This method is available in <strong>3ds Max 2008 and higher</strong>.</p>\n\
<p>Within the file, the section identified by <span class=\'code\'>&lt;section_string&gt;</span> is located, and then the key specified by the <span class=\'code\'>&lt;key_string&gt;</span> is tested for.</p>\n\
<p>If <span class=\'code\'>&lt;key_string&gt;</span> is not specified, the section specified by <span class=\'code\'>&lt;section_string&gt;</span> is tested for.</p>\n\
<div class=\'section\'><a id=\"related-methods\"></a><h3 id=\"related-methods\">Related Methods:</h3></div>\n\
<div class=\'codeBlock\'><pre>getMAXIniFile() \n\
</pre></div><p>In <strong>3ds Max 6 and higher</strong>, returns the current 3dsmax.ini file as a string. For some products that store the ini settings in the registry, this method returns undefined.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";