var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>External File Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>External File Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"external-file-methods\"></a></div>\n\
<p>The following methods provide access to external files and directories.</p>\n\
<div class=\'codeBlock\'><pre>getFiles &lt;wild_card_filename_string&gt; recurse:&lt;boolean&gt; \n\
</pre></div><p>Returns an array of file names that match the given wild-card path name. If <span class=\'code\'>recurse</span> is specified as true, recursively searches directories starting at the specified directory. The default is false.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE,</strong></p>\n\
<p>The following code gets an array of all the .max scene files in c:\\foo and then loops over the array, opening each file and printing the objects in each:</p>\n\
<p>``` files = getFiles &quot;c:\\foo\\*.max&quot; for f in files do (loadMAXFile f; print objects)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><span class=\'code\'>getFiles()</span> can also be used to determine if a <strong>file or file pattern</strong> exists.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>the following function will return <span class=\'code\'>true</span> if the specified file name or pattern exists:</p>\n\
<p>``` fn existFile fname = (getfiles fname).count != 0</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>See also <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/External-Files-Access/GUID-0EE531B2-6FF8-4D0B-ACA1-5400E0B9D604.html\' title=\'\'>doesFileExist()</a> which checks for a single file only and does not support wildcard patterns.</p>\n\
<div class=\'codeBlock\'><pre>getDirectories &lt;wild_card_directory_name_string&gt; recurse:&lt;boolean&gt;  \n\
</pre></div><p>Returns an array of directory paths that match the given wild-card directory path name. If <span class=\'code\'>recurse</span> is specified as true, recursively searches directories starting at the specified directory. The default is false.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` fn getFilesRecursive root pattern = ( dir_array = GetDirectories (root+&quot;/<em>&quot;) for d in dir_array do join dir_array (GetDirectories (d+&quot;/</em>&quot;)) my_files = #() for f in dir_array do join my_files (getFiles (f + pattern)) my_files ) --get all .ms files from the folder c:/temp --and all its subfolders: getFilesRecursive &quot;c:/temp&quot; &quot;*.ms&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>makeDir &lt;directory_path_string&gt; all:&lt;boolean&gt; \n\
</pre></div><p>Creates a new directory with the given name.</p>\n\
<p>Returns <span class=\'code\'>true</span> if the path was created successfully or if it existed already.</p>\n\
<p>Returns <span class=\'code\'>false</span> if the path could not be created either because the argument was not a valid path or due to insufficient writing rights.</p>\n\
<p>If the optional <span class=\'code\'>all:</span> keyword argument is set to <span class=\'code\'>true</span> (default since <strong>3ds Max 9</strong>, in <strong>3ds Max 8</strong> the default was <span class=\'code\'>false</span> ), all sub-directory levels specified in the path will be created if they do not exist.</p>\n\
<p>MAXScript does not provide a method for deleting directories. See the last example for <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/External-Files-Access/GUID-846B6AB0-EFF6-43E5-8A67-8D348FF78A57.html\' title=\'\'>HiddenDOSCommand()</a> for a possible workaround.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLES</strong></p>\n\
<p>``` makeDir @&quot;c:\\temp\\test\\deleteme\\if\\you\\can&quot; all:false false --unless the path already exists up to the \\you folder makeDir @&quot;c:\\temp\\test\\deleteme\\if\\you\\can&quot; all:true true --creates all the folders listed in the path makeDir @&quot;c:\\temp\\test\\deleteme\\if\\you&quot; all:true true --even if the previous call had created the path, still ok makeDir @&quot;a:\\temp&quot; false --unless you still have a Floppy drive and a disk for it!</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;removeDir &lt;directory_path_string&gt; \n\
</pre></div><p>Removes the specified directory. Returns true if the directory was removed.</p>\n\
<div class=\'codeBlock\'><pre>deleteFile &lt;filename_string&gt; \n\
</pre></div><p>Deletes the named file.</p>\n\
<p>Fails if the file is open in MAXScript.An open file can be closed using the respective close() method for ASCII or Binary streams, or if the handle is not accessible due to local scope, by calling manual Garbage Collection using <span class=\'code\'>gc().</span></p>\n\
<p>Does <strong>not</strong> work on directories created using <span class=\'code\'>makeDir()</span> , only on actual files. For a way to delete a directory, see the last example for</p>\n\
<p><a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/External-Files-Access/GUID-846B6AB0-EFF6-43E5-8A67-8D348FF78A57.html\' title=\'\'>HiddenDOSCommand()</a></p>\n\
<p>.</p>\n\
<p>Returns <span class=\'code\'>true</span> on success, <span class=\'code\'>false</span> on failure.</p>\n\
<div class=\'codeBlock\'><pre>renameFile &lt;old_filename_string&gt; &lt;new_filename_string&gt; \n\
</pre></div><p>Renames the old file to the new file.</p>\n\
<p>This can also be used to <strong>move</strong> a file between directories.</p>\n\
<p>Fails if the new file already exists or if the old file is open in MAXScript.</p>\n\
<p>Returns <span class=\'code\'>true</span> on success, <span class=\'code\'>false</span> on failure.</p>\n\
<div class=\'codeBlock\'><pre>copyFile &lt;existing_filename_string&gt; &lt;target_filename_string&gt; \n\
</pre></div><p>Copies the existing file to the new file.</p>\n\
<p>Fails if the existing file is open in MAXScript, the target file cannot be created, or the target file already exists. In the latter case, you can use <span class=\'code\'>deleteFile()</span> to remove the existing target file first.</p>\n\
<p>Returns <span class=\'code\'>true</span> on success, <span class=\'code\'>false</span> on failure.</p>\n\
<div class=\'codeBlock\'><pre>getFileSize &lt;filename_string&gt; \n\
</pre></div><p>Returns the size of the specified file in bytes.</p>\n\
<p>Returns 0 if the file could not be found.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` GetFileSize (getDir #maxRoot + &quot;\\3dsmax.exe&quot;) --&gt; 9881600</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>getFileAttribute &lt;filename_string&gt; &lt;attribute&gt; \n\
setFileAttribute &lt;filename_string&gt; &lt;attribute&gt; &lt;boolean&gt; \n\
</pre></div><p>Get and set the attributes associated with a file.</p>\n\
<p>The get function returns <span class=\'code\'>true</span> or <span class=\'code\'>false</span> depending on the state of the specified attribute.</p>\n\
<p>The set function sets the state of the individual attribute specified (leaving other attributes as they were).</p>\n\
<p>The valid <span class=\'code\'>&lt;attribute&gt;</span> values are:</p>\n\
<div class=\'codeBlock\'><pre>#readOnly #hidden #system #directory #archive #temporary #normal \n\
getFileModDate &lt;filename_string&gt; \n\
</pre></div><p>Returns a String value containing the modification date for the specified file, for example <span class=\'code\'>&quot;1/29/99 1:52:05 PM&quot;</span> .</p>\n\
<div class=\'codeBlock\'><pre>getFileCreateDate &lt;filename_string&gt; \n\
</pre></div><p>Returns a String value containing the creation date for the specified file.</p>\n\
<div class=\'codeBlock\'><pre>getFileVersion &lt;filename_string&gt; \n\
</pre></div><p>Returns the file and product version for the specified file, or unknown if this data is not specified in the file. This data is typically specified only for executable and application extension (i.e., .dll) files.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` GetFileVersion (getDir #maxRoot + &quot;\\3dsmax.exe&quot;) --&gt; &quot;12,0,0,91 12,0,0,91&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>getFileSecurityInfo &lt;file_name&gt; &lt;attribute&gt; testFileAttribute: &lt;boolean&gt; \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the specified file exists and the specified security attribute is set, where <span class=\'code\'>&lt;attribute&gt;</span> is one of <span class=\'code\'>#read</span> , <span class=\'code\'>#write</span> , <span class=\'code\'>#execute</span> , <span class=\'code\'>#all</span> .</p>\n\
<p>If <span class=\'code\'>&lt;file_name&gt;</span> is a directory and <span class=\'code\'>&lt;attribute&gt;</span> is <span class=\'code\'>#write</span> or <span class=\'code\'>#all</span> and the directory&#39;s security attributes show the directory is writable, the method will also attempt to create a temporary file in the directory to confirm it is writable.</p>\n\
<p>if <span class=\'code\'>testFileAttribute:</span> is <span class=\'code\'>false</span> or not specified, or <span class=\'code\'>&lt;file_name&gt;</span> specifies a directory, the file attributes on the file are <strong>not</strong> included in the test.</p>\n\
<p>If <span class=\'code\'>testFileAttribute:</span> is <span class=\'code\'>true</span> and <span class=\'code\'>&lt;file_name&gt;</span> specifies a file, the file attributes (read, write, execute) are AND-ed with the security attributes.</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>isDirectoryWriteable &lt;dir_name&gt; \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the specified directory exists and the directory can be written into.</p>\n\
<p>Available in <strong>3ds Max 2010</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>getMAXIniFile() \n\
</pre></div><p>In <strong>3ds Max 6 and higher</strong>, returns the current 3dsmax.ini file as a string. For some products that store the ini settings in the registry, this method returns undefined. See also <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/File-Access/External-Files-Access/Accessing-INI-File-Keys.html\' title=\'\'>Accessing INI File Keys</a>.</p>\n\
<blockquote>\n\
<p><strong>MORE EXAMPLES:</strong></p>\n\
<p>``` for f in getFiles &quot;3dsmax\\maps\\*.jpg&quot; do deleteFile f</p>\n\
<p>```</p>\n\
<p>``` for d in getDirectories &quot;D:\\foo\\<em>&quot; do for f in getFiles (d + &quot;</em>.*&quot;) do copyFile f (&quot;C:\\temp\\&quot; + getFilenameFile f + getFilenameType f)</p>\n\
<p>```</p>\n\
<p>``` if (getFiles &quot;foo<em>.max&quot;).count == 0 do print &quot;No Files Match Pattern &#39;foo</em>.max&#39;!&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";