var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Adding Selection and Display Filters</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Adding Selection and Display Filters</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"adding-selection-and-display-filters\"></a></div>\n\
<p>In the Selection filters/Combos filter, you can add <span class=\'code\'>class id</span> filters in addition to registering superclassid filters. The bottom left list box displays a list of all helper and geometry class ids. To add a filter, select an entry from the list and hit the add button below the list box. The filter will appear in the lower right list box. This list displays all of the current class id filters. Once OK is pressed, the select filter drop down contains those class ids that were added.</p>\n\
<p>You can also register custom scripted functions as filters through a callback in MAXScript:</p>\n\
<p><strong>Methods</strong></p>\n\
<div class=\'codeBlock\'><pre>registerSelectFilterCallback &lt;filterFunction&gt; &lt;name&gt;\n\
</pre></div><p>Registers a custom selection filter. The two parameters are the filter function to be registered and the name of the filter to appear in the selection filter drop down list.</p>\n\
<p>The filter function itself expects one parameter which is the node to be checked.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>If you want to filter only objects that are renderable (in other words have their node-level Renderable property set to true / Renderable box checked in Properties dialog), you can register the following function:</p>\n\
<p>``` fn filterRenderableCallback node = --the node to be filtered is passed as argument ( node.renderable --return true if the node is renderable ) --Register the function as Select filter Callback function --The filter will appear under the name &quot;Renderable&quot;: registerSelectFilterCallback filterRenderableCallback &quot;Renderable&quot; --To see how it works, execute the code below to generate 10 boxes --with random .renderable state for i = 1 to 10 do b = box pos:[i*30,0,0] renderable:((random 0.0 1.0) &lt; 0.5 ) --Now select the filter &quot;Renderable&quot; from the drop-down list and try --to select all 10 boxes - only those that are renderable will --be selected!</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>unregisterSelectFilterCallback ( &lt;filterFunction&gt; | undefined )\n\
</pre></div><p>Removes the specified callback function from the list of selection filters.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` unregisterSelectFilterCallback filterRenderableCallback</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt; selectFilterCallbacksEnabled()\n\
</pre></div><p>Returns whether selection filter callbacks are enabled. <strong>Available in 3ds Max 2021.1 Update and higher.</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt; enableSelectFilterCallbacks()\n\
&lt;boolean&gt; disableSelectFilterCallbacks()\n\
</pre></div><p>Enables or disables selection filter callbacks. These functions return the current callbacks enabled state. So, for example, calling <span class=\'code\'>disableSelectFilterCallbacks()</span> when callbacks are already disabled will return <strong>false</strong>. <strong>Available in 3ds Max 2021.1 Update and higher.</strong></p>\n\
<div class=\'codeBlock\'><pre>showregisteredSelectFilterCallbacks [to:stream] [asArray:&lt;boolean&gt;]\n\
</pre></div><p>Returns a list of registered selection filter callbacks, listing the function name, source file (if applicable) and line number in the source file where the function is defined. If the optional <strong>to</strong> argument is specified, the output is sent to that output stream. If the optional <strong>asArray</strong> argument is specified, the return value is formatted as an array of arrays, where for each registered callback function the first element is the callback function name, the second element is the source file name and line number where the callback function is defined (or an empty string if the function was not defined in a file), and the third element is the actual function value which can be used to de-register the callback. <strong>Available in 3ds Max 2021.1 Update and higher.</strong> ## Display Filters</p>\n\
<p>Display filters are used to show or hide nodes, and are accessed on the Hide by Category panel of the Display Tab in the command panel. New display filters can be added here, or through MAXScript.</p>\n\
<div class=\'codeBlock\'><pre>registerDisplayFilterCallback &lt;filterFunction&gt; &lt;name&gt;\n\
</pre></div><p>Registers a custom display filter. The two parameters are the filter function to be registered and the name of the filter to appear in the list of available categories.</p>\n\
<p>The filter function itself expects one parameter which is the node to be checked.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>If you want to filter only objects that with a name that starts with &quot;B&quot;:</p>\n\
<p>``` fn filterBCallback node = (node.name[1] == &quot;B&quot;)</p>\n\
<p>registerDisplayFilterCallback filterBCallback &quot;OnlyB!&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>unregisterDisplayFilterCallback &lt;filterFunction&gt;\n\
</pre></div><p>Removes the specified callback function from the list of display filters.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt; displayFilterCallbacksEnabled()\n\
</pre></div><p>Returns whether display filter callbacks are enabled. <strong>Available in 3ds Max 2021.1 Update and higher.</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt; enableDisplayFilterCallbacks()\n\
&lt;boolean&gt; disableDisplayFilterCallbacks()\n\
</pre></div><p>Enables or disables display filter callbacks. These functions return the current callbacks enabled state. So, for example, calling <span class=\'code\'>disableDisplayFilterCallbacks()</span> when callbacks are already disabled will return <strong>false</strong>. <strong>Available in 3ds Max 2021.1 Update and higher.</strong></p>\n\
<div class=\'codeBlock\'><pre>showregisteredDisplayFilterCallbacks [to:stream] [asArray:&lt;boolean&gt;]\n\
</pre></div><p>Returns a list of registered display filter callbacks, listing the function name, source file (if applicable) and line number in the source file where the function is defined. If the optional <strong>to</strong> argument is specified, the output is sent to that output stream. If the optional <strong>asArray</strong> argument is specified, the return value is formatted as an array of arrays, where for each registered callback function the first element is the callback function name, the second element is the source file name and line number where the callback function is defined (or an empty string if the function was not defined in a file), and the third element is the actual function value which can be used to de-register the callback.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";