var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Menu Manager</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Menu Manager</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"menu-manager\"></a></div>\n\
<p>MAXScript has full access to the menu manager and menu creation system.</p>\n\
<p>Note: Be very careful when using or testing this API. It makes permanent changes to the menu database, and it is very easy to mess things up quite badly. For example, if you &quot;unRegister&quot; the main menu bar, <strong>3ds Max</strong> won&#39;t start.</p>\n\
<p>Anyone using this API should make a copy of the &quot;..\\UI\\MaxStartUI.mnu&quot; file before running any of the scripts. If anything messes up, just copy the backup version back on to MaxMenu.mnu.</p>\n\
<p>There are 4 exposed interfaces to MAXScript: the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/M/Interface-menuMan.html\' title=\'\'>menu manager</a>, <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/U-V-W-X-Y-Z/Interface-UIAccessor.html\' title=\'\'>menu objects</a>, <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/M/Interface-menuMan.html\' title=\'\'>quad menu objects</a> and <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/M/Interface-menuMan.html\' title=\'\'>menu items</a>.</p>\n\
<ul>\n\
<li><p>The menu manager is a database of menus and quad menus.</p></li>\n\
<li><p>The main menubar and all sub-menus are menu objects.</p></li>\n\
<li><p>A quad menu object holds 4 menu objects, one for each quad.</p></li>\n\
<li><p>A menu object is a container for menu items.</p></li>\n\
<li><p>A menu item can be a separator, an action that invokes a macroScript or a sub-menu that pops up a cascading menu.</p></li>\n\
</ul>\n\
<p><strong>Menu Manager</strong></p>\n\
<div class=\'codeBlock\'><pre>menuMan.loadMenuFile &quot;file.mnu&quot;\n\
</pre></div><p>This loads a new menu file with the given name. It looks in the current &quot;UI&quot; directory for the file. It return true if successful, and false if not.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.saveMenuFile &quot;file.mnu&quot;\n\
</pre></div><p>This saves a new menu file with the given name. It saves it in the current &quot;UI&quot; directory.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.getMenuFile()\n\
</pre></div><p>Returns the full path to the current menu file.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.updateMenuBar()\n\
</pre></div><p>This updates the main menu bar with any changes that have been made. This MUST be called after changing anything on the main menu bar.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.registerMenuContext contextId\n\
</pre></div><p>This call is used to register menu extensions. The &quot;contextId&quot; is a random 32-bit integer. It can be generated using the <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Creating-MAXScript-Tools/Scripted-Plug-ins/The-Super-Class-ID-and-the-Class.html\' title=\'\'>&quot;genclassid()&quot;</a>. This function registers an extension with the menu manager that is remembered permanently. It returns true the first time the extension is registered, and false every time thereafter. This is saved in the MaxMenu.mnu file, so it is sticky from session to session. This is used so that scripts can add items and sub-menus MAX&#39;s main menu bar and quad menus. See the sample scripts below for the proper usage.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.findMenu &quot;menuName&quot;\n\
</pre></div><p>This function returns the menu with the given name. It returns &quot;undefined&quot; if no menu exists in the menu manager with the given name. This requires the full name of the menu, including and &quot;&amp;&quot; characters that might be in the name.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` helpMenu = menuMan.findMenu &quot;&amp;Help&quot; -- Retrieve3ds Max’shelp menu.</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>menuMan.findQuadMenu &quot;quadMenuName&quot;\n\
</pre></div><p>This method works like &quot;findMenu&quot; but it gets quad menus instead of menus.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.unRegisterMenumenu\n\
</pre></div><p>This method removes a menu from the menu manager.</p>\n\
<blockquote>\n\
<p><strong>WARNING! USE EXTREME CAUTION WHEN USING THIS METHOD!</strong></p>\n\
<p>If you unregister a menu that is used as a sub-menu, or in a quad menu, or the main menu bar, you will corrupt your <strong>3ds Max</strong> installation.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>menuMan.unRegisterQuadMenuquadMenu\n\
</pre></div><p>This method works like &quot;unregisterMenu&quot; but for quad menus.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.createMenu &quot;name&quot;\n\
</pre></div><p>This method creates a new, empty menu with the given name.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.createQuadMenu &quot;name&quot; &quot;quad1Name&quot; &quot;quad2Name&quot; &quot;quad3Name&quot; &quot;quad4Name&quot;\n\
</pre></div><p>This method creates a new, empty quad menu. It contains, 4 empty menus, one for each quad.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.createSubMenuItem &quot;name&quot; subMenu\n\
</pre></div><p>This method creates a new sub-menu item that can be added to a menu. It uses the given &quot;name&quot; and it displays the given sub-menu.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.createSeparatorItem()\n\
</pre></div><p>This method creates a new menu separator that can be added to a menu.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.createActionItem &quot;macroScriptName&quot; &quot;macroScriptCategory&quot;\n\
</pre></div><p>This method creates a new menu item that can be added to a menu. The item is an action that executes the macro script with the given name and category. This returns &quot;undefined&quot; if there is no macroScript with the given name and category.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.setViewportRightClickMenu which quadMenu\n\
</pre></div><p>This method sets the viewport right click menu to be the given quad menu. The value of &quot;which&quot; can be one of the following:</p>\n\
<div class=\'codeBlock\'><pre>#nonePressed #shiftPressed #altPressed #controlPressed #shiftAndAltPressed #shiftAndControlPressed #controlAndAltPressed #shiftAndAltAndControlPressed\n\
</pre></div><p>The following example sets the default (no keys pressed) quad menu the &quot;Modeling 2&quot;. The menu name must be a quad menu that is listed in the &quot;Quads&quot; customization dialog, and the name must match exactly, including capitalization. <span class=\'code\'>menuMan.SetViewportRightClickMenu</span> returns FALSE if you try to set the viewport right-click menu to a menu that is not allowed.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` menuMan.setViewportRightClickMenu #nonePressed &quot;Modeling 2&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>menuMan.getViewportRightClickMenu which\n\
</pre></div><p>Retrieves the quad menu used for right-clicking in the viewport. The &quot;which&quot; parameter can be one of the following:</p>\n\
<div class=\'codeBlock\'><pre> #nonePressed #shiftPressed #altPressed #controlPressed #shiftAndAltPressed #shiftAndControlPressed #controlAndAltPressed #shiftAndAltAndControlPressed menuMan.getMainMenuBar()\n\
</pre></div><p>Returns the menu being used as MAX&#39;s main menu bar.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.setMainMenuBar menu\n\
</pre></div><p>Sets the menu being used as MAX&#39;s main menu bar. You must call &quot;menuMan.updateMenuBar()&quot; in order to see the result.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.getShowAllQuads quadMenu\n\
</pre></div><p>Gets the &quot;show all quads&quot; setting for the given quad menu.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.setShowAllQuads quadMenu value\n\
</pre></div><p>This sets the &quot;show all quads&quot; flag for the given quad menu. &quot;value&quot; can be <span class=\'code\'>true</span> or <span class=\'code\'>false</span> .</p>\n\
<div class=\'codeBlock\'><pre>menuMan.getQuadMenuName quadMenu\n\
</pre></div><p>This returns the name of the given quad menu.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.setQuadMenuName quadMenu &quot;name&quot;\n\
</pre></div><p>This sets the name of the give quad menu.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.numMenus()\n\
</pre></div><p>Returns the total number of menus in registered with the menu manager.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.getMenu index\n\
</pre></div><p>Retrieves the &quot;index&quot;th menu in the menu manager. This is a 1-based index.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.numQuadMenus()\n\
</pre></div><p>Returns the total number of quad menus registered with the menu manager.</p>\n\
<div class=\'codeBlock\'><pre>menuMan.getQuadMenu index\n\
</pre></div><p>Retrieves the &quot;index&quot;th quad menu in the menu manager. This is a 1-based index.</p>\n\
<div class=\'section\'><a id=\"quad-menu-objects\"></a><h3 id=\"quad-menu-objects\">Quad Menu objects</h3></div>\n\
<p>Quad menu objects have the following functions available:</p>\n\
<div class=\'codeBlock\'><pre>quadMenu.getMenu quadIndex\n\
</pre></div><p>Retrieves the menu object associated with the 4 quads of the menu. &quot;quadIndex&quot; can take the value 0, 1, 2, or 3. Quad 0 is the lower-right, and they are numbered counter-clockwise from there.</p>\n\
<div class=\'codeBlock\'><pre>quadMenu.trackMenu showAllQuads\n\
\n\
</pre></div><p>This displays the quad menu. If &quot;showAllQuads&quot; is true, then all 4 quads are shows at once. It is displayed at the current cursor position.</p>\n\
<div class=\'section\'><a id=\"menu-objects\"></a><h3 id=\"menu-objects\">Menu Objects</h3></div>\n\
<p>Menus are containers for menu items, and have the following functions:</p>\n\
<div class=\'codeBlock\'><pre>menu.setTitle &quot;title&quot;\n\
</pre></div><p>Sets the title of the menu to the give string.</p>\n\
<div class=\'codeBlock\'><pre>menu.getTitle()\n\
</pre></div><p>Returns the current title of the menu.</p>\n\
<div class=\'codeBlock\'><pre>menu.numItems()\n\
</pre></div><p>Returns the number of items the menu holds.</p>\n\
<div class=\'codeBlock\'><pre>menu.getItem index\n\
</pre></div><p>Retrieves the menu item at the given index.</p>\n\
<p>Note:</p>\n\
<p>The index is 0-based.</p>\n\
<div class=\'codeBlock\'><pre>menu.addItem menuItem position\n\
</pre></div><p>This inserts an item in the menu at the given position, which is 0-based. If the position is -1, then the item is appended to the end of the menu.</p>\n\
<div class=\'codeBlock\'><pre>menu.removeItemByPosition position\n\
</pre></div><p>This removes the item at the given position.</p>\n\
<div class=\'codeBlock\'><pre>menu.removeItem menuItem\n\
</pre></div><p>This removes the given item from the menu, if it is in the menu.</p>\n\
<div class=\'section\'><a id=\"menu-item-objects\"></a><h3 id=\"menu-item-objects\">Menu Item objects</h3></div>\n\
<p>A menu item can be a separator, a sub-menu or an action that is connected to a macroScript. The following functions are available for menuItems:</p>\n\
<div class=\'codeBlock\'><pre>menuItem.setTitle &quot;title&quot;\n\
</pre></div><p>Sets the name associated with the item.</p>\n\
<div class=\'codeBlock\'><pre>menuItem.getTitle()\n\
</pre></div><p>Returns the name associated with the item.</p>\n\
<div class=\'codeBlock\'><pre>menuItem.setUseCustomTitle value\n\
</pre></div><p>When value is true, this tells an item that is associated with a macroScript to use the item title when displaying the menu. Otherwise it will use the name of the macro or the &quot;buttontext&quot; of the macroScript.</p>\n\
<div class=\'codeBlock\'><pre>menuItem.getUseCustomTitle()\n\
\n\
</pre></div><p>Returns the current value of the custom title flag.</p>\n\
<div class=\'codeBlock\'><pre>menuItem.setDisplayFlat value\n\
</pre></div><p>This is for sub-menu items. When value is true, it tells the menu to display the sub-menu in-line, rather than as a cascading sub-menu.</p>\n\
<div class=\'codeBlock\'><pre>menuItem.getDisplayFlat()\n\
</pre></div><p>Returns the current value for the &quot;display flat&quot; flag.</p>\n\
<div class=\'codeBlock\'><pre>menuItem.getIsSeparator()\n\
</pre></div><p>Return true if the item is a separator, and false otherwise.</p>\n\
<div class=\'codeBlock\'><pre>menuItem.getSubMenu()\n\
</pre></div><p>If the item is a sub-menu item, this returns the menu associated with the sub-menu.</p>\n\
<p>Included below is a script that shows how to use the menuMan interface to register menu extensions. This script should go in the &quot;stdplugs\\stdscripts&quot; folder.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` -- Sample menu extension script -- If this script is placed in the &quot;stdplugs\\stdscripts&quot; -- folder, then this will add the new items to MAX&#39;s menu bar -- when MAX starts. -- A sample macroScript that we will attach to a menu item macroScript MyTest category: &quot;Menu Test&quot; tooltip: &quot;Test Menu Item&quot; ( on execute do print &quot;Hello World!&quot; )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Note: The macroScript above must be present before running the example below.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` -- This example adds a new entry to MAX&#39;s main &quot;Help&quot; menu. -- Register a menu context. This returns true the first time it -- is registered, and we can add things to the menu. If -- it returns false, then the context is already registered, -- and the items are already in the menu. -- The number 0x246c6dbe is random, and can be generated -- using the genClassID() function. if menuMan.registerMenuContext 0x246c6dbe then ( -- Get the main menu bar local mainMenuBar = menuMan.getMainMenuBar() -- The help menu is always the last menu. local helpMenuIndex = mainMenuBar.numItems() -- Get the menu item that holds the help menu local helpMenuItem = mainMenuBar.getItem(helpMenuIndex) -- Get the menu from the item local helpMenu = helpMenuItem.getSubMenu() -- create a menu separator item local sepItem = menuMan.createSeparatorItem() -- create a menu items that calls the sample macroScript local testItem = menuMan.createActionItem &quot;MyTest&quot; &quot;Menu Test&quot; -- Add the separator to the end of the help menu. -- the position of -1 means add it to the end. helpMenu.addItem sepItem -1 -- Add the action item to the end of the help menu. helpMenu.addItem testItem -1 -- redraw the menu bar with the new item menuMan.updateMenuBar() )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` -- This example adds a new sub-menu to MAX&#39;s main menu bar. -- It adds the menu just before the &quot;Help&quot; menu. if menuMan.registerMenuContext 0x1ee76d8e then ( -- Get the main menu bar local mainMenuBar = menuMan.getMainMenuBar() -- Create a new menu local subMenu = menuMan.createMenu &quot;Test Menu&quot; -- create a menu item that calls the sample macroScript local testItem = menuMan.createActionItem &quot;MyTest&quot; &quot;Menu Test&quot; -- Add the item to the menu subMenu.addItem testItem -1 -- Create a new menu item with the menu as it&#39;s sub-menu local subMenuItem = menuMan.createSubMenuItem &quot;Test Menu&quot; subMenu -- compute the index of the next-to-last menu item in the main menu bar local subMenuIndex = mainMenuBar.numItems() - 1 -- Add the sub-menu just at the second to last slot mainMenuBar.addItem subMenuItem subMenuIndex -- redraw the menu bar with the new item menuMan.updateMenuBar() )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` -- This example adds a new command to MAX&#39;s default right-click quad menu if menuMan.registerMenuContext 0x36690115 then ( -- Get the default viewport right-click quad menu local quadMenu = menuMan.getViewportRightClickMenu #nonePressed -- Get the lower-left menu from the quad local menu = quadMenu.getMenu 3 -- create a menu item that calls the sample macroScript local testItem = menuMan.createActionItem &quot;MyTest&quot; &quot;Menu Test&quot; -- Add the item to the menu menu.addItem testItem -1 )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p><strong>Here are two macroScripts that set and reset two of the right-click menus:</strong></p>\n\
<blockquote>\n\
<p>``` macroScript SetQuads category:&quot;Custom UI&quot; tooltip:&quot;Set Quad&quot; ( on execute do ( quadmenu = menuMan.findQuadMenu &quot;Modeling 2&quot; if quadmenu != undefined do menuMan.setViewportRightClickMenu #nonePressed quadmenu quadmenu = menuMan.findQuadMenu &quot;Sample 4x1&quot; menuMan.setViewportRightClickMenu #controlPressed quadmenu ) )</p>\n\
<p>```</p>\n\
<p>``` macroScript ResetQuads category:&quot;Custom UI&quot; tooltip:&quot;Reset Quads&quot; ( on execute do ( quadmenu = menuMan.findQuadMenu &quot;Default Viewport Quad&quot; if quadmenu != undefined do menuMan.setViewportRightClickMenu #nonePressed quadmenu quadmenu = menuMan.findQuadMenu &quot;Modeling 1 [Cntrl+RMB]&quot; if quadmenu != undefined do menuMan.setViewportRightClickMenu #controlPressed quadmenu ) )</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";