var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Render To Texture Using MAXScript</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Render To Texture Using MAXScript</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"render-to-texture-using-maxscript\"></a></div>\n\
<p><strong>Render To Texture</strong> (also known as <strong>Texture Baking</strong>) is a procedure for capturing various aspects of <strong>3ds Max</strong> geometry scene objects&#39; surfaces to bitmaps using the production renderer. The <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/RendererClass/Default_Scanline_Renderer.html\' title=\'\'>Default Scanline renderer</a> supports this functionality.</p>\n\
<p>The actual <strong>3ds Max Render To Texture tool</strong> available through the <strong>Main Menu&gt;Rendering&gt;Render To Texture</strong> menu item is implemented as a scripted tool. Its source code can be found in the following subfolder of the <strong>3ds Max</strong> installation:</p>\n\
<p><strong>..\\ui\\macroscripts\\Macro_BakeTextures.mcr</strong></p>\n\
<p>In addition, some Render To Texture methods used by the network version of the tool can be found in the file</p>\n\
<p><strong>..\\stdplugs\\stdscripts\\RTT_methods.ms</strong></p>\n\
<div class=\'section\'><a id=\"render-to-texture-components\"></a><h2 id=\"render-to-texture-components\">Render To Texture Components</h2></div>\n\
<p>Here is a short overview of the MAXScript classes, interfaces, properties and methods used in the process and how to use them to create your own texture baking tools:</p>\n\
<div class=\'section\'><a id=\"bake-elements\"></a><h3 id=\"bake-elements\">Bake Elements</h3></div>\n\
<p>The main object class involved in the texture baking process is the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/BakeElement/Bake-Elements.html\' title=\'\'>Bake Element</a>.</p>\n\
<p>It implements an object capable of capturing a specific channel out of the production renderer, for example Diffuse, Lighting, Ambient Occlusion, Normals, Shadows and so on.</p>\n\
<div class=\'section\'><a id=\"inodebakeproperties-interface\"></a><h3 id=\"inodebakeproperties-interface\">INodeBakeProperties Interface</h3></div>\n\
<p>The geometry objects whose surfaces will be baked have to be set up for the process using the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Node-Interfaces/Node-Interfaces-Documentation/Interface-INode.html\' title=\'\'>INodeBakeProperties Interface</a> exposed by all scene nodes.</p>\n\
<p>This interface is used to add one or more Bake Elements to specific nodes, enable the baking and control some other related parameters.</p>\n\
<div class=\'section\'><a id=\"production-renderer\"></a><h3 id=\"production-renderer\">Production Renderer</h3></div>\n\
<p>The <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Render-Scene-Dialog/Controlling-the-Renderer.html\' title=\'\'>production renderer</a>, including the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/RendererClass/Default_Scanline_Renderer.html\' title=\'\'>Default Scanline renderer</a>, has to be called via MAXScript in a special mode invoked via</p>\n\
<div class=\'codeBlock\'><pre>render rendertype:#bakeSelected\n\
</pre></div><div class=\'section\'><a id=\"unwrap-uvw\"></a><h3 id=\"unwrap-uvw\">Unwrap UVW</h3></div>\n\
<p>For the baked texture to be usable, the object being rendered has to provide good texture coordinates without any overlapping.</p>\n\
<p>The Render To Texture script shipping with <strong>3ds Max</strong> provides controls over the automatic application and setup of <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Modifier-MAXWrapper-and/Modifier-and-SpacewarpModifier/Modifiers/UVW-Modifiers/Unwrap_UVW-Modifier.html\' title=\'\'>Unwrap_UVW Modifiers</a> to ensure the texture coordinates are usable for baking. You might have to ensure the same in your own script, unless your object has good UV coordinates to work with.</p>\n\
<div class=\'section\'><a id=\"projection-mapping\"></a><h3 id=\"projection-mapping\">Projection Mapping</h3></div>\n\
<p>In some cases, especially when generating Normal Maps, the surface being rendered is a high-resolution version of an object, while the target object being mapped is a lower-resolution version. In this case, the texture coordinates of the low-resolution object have to be generated by projecting from the high-resolution one.</p>\n\
<p>The <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Node-Interfaces/Node-Interfaces-Documentation/Interface-15.html\' title=\'\'>Interface: INodeBakeProjProperties</a>, the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Modifier-MAXWrapper-and/Modifier-and-SpacewarpModifier/Modifiers/Projection-Mapping-Modifiers/Projection-Modifier.html\' title=\'\'>Projection Modifier</a> and the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Modifier-MAXWrapper-and/Modifier-and-SpacewarpModifier/Modifiers/Projection-Mapping-Modifiers/Project_Mapping-ReferenceTarget.html\' title=\'\'>Project_Mapping ReferenceTarget</a> are the main elements of the Projection Mapping system of <strong>3ds Max</strong>.</p>\n\
<div class=\'section\'><a id=\"shell-material\"></a><h3 id=\"shell-material\">Shell Material</h3></div>\n\
<p>The <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Material-MAXWrapper/Material-Types/Shell_Material-Material.html\' title=\'\'>Shell Material</a> has been specifically designed to be used together with the Render To Texture tools. It can hold two different materials, typically the original material and the baked material. Either one can be used in the Viewport or in the Renderer.</p>\n\
<div class=\'section\'><a id=\"developing-a-simple-render-to-texture-script\"></a><h2 id=\"developing-a-simple-render-to-texture-script\">Developing a Simple Render To Texture Script</h2></div>\n\
<p>The following example shows the basic steps to create a custom Render To Texture script.</p>\n\
<p>The script creates a simple scene containing a textured sphere on a textured plane lit by a shadow-casting omni light.</p>\n\
<p>Then it bakes the Diffuse and Lighting Elements of both objects to TGA files on disk and creates a Shell Material containing the old material in the one slot and the baked material in the other.</p>\n\
<p>The Baked material uses a Composite map to combine the diffuse and the lighting information into a single diffuse map.</p>\n\
<p>In this simple case, the texture coordinates of both objects are procedurally generated by the geometry primitives and are usable for baking. Also, no projection mapping is required in this simple case.</p>\n\
<blockquote>\n\
<p><strong>SCRIPT</strong></p>\n\
<p>``` fn BakeDiffuseAndLighting obj size = ( --Clear all render elements obj.iNodeBakeProperties.removeAllBakeElements() --Preparing the Bake Elements: be1 = diffusemap() --instance of the bake element class be1.outputSzX = be1.outputSzY = size --set the size of the baked map --specifythe full file path, name and type: be1.fileType = (getDir #image+&quot;\\&quot;+obj.name+&quot;_diffuse.tga&quot;) be1.fileName = filenameFromPath be1.fileType be1.filterOn = true --enable filtering be1.shadowsOn = false --disable shadows be1.lightingOn = false --disable lighting be1.enabled = true --enable baking be2 = LightingMap() -- instance of the bake element class be2.outputSzX =be2.outputSzY = size --set the size of the baked map --specifythe full file path, name and type: be2.fileType = (getDir #image+&quot;\\&quot;+obj.name+&quot;_lighting.tga&quot;) be2.fileName = filenameFromPath be2.fileType be2.filterOn = true --enable filtering be2.shadowsOn =true --enable shadows be2.enabled = true --enable baking --Preparing theobjectfor baking: obj.INodeBakeProperties.addBakeElement be1 --add first element obj.INodeBakeProperties.addBakeElement be2 --add second element obj.INodeBakeProperties.bakeEnabled = true --enabling baking obj.INodeBakeProperties.bakeChannel = 1 --channel to bake obj.INodeBakeProperties.nDilations = 1 --expand the texturea bit select obj --we are baking the selection, so we select the object --Call the renderer to bake both elements: render rendertype:#bakeSelected vfb:off progressBar:true outputSize:[size,size] theComp = CompositeTextureMap() --create a composite map theComp.add() --add a second layer theComp.blendMode = #(0,5) --set second layer to Multiply --Create two maps, one with the diffuse, one with the lighting map theMap1 =bitmaptexture filename:be1.fileType theMap2=bitmaptexture filename:be2.fileType theComp.mapList = #(theMap1,theMap2) --composite the two maps theComp.opacity = #(100,70) --set the lighting map to 70% opacity --Create a standard self-illum material using the Composite map bakedMat = standard diffusemap:theComp selfIllumAmount:100 --Assign a Shell Material to the object, --keep the old material as original material, --set the new bakedMat as the baked material: obj.material = Shell_Material originalMaterial:obj.material<br> bakedMaterial:bakedMat viewportMtlIndex:1 renderMtlIndex:1 --Show the textures of the baked material in the viewport showTextureMap obj.material obj.material.bakedMaterial true )--end fn resetMaxFile #noprompt--reset the scene to start from scratch --Create a shadow casting white Omni light theLight = omniLight pos:[0,-60,100] rgb:white theLight.baseobject.castshadows = true --Create a mapped sphere object above the ground plane theObject = Sphere segs:32 mapcoords:true pos:[0,0,25] --Create a Cellular map and assign via Standard material to object theMap = cellular cellColor:blue divColor1:red divColor2:yellow size:15 theObject.material = standard diffusemap:theMap --Call the Bake function with the object and the desired size BakeDiffuseAndLighting theObject 256 --Create a mappedplaneobjecton theground plane theObject = Plane width:200 length:200 mapcoords:true --Create a checker map and set the tiling to 4x4, then assign to object theMap = checker Color1:green Color2:orange theMap.coordinates.uTiling = theMap.coordinates.vTiling = 4 theObject.material = standard diffusemap:theMap --Call the Bake function with the object and the desired size BakeDiffuseAndLighting theObject 256 --Delete the light from the scene and deselect everything delete theLight max select none</p>\n\
<p>```</p>\n\
<p><strong>RESULTS</strong></p>\n\
<p>After running the script, the following four baked textures will be written to the Images folder and will appear on the scene objects in the viewports:</p>\n\
<p><img src=\'developer/images/GUID-FF0F53D5-EE97-47A9-AF27-694AC2FF4560-low.gif\' title=\'\'> <img src=\'developer/images/GUID-45F90F71-AE5C-45FC-832A-E2580C954135-low.gif\' title=\'\'></p>\n\
<p><img src=\'developer/images/GUID-9E043D54-9F4C-467C-8FE5-B1957AC096D9-low.gif\' title=\'\'> <img src=\'developer/images/GUID-95AFC7E6-E364-46E0-9FD1-C2FEF4922189-low.gif\' title=\'\'></p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-22F2E537-1BD7-40A2-B9C6-8DF33DA01B87-low.gif\' title=\'\'></div>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";