var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Progress Bar Display</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Progress Bar Display</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"progress-bar-display\"></a></div>\n\
<p>This group of functions lets you display a progress bar for operations that might be time consuming, similar to the progress bar that <strong>3ds Max</strong> uses for IK, Preview Rendering, and Reduce Key computations.</p>\n\
<p>The functions are:</p>\n\
<div class=\'codeBlock\'><pre>progressStart &quot;caption&quot;      \n\
</pre></div><p>Initially displays the progress bar with the caption given.</p>\n\
<div class=\'codeBlock\'><pre>progressUpdate &lt;percent&gt;   \n\
</pre></div><p>Updates the bar display to show the given percentage complete (in the range 0-100). This function also checks to see if the user has clicked the Cancel button in the progress bar, and returns <span class=\'code\'>true</span> if the computation must continue and <span class=\'code\'>false</span> if the user has requested a cancel. You can also call <span class=\'code\'>getProgressCancel()</span> (described below) to check the cancel status, which is a low overhead function and might be called more frequently than <span class=\'code\'>progressUpdate()</span> .</p>\n\
<div class=\'codeBlock\'><pre>progressEnd() \n\
</pre></div><p>Signals the end of the operation and removes the progress bar display.</p>\n\
<div class=\'codeBlock\'><pre>getProgressCancel() \n\
</pre></div><p>A low-overhead function that checks whether the user has canceled the operation using the Cancel button in the progress bar. You might want to call this function frequently within deep loops in your code to reduce cancel latency for the user because you must only call <span class=\'code\'>progressUpdate()</span> as needed to show significant progress bar changes to keep overhead low. The <span class=\'code\'>getProgressCancel()</span> function as well as <span class=\'code\'>progressUpdate()</span> displays a confirmation dialog if the user hits the cancel button and returns the cancel status from that confirmation. Unlike <span class=\'code\'>progressUpdate()</span> , this function returns <span class=\'code\'>true</span> if the user has made a confirmed cancel request and <span class=\'code\'>false</span> otherwise.</p>\n\
<div class=\'codeBlock\'><pre>setProgressCancel &lt;boolean&gt; \n\
</pre></div><p>Sets or clears the Cancel flag for the progress bar. By passing a value of <span class=\'code\'>true</span> , the Cancel flag is set and will be detected by <span class=\'code\'>progressUpdate()</span> and <span class=\'code\'>getProgressCancel()</span> . By passing a value of <span class=\'code\'>false</span> , the Cancel flag is cleared if set.</p>\n\
<p>The following <strong>3ds Max</strong> system global variable is associated with the Progress Bar display:</p>\n\
<div class=\'codeBlock\'><pre>escapeEnable \n\
</pre></div><p>Lets you get and set a Boolean value defining whether <span class=\'code\'>ESC</span> key interrupt detection is on or off. Setting <span class=\'code\'>enableEscape</span> to <span class=\'code\'>false</span> turns <span class=\'code\'>ESC</span> key interrupt detection off, setting it to <span class=\'code\'>true</span> turns it on again. This variable is useful when used in conjunction with a Progress Bar. You can set <span class=\'code\'>enableEscape</span> to <span class=\'code\'>false</span> when you do not want the user to interrupt a script running a long computation and you have set up a progress bar with its own Cancel button.</p>\n\
<blockquote>\n\
<p><strong>NOTES ON CALCULATING PERCENTAGES:</strong></p>\n\
<p>When calculating the percentage from a current Integer value and a total Integer value, the order in which the values are multiplied and divided does matter. Dividing them first and then multiplying by 100.0 will always return 0.0 because an Integer divided by an Integer yields an Integer, and because the result is less than zero, it is rounded down to zero. If the total value is 20, for each value between 1 and 19, you will get:</p>\n\
<p>``` 1/20<em>100.0 -&gt; 0</em>100.0 -&gt; 0.0 2/20<em>100.0 -&gt; 0</em>100.0 -&gt; 0.0 3/20<em>100.0 -&gt; 0</em>100.0 -&gt; 0.0 ... 19/20<em>100.0-&gt; 0</em>100.0 -&gt; 0.0 20/20<em>100.0-&gt; 1</em>100.0 -&gt; 100.0</p>\n\
<p>```</p>\n\
<p>but</p>\n\
<p>``` 100.0<em>1/20 -&gt; 100.0/20 -&gt; 5.0 100.0</em>2/20 -&gt; 200.0/20 -&gt; 10.0 100.0<em>3/20 -&gt; 300.0/20 -&gt; 15.0 ... 100.0</em>19/20-&gt; 1900.0/20-&gt; 95.0 100.0*20/20-&gt; 2000.0/20-&gt; 100.0</p>\n\
<p>```</p>\n\
<p>When starting with the Float value 100.0, the final result is implicitly converted to a Float because a Float multiplied by an Integer returns a Float, and a Float divided by an Integer still returns a Float.</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";