var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>TabbedDialogs - Controlling Tabbed Dialogs</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>TabbedDialogs - Controlling Tabbed Dialogs</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"tabbeddialogs---controlling-tabbed-dialogs\"></a></div>\n\
<p>These methods let you control <strong>3ds Max</strong> tabbed dialogs like Rendering, Environment and Effects, Object Properties, Configure Paths, and so on.</p>\n\
<p><strong>Specs:</strong></p>\n\
<p>The following specs define what a valid argument looks like for the tabbedDialogs methods. MAXScript does not have a class that corresponds to Class_ID, so these are passed as a two element array of integers.</p>\n\
<div class=\'codeBlock\'><pre>tabbedDialogSpec ::= ( #render | #renderVP | #envEffects | #objProp | #preferences | #configPath | #(&lt;int&gt;,&lt;int&gt;) )\n\
\n\
#(&lt;int&gt;,&lt;int&gt;) is Class_ID of tabbed dialog\n\
tabPageSpec ::= ( &lt;int&gt; | #(&lt;int&gt;,&lt;int&gt;) )\n\
&lt;int&gt; is index in dialog (1-based)\n\
#(&lt;int&gt;,&lt;int&gt;) is Class_ID of tab page\n\
\n\
</pre></div><p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;tabbedDialogs.isOpen &lt;tabbedDialogSpec&gt;\n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the specified dialog is open.</p>\n\
<blockquote>\n\
<p>Warning: The <span class=\'code\'>tabbedDialogs.isOpen</span> method must be called before calling any of the other methods. If the specified dialog is not open, the remainder of the methods will not perform any action or throw an error, and those methods that return a value will return &#39;undefined&#39;.</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;#(&lt;int&gt;,&lt;int&gt;)&gt;tabbedDialogs.getDialogID &lt;tabbedDialogSpec&gt;\n\
</pre></div><p>Returns the Class_ID of the specified tabbed dialog.</p>\n\
<div class=\'codeBlock\'><pre>tabbedDialogs.invalidate &lt;tabbedDialogSpec&gt;\n\
</pre></div><p>Invalidates all pages in the dialog.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;tabbedDialogs.OkToCommit &lt;tabbedDialogSpec&gt;\n\
</pre></div><p>Returns <span class=\'code\'>true</span> if all pages in dialog are ok to commit changes. Used for modal dialogs with IDOK and IDCANCEL.</p>\n\
<div class=\'codeBlock\'><pre>tabbedDialogs.CommitPages &lt;tabbedDialogSpec&gt;\n\
</pre></div><p>Commits changes in all pages. Used for modal dialogs with IDOK and IDCANCEL.</p>\n\
<div class=\'codeBlock\'><pre>tabbedDialogs.CloseDialog &lt;tabbedDialogSpec&gt;\n\
</pre></div><p>Closes the dialog.</p>\n\
<div class=\'codeBlock\'><pre>tabbedDialogs.CancelDialog &lt;tabbedDialogSpec&gt;\n\
</pre></div><p>Cancels the dialog.</p>\n\
<div class=\'codeBlock\'><pre>&lt;int&gt;tabbedDialogs.getNumPages &lt;tabbedDialogSpec&gt;\n\
</pre></div><p>Returns the number of tab pages in the specified dialog.</p>\n\
<div class=\'codeBlock\'><pre>&lt;#(&lt;int&gt;,&lt;int&gt;)&gt;tabbedDialogs.getPageID &lt;tabbedDialogSpec&gt; &lt;tabPageSpec&gt;\n\
</pre></div><p>Returns the Class_ID of the specified tab page.</p>\n\
<div class=\'codeBlock\'><pre>&lt;#(&lt;int&gt;,&lt;int&gt;)&gt;tabbedDialogs.getCurrentPage &lt;tabbedDialogSpec&gt;\n\
</pre></div><p>Returns the Class_ID of the current tab page.</p>\n\
<div class=\'codeBlock\'><pre>tabbedDialogs.setCurrentPage &lt;tabbedDialogSpec&gt; &lt;tabPageSpec&gt;\n\
</pre></div><p>Sets the specified tab page as the current tab page.</p>\n\
<div class=\'codeBlock\'><pre>tabbedDialogs.invalidatePage &lt;tabbedDialogSpec&gt; &lt;tabPageSpec&gt;\n\
</pre></div><p>Invalidates the specified tab page.</p>\n\
<div class=\'codeBlock\'><pre>tabbedDialogs.getPageTitle &lt;tabbedDialogSpec&gt; &lt;tabPageSpec&gt;\n\
</pre></div><p>Returns the tab title for the specified tab page. This title is localized.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;tabbedDialogs.isPage &lt;tabbedDialogSpec&gt; &lt;tabPageSpec&gt;\n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the specified tab page is present in the dialog.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` --Switch to Adv.Lighting tab if Render Scene dialog is open: if tabbedDialogs.isOpen #render do tabbedDialogs.setCurrentPage #render #(1758358594, 1812881699)</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";