var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Units Struct - Accessing System and Display Units</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Units Struct - Accessing System and Display Units</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"units-struct---accessing-system-and-display-units\"></a></div>\n\
<p>The Units struct provides access to system global variables and some methods to get and set the System Units scale, type, and Display Units.</p>\n\
<p><strong>System Globals:</strong></p>\n\
<div class=\'codeBlock\'><pre>units.DisplayType\n\
</pre></div><p>Gets/sets the current unit display type as a <span class=\'code\'>&lt;name&gt;</span>.</p>\n\
<p>Valid unit display types are:</p>\n\
<div class=\'codeBlock\'><pre>#Generic #Metric #US #custom\n\
units.MetricType\n\
</pre></div><p>Gets/sets the current metric unit display type as a <span class=\'code\'>&lt;name&gt;</span>.</p>\n\
<p>Valid metric unit display types are:</p>\n\
<div class=\'codeBlock\'><pre>#Millimeters #Centimeters #Meters #Kilometers\n\
units.USType\n\
</pre></div><p>Gets/sets the current US standard unit display type as a <span class=\'code\'>&lt;name&gt;</span>.</p>\n\
<p>Valid US standard unit display types are:</p>\n\
<div class=\'codeBlock\'><pre>#Frac_In #Dec_In #Frac_Ft #Dec_Ft #Ft_Frac_In #Ft_Dec_In\n\
units.USFrac\n\
</pre></div><p>Gets/sets the current US fraction display type as a <span class=\'code\'>&lt;name&gt;</span>.</p>\n\
<p>Valid US fraction display types are:</p>\n\
<div class=\'codeBlock\'><pre>#Frac_1_1 #Frac_1_2 #Frac_1_4 #Frac_1_8 #Frac_1_10 #Frac_1_16 #Frac_1_32 #Frac_1_64 #Frac_1_100 \n\
units.CustomName \n\
</pre></div><p>Gets/sets the current custom unit name as a <span class=\'code\'>&lt;string&gt;</span>.</p>\n\
<div class=\'codeBlock\'><pre>units.CustomValue \n\
</pre></div><p>Gets/sets the current custom unit value as a <span class=\'code\'>&lt;float&gt;</span>.</p>\n\
<div class=\'codeBlock\'><pre>units.CustomUnit \n\
</pre></div><p>Gets/sets the current custom unit type as a <span class=\'code\'>&lt;name&gt;</span>.</p>\n\
<p>Valid custom unit display types are:</p>\n\
<div class=\'codeBlock\'><pre>#Inches #Feet #Miles #Millimeters #Centimeters #Meters #Kilometers \n\
units.SystemScale \n\
</pre></div><p>Gets/sets the current system unit scale value as a <span class=\'code\'>&lt;float&gt;</span>.</p>\n\
<p>This is the value shown in Customize Units Setup &gt; System Units Setup &gt; System Units Scale group.</p>\n\
<div class=\'codeBlock\'><pre>units.SystemType\n\
</pre></div><p>Gets/sets the current system unit scale type as a <span class=\'code\'>&lt;name&gt;</span>.</p>\n\
<p>This is the unit shown in Customize &gt; Units Setup &gt; System Units Setup &gt; System Units Scale group.</p>\n\
<p>Valid system unit scale types are:</p>\n\
<div class=\'codeBlock\'><pre>#Inches #Feet #Miles #Millimeters #Centimeters #Meters #Kilometers \n\
</pre></div><p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>units.formatValue &lt;float&gt; \n\
</pre></div><p>Returns a <span class=\'code\'>&lt;string&gt;</span> value representing the <span class=\'code\'>&lt;float&gt;</span> in the current unit scale.</p>\n\
<p>This method can cause a string overflow, especially when the units are set to miles or kilometers.</p>\n\
<p>If an overflow occurs a run-time error is thrown.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` units.DisplayType = #Generic --&gt;#Generic units.SystemType = #inches --&gt;#inches units.formatValue 123.45 --&gt;&quot;123.45&quot; units.DisplayType = #Metric --&gt;#metric units.MetricType = #meters --&gt;#meters units.formatValue 123.45 --&gt;&quot;3.136m&quot; units.MetricType = #centimeters --&gt;#centimeters units.formatValue 123.45 --&gt;&quot;313.563cm&quot; units.DisplayType = #US --&gt;#us units.USType = #ft_Frac_In --&gt;#ft_Frac_In units.formatValue 123.45 --&gt;&quot;10&#39;3 14/32&quot;&quot; units.USType = #Dec_Ft --&gt;#dec_Ft units.formatValue 123.45 --&gt;&quot;10.287&#39;&quot; units.DisplayType = #Custom --#custom units.formatValue 123.45 --&gt;&quot;0.016FL&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>units.decodeValue &lt;string&gt; \n\
</pre></div><p>Parses <span class=\'code\'>&lt;string&gt;</span> using the current unit settings and returns a <span class=\'code\'>&lt;float&gt;</span>.</p>\n\
<p>A run-time error is thrown if an error occurs in the parsing of the string.</p>\n\
<p>This is the inverse function of <span class=\'code\'>units.formatValue()</span> described above.</p>\n\
<p>The back and forth conversion of values can lead to precision loss due to rounding errors.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` units.DisplayType = #Generic --&gt;#Generic units.decodeValue &quot;3.136m&quot; --&gt;123.465 units.decodeValue &quot;313.563cm&quot; --&gt;123.45 units.decodeValue &quot;10&#39;3 14/32&quot;&quot; --&gt;123.438 units.decodeValue &quot;10.287&#39;&quot; --&gt;123.444 units.decodeValue &quot;0.016FL&quot; --&gt;126.72</p>\n\
<p>```</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";