var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Accessing Active Viewport Info, Type, and Transforms</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Accessing Active Viewport Info, Type, and Transforms</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"accessing-active-viewport-info-type-and-transforms\"></a></div>\n\
<p>The following global variables and methods provide access to the Viewports of <strong>3ds Max</strong>.</p>\n\
<p>In addition, the <strong><a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/U-V-W-X-Y-Z/Interface-ViewPanelManager.html\' title=\'\'>ViewPanelManager</a> Core Interface</strong> introduced in <strong>3ds Max 2013</strong> exposes the View Panel management functionality, as well as methods related to controlling the placement of the splitter bars and the setting of viewports to Extended types.</p>\n\
<p>{{toc}}</p>\n\
<div class=\'section\'><a id=\"viewport-related-system-global-variables\"></a><h2 id=\"viewport-related-system-global-variables\">Viewport-Related System Global Variables</h2></div>\n\
<p>The following <strong>3ds Max</strong> system global variables are associated with the viewports:</p>\n\
<div class=\'codeBlock\'><pre>viewport.numViews \n\
</pre></div><p>This <strong>3ds Max system global variable</strong> contains the number of 3D viewports in the current viewport layout.</p>\n\
<p>This variable is read-only.</p>\n\
<p>This variable does not reflect any 2D (Track View, Schematic View, MAXScript Listener, and so on) views in the viewport layout.</p>\n\
<p>So, for example, if <span class=\'code\'>viewport.getLayout()</span> returns <span class=\'code\'>#layout_4</span> and this variable contains the value 2, you know that two of the viewports contain 2D views.</p>\n\
<p>Up until <strong>3ds Max 2013</strong>, MAXScript did not allow any access to 2D view viewports. Since <strong>3ds Max 2013</strong>, viewports can be set to some of the extended types, in particular Track View, Schematic View and Scene Explorer. See the method <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/U-V-W-X-Y-Z/Interface-ViewPanelManager.htmlGUID-984BDD3C-DEDD-4667-B1F5-15236D776BFC\' title=\'\'>ViewPanelManager.SetExtendedView()</a> for details.</p>\n\
<div class=\'codeBlock\'><pre>viewport.activeViewport \n\
</pre></div><p>This <strong>3ds Max system global variable</strong> lets you get and set the index of the active viewport.</p>\n\
<p>If you change the currently active viewport to a 2D view, this variable will contain the value 0.</p>\n\
<div class=\'codeBlock\'><pre>viewport.activeViewportID\n\
</pre></div><p>Let&#39;s you get and set the ID of the active viewport.</p>\n\
<p>Available in <strong>3ds Max 2014 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;viewport.numViewEx [ viewPanelIndex:&lt;view panel index&gt; ]\n\
</pre></div><p>Returns the number of viewports.</p>\n\
<p>The optional <strong><span class=\'code\'>viewPanelIndex</span></strong> keyword argument specifies the indexed viewPanel, and defaults to the current viewPanel if not specified (the same value as returned by <span class=\'code\'>ViewPanelManager.GetActiveViewPanelIndex()</span>).</p>\n\
<p>Available in <strong>3ds Max 2014 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;viewport.activeViewportEx &lt;viewportIndex&gt; [ viewPanelIndex:&lt;view panel index&gt; ]\n\
</pre></div><p>Activates the specified indexed viewport.</p>\n\
<p>The optional <strong><span class=\'code\'>viewPanelIndex</span></strong> keyword argument specifies the indexed viewPanel, and defaults to the current viewPanel if not specified (the same value as returned by <span class=\'code\'>ViewPanelManager.GetActiveViewPanelIndex()</span>).</p>\n\
<p>Available in <strong>3ds Max 2014 and higher</strong>.</p>\n\
<div class=\'section\'><a id=\"viewport-layout\"></a><h2 id=\"viewport-layout\">Viewport Layout</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;view_layout_name&gt;viewport.getLayout() \n\
</pre></div><p>Returns the viewport layout. For the list of possible layout names, see below.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;viewport.setLayout &lt;view_layout_name&gt; \n\
</pre></div><p>Sets the viewport layout, where <span class=\'code\'>&lt;view_layout_name&gt;</span> specifies the viewport layout configuration.</p>\n\
<p>When setting the layout, the view shown in each viewport is based on the configuration set in <strong>Customize &gt; Viewport Configuration &gt; Layout</strong>.</p>\n\
<p>The list of valid <span class=\'code\'>&lt;view_layout_name&gt;</span> values below uses the following syntax:</p>\n\
<div class=\'codeBlock\'><pre># is the total number of viewports.\n\
V = vertical split\n\
H = horizontal split\n\
L/R = left/right placement\n\
T/B = top/bottom placement\n\
</pre></div><p>The valid <span class=\'code\'>&lt;view_layout_name&gt;</span> values are:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"header\">\n\
<th align=\"left\">Layout</th>\n\
<th align=\"left\">Name</th>\n\
<th align=\"left\">Description</th>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"></td>\n\
<td align=\"left\">#layout_1</td>\n\
<td align=\"left\">One viewport</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"></td>\n\
<td align=\"left\">#layout_2v</td>\n\
<td align=\"left\">Two Viewports, Vertical Split, Equally Sized</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"></td>\n\
<td align=\"left\">#layout_2h</td>\n\
<td align=\"left\">Two Viewports, Horizontal Split, Equally Sized</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"></td>\n\
<td align=\"left\">#layout_2ht</td>\n\
<td align=\"left\">Two Viewports, Horizontal Split, Top Viewport Smaller</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"></td>\n\
<td align=\"left\">#layout_2hb</td>\n\
<td align=\"left\">Two Viewports, Horizontal Split, Bottom Viewport Smaller</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"></td>\n\
<td align=\"left\">#layout_3vl</td>\n\
<td align=\"left\">Three Viewports, Vertical Split, Horizontal Split On Left</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"></td>\n\
<td align=\"left\">#layout_3vr</td>\n\
<td align=\"left\">Three Viewports, Vertical Split, Horizontal Split On Right</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"></td>\n\
<td align=\"left\">#layout_3ht</td>\n\
<td align=\"left\">Three Viewports, Horizontal Split, Vertical Split On Top</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"></td>\n\
<td align=\"left\">#layout_3hb</td>\n\
<td align=\"left\">Three Viewports, Horizontal Split, Vertical Split On Bottom</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"></td>\n\
<td align=\"left\">#layout_4vl</td>\n\
<td align=\"left\">Four Viewports, Vertical Split, Two Horizontal Splits On Left</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"></td>\n\
<td align=\"left\">#layout_4vr</td>\n\
<td align=\"left\">Four Viewports, Vertical Split, Two Horizontal Splits On Right</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"></td>\n\
<td align=\"left\">#layout_4ht</td>\n\
<td align=\"left\">Four Viewports, Horizontal Split, Two Vertical Splits On Top</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\"></td>\n\
<td align=\"left\">#layout_4hb</td>\n\
<td align=\"left\">Four Viewports, Horizontal Split, Two Vertical Splits On Bottom</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\"></td>\n\
<td align=\"left\">#layout_4</td>\n\
<td align=\"left\">Four Viewports, Equally Sized</td>\n\
</tr>\n\
</table>\n\
<p>Since <strong>3ds Max 2013</strong>, the exact location of the splitter bars can be controlled using MAXScript. See the method <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/U-V-W-X-Y-Z/Interface-ViewPanelManager.htmlGUID-84619C6E-DF8F-465F-B773-5D2D08ACD199\' title=\'\'>ViewPanelManager.SetSplitterBarPos()</a> for details.</p>\n\
<div class=\'codeBlock\'><pre>&lt;view_type_name&gt;viewport.getType [ index:&lt;integer&gt;  viewPanelIndex:&lt;int&gt;] \n\
</pre></div><p>This method returns the type of the specified viewport, or the currently active viewport if none is specified.</p>\n\
<p>The optional <strong><span class=\'code\'>index:</span></strong> keyword argument specifies the indexed viewport, or the currently active viewport (the same value as returned by <span class=\'code\'>viewport.activeViewport()</span>).</p>\n\
<p>The optional <strong><span class=\'code\'>viewPanelIndex</span></strong> keyword argument specifies the indexed viewPanel, and defaults to the current viewPanel if not specified (the same value as returned by <span class=\'code\'>ViewPanelManager.GetActiveViewPanelIndex()</span>).</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;viewport.setType &lt;view_type_name&gt; \n\
</pre></div><p>This method sets the view type of the active viewport.</p>\n\
<p>Returns True if setting the view type was success, False if not.</p>\n\
<p>Valid <span class=\'code\'>&lt;view_type_name&gt;</span> values are:</p>\n\
<table class=\'ruled\'>\n\
<tr class=\"odd\">\n\
<td align=\"left\">#view_top</td>\n\
<td align=\"left\">Top</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">#view_bottom</td>\n\
<td align=\"left\">Bottom</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">#view_right</td>\n\
<td align=\"left\">Right</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">#view_left</td>\n\
<td align=\"left\">Left</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">#view_front</td>\n\
<td align=\"left\">Front</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">#view_back</td>\n\
<td align=\"left\">Back</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">#view_persp_user</td>\n\
<td align=\"left\">Perspective</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">#view_iso_user</td>\n\
<td align=\"left\">User</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">#view_camera</td>\n\
<td align=\"left\">Camera</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">#view_spot</td>\n\
<td align=\"left\">Light</td>\n\
</tr>\n\
<tr class=\"odd\">\n\
<td align=\"left\">#view_shape</td>\n\
<td align=\"left\">Shape</td>\n\
</tr>\n\
<tr class=\"even\">\n\
<td align=\"left\">#view_grid</td>\n\
<td align=\"left\">Grid</td>\n\
</tr>\n\
</table>\n\
<p>If the current viewport is an extended viewport (that is, a Schematic View, Asset Manager, or MAXScript Listener viewport), <span class=\'code\'>getType()</span> will return <span class=\'code\'>undefined</span> . If a Camera is specified with <span class=\'code\'>setType()</span> , and there is not exactly one camera selected, a dialog will be displayed for the user to select the camera to use. If there is no Camera, a message box &quot;No Cameras in scene&quot; will be issued.</p>\n\
<p><span class=\'code\'>viewport.getType</span> can also return a value of <span class=\'code\'>#view_none</span> . If none of the viewports have focus, a value of False is returned.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` viewport.setType #view_top -- set active viewport to Top view --&gt; true viewport.getType() -- should return what you expect... --&gt; #view_top</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>Since <strong>3ds Max 2013</strong>, the viewport can be set to some of the Extended Viewport Types - Track View, Schematic View or Scene Explorer. See the method <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/U-V-W-X-Y-Z/Interface-ViewPanelManager.htmlGUID-984BDD3C-DEDD-4667-B1F5-15236D776BFC\' title=\'\'>ViewPanelManager.SetExtendedView()</a> for details.</p>\n\
<div class=\'codeBlock\'><pre>&lt;index&gt;viewport.GetID &lt;viewportIndex&gt; [ viewPanelIndex:&lt;view panel index&gt; ]\n\
</pre></div><p>Returns the ID of the indexed viewport in <strong>3ds Max 2009 and higher</strong>. The ID cannot be set.</p>\n\
<p>When a viewport is maximized, its index is always 1, and its ID corresponds to its index when not maximized. For example, if the bottom right viewport with index 4 is maximized, its index will become 1, but its ID will remain 4.</p>\n\
<p>The optional <strong><span class=\'code\'>viewPanelIndex</span></strong> keyword argument specifies the indexed viewPanel, and defaults to the current viewPanel if not specified (the same value as returned by <span class=\'code\'>ViewPanelManager.GetActiveViewPanelIndex()</span>).</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;viewport.ResetAllViews() \n\
</pre></div><p>This method will reset all viewports in <strong>3ds Max</strong> to the default layout.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;getActiveCamera()\n\
</pre></div><p>Returns the camera node associated with the active view, <strong><span class=\'code\'>undefined</span></strong> if the view is not a camera view.</p>\n\
<div class=\'codeBlock\'><pre>&lt;node&gt;viewport.getCamera [ index:&lt;integer&gt; viewPanelIndex:&lt;view panel index&gt; ] \n\
</pre></div><p>Returns the camera node associated with the active view. <strong><span class=\'code\'>undefined</span></strong> if the view is not a camera view.</p>\n\
<p>If the optional <span class=\'code\'>index:</span> keyword is specified in <strong>3ds Max 2009 and higher</strong>, returns the camera of the indexed viewport instead of the active viewport.</p>\n\
<p>The index numbers correspond to the ones used by <strong><span class=\'code\'>viewport.activeViewport</span></strong> .</p>\n\
<p>The optional <strong><span class=\'code\'>viewPanelIndex</span></strong> keyword argument specifies the indexed viewPanel, and defaults to the current viewPanel if not specified (the same value as returned by <span class=\'code\'>ViewPanelManager.GetActiveViewPanelIndex()</span>).</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;viewport.setCamera &lt;camera_or_light_node&gt; \n\
</pre></div><p>Sets the active viewport to a Camera view, using the specified camera.</p>\n\
<p>You can also set the active view to a Light view using a free, target or direct light.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;viewport.CanSetToViewport() \n\
</pre></div><p>Returns True for cameras and lights that can be used as a viewport camera (in other words the object is a valid argument for <strong><span class=\'code\'>viewport.setCamera()</span></strong> )</p>\n\
<div class=\'section\'><a id=\"viewport-display-and-render-controls\"></a><h2 id=\"viewport-display-and-render-controls\">Viewport Display and Render Controls</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;viewport.setGridVisibility {&lt;int&gt; | #all} &lt;boolean&gt; [ viewPanelIndex:&lt;view panel index&gt; ]\n\
</pre></div><p>This method sets the Grid visibility in a viewport.</p>\n\
<p><span class=\'code\'>&lt;int&gt;</span> is the viewport index, and <span class=\'code\'>&lt;boolean&gt;</span> is the new Grid visibility state.</p>\n\
<p>If <strong><span class=\'code\'>#all</span></strong> is specified, the grid visibility for all viewports is set to the specified state.</p>\n\
<p>The optional <strong><span class=\'code\'>viewPanelIndex</span></strong> keyword argument specifies the indexed viewPanel, and defaults to the current viewPanel if not specified (the same value as returned by <span class=\'code\'>ViewPanelManager.GetActiveViewPanelIndex()</span>).</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;viewport.getGridVisibility &lt;int&gt; [ viewPanelIndex:&lt;view panel index&gt; ] \n\
</pre></div><p>This method returns True when the Grid is visible in the specified viewport, False when it is not.</p>\n\
<p>The <span class=\'code\'>&lt;int&gt;</span> argument is the viewport index.</p>\n\
<p>The optional <strong><span class=\'code\'>viewPanelIndex</span></strong> keyword argument specifies the indexed viewPanel, and defaults to the current viewPanel if not specified (the same value as returned by <span class=\'code\'>ViewPanelManager.GetActiveViewPanelIndex()</span>).</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;viewport.isWire() \n\
</pre></div><p>This method returns True if the active viewport is in Wire mode</p>\n\
<div class=\'codeBlock\'><pre>viewport.DispBkgImage \n\
</pre></div><p>When this property is set to True, the background image will be displayed in the active viewport. When set to False, the background image will not be displayed.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;viewport.EnableSolidBackgroundColorMode &lt;boolean&gt;\n\
</pre></div><p>This method controls the Solid Background Color display vs Gradient Background Color display.</p>\n\
<p>When the boolean argument is True, the background of the current viewport will be set to Solid Color (in other words, the Gradient will be disabled).</p>\n\
<p>When the boolean argument is False, the background of the current viewport will apply the Gradient colors.</p>\n\
<p>Returns True on success, False on failure.</p>\n\
<p>Available in <strong>3ds Max 2013 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;viewport.IsSolidBackgroundColorMode()\n\
</pre></div><p>This method returns True if the current viewport is in Solid Background Color mode, False if it is in Gradient mode.</p>\n\
<p>Available in <strong>3ds Max 2013 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;render_level&gt;viewport.GetRenderLevel() \n\
</pre></div><p>Returns the viewport render level.</p>\n\
<p>The return value can be one of the following: <span class=\'code\'>#smoothhighlights</span> , <span class=\'code\'>#wireFrame</span> , <span class=\'code\'>#smooth</span> , <span class=\'code\'>#facethighlights</span> , <span class=\'code\'>#facet</span> , <span class=\'code\'>#flat</span> , <span class=\'code\'>#litwireframe</span> , <span class=\'code\'>#Box</span> , <span class=\'code\'>#hiddenline</span></p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;viewport.SetRenderLevel &lt;render_level&gt; \n\
</pre></div><p>Sets the current viewport&#39;s render level to the specified mode.</p>\n\
<p>Valid argument values are <span class=\'code\'>#smoothhighlights</span> , <span class=\'code\'>#wireFrame</span> , <span class=\'code\'>#smooth</span> , <span class=\'code\'>#facethighlights</span> , <span class=\'code\'>#facet</span> , <span class=\'code\'>#flat</span> , <span class=\'code\'>#litwireframe</span> , <span class=\'code\'>#Box</span> , <span class=\'code\'>#hiddenline</span></p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;viewport.GetShowEdgeFaces() \n\
</pre></div><p>Returns True if Edged Faces display is enabled in the current viewport, False otherwise.</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;viewport.SetShowEdgeFaces &lt;boolean&gt; \n\
</pre></div><p>Turns the Edged Faces display on or off depending on the boolean argument.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;viewport.GetTransparencyLevel() \n\
</pre></div><p>Returns the current viewport&#39;s transparency level. Possible values are:</p>\n\
<p>1 - None</p>\n\
<p>2 - Simple</p>\n\
<p>3 - Best</p>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;viewport.SetTransparencyLevel &lt;transp_level&gt; \n\
</pre></div><p>When Sets the current viewport&#39;s transparency level. See above for possible values.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;viewport.IsEnabled() \n\
</pre></div><p>Returns True if the current viewport is enabled, False if it is disabled.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;viewport.IsPerspView() \n\
</pre></div><p>Returns True if the current viewport is a perspective viewport (Pespective or non-othographic Camera), False if it is an orthographic view (Top, Bottom, Front, Back, Left, Right, User, orthographic Camera...).</p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;viewport.GetFPS() \n\
</pre></div><p>Returns the last frame rate value in frames per second calculated by the Show Statistics overlay for the current viewport. If the viewport&#39;s Show Statistics option is not turned on, the value will <strong>not</strong> represent the current frame rate of the viewport.</p>\n\
<p>Available in <strong>3ds Max 9</strong> and higher.</p>\n\
<p>In <strong>3ds Max 2008</strong> and higher, if the Adaptive Degradation is turned on, the value reported will be the target frame rate, not the actual frame rate.</p>\n\
<div class=\'section\'><a id=\"viewport-transformations\"></a><h2 id=\"viewport-transformations\">Viewport Transformations</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;matrix3&gt;getViewTM() \n\
&lt;matrix3&gt;viewport.getTM() viewport.setTM &lt;matrix3&gt; \n\
</pre></div><p>Get or set the active view screen-to-world transform matrix for non-orthographic (perspective and isometric user views) viewports. This is the affine camera or viewport matrix. <span class=\'code\'>setTM</span> only operates on Perspective viewports, and returns a value of True if the view transform matrix was successfully set, False otherwise.</p>\n\
<p>The following function returns as a Ray value the &quot;eye&quot; location and direction for the active viewport. The viewport needs to be anon-orthographic viewport.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` fn getViewDirectionRay = ( -- The affine TM transforms from world coords to view coords -- so we need the inverse of this matrix local coordSysTM = Inverse(getViewTM()) -- The Z axis of this matrix is the view direction. local viewDir = -coordSysTM.row3 -- get the view position from this matrix local viewPt = coordSysTM.row4 return ray viewPt viewDir )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;fov_value&gt;getViewFOV() \n\
</pre></div><p>Returns the Field of View for the active viewport. If the viewport is an orthographic viewport, a value of 57.2958 degrees (1 radian) is returned.</p>\n\
<div class=\'codeBlock\'><pre>&lt;fov_value&gt;viewport.GetFOV() \n\
</pre></div><p>Returns the Field of View for the active viewport. Same as <span class=\'code\'>getViewFOV()</span></p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;viewport.SetFOV &lt;float&gt; \n\
</pre></div><p>Sets the Field of View for the active viewport to the specified angle in degrees.</p>\n\
<p>Works only with perspective and camera views.</p>\n\
<p>Returns True if successful, False if the current viewport is not a perspective or camera view.</p>\n\
<p>Available in <strong>3ds Max 2008</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>&lt;focal_distance&gt;viewport.getFocalDistance() \n\
</pre></div><p>Return the focal distance of the active viewport if a perspective view, undefined otherwise.</p>\n\
<p>Available in <strong>3ds Max 2008</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;viewport.setFocalDistance &lt;focal_distance&gt; \n\
</pre></div><p>Sets the focal distance of the active viewport.</p>\n\
<p>Works only with perspective views, does not work with camera views.</p>\n\
<p>Returns True if successful, False if the current viewport is not a perspective or camera view.</p>\n\
<p>Available in <strong>3ds Max 2008</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;viewport.pan &lt;float&gt; &lt;float&gt; [applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Performs a pan of the current viewport using the first argument as the X and the second argument as the Y screen delta in pixels.</p>\n\
<p>Works with all viewport types <strong>except</strong> object-based ones (Camera, Light etc.).</p>\n\
<p>Returns True if successful, False if the viewport is object-based.</p>\n\
<p>The <span class=\'code\'>applyUIScaling</span> parameter indicates whether to apply UI scaling on high-DPI displays.</p>\n\
<p>Available in <strong>3ds Max 2008</strong> and higher.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` viewport.pan 10 0 -- pan horizontally by ten pixel completeredraw() -- redraw the views to see the changes</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;viewport.zoom &lt;float&gt; \n\
</pre></div><p>Performs a zoom of the current viewport using the supplied float value as zoom factor- for example, 2.0 zooms out two times, 0.5 zooms in two times.</p>\n\
<p>Works with all viewport types <strong>except</strong> object-based ones (Camera, Light etc.).</p>\n\
<p>Returns True if successful, False if the view is object-based.</p>\n\
<p>Available in <strong>3ds Max 2008</strong> and higher.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` --while the perspective viewport is active, evaluate viewport.setFOV 50.0 --set viewport Field Of View to 50 deg. true completeredraw() --redraw the views OK viewport.zoom 2.0 --zoom out two times true completeredraw() --redraw the views OK viewport.getFOV() --get the new Field Of View 86.0061</p>\n\
<p>```</p>\n\
<p>What does this result mean?</p>\n\
<p>The FOV angle is dependent on the width of the image plane, but the target distance remains the same.</p>\n\
<p>When the angle is 50 degrees, tangent of half the angle is</p>\n\
<p>tan (50.0/2) -&gt; 0.466308</p>\n\
<p>When you zoom in two times, the width increases twice.</p>\n\
<p>Thus, atan(0.466308*2) -&gt; 43.0031 (new half-angle) and</p>\n\
<p>43.0031 * 2 =86.0062 which is the full viewport FOV angle:</p>\n\
<div class=\'figure\'><img src=\'developer/images/GUID-0C6EBC8D-8A6C-484C-A1B1-D33EB022B6B9-low.gif\' title=\'\'></div>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;viewport.zoomPerspective &lt;float&gt; \n\
</pre></div><p>Zooms the active viewport. Exactly equivalent to the Interactive Zoom tool in the <strong>3ds Max</strong> UI.</p>\n\
<p>This method only works with Perspective views. Does not work for camera views. In the <strong>3ds Max</strong> UI, when a user zooms in an orthographic or Isometric User view, internally, a switch is performed on the viewport type, and instead a call to ViewExp::Zoom ( <span class=\'code\'>viewport.zoom()</span> )is made.</p>\n\
<p>Returns True if successful, False if the viewport is not a perspective view.</p>\n\
<p>Available in <strong>3ds Max 2008</strong> and higher.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;viewport.rotate &lt;quat&gt; [center:&lt;Point3&gt;] \n\
</pre></div><p>Performs a rotate of the current viewport using the supplied quaternion value for the rotation and the Point3 value as the center to perform the rotation about.</p>\n\
<p>Works with all viewport types <strong>except</strong> object-based ones (Camera, Light etc.).</p>\n\
<p>Returns True if successful, False if the view is object-based.</p>\n\
<p>Available in <strong>3ds Max 2008</strong> and higher.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` theAxis = (viewport.getTM()).row3 for i = 1 to 180 do ( viewport.rotate (quat 2 theAxis) completeredraw() )</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>viewport.setCanvasNavigationMode &lt;boolean&gt;\n\
</pre></div><p>Set the Canvas Navigation Mode of the active viewport on or off.</p>\n\
<p>When a viewport is in 2D Canvas Navigation Mode, the user can only perform 2D pan and zoom in the viewport, all other viewport navigation commands will be rejected.</p>\n\
<p>Available in <strong>3ds Max 2014 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;viewport.isCanvasNavigationMode()\n\
</pre></div><p>Returns True if the viewport is in Canvas Navigation Mode, False if it is not.</p>\n\
<p>When a viewport is in 2D Canvas Navigation Mode, the user can only perform 2D pan and zoom in the viewport, all other viewport navigation commands will be rejected.</p>\n\
<p>Available in <strong>3ds Max 2014 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;bitmap&gt;viewport.getViewportDib index:&lt;int&gt; viewPanelIndex:&lt;int&gt; captureAlpha:&lt;boolean&gt; gammaCorrect:&lt;boolean&gt;  \n\
</pre></div><p>This method returns the active viewport&#39;s graphics window image as a Bitmap value.</p>\n\
<p>The size of the bitmap is the same size as the viewport.</p>\n\
<p>This method is different from <span class=\'code\'>gw.getViewportDib()</span> <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Viewports/GUID-1B088FF0-6A36-420E-9F37-F0DBE9FB2676.html#dib--device-independent-bitmap--methods\' title=\'\'>documented here</a> in that it includes the results of using <span class=\'code\'>maxops.displayActiveCameraViewWithMultiPassEffect()</span> . Thus, it can be used to generate viewport images containing Depth Of Field or Motion Blur previews.</p>\n\
<p>Available in <strong>3ds Max 2008 and higher</strong> . Previously available in <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<p>The following options were added in <strong>3ds Max 2015</strong>:</p>\n\
<p>If neither <span class=\'code\'>index:</span> nor <span class=\'code\'>viewPanelIndex:</span> are specified, returns the currently active viewport.</p>\n\
<p>if only <span class=\'code\'>index:</span> is specified, returns the bitmap of the indexed viewport in the current viewPanel.</p>\n\
<p>If <span class=\'code\'>viewPanelIndex:</span> is specified but <span class=\'code\'>index:</span> is not specified, returns the bitmap of the active viewport in the indexed viewPanel.</p>\n\
<p>If both <span class=\'code\'>viewPanelIndex:</span> and <span class=\'code\'>index:</span> are specified, returns the bitmap of the indexed viewport in the indexed viewPanel.</p>\n\
<p>If the <span class=\'code\'>captureAlpha:</span> optional keyword argument is specified and set to True, the viewport Alpha will also be captured. If set to False or not specified, the returned image will contain no Alpha and only the RGB channels (old behavior).</p>\n\
<p>If the <span class=\'code\'>gammaCorrect:</span> optional keyword argument is not specified or set to True, gamma correction will be performed on the returned Bitmap value. If set to False, no gamma correction will be performed.</p>\n\
<p>See also <span class=\'code\'>windows.snapshot()</span> <a href=\'#!/url=./developer/Interaction-With-The-Operating/Windows-Structure.htmlGUID-BD84D9F4-C612-4217-8BD8-32838DB410B4\' title=\'\'>documented here</a>.</p>\n\
<div class=\'codeBlock\'><pre>&lt;IntegerPtr&gt;viewport.getHWnd [ index:&lt;int&gt;viewPanelIndex:&lt;int&gt; ]\n\
</pre></div><p>Returns the HWND Windows handle of the specified viewport or viewPanel.</p>\n\
<p>If neither <span class=\'code\'>index:</span> nor <span class=\'code\'>viewPanelIndex:</span> are specified, returns the currently active viewport.</p>\n\
<p>if only <span class=\'code\'>index:</span> is specified, returns the HWND of the indexed viewport in the current viewPanel.</p>\n\
<p>If <span class=\'code\'>viewPanelIndex:</span> is specified but <span class=\'code\'>index:</span> is not specified, returns the HWND of the active viewport in the indexed viewPanel.</p>\n\
<p>If both <span class=\'code\'>viewPanelIndex:</span> and <span class=\'code\'>index:</span> are specified, returns the HWND of the indexed viewport in the indexed viewPanel.</p>\n\
<p>Available in <strong>3ds Max 2015 and higher</strong>.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` --Print the HWND Handles of all valid viewports: for i = 1 to viewport.numViews do format &quot;HWND of Viewport % is %\\n&quot; i (viewport.getHWnd index:i)</p>\n\
<p>--Snapshot the valid viewports: for i = 1 to viewport.numViews do display (windows.snapshot (viewport.getHWnd index:i)) caption:(&quot;Viewport &quot;+i as string)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;void&gt;viewport.ZoomToBounds &lt;All_Bool&gt; &lt;A_Point3&gt; &lt;B_Point3&gt; \n\
</pre></div><p>Zooms all or the current viewport to a bounding region.</p>\n\
<p>When the first argument is passed as True, all viewports are zoomed. When False, only the selected viewport is zoomed.</p>\n\
<p>The second and third arguments define the bounding region to zoom to.</p>\n\
<div class=\'codeBlock\'><pre>&lt;point2&gt;getViewSize [ removeUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Returns the active view size as <span class=\'code\'>point2</span> in pixels.</p>\n\
<p>The optional <span class=\'code\'>removeUIScaling</span> parameter indicates whether to remove scaling on high-DPI displays.</p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;getScreenScaleFactor &lt;point3&gt; \n\
</pre></div><p>Returns the active view scale factor, giving the width in world-space units at the point&#39;s distance from the view space origin.</p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;viewport.GetScreenScaleFactor() \n\
</pre></div><p>Returns the active view scale factor, giving the width in world-space units at the point&#39;s distance from the view space origin. Same as <span class=\'code\'>getScreenScaleFactor()</span></p>\n\
<div class=\'codeBlock\'><pre>&lt;ray&gt;mapScreenToWorldRay &lt;pixel_coord_point2&gt; applyUIScaling:&lt;true&gt;\n\
</pre></div><p>Returns a <span class=\'code\'>Ray</span> value in world space through the given viewport pixel coordinates in the current active view, and perpendicular to the viewport plane. When <span class=\'code\'>applyUIScaling</span> is true (the default), any scaling required by HDPI displays is applied to the returned ray.</p>\n\
<div class=\'codeBlock\'><pre>&lt;point3&gt;mapScreenToView &lt;pixel_coord_point2&gt; &lt;depth_float&gt; \\\n\
  [ &lt;viewport_size_point2&gt; ]  applyUIScaling:&lt;true&gt;\n\
</pre></div><p>Returns a 3D point in the view coordinate space. Given a point in the active viewport screen (in viewport pixel coordinates), and a depth in view coordinates, this method maps the point into view coordinates. If <span class=\'code\'>&lt;viewport_size_point2&gt;</span> is supplied, the specified viewport size is used instead of the actual viewport size. When <span class=\'code\'>applyUIScaling</span> is true (the default), any scaling required by HDPI displays is applied to the returned point3.</p>\n\
<div class=\'codeBlock\'><pre>&lt;point3&gt;mapScreenToCP &lt;pixel_coord_point2&gt; [ &lt;viewport_size_point2&gt; ] \\\n\
  applyUIScaling:&lt;true&gt;\n\
</pre></div><p>Maps viewport pixel coordinates in the current active view to the construction plane in world coordinates. If <span class=\'code\'>&lt;viewport_size_point2&gt;</span> is supplied, the specified viewport size is used instead of the actual viewport size. When <span class=\'code\'>applyUIScaling</span> is true (the default), any scaling required by HDPI displays is applied to the returned point3.</p>\n\
<div class=\'codeBlock\'><pre>&lt;matrix3&gt;getCPTM() \n\
</pre></div><p>Returns the construction-plane-to-world transformation matrix.</p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;gw.nonScalingObjectSize() \n\
</pre></div><p>The value returned from this method may be used as a scale factor that will counteract the viewport zoom. For example, lights, cameras, and tape helper objects use this factor so the size of the node in the scene remains constant when the viewport is zoomed in and out.</p>\n\
<p>This value is affected by the &#39;Non-Scaling Object Size&#39; spinner in the Viewport Preferences dialog, so the user has some control over this as well.</p>\n\
<div class=\'codeBlock\'><pre>&lt;point3&gt;gw.getPointOnCP &lt;pixel_coord_point2&gt; [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Returns a point in world space on the current construction plane based on the specified screen coordinate.</p>\n\
<p>The <span class=\'code\'>applyUIScaling</span> parameter indicates whether to apply UI scaling on high-DPI displays.</p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;gw.getCPDisp &lt;base_point3&gt; &lt;dir_point3&gt; &lt;start_pixel_coord_point2&gt; \\ \n\
  &lt;end_pixel_coord_point2&gt; [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>This method returns a length in world space given a start screen point (<span class=\'code\'>&lt;start_pixel_coord_point2&gt;</span>), an end screen point (<span class=\'code\'>&lt;end_pixel_coord_point2&gt;</span>), a base point (<span class=\'code\'>&lt;base_point3&gt;</span>) and a direction vector (<span class=\'code\'>&lt;dir_point3&gt;</span>). For example, when creating a cylinder, the user clicks the mouse down to define the center point of the cylinder (base), then drags out a radius. They then drag out a height for the cylinder. This method is used to return intermediate and final heights for the cylinder based on the initial base point, the direction vector (the Z axis), the start mouse point, and the current point the user is interactively adjusting.</p>\n\
<p>The <span class=\'code\'>applyUIScaling</span> parameter indicates whether to apply UI scaling on high-DPI displays.</p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;gw.getVPWorldWidth &lt;point3&gt; \n\
</pre></div><p>Returns the viewport screen width factor in world space at a point in world space.</p>\n\
<div class=\'codeBlock\'><pre>&lt;point3&gt;gw.mapCPToWorld &lt;point3&gt; \n\
</pre></div><p>Returns the corresponding world space point given a point on the construction plane. For example, if you use <span class=\'code\'>gw.getPointOnCP()</span> to convert a screen coordinate to a point on the construction plane, you could then call this method to convert that point on the construction plane to a world space point.</p>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;gw.getFocalDist() \n\
</pre></div><p>Returns the focal distance of an active perspective view.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;gw.IsPerspView() \n\
</pre></div><p>Returns True if the active viewport is a perspective view; otherwise returns False.</p>\n\
<div class=\'section\'><a id=\"viewport-snapping\"></a><h2 id=\"viewport-snapping\">Viewport Snapping</h2></div>\n\
<div class=\'codeBlock\'><pre>&lt;point3&gt;gw.snapPoint&lt;pixel_coord_point2&gt; [ snapType:&lt;snapType_name&gt; ] \\\n\
  [ snapPlane:&lt;matrix3&gt; ]  [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Given a 2D screen coordinate, this method returns a 3D point on either the current construction plane or the optional <span class=\'code\'>snapPlane</span> based on the current snap settings and the optional <span class=\'code\'>snapType:</span> parameter.</p>\n\
<p>The valid <span class=\'code\'>&lt;snapType_name&gt;</span> values are:</p>\n\
<p><strong>#in3d</strong> - Snap to all points.</p>\n\
<p><strong>#inPlane</strong> - Snap only to points on the construction plane.</p>\n\
<p><strong>#unSelObjs</strong> - Ignore selected nodes when considering snap points.</p>\n\
<p><strong>#selObjs</strong> - Ignore unselected nodes when considering snap points.</p>\n\
<p><strong>#unSelSubobj</strong> - Ignore selected sub-object geometry when considering snap points.</p>\n\
<p><strong>#selSubobj</strong> - Ignore unselected sub-object geometry when considering snap points.</p>\n\
<p><strong>#force3d</strong> - Override user settings to force snap in 3D.</p>\n\
<p>The optional <span class=\'code\'>snapPlane:</span> argument available in <strong>3ds Max 8 and higher</strong> is a matrix3 value which is the transform that maps the XY plane to the snapping plane. If the matrix3 value supplied is equal to the identity matrix (Matrix3 1), the snapping plane is identical to the XY construction plane.</p>\n\
<p>The <span class=\'code\'>applyUIScaling</span> parameter indicates whether to apply UI scaling on high-DPI displays.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>``` tm = Matrix3(1) --represents the XY plane m = Point2 0 0 --screen pixel coordinates p = gw.snapPoint m snapPlane:tm --returns the snapping point</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>&lt;float&gt;gw.snapLength &lt;length_float&gt; \n\
</pre></div><p>This method snaps the length to the nearest snap increment and returns the snapped distance.</p>\n\
<div class=\'section\'><a id=\"viewport-regions\"></a><h2 id=\"viewport-regions\">Viewport Regions</h2></div>\n\
<div class=\'codeBlock\'><pre>viewport.setRegionRect &lt;viewport index&gt; &lt;box2&gt; \\\n\
  [ viewPanelIndex:&lt;view panel index&gt;  applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Sets the region rectangle for the specified viewport.</p>\n\
<p>The <span class=\'code\'>applyUIScaling</span> parameter indicates whether to apply UI scaling on high-DPI displays.</p>\n\
<p>The <strong><span class=\'code\'>index:</span></strong> keyword argument specifies the indexed viewport.</p>\n\
<p>The optional <strong><span class=\'code\'>viewPanelIndex</span></strong> keyword argument specifies the indexed viewPanel, and defaults to the current viewPanel if not specified (the same value as returned by <span class=\'code\'>ViewPanelManager.GetActiveViewPanelIndex()</span>).</p>\n\
<div class=\'codeBlock\'><pre>viewport.getRegionRect &lt;viewport index&gt; [ viewPanelIndex:&lt;view panel index&gt; removeUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Get the region rectangle for the specified viewport.</p>\n\
<p>The optional <span class=\'code\'>removeUIScaling</span> parameter indicates whether to remove scaling on high-DPI displays.</p>\n\
<p>The <strong><span class=\'code\'>index:</span></strong> keyword argument specifies the indexed viewport.</p>\n\
<p>The optional <strong><span class=\'code\'>viewPanelIndex</span></strong> keyword argument specifies the indexed viewPanel, and defaults to the current viewPanel if not specified (the same value as returned by <span class=\'code\'>ViewPanelManager.GetActiveViewPanelIndex()</span>).</p>\n\
<div class=\'codeBlock\'><pre>viewport.setBlowupRect &lt;viewport index&gt; &lt;box2&gt; \\\n\
  [ viewPanelIndex:&lt;view panel index&gt; applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Set the blowup rectangle for the specified viewport. The blowup rectangle must have the same aspect as the current render output size aspect. The top, bottom, and left component values are taken from the Box2 value argument, but the right component value is re-calculated to force the proper aspect.</p>\n\
<p>The <span class=\'code\'>applyUIScaling</span> parameter indicates whether to apply UI scaling on high-DPI displays.</p>\n\
<p>The <strong><span class=\'code\'>index:</span></strong> keyword argument specifies the indexed viewport.</p>\n\
<p>The optional <strong><span class=\'code\'>viewPanelIndex</span></strong> keyword argument specifies the indexed viewPanel, and defaults to the current viewPanel if not specified (the same value as returned by <span class=\'code\'>ViewPanelManager.GetActiveViewPanelIndex()</span>).</p>\n\
<div class=\'codeBlock\'><pre>viewport.getBlowupRect &lt;viewport index&gt;  [ viewPanelIndex:&lt;view panel index&gt; removeUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Get the blowup rectangle for the specified viewport.</p>\n\
<p>The optional <span class=\'code\'>removeUIScaling</span> parameter indicates whether to remove scaling on high-DPI displays.</p>\n\
<p>You can use the <a href=\'#!/url=./developer/3ds-Max-Objects-and-Interfaces/Interfaces/Core-Interfaces/Core-Interfaces-Documentation/E-F-G-H/Interface-EditRenderRegion.html\' title=\'\'>Interface: EditRenderRegion</a> to control the manual region editing gizmo in <strong>3ds Max 2009 and higher</strong>.</p>\n\
<p>The <strong><span class=\'code\'>index:</span></strong> keyword argument specifies the indexed viewport.</p>\n\
<p>The optional <strong><span class=\'code\'>viewPanelIndex</span></strong> keyword argument specifies the indexed viewPanel, and defaults to the current viewPanel if not specified (the same value as returned by <span class=\'code\'>ViewPanelManager.GetActiveViewPanelIndex()</span>).</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";