var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Picking Points in the Viewports</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Picking Points in the Viewports</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"picking-points-in-the-viewports\"></a></div>\n\
<p>The <span class=\'code\'>pickPoint()</span> function lets the user pick a 3D point in a <strong>3ds Max</strong> viewport or type in a 3D point in the Listener. When called, the function puts <strong>3ds Max</strong> into a special point-picking command mode and the cursor changes to a cross-hair. The user can either click in one of the <strong>3ds Max</strong>&#39;s viewports or type a 3D point into the Listener and the function returns that point as a MAXScript Point3 value in world-space coordinates.</p>\n\
<div class=\'codeBlock\'><pre>pickPoint [ prompt:&lt;string&gt; ] [ snap:#2D|#3D ] \\\n\
[ rubberBand:&lt;start_point3&gt; ] \\\n\
[ mouseMoveCallback:fn | #(fn,arg) ] \\\n\
[ relativeTo:&lt;relativePt_point3&gt; ] \\\n\
[ terminators:#(&lt;string&gt;,&lt;string&gt;,...) ]\n\
</pre></div><p>The function takes an optional <span class=\'code\'>prompt:</span> string argument that it prints in the Listener as a prompt message. There is also an optional <span class=\'code\'>snap:</span> keyword argument that controls viewport point picking if Snap is turned on in the <strong>3ds Max</strong> interface. If <span class=\'code\'>#3D</span> is specified, the cursor snaps to point anywhere in 3D space. If <span class=\'code\'>#2D</span> is specified (the default), the cursor only snaps on the current active grid construction plane. If Snap is off in the <strong>3ds Max</strong> interface, the clicked point is always taken to be on the current active grid construction plane.</p>\n\
<p>The user can either press the ESC key or click the right mouse button at any time to abort the point picking. The function immediately returns the special MAXScript value <span class=\'code\'>#escape</span> if the escape key is pressed or <span class=\'code\'>#rightClick</span> if the right mouse button is clicked.</p>\n\
<p>You can get the <span class=\'code\'>pickPoint()</span> function to display a rubberbanding dashed line during point input by supplying the optional keyword argument <span class=\'code\'>rubberBand:&lt;start_point3&gt;</span> . If you include this on a call to <span class=\'code\'>pickPoint()</span> , it rubberbands a dashed line from the specified start point to follow the mouse. You can use it in a chain of point picks by specifying the last picked point as the <span class=\'code\'>rubberBand:</span> start point for each successive pick. The start point given to <span class=\'code\'>rubberBand:</span> must be in world coordinates.</p>\n\
<p>You can also set up a mouse move callback function for tracking free mouse moves during point input. The optional keyword argument for this is <span class=\'code\'>mouseMoveCallback:</span> and it has two forms:</p>\n\
<div class=\'codeBlock\'><pre>mouseMoveCallback:fn\n\
mouseMoveCallback:#(fn, arg)\n\
</pre></div><p>The second form allows you to supply an argument value that is sent to the callback function each time it is called.</p>\n\
<p>The <span class=\'code\'>fn</span> you supply must take one argument in the first form above and two in the second. When the callback function is called, the first argument it gets is always the current world coordinates of the mouse and the second if given is the <span class=\'code\'>arg</span> you supplied. You can use a callback function to implement a more sophisticated form of rubberbanding, for example, by adjusting a spline&#39;s vertex or a box&#39;s height to follow the mouse. If you do this, make sure you call any needed <span class=\'code\'>update()</span> mesh or spline functions.</p>\n\
<div class=\'section\'><a id=\"command-line-input-in-the-listener\"></a><h2 id=\"command-line-input-in-the-listener\">Command Line Input in the Listener</h2></div>\n\
<p>The <span class=\'code\'>pickPoint()</span> function allows coordinates to be entered <strong>either</strong> by clicking in a <strong>3ds Max</strong> viewport or by typing numbers into the MAXScript Listener window. The user can enter coordinates in one of several forms (based on the command line input syntax for AutoCAD) as follows:</p>\n\
<div class=\'codeBlock\'><pre>x, y, z or [x, y, z]\n\
</pre></div><p>Explicit point in current construction plane coordinates</p>\n\
<div class=\'codeBlock\'><pre>x, y or [x, y]\n\
</pre></div><p>Point on the construction plane (cp)</p>\n\
<div class=\'codeBlock\'><pre>d\n\
</pre></div><p>Point d units away in mouse direction from last point</p>\n\
<div class=\'codeBlock\'><pre>@ x, y, z or @[x, y, z]\n\
</pre></div><p>Relative, offset to last input point</p>\n\
<div class=\'codeBlock\'><pre>@ x, y or @[x, y]\n\
</pre></div><p>On cp, relative to last point&#39;s projection on cp</p>\n\
<div class=\'codeBlock\'><pre>d &lt; a\n\
</pre></div><p>Polar on cp, distance from cp origin at a angle from x-axis</p>\n\
<div class=\'codeBlock\'><pre>@ d &lt; a\n\
</pre></div><p>relative polar on cp, centered on last point</p>\n\
<div class=\'codeBlock\'><pre>d &lt; a1 &lt; a2\n\
</pre></div><p>Spherical on cp, d from cp origin at a1 from x and a2 angle from xy-plane</p>\n\
<div class=\'codeBlock\'><pre>@ d &lt; a1 &lt; a2\n\
</pre></div><p>Relative spherical</p>\n\
<p>There can be zero or more white space characters before and between numbers and metacharacters.</p>\n\
<p>These typed-coordinates are interpreted as relative to the current active grid construction plane and the coordinates returned by <span class=\'code\'>pickPoint()</span> are always in world-space.</p>\n\
<p>When the <span class=\'code\'>relativeTo</span> : keyword argument is supplied, <span class=\'code\'>pickPoint()</span> will evaluate the result using the relativePt Point3 value instead of the last point picked if the relative coordinate syntax is used for the entry.</p>\n\
<p>Keyboard input by the user that is not in one of the expected coordinate input forms is returned as a String value, so the author can handle the error gracefully or permit other kinds of input to be parsed by the script.</p>\n\
<p>You can test for these return conditions using the <span class=\'code\'>classOf()</span> function, for example:</p>\n\
<div class=\'codeBlock\'><pre>p = pickPoint()\n\
case of\n\
(\n\
(p == undefined): ... -- user pressed escape\n\
(p == #rightClick): ... -- user clicked RMB\n\
(classOf p == Point3): ... -- user entered a point\n\
(classOf p == String): ... -- user keyed a non-point\n\
)\n\
\n\
</pre></div><p>The <span class=\'code\'>terminators:</span> keyword argument expects an array of 1 or more strings, each of 1 or more characters. When supplied, this list of strings specifies a set of keyboard input terminating character sequences. If any one of them is typed at the end of some input, the <span class=\'code\'>pickPoint()</span> function returns immediately without waiting for an ENTER to be typed. In all cases, when the <span class=\'code\'>terminators:</span> keyword argument is supplied, the <span class=\'code\'>pickPoint()</span> function returns a two-element array. The first element is the input point, the second element is the terminating string, or <span class=\'code\'>undefined</span> if the point was input with a mouse click or terminated with ENTER.</p>\n\
<p>This allows the user to type in a point terminated by a terminator string, or just type the terminator string. In the second case, the first element in the result array is the value <span class=\'code\'>undefined</span> . You can inspect the second element in the array to see what terminator, if any, the user actually typed.</p>\n\
<p>For example,</p>\n\
<div class=\'codeBlock\'><pre>pp = pickPoint prompt:&quot;foo: &quot; terminators:#(&quot; &quot;,&quot;a&quot;,&quot;oo&quot;)\n\
if pp[2] == &quot;a&quot; then ...\n\
\n\
</pre></div><p>Often, the <span class=\'code\'>pickPoint()</span> function will be used repeatedly within a script to request multiple points such as, successive vertices in a line. You might need to use the new function <span class=\'code\'>redrawViews()</span> to force a viewport update as you gradually construct new scene objects this way. MAXScript normally delays viewport redraw until the script finishes running.</p>\n\
<div class=\'codeBlock\'><pre>pickOffsetDistance [ prompt:&lt;string&gt; ] [ pt2Prompt:&lt;string&gt; ] \\ \n\
[ errPrompt:&lt;string&gt; ] [ snap:#2D|#3D ] \\ \n\
[ keyword:&lt;string&gt; ]\n\
</pre></div><p>This function issues the <span class=\'code\'>prompt</span> message, if any, to Listener and waits for the user to either click in a viewport (which determines a point exactly like the <span class=\'code\'>pickPoint()</span> function) to type in a number ended by ENTER (which determines a number), or to type all or the beginning of the <span class=\'code\'>keyword</span> ended by ENTER. If the user types the keyword, the function returns <span class=\'code\'>true</span> . If the user types a number, the function returns its value. If the user clicks a point, the function issues the <span class=\'code\'>pt2Prompt</span> message, if any, to Listener and waits for a second point to be clicked, and then returns the world-space distance between the two points. If the user types something which is not a number and does not match the keyword, the function issues the <span class=\'code\'>errPrompt</span> message (if any), otherwise the <span class=\'code\'>prompt</span> message (if any), and waits for the user to try again.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";