var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Viewport Drawing Methods</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Viewport Drawing Methods</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"viewport-drawing-methods\"></a></div>\n\
<p>The methods documented in this topic provide low-level access to <strong>3ds Max</strong>&#39;s graphics system. These methods are available for scripts to do any graphics work not possible using the standard high-level graphics methods.</p>\n\
<p>These methods are for use in the existing <strong>3ds Max</strong> viewports, and only work on the active viewport. Note that these methods typically are not for casual use, as they are not intended to be a high level graphics library. For example, many steps are required to display a single lit polygon. These methods are optimized for speed, and not at all for script programmer ease of use.</p>\n\
<p>The methods described in this topic actually operate on graphic windows. While graphic windows are not the same as viewports, they are related to one another. Each viewport has its own graphics window, and the contents of the viewport display can be thought of as a snapshot of the graphics window contents. Since writing to display memory a relatively slow operation, <strong>3ds Max</strong> writes instead to the graphics window, and then when all the writes have been finished, it redraws the viewports with the graphics window contents.</p>\n\
<p>Many of these methods take an optional <span class=\'code\'>applyUIScaling</span> argument, which always defaults to true. This argument specifies whether to apply any scaling applied by the system on high-DPI displays.</p>\n\
<div class=\'section\'><a id=\"viewport-drawing-and-the-nitrous-graphics-manager\"></a><h2 id=\"viewport-drawing-and-the-nitrous-graphics-manager\">Viewport Drawing and the Nitrous Graphics Manager</h2></div>\n\
<p>The Nitrous Graphics Manager introduced in <strong>3ds Max 2012</strong> performs continuous updates to refine the final image. This requires special handling of all Graphics Methods described further in this topic. These Methods will only be executed if they are wrapped in a Scene Redraw Callback function.</p>\n\
<p>In other words, existing scripts will have to be modified to check for the Nitrous Graphics Manager if running <strong>3ds Max 2012 or higher</strong> and call all viewport drawing operations from a Scene Redraw Callback function, and newly developed scripts must take this into account and implement the same approach.</p>\n\
<p>The MacroScript <em>Macro_GrabViewport.mcr</em> shipping with <strong>3ds Max</strong> has been updated according to these rules and can be used as an example.</p>\n\
<p>Here is another example:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE</strong></p>\n\
<p>The following script will display the class, name and position of every object in the scene:</p>\n\
<p>``` unregisterRedrawViewsCallback GW_displayObjectNames fn GW_displayObjectNames = ( gw.setTransform (matrix3 1) for o in objects where not o.isHiddenInVpt do gw.text o.pos (o as string) color:yellow gw.enlargeUpdateRect #whole<br> ) registerRedrawViewsCallback GW_displayObjectNames</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>While the above example would also work in older versions of <strong>3ds Max</strong> and using the Direct3D driver, this is the ONLY way to implement gw Viewport Drawing methods when using the Nitrous Graphics Manager in <strong>3ds Max 2012</strong>.</p>\n\
<div class=\'section\'><a id=\"graphics-driver-configuration-and-support-methods\"></a><h2 id=\"graphics-driver-configuration-and-support-methods\">Graphics Driver Configuration and Support Methods</h2></div>\n\
<div class=\'codeBlock\'><pre>gw.getDriverString()        \n\
</pre></div><p>This method returns a string identifying the graphics driver (and includes manufacturer info if available)</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>on an nVidia card using MAXtreme drivers, the result would look like this:</p>\n\
<p>``` gw.getDriverString() --&gt;&quot;NVIDIA MAXtreme v. 6.00.07&quot;</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>gw.querySupport &lt;feature_name&gt;   \n\
</pre></div><p>Determines whether the driver supports the specified feature. The valid <span class=\'code\'>&lt;feature_name&gt;</span> values are:</p>\n\
<div class=\'codeBlock\'><pre>#txtCorrect \n\
</pre></div><p>Determines whether the driver supports texture correction.</p>\n\
<div class=\'codeBlock\'><pre>#geomAccel \n\
</pre></div><p>This is used to indicate to <strong>3ds Max</strong> (and the mesh class in particular) that the driver wants to handle all of the 3D data natively. In this case, meshes are rendered by passing 3D world space data and letting the driver transform, clip, and light the vertices. If this returns <span class=\'code\'>false</span> , then the mesh class handles all transforms, clipping and lighting calculations and then calls the hPolygon or hPolyline 2 1/2D calls for the driver to rasterize. (Primitives that are actually clipped are still sent to the polygon/polyline methods.)</p>\n\
<p>Currently, only the OpenGL driver returns <span class=\'code\'>true</span> to this query, but other drivers have been developed that return <span class=\'code\'>true</span> , and the HEIDI and D3D drivers may change in the future.</p>\n\
<div class=\'codeBlock\'><pre>#triStrips \n\
</pre></div><p>If this returns <span class=\'code\'>true</span> , then <strong>3ds Max</strong> will try to stripify meshes before calling the rendering methods. Currently, the drivers just return the user preference that is set in the driver configuration dialog. This preference defaults to <span class=\'code\'>true</span> .</p>\n\
<div class=\'codeBlock\'><pre>#dualPlanes \n\
</pre></div><p>If a driver has dual-planes support it returns <span class=\'code\'>true</span>. The standard <strong>3ds Max</strong> OpenGL display driver only returns <span class=\'code\'>true</span> for this if the underlying display driver has implemented a custom OpenGL extension that allows <strong>3ds Max</strong> to handle this efficiently.</p>\n\
<div class=\'codeBlock\'><pre>#swapModel \n\
</pre></div><p>This returns <span class=\'code\'>true</span> if <strong>3ds Max</strong> has to redraw the whole scene any time the viewports are exposed.</p>\n\
<div class=\'codeBlock\'><pre>#incrUpdate \n\
</pre></div><p>This returns <span class=\'code\'>true</span> if the driver can update a rectangular subset of the viewport without trashing the image outside that rectangle. This is <span class=\'code\'>true</span> for most drivers that blit the viewport region and <span class=\'code\'>false</span> for those that do page-flipping in the hardware. For OpenGL, this is <span class=\'code\'>true</span> if the display driver implements the Microsoft <span class=\'code\'>glSwapRectHintWIN</span> extension.</p>\n\
<div class=\'codeBlock\'><pre>#passDecal \n\
</pre></div><p>This is <span class=\'code\'>true</span> if the driver can handle de-calling with only one pass. Currently, this is <span class=\'code\'>true</span> for OpenGL, but <span class=\'code\'>false</span> for HEIDI and D3D.</p>\n\
<div class=\'codeBlock\'><pre>#driverConfig \n\
</pre></div><p>This is <span class=\'code\'>true</span> if the driver has a configuration dialog. This is <span class=\'code\'>true</span> for all three of <strong>3ds Max</strong>’s standard drivers.</p>\n\
<div class=\'codeBlock\'><pre>#texturedBkg \n\
</pre></div><p>This is <span class=\'code\'>true</span> if the viewport background is implemented as a textured rectangle, and <span class=\'code\'>false</span> if it is a blitted bitmap.</p>\n\
<div class=\'codeBlock\'><pre>#virtualVpts \n\
</pre></div><p>This is <span class=\'code\'>true</span> if the driver allows viewports to be made larger than the physical window they are attached to. Currently, this is only <span class=\'code\'>true</span> for OpenGL.</p>\n\
<div class=\'codeBlock\'><pre>#paintDoesBlit \n\
</pre></div><p>This is <span class=\'code\'>true</span> if WM_PAINT messages result in a blit of the backbuffer (as opposed to a page-flipping swap). This allows <strong>3ds Max</strong> to do quick damage region repair, and works together with the <span class=\'code\'>#swapModel</span> flag.</p>\n\
<div class=\'codeBlock\'><pre>#wireframeStrips \n\
</pre></div><p>This is <span class=\'code\'>true</span> if the driver wants <strong>3ds Max</strong> to send down wireframe models using triangle strips instead of a bundle of 2-point segments. This is only used by the OpenGL driver, and it is there as a user-choosable performance-accuracy tradeoff (since the strips are faster and are back-culled, but they display hidden edges as though they are visible).</p>\n\
<div class=\'codeBlock\'><pre>gw.dualPlane \n\
</pre></div><p>Gets/Sets the status of the Viewport Parameters/Use Dual Planes checkbox in the Preference Settings dialog, Viewports tab.</p>\n\
<div class=\'section\'><a id=\"window-and-viewport-transformation-methods\"></a><h2 id=\"window-and-viewport-transformation-methods\">Window and Viewport Transformation Methods</h2></div>\n\
<div class=\'codeBlock\'><pre>gw.isPerspectiveView() \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the view is in perspective projection; otherwise <span class=\'code\'>false</span> (orthographic projection).</p>\n\
<div class=\'codeBlock\'><pre>gw.setTransform &lt;matrix3&gt; \n\
</pre></div><p>Sets the active viewport’s graphics window transformation matrix to the specified matrix3 value, and updates the modeling coordinates to normalized projection coordinates matrix. This routine also back-transforms each light and the eye point so that lighting can be done in modeling coordinates.</p>\n\
<p>This method may be used to set a matrix that transforms the point passed to the drawing methods (like <span class=\'code\'>gw.text()</span> , <span class=\'code\'>gw.marker()</span> , <span class=\'code\'>gw.polyline()</span> or <span class=\'code\'>gw.polygon()</span> ). Normally these methods expect world coordinates. However if this matrix is set to an object’s transformation matrix you can pass coordinates in the object’s space coordinates and they will be transformed into world space (and then put into screen space when they are drawn). If however this is set to the identity matrix, you would pass world space coordinates. You can set this matrix to the object’s transform matrix using the following</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` gw.setTransform node.transform</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>For world-to-screen space conversions by the methods <span class=\'code\'>gw.text()</span> , <span class=\'code\'>gw.marker()</span> , <span class=\'code\'>gw.polyline()</span> or <span class=\'code\'>gw.polygon()</span> , etc, a developer must explicitly set this matrix to the identity matrix. This is because the graphics window may have a non-identity transform matrix already in place from a previous operation.</p>\n\
<blockquote>\n\
<p><strong>FOR EXAMPLE</strong></p>\n\
<p>``` gw.setTransform (matrix3 1)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>gw.getFlipped() \n\
</pre></div><p>Returns <span class=\'code\'>true</span> if the determinant of the current transform is positive, <span class=\'code\'>false</span> if negative.</p>\n\
<div class=\'section\'><a id=\"position-size-and-depth-clipping-methods\"></a><h2 id=\"position-size-and-depth-clipping-methods\">Position, Size, and Depth Clipping Methods</h2></div>\n\
<div class=\'codeBlock\'><pre>gw.setPos &lt;x_integer&gt; &lt;y_integer&gt; &lt;w_integer&gt; &lt;h_integer&gt; [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Sets the size and position of the graphics window. The coordinates are all Windows coordinates in the space of the graphics windows&#39; parent window. All coordinates are in Windows format, with the origin in the upper left.</p>\n\
<p>x - Specifies the left graphics window origin; y - Specifies the top graphics window origin; w - Specifies the graphics window width; h - Specifies the graphics window height.</p>\n\
<div class=\'codeBlock\'><pre>gw.getWinSizeX() [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>This method gets the current window size in X.</p>\n\
<div class=\'codeBlock\'><pre>gw.getWinSizeY() [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>This method gets the current window size in Y.</p>\n\
<div class=\'codeBlock\'><pre>gw.getWinDepth() \n\
</pre></div><p>This method returns the z-buffer depth (in bits).</p>\n\
<p>Note: This method does not return the proper Z depth value in <strong>3ds Max</strong>.</p>\n\
<div class=\'codeBlock\'><pre>gw.getHitherCoord() \n\
</pre></div><p>This method returns the largest device Z value.</p>\n\
<div class=\'codeBlock\'><pre>gw.getYonCoord() \n\
</pre></div><p>This method returns the smallest device Z value.</p>\n\
<p>Note: This method does not return the proper Z depth value in <strong>3ds Max</strong>.</p>\n\
<div class=\'section\'><a id=\"dib-device-independent-bitmap-methods\"></a><h2 id=\"dib-device-independent-bitmap-methods\">DIB (Device-Independent Bitmap) Methods</h2></div>\n\
<div class=\'codeBlock\'><pre>gw.getViewportDib captureAlpha:&lt;boolean&gt; gammaCorrect:&lt;boolean&gt; \n\
</pre></div><p>This method returns the active viewport’s graphics window image as a Bitmap value.</p>\n\
<p>The size of the bitmap is the same size as the viewport.</p>\n\
<p>Since <strong>3ds Max 2015</strong>, if the <span class=\'code\'>captureAlpha:</span> optional keyword argument is specified and set to True, the viewport Alpha will also be captured. If set to False or not specified, the returned image will contain no Alpha and only the RGB channels.</p>\n\
<p>Moreover, since <strong>3ds Max 2015</strong> if the <span class=\'code\'>gammaCorrect:</span> optional keyword argument is specified and set to False, no Gamma correction will be performed on the bitmap value. If set to True or not specified, the returned image will be Gamma corrected.</p>\n\
<p>See also <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Viewports/GUID-8AA71F9E-F4F0-4437-A44E-9683619E89DE.html\' title=\'\'>Viewport.GetViewportDib()</a> and <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Viewports/GUID-282F32AC-5A80-4FDB-B8C0-275D2CC15845.html\' title=\'\'>windows.snapshot()</a>.</p>\n\
<div class=\'section\'><a id=\"drawing-setup\"></a><h2 id=\"drawing-setup\">Drawing Setup</h2></div>\n\
<div class=\'codeBlock\'><pre>gw.resetUpdateRect() \n\
</pre></div><p>This method resets the update rectangle. The update rectangle is the region of the screen that needs to be updated to reflect items that have changed. When the system is done rendering items, the goal is to only update the region of the viewport that has actually been altered. This method sets the update rectangle (the region that will be blitted to the display) to a special &quot;empty&quot; value. This way when <span class=\'code\'>gw.enlargeUpdateRect()</span> is later called, the Box2 region passed will be used as the region.</p>\n\
<div class=\'codeBlock\'><pre>gw.enlargeUpdateRect ( &lt;Box2&gt; | #whole ) [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>This method enlarges the update rectangle to include the Box2 value passed. If <span class=\'code\'>#whole</span> is specified, the whole viewport will later be updated</p>\n\
<div class=\'codeBlock\'><pre>gw.getUpdateRect() [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>This method retrieves the current update rectangle as a Box2 value. Returns a special an Box2 &quot;empty&quot; value if no region of the viewport needs to be updated.</p>\n\
<div class=\'codeBlock\'><pre>gw.setRndLimits &lt;render_limits_name_array&gt; \n\
</pre></div><p>Sets the rendering limits used by primitive calls. Setting the rendering limits is used in communication between the various parts of <strong>3ds Max</strong> that handle the display of objects. For example, setting this limit to #polyEdges and then drawing a polygon won&#39;t result in a polygon drawn with edges. It only sets a flag that indicates the edge should be drawn.</p>\n\
<p>What happens is as follows. Inside the upper level <strong>3ds Max</strong>, part of the code knows that polygon edges have been turned on. However this is not related through the object oriented architecture to the part of <strong>3ds Max</strong> that does the actual drawing. When <strong>3ds Max</strong> goes to draw objects it will see that the polygon edge flag is on. This tells it to do two drawing passes -- one to draw the polygon, then it calls <span class=\'code\'>outlinePass()</span> call with <span class=\'code\'>true</span> , draws a bunch of edges, then calls <span class=\'code\'>outlinePass()</span> with <span class=\'code\'>false</span> . Thus, the drawing routine is responsible for looking at the flags and drawing appropriately. This method is only responsible setting the limit which can later be checked.</p>\n\
<p><span class=\'code\'>&lt;render_limits_name_array&gt;</span> specifies the rendering limits used by the viewport as an array of <span class=\'code\'>&lt;render_limits_name&gt;</span> values. The valid <span class=\'code\'>&lt;render_limits_name&gt;</span> values are:</p>\n\
<div class=\'codeBlock\'><pre>#allEdges \n\
</pre></div><p>All edges of the item are shown (including hidden ones).</p>\n\
<div class=\'codeBlock\'><pre>#boxMode \n\
</pre></div><p>Objects are shown using their bounding box.</p>\n\
<div class=\'codeBlock\'><pre>#backcull \n\
</pre></div><p>Backface culling is used. Entities whose surface normal face away from the view direction are not drawn.</p>\n\
<div class=\'codeBlock\'><pre>#colorVerts \n\
</pre></div><p>This turns on color-per-vertex display.</p>\n\
<div class=\'codeBlock\'><pre>#flat \n\
</pre></div><p>Flat (facet) shading mode.</p>\n\
<div class=\'codeBlock\'><pre>#illum \n\
</pre></div><p>This indicates that you have colors per vertex in your polygons and that they should be used. If you had colors per vertex but this flag was not set, the colors would be ignored.</p>\n\
<div class=\'codeBlock\'><pre>#lighting \n\
</pre></div><p>This is the same as setting <span class=\'code\'>#illum</span> and <span class=\'code\'>#specular</span> .</p>\n\
<div class=\'codeBlock\'><pre>#noAtts \n\
</pre></div><p>No attributes are specified.</p>\n\
<div class=\'codeBlock\'><pre>#perspCorrect \n\
</pre></div><p>In this mode textures are corrected for perspective display.</p>\n\
<div class=\'codeBlock\'><pre>#pick \n\
</pre></div><p>This indicates hit testing will be performed (not rendering).</p>\n\
<div class=\'codeBlock\'><pre>#polyEdges \n\
</pre></div><p>This mode causes polygon edges (Edged Faces) to be on.</p>\n\
<div class=\'codeBlock\'><pre>#shadeCverts \n\
</pre></div><p>This modifies <span class=\'code\'>#colorVerts</span> . If set, lighting is enabled and the vertex colors are used to modulate the colors that result from lighting. If off, the colors on each vertex are used directly to shade the triangle. When <strong>3ds Max</strong> uses <span class=\'code\'>#shadeCverts</span> mode, it puts a white diffuse-only material on the object so that it appears that the colors are shaded without distortion.</p>\n\
<p>Described further, when <span class=\'code\'>#shadeCverts</span> is OFF, then the vertex colors are used directly. This is equivalent to saying that they are modulated by a pure white self-illuminated material.</p>\n\
<p>When <span class=\'code\'>#shadeCverts</span> is ON, the diffuse white material is illuminated by the scene lighting, resulting in shades ranging from black to white, with most vertices being some shade of pure gray. When the vertex colors are modulated by the material color, they get multiplied (in general) by a number less than 1, which makes them appear darker.</p>\n\
<p>The RGB components of the colors are modulated uniformly, so that there is no shift from, say, red to green. That would happen if the underlying material was not evenly weighted (that is, a pure gray lying between black and white). Said another way, only the intensity of the vertex colors is changed when shading is on, not luminance, chrominance, etc.</p>\n\
<div class=\'codeBlock\'><pre>#specular \n\
</pre></div><p>This enables specular highlight display.</p>\n\
<div class=\'codeBlock\'><pre>#texture \n\
</pre></div><p>This enables texture display.</p>\n\
<div class=\'codeBlock\'><pre>#twoSided \n\
</pre></div><p>Faces are displayed regardless of their surface normal orientation.</p>\n\
<div class=\'codeBlock\'><pre>#vertTicks \n\
</pre></div><p>This mode is really a pseudo-mode, in that it doesn&#39;t actually cause the graphics drivers to do anything differently, but rather is tested by the Mesh class, which sends down vertex markers (+) if the mode is on.</p>\n\
<div class=\'codeBlock\'><pre>#wireframe \n\
</pre></div><p>Wireframe rendering mode.</p>\n\
<div class=\'codeBlock\'><pre>#zBuffer \n\
</pre></div><p>When coordinates are specified for drawing primitives they have x, y, and z values. Sometimes when drawing entities in the viewports it is desirable to ignore the z values. For example in the <strong>3ds Max</strong> viewports the text that display the type of viewport (Front, Left, and so on) are drawn without z values. So are the arc-rotate circle control and the axis tripods. These items are drawn without this flag being set so they always show up in front.</p>\n\
<div class=\'codeBlock\'><pre>gw.getRndLimits() \n\
</pre></div><p>Retrieves the rendering limits used by primitive calls as an array of names. See <span class=\'code\'>gw.setRndLimits()</span> for a list of the returned name values.</p>\n\
<div class=\'codeBlock\'><pre>gw.getRndMode() \n\
</pre></div><p>Returns the current rendering mode used by the viewport as an array of names. This is a subset of the rendering limit, in that any limits imposed by the rendering limit are forced onto the current mode. See <span class=\'code\'>gw.setRndLimits()</span> for a list of the returned name values.</p>\n\
<div class=\'codeBlock\'><pre>gw.setSkipCount &lt;skip_count_integer&gt; \n\
</pre></div><p>Sets the number of triangles skipped when the viewport is set as a &#39;Fast View Display&#39; viewport. To disable fastview, specify 1. Since triangles are handed down to graphics driver one at a time, it is up to the code that feeds triangles to the graphics driver to skip the specified number of triangles. The mesh rendering in <strong>3ds Max</strong> uses the skip count in this way.</p>\n\
<p><span class=\'code\'>&lt;skip_count_integer&gt;</span> specifies that every &#39;n-th&#39; triangle should be drawn. If set to 2, every other triangle should be drawn.</p>\n\
<div class=\'codeBlock\'><pre>gw.getSkipCount()\n\
</pre></div><p>Returns the current skip count setting.</p>\n\
<blockquote>\n\
<p><strong>The following is an example of using the above functions</strong></p>\n\
<p>``` -- Get the current rendering limits lim = gw.getRndLimits() -- Add another limit append lim #polyEdges -- Set the new rendering limits gw.setRndLimits lim -- Get back the rendering limits to check gw.getRndLimits() -- Get back the rendering mode to check gw.getRndMode()</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>gw.setDirectXDisplayAllTriangle &lt;boolean&gt; \n\
</pre></div><p>Exposes the <strong>Display All Triangle Edges</strong> option available in the UI as a checkbox in the <strong>Customize&gt;Preferences&gt;Viewports&gt;Configure Driver</strong> dialog of the Direct3D driver. When set to true, all edges will be drawn. When set to false, only visible edges will be drawn.</p>\n\
<p>Available in <strong>3ds Max 9</strong> and higher.</p>\n\
<div class=\'section\'><a id=\"light-and-camera-methods\"></a><h2 id=\"light-and-camera-methods\">Light and Camera Methods</h2></div>\n\
<div class=\'codeBlock\'><pre>gw.getMaxLights() \n\
</pre></div><p>Returns the maximum number of lights that may be used by the interactive renderer.</p>\n\
<div class=\'section\'><a id=\"coordinate-transformation-methods\"></a><h2 id=\"coordinate-transformation-methods\">Coordinate Transformation Methods</h2></div>\n\
<p>The following methods map points from the graphic window&#39;s current transform to device space. If the graphic window&#39;s transform is set to the identity matrix then the mapping is done from points specified in world space. Otherwise the points given are transformed by the graphic window’s transform, and are then considered to be in world space. Thus, o get a world-space to screen-space conversion, you need to set the graphic window’s transform to the identity with</p>\n\
<blockquote>\n\
<p><strong>CODE:</strong></p>\n\
<p>``` gw.setTransform(Matrix3 1)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>gw.hTransPoint &lt;point3&gt; [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>This method converts the point3 coordinate to a &quot;h&quot; format device coordinate. Each component of the return value is in integer format in the native device coordinates for the graphics driver. For HEIDI and OpenGL, the origin is at the lower left. For Direct3D the origin is at the upper left.</p>\n\
<div class=\'codeBlock\'><pre>gw.wTransPoint &lt;point3&gt; [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>This method converts the point3 coordinate to a &quot;w&quot; format device coordinate. Each component of the return value is in integer format with the origin at the upper left.</p>\n\
<div class=\'codeBlock\'><pre>gw.transPoint &lt;point3&gt; [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>This method converts the point3 coordinate to a &quot;h&quot; floating point coordinate. Each component of the return value is in float format with the origin at the upper left. This is just a helper routine to avoid building up round-off error. <strong>3ds Max</strong> uses it just for IK.</p>\n\
<div class=\'section\'><a id=\"drawing-methods\"></a><h2 id=\"drawing-methods\">Drawing Methods</h2></div>\n\
<p>Methods that start with &quot;h&quot; take integer device coordinates with the origin at the lower-left. Methods that start with &quot;w&quot; in front take Windows device coordinates with the origin at the upper left. These &quot;h&quot; and &quot;w&quot; routines perform NO clipping unless otherwise noted. Drawing outside the allowable region is likely to cause <strong>3ds Max</strong> to crash. These coordinate systems are left-handed.</p>\n\
<p>Methods that don’t start with &quot;h&quot; or &quot;w&quot; map points from the graphic window&#39;s current transform to device space. This coordinate system is right-handed. If the graphic window&#39;s transform is set to the identity matrix then the mapping is done from points specified in world space. Otherwise the points given are transformed by the graphic window’s transform, and are then considered to be in world space. Thus, to get a world-space to screen-space conversion, you need to set the graphic window’s transform to the identity with:</p>\n\
<blockquote>\n\
<p><strong>CODE:</strong></p>\n\
<p>``` gw.setTransform(Matrix3 1)</p>\n\
<p>```</p>\n\
</blockquote>\n\
<p>After completing any drawing to the graphics window with the methods described in this section, you need to call <span class=\'code\'>gw.updateScreen()</span> to update the viewport display.</p>\n\
<div class=\'codeBlock\'><pre>gw.updateScreen() \n\
</pre></div><p>Updates the viewport display to display any text, markers, polylines, polygons, or tristrips written to the graphics window via the methods described below.</p>\n\
<div class=\'codeBlock\'><pre>gw.text &lt;point3&gt; &lt;string&gt; [ color:&lt;color&gt; ]\n\
gw.hText &lt;point3&gt; &lt;string&gt; [ color:&lt;color&gt; ] [ applyUIScaling:&lt;true&gt; ]\n\
gw.wText &lt;point3&gt; &lt;string&gt; [ color:&lt;color&gt; ] [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Draws 2D fixed font annotation string text to the specified location using the specified (optional) color. If the color is not specified, a default color of red is used.</p>\n\
<p>Multi-line text is supported since <strong>3ds Max 2015</strong> - use the \\n escape sequence to introduce New Lines into the string. In previous versions of <strong>3ds Max</strong>, only single-line text was supported.</p>\n\
<p>Note:</p>\n\
<p>This routine DOES perform clipping of the text if it is off the screen.</p>\n\
<div class=\'codeBlock\'><pre>gw.getTextExtent &lt; string &gt; [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Returns the text extents of the string as it would be displayed in the viewports as a point2 value.</p>\n\
<div class=\'codeBlock\'><pre>gw.Marker &lt;point3&gt; &lt;marker_name&gt; [ color:&lt;color&gt; ] \n\
gw.hMarker &lt;point3&gt; &lt;marker_name&gt; [ color:&lt;color&gt; ] [ applyUIScaling:&lt;true&gt; ]\n\
gw.wMarker &lt;point3&gt; &lt;marker_name&gt; [ color:&lt;color&gt; ] [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Draws a marker at the specified location. This is can be paired with <span class=\'code\'>pickpoint()</span> to quickly show where the user has clicked. These markers are temporary and will be erased whenever the viewports are updated. If the color is not specified, a default color of red is used. The valid <span class=\'code\'>&lt;marker_name&gt;</span> types are:</p>\n\
<div class=\'codeBlock\'><pre>#point #hollowBox #plusSign #asterisk #xMarker #bigBox #circle #triangle #diamond #smallHollowBox #smallCircle #smallTriangle #smallDiamond \n\
</pre></div><p>The following is an example that creates an instance of all types of markers, spaced equally:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` arr = #(&quot;point&quot;,&quot;hollowBox&quot;,&quot;plusSign&quot;,&quot;asterisk&quot;,&quot;xMarker&quot;, &quot;bigBox&quot;,&quot;circle&quot;,&quot;triangle&quot;,&quot;diamond&quot;,&quot;smallHollowBox&quot;, &quot;smallCircle&quot;,&quot;smallTriangle&quot;,&quot;smallDiamond&quot;) for i=1 to arr.count do ( gw.hMarker <a href=\'#!/url=./developer/MAXScript-Tools-and-Interaction/Interacting-with-the-3ds-Max/Viewports/arr[i]%20as%20name/\' title=\'\'>100, (50 + i*10), 50</a> ) gw.enlargeUpdateRect #whole gw.updateScreen()</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>gw.Polyline &lt;vertex_point3_array&gt; &lt;isClosed_boolean&gt; [rgb:&lt;color_array&gt;] \n\
gw.hPolyline &lt;vertex_point3_array&gt; &lt;isClosed_boolean&gt; [rgb:&lt;color_array&gt;] [ applyUIScaling:&lt;true&gt; ] \n\
gw.wPolyline &lt;vertex_point3_array&gt; &lt;isClosed_boolean&gt; [rgb:&lt;color_array&gt;] [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>This method draws a multi-segment polyline. Each value in <span class=\'code\'>&lt;vertex_point3_array&gt;</span> is a vertex on the polyline. If <span class=\'code\'>&lt;isClosed_boolean&gt;</span> is <span class=\'code\'>true</span> , the first point is connected to the last point, that is, the polyline is closed. If <span class=\'code\'>false</span> , the polyline is left open. If the optional rgb color array is specified, and shade mode is set to smooth, the polyline will be drawn Gourand shaded. This is how <strong>3ds Max</strong> draws lit wireframes for instance. If the optional rgb color array is not specified, the line is drawn with the line color specified via <span class=\'code\'>gw.setColor()</span> . The number of elements in <span class=\'code\'>&lt;color_array&gt;</span> must be the same as in <span class=\'code\'>&lt;vertex_point3_array&gt;</span>.</p>\n\
<div class=\'codeBlock\'><pre>gw.Polygon &lt;vertex_point3_array&gt; &lt;color_array&gt; &lt;uvw_point3_array&gt; \n\
gw.hPolygon &lt;vertex_point3_array&gt; &lt;color_array&gt; &lt;uvw_point3_array&gt; [ applyUIScaling:&lt;true&gt; ]\n\
gw.wPolygon &lt;vertex_point3_array&gt; &lt;color_array&gt; &lt;uvw_point3_array&gt; [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>This method draws a multi-point polygon. Each value in <span class=\'code\'>&lt;vertex_point3_array&gt;</span> is a vertex on the polygon. <span class=\'code\'>&lt;color_array&gt;</span> specifies the color at each vertex. The rendering mode (set via <span class=\'code\'>gw.setRndLimits()</span> ) must include <span class=\'code\'>#colorVerts</span> for the color values to be used. <span class=\'code\'>&lt;uvw_point3_array&gt;</span> specifies the UVW coordinates at each. The rendering mode must include <span class=\'code\'>#texture</span> for the UVW coordinates to be used. The number of elements in each array must be identical.</p>\n\
<div class=\'codeBlock\'><pre>gw.hRect &lt;box2&gt; &lt;color&gt; [ applyUIScaling:&lt;true&gt; ]\n\
gw.wRect &lt;box2&gt; &lt;color&gt; [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Draws a rectangle in the given color using the coordinates specified by box2.</p>\n\
<p>Available in <strong>3ds Max 2008</strong> and higher. reviously available in <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` rect = (box2 13 47 96 97) gw.wrect rect red gw.wmarker [rect.left,rect.top,0] #point color:green gw.wmarker [rect.left,rect.bottom,0] #point color:green gw.wmarker [rect.right,rect.top,0] #point color:green gw.wmarker [rect.right,rect.bottom,0] #point color:green eRect = rect -- enlargeUpdateRect 1 pixel too small in either direction? eRect.right += 1 eRect.bottom += 1 gw.enlargeUpdateRect eRect gw.updateScreen()</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>gw.startTriangles() \n\
</pre></div><p>This method is called to begin sending a series of triangles to render. Call this method, then <span class=\'code\'>gw.triangle()</span> one or more times, then <span class=\'code\'>gw.endTriangles()</span> to finish.</p>\n\
<p>Available in <strong>3ds Max 2008</strong> and higher. Previously available in <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>gw.endTriangles() \n\
</pre></div><p>Call this method to finish rendering triangles.</p>\n\
<p>Available in <strong>3ds Max 2008</strong> and higher. reviously available in <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>gw.triangle &lt;vertex_point3_array&gt; &lt;color_array&gt; \n\
</pre></div><p>This method draws a triangle. Each value in <span class=\'code\'>&lt;vertex_point3_array&gt;</span> is a vertex on the triangle.</p>\n\
<p><span class=\'code\'>&lt;color_array&gt;</span> specifies the color at each vertex. The rendering mode set via <span class=\'code\'>gw.setRndLimits()</span> must include <span class=\'code\'>#illum</span> for the color values to be used.</p>\n\
<p>There must be 3 elements in each array.</p>\n\
<p>Call <span class=\'code\'>gw.startTriangles()</span> first, call <span class=\'code\'>gw.triangle()</span> one or more times, then <span class=\'code\'>gw.endTriangles()</span> when done drawing triangles.</p>\n\
<p>Available in <strong>3ds Max 2008</strong> and higher. reviously available in <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` gw.setTransform(Matrix3 1) gw.startTriangles() gw.triangle #([0,0,0], [50,0,0], [50,50,0]) #(red,red,red) gw.triangle #([0,0,0], [50,50,0], [0,50,0]) #(green,green,green) gw.endTriangles() gw.enlargeUpdateRect #whole gw.updateScreen()</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>gw.triStrip&lt;vertex_point3_array&gt; &lt;color_array&gt; &lt;uvw_point3_array&gt; \n\
</pre></div><p>This method is used for drawing a series of triangles specified as &#39;strips&#39;.</p>\n\
<p>The method takes 3 or more vertices and builds triangles in a strip. This sends a lot less data and the underlying graphics library has to set up a lot less data since it can use the previous information to start the rasterization, resulting in a significant speed increase. This routine does no clipping so all the vertices passed must be within view.</p>\n\
<p>The parameters are the same as for the <span class=\'code\'>gw.Polygon()</span> . However, the <span class=\'code\'>&lt;vertex_point3_array&gt;</span> is handled differently. After the first two vertices, each new vertex is used to create a new triangle. For instance, to draw a quad, the first three vertices specify the first triangle and the next one is combined with the previous two to complete the square.</p>\n\
<p>Available in <strong>3ds Max 2008</strong> and higher. Previously available in <a href=\'#!/url=./developer/MAXScript-Introduction/MAXScript-for-New-and-Casual/Avguard-DLX-Extension.html\' title=\'\'>Avguard Extensions</a>.</p>\n\
<div class=\'codeBlock\'><pre>gw.hTriStrip &lt;vertex_point3_array&gt; &lt;color_array&gt; &lt;uvw_point3_array&gt; [ applyUIScaling:&lt;true&gt; ]\n\
gw.wTriStrip &lt;vertex_point3_array&gt; &lt;color_array&gt; &lt;uvw_point3_array&gt; [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Note:</p>\n\
<p>These two methods are currently broken. Please use the gw.triStrip and Polygon methods above.</p>\n\
<p>The following is an example of using the above functions:</p>\n\
<blockquote>\n\
<p><strong>EXAMPLE:</strong></p>\n\
<p>``` -- Draw some primitives gw.hPolyline #([300,50,16], [300,200,8], [450,250,4]) true -- gw.hPolygon #([200,100,16], [280,100,8], [250,200,4])<br> #(red, blue, green)<br> #([1.0,.5,0], [0.5,0.5,0], [0,0,0.5]) -- Update the viewports gw.enlargeUpdateRect #whole gw.updateScreen()</p>\n\
<p>```</p>\n\
</blockquote>\n\
<div class=\'codeBlock\'><pre>gw.setColor &lt;type_name&gt; &lt;color_value&gt; \n\
</pre></div><p>Sets the RGB color used for the specified drawing type. The valid <span class=\'code\'>&lt;type_name&gt;</span> values are:</p>\n\
<div class=\'codeBlock\'><pre>#line -- line drawing color \n\
#fill -- polygon fill color \n\
#text -- text drawing color \n\
#clear -- The color that the viewport is cleared to when you call gw.clearScreen() \n\
gw.clearScreen &lt;Box2&gt; [ useBkg:&lt;boolean&gt; ] [ applyUIScaling:&lt;true&gt; ]\n\
</pre></div><p>Clears the specified rectangular region of the screen. If the optional <span class=\'code\'>useBkg</span> parameter is set to <span class=\'code\'>false</span> , the region is set to the &quot;clear&quot; color (see <span class=\'code\'>gw.setColor()</span> above). If <span class=\'code\'>true</span> , the background should be used to fill the cleared area. The default <span class=\'code\'>useBkg</span> value is <span class=\'code\'>false</span> .</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";