var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>thehold</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>thehold</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"thehold\"></a></div>\n\
<p>This structure exposes all but 3 of the <strong>theHold</strong> public SDK methods. (The 3 methods missing are not useful in the MXS scripting context.)</p>\n\
<p>The undo / redo system of <strong>3ds Max</strong> uses a global instance of the Hold class called theHold. Developers call methods of theHold object to participate in the undo / redo system.</p>\n\
<blockquote>\n\
<p>Warning: These <strong>are straight SDK method exposures</strong> with <strong>no additional protection</strong> built in! You better know what you are doing! You should run your code within try/catch blocks to keep the hold system in a consistent state.</p>\n\
</blockquote>\n\
<p>For methods that take arguments, the arguments are checked before use, but they won&#39;t throw an error if argument is incorrect. Instead, a default string of &quot;&quot; will be used for Accept and SuperAccept, and &amp;unsupplied for Restoring.</p>\n\
<p><strong>Methods:</strong></p>\n\
<div class=\'codeBlock\'><pre>theHold.Accept &lt;string&gt;      \n\
</pre></div><p>Leaves the database in its modified state and registers an undo object with the undo system. This will allow the user to undo the operation. The parameter is the string to appear in the Edit menu next to Undo or Redo.</p>\n\
<div class=\'codeBlock\'><pre>theHold.Begin()   \n\
</pre></div><p>When a developer is about to modify the database he should check to see if <span class=\'code\'>theHold</span> is &#39;holding&#39;. This indicates that the <span class=\'code\'>Begin()</span> method has been called. This signifies the beginning of a potential undo/redo operation. If the Hold is not holding, they should call <span class=\'code\'>Begin()</span>. After <span class=\'code\'>Begin()</span> has been called the system is ready to accept restore objects.</p>\n\
<p>In certain cases the system may already be &#39;holding&#39; when the plug-in is about to begin its modification to the database. For example controllers would normally not call <span class=\'code\'>Begin()</span> because it usually has been called already. A procedural object will normally call <span class=\'code\'>Begin()</span> because there is no other part of the system that may alter a procedural object so <span class=\'code\'>Begin()</span> would not have been called.</p>\n\
<div class=\'codeBlock\'><pre>theHold.Cancel() \n\
</pre></div><p>Restores the database to its previous state and throws out the restore object. This cancels the operation.</p>\n\
<div class=\'codeBlock\'><pre>theHold.DisableUndo() \n\
</pre></div><p>This is used internally. Plug-In developers should not call this method. Prevents Undo when Accept() is called.</p>\n\
<div class=\'codeBlock\'><pre>theHold.EnableUndo() \n\
</pre></div><p>This is used internally. Plug-In developers should not call this method. Allows Undo when Accept() is called.</p>\n\
<div class=\'codeBlock\'><pre>theHold.End() \n\
</pre></div><p>This method is used internally to 3ds Max and should not be called by a plug-in developer. It leaves the database in its modified state but throws out the restore object.</p>\n\
<div class=\'codeBlock\'><pre>&lt;integer&gt;theHold.GetGlobalPutCount() \n\
</pre></div><p>Returns the number of times Put() has been called in the current session of3ds Max.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;theHold.Holding() \n\
</pre></div><p>This indicates if theHold.Begin() has been called. Any operation that modifies the database checks to see if theHold is currently in a holding state. If the undo system is &#39;holding&#39; it is ready to accept restore objects.</p>\n\
<p>Return Value: true if theHold is holding; otherwise false.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;theHold.Redoing() \n\
</pre></div><p>Returns nonzero if the system is redoing and zero if not.</p>\n\
<div class=\'codeBlock\'><pre>theHold.Release() \n\
</pre></div><p>This tosses out the restore objects since the last Begin() but still continues holding. Group several Begin-End lists into a single Super-group.</p>\n\
<div class=\'codeBlock\'><pre>theHold.Restore() \n\
</pre></div><p>This method will call Restore() on all the restore objects registered since the last Begin(). This restores the database to the state it was in when Begin() was called. The restore objects are NOT deleted.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;theHold.RestoreOrRedoing() \n\
</pre></div><p>Returns nonzero if the system is restoring or redoing and zero if not.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;theHold.Restoring isUndo:&lt;&amp;integer&gt; -- pass by reference \n\
</pre></div><p>Returns nonzero if the system is restoring and zero if not. The isUndo parameter is updated to indicate if the restore is coming from an undo. It&#39;s assigned nonzero if it is; zero if not.</p>\n\
<div class=\'codeBlock\'><pre>theHold.Resume() \n\
</pre></div><p>This is used internally. It resumes holding if it was suspended.</p>\n\
<div class=\'codeBlock\'><pre>theHold.SuperAccept &lt;string&gt; \n\
</pre></div><p>When a developer has used SuperBegin(), this method is used to Accept. This leaves the database in its modified state and registers the restore object with the undo system. This will allow the user to undo the operation. The string parameter is the text to appear in the Edit menu next to Undo or Redo.</p>\n\
<div class=\'codeBlock\'><pre>theHold.SuperBegin() \n\
</pre></div><p>Normally this is NOT needed but in special cases this can be useful. This allows a developer to group a set of Begin()/Accept() sequences to be undone in one operation.</p>\n\
<p>Consider the case of the user using the Shift-Move command to create a new node in the scene. There are two parts to this process. First the node must be cloned and second the position must be tracked as the user moves the mouse to place the new node in the scene. Naturally if the user wanted to Undo this operation, they would expect a single selection of the Undo command would accomplish it. However the process was not a single operation. There was the initial cloning of the node, and then the iterative process of moving the node in the scene, restoring its position, moving it again, restoring it again, etc. Cases like this are handled using methods of theHold named SuperBegin(), SuperAccept() and SuperCancel(). These allow the developer to group several restore objects together so that they may be undone via a single selection of Undo. Note that in this example it is only necessary to use SuperBegin() and SuperAccept() because the move was restoring interactively. Normally a developer does NOT need to use these methods even if they have several operations that modify the database. The undo system will automatically register all the restore objects needed as part of the undo object when theHold.Accept() is called and these may be undone using a single UNDO command.</p>\n\
<div class=\'codeBlock\'><pre>theHold.SuperCancel() \n\
</pre></div><p>When a developer has used SuperBegin(), this method is used to Cancel. This restores the database to its previous state and throws out the restore object. This cancels the operation.</p>\n\
<div class=\'codeBlock\'><pre>theHold.Suspend() \n\
</pre></div><p>Suspends the holding.</p>\n\
<div class=\'codeBlock\'><pre>&lt;boolean&gt;theHold.IsSuspended() \n\
</pre></div><p>Returns true if suspended, false otherwise.</p>\n\
<div class=\'codeBlock\'><pre>theHold.SuperLevel() \n\
</pre></div><p>Returns the superlevel depth. Normally 0, incremented for each call to SuperBegin, decremented for each call to SuperAccept or SuperCancel.</p>\n\
<div class=\'codeBlock\'><pre>theHold.getCurrentUndoLevels() \n\
</pre></div><p>Returns the current number of undo/redo entries. Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>theHold.getMaxUndoLevels() \n\
</pre></div><p>Returns the maximum number of undo/redo entries - same as &#39;Scene Undo Levels&#39; setting in Preference Settings dialog. Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<div class=\'codeBlock\'><pre>theHold.setMaxUndoLevels &lt;int&gt; \n\
</pre></div><p>Sets the maximum number of undo/redo entries. Available in <strong>3ds Max 8 and higher</strong>.</p>\n\
<p>See also the SDK documentation on theHold methods.</p>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";