var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>State Sets MAXScript Access</title>\n\
   <meta name=\"topic-subtype\" content=\"MAXScript\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>State Sets MAXScript Access</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"state-sets-maxscript-access\"></a></div>\n\
<p>The State Sets render pass management system was first introduced in the <strong>Subscription Advantage Pack</strong> extension to <strong>3ds Max 2012</strong> and is now integral part of <strong>3ds Max 2013 and higher</strong>. In <strong>3ds Max 2018 and higher</strong>, the compositing editor is a node-based system.</p>\n\
<p>This feature is exposed to MAXScript via a DotNet object and its properties and methods.</p>\n\
<p>The following example shows the basic steps involved in accessing and manipulating State Sets.</p>\n\
<blockquote>\n\
<p><strong>Getting Access To State Sets</strong></p>\n\
<p>``` stateSetsDotNetObject = dotNetObject &quot;Autodesk.Max.StateSets.Plugin&quot; --Get StateSets dotNet object. stateSets = stateSetsDotNetObject.Instance --Get the state sets instance from the dotNet object.</p>\n\
<p>```</p>\n\
<p><strong>Opening and closing State Sets window</strong></p>\n\
<p>``` stateSets.ShowMainFrame() --Open the State Sets window. stateSets.HideMainFrame() --Close the State Sets window.</p>\n\
<p>```</p>\n\
<p><strong>Getting access to the Master state</strong></p>\n\
<p><span class=\'code\'>masterState = stateSets.EntityManager.RootEntity.MasterStateSet</span></p>\n\
<p><strong>Adding and renaming a new state set</strong></p>\n\
<p>``` stateSet = masterState.AddState() stateSet.Name = &quot;MyStateSet&quot; masterState.AssignUniqueName stateSet &quot;MyMasterStateset&quot; --Assigns a unique name to the state set</p>\n\
<p>```</p>\n\
<p><strong>Changing current state set, starting, and ending recording</strong></p>\n\
<p>``` previousCurrentStateSet = masterState.CurrentState.Items[0] --Record current state set. masterState.CurrentState = #(stateSet) --Assign current state set. stateSet.BeginRecording() --Begin recording state set.<br> stateSet.EndRecording() --End recording state set. masterState.CurrentState = #(previousCurrentStateSet) --Assign previous state set.</p>\n\
<p>```</p>\n\
<p><strong>Adding and rendering a child sub-state set, and doing other operations</strong></p>\n\
<p>``` subStateSet = stateSet.AddState() subStateSet = stateSet.Render #(stateSet) --Render state set, note that we specify a path because this state set could be located under multiple parents.</p>\n\
<p>scriptedState = stateSet.AddScriptedState(false) --Add a scripted state. scriptedState.ApplyScript = &quot;-- MaxScript executed when applying state set&quot; --Assign the apply script. scriptedState.RevertScript = &quot;-- MaxScript executed when reverting state set&quot; --Assign the revert script. stateSet.CreateTemplate() --Create a template for this state set</p>\n\
<p>```</p>\n\
<p><strong>Deleting state set and first child</strong></p>\n\
<p>``` masterState.RemoveChild stateSet --Removes the state set masterState.RemoveChild masterState.Children.Item[0] --Removes the first child</p>\n\
<p>```</p>\n\
<p><strong>Adding a compositor view</strong></p>\n\
<p>``` masterState.CreateCompositingView true --Add compositor view with render elements masterState.CreateCompositingView false --Add compositor view without render elements</p>\n\
<p>```</p>\n\
<p><strong>Getting the nodes in the active compositor view</strong></p>\n\
<p>``` cViewNodes = stateSets.CompositingViewNodes</p>\n\
<p>for i in 0 to (cViewNodes.Count - 1 ) do ( node = cViewNodes.Item(i) node.Collapsed = true print node.Tag.Name )</p>\n\
<p>```</p>\n\
<p><strong>Rendering all state sets in the scene</strong></p>\n\
<p><span class=\'code\'>masterState.RenderAllStates()</span></p>\n\
<p><strong>Getting access to objects state set</strong></p>\n\
<p><span class=\'code\'>objectStateSet = masterState.ObjectStateSet</span></p>\n\
</blockquote>\n\
<p>All properties and methods of all DotNet objects and classes implemented by the State Sets system are accessible to MAXScript using the DotNet inspector functions.</p>\n\
<blockquote>\n\
<p><strong>Exploring State Set Plugin Instance</strong></p>\n\
<p>``` stateSetsDotNetObject = dotNetObject &quot;Autodesk.Max.StateSets.Plugin&quot; dotNetObject:Autodesk.Max.StateSets.Plugin</p>\n\
<p>stateSets = stateSetsDotNetObject.Instance dotNetObject:Autodesk.Max.StateSets.Plugin</p>\n\
<p>showProperties stateSets .AbsentLayerStatesWereRemovedOnLoad : <system.boolean> .ActiveViewId : <system.uint16> .BitmapInfos : <system.collections.generic.dictionary`2[system.int32,autodesk.max.ibitmapinfo]>, read-only .ClassDescManager : <autodesk.max.statesets.classdescmanager>, read-only .CompositingView : <ephere.gui.nodeviews.nodeview>, read-only .CompositingViewNodes : <system.collections.generic.ilist`1[ephere.gui.nodeviews.nodeview+node]>, read-only .CompositorLink : <autodesk.max.statesets.compositorlink.compositorlinksettingscontroller>, read-only .CompositorLinkTargetViewId : <system.uint16> .Configuration : <autodesk.max.statesets.configuration> .EntityManager : <autodesk.max.statesets.entities.entitymanager>, read-only .Global : <autodesk.max.iglobal> .GlobalStringFormat : <system.drawing.stringformat>, read-only .HasRenderPreviewNode : <system.boolean>, read-only .Instance : <autodesk.max.statesets.plugin>, static .InvokeRequired : <system.boolean>, read-only .IsInSequencerMode : <system.boolean> .IsMainFrameInitialized : <system.boolean>, read-only .IsMainFrameVisible : <system.boolean> .LoadedVersion : <system.version> .MainFrameBounds : <system.drawing.rectangle> .NodeEvents : <autodesk.max.statesets.plugin+nodeeventcallback>, read-only .OpenViewCount : <system.int32>, read-only .PluginWasRegistered : <system.boolean> .PreviewRenderNode : <autodesk.max.iinode>, read-only .SequencerTreeView : <ephere.gui.nodeviews.nodeview>, read-only .Skin : <ephere.gui.nodeviews.skin>, read-only .Sync : <system.componentmodel.isynchronizeinvoke> .ToolbarTreeView : <ephere.gui.nodeviews.nodeview>, read-only .TreeView : <ephere.gui.nodeviews.nodeview>, read-only .TreeViews : <ephere.gui.nodeviews.nodeview[]>, read-only .accumCallbacks : <system.int32[]> true<p>\n\
<p>showMethods stateSets .<system.int32>AccumCallbackCount <autodesk.max.statesets.plugin+accumcallbacktype>type .AccumCallbackIncrement <autodesk.max.statesets.plugin+accumcallbacktype>type .AccumCallbackIncrement <autodesk.max.statesets.plugin+accumcallbacktype>type <system.int32>n .AccumCallbackReset <autodesk.max.statesets.plugin+accumcallbacktype>type -- Added in 3ds Max 2018: .<ephere.gui.nodeviews.nodeview>AddTreeView() .<system.iasyncresult>BeginInvoke <system.delegate>method <system.object[]>args .Cleanup() .<t>CreateInstance() .<system.runtime.remoting.objref>CreateObjRef <system.type>requestedType .<system.object>EndInvoke <system.iasyncresult>result .<system.boolean>Equals <system.object>obj .[static]<system.boolean>Equals <system.object>objA <system.object>objB .<system.int32>GetHashCode() .<system.object>GetLifetimeService() .<system.type>GetType() .<system.int32>GetUniqueBitmapInfoId() .HideMainFrame() .Initialize <autodesk.max.iglobal>global <system.componentmodel.isynchronizeinvoke>sync .<system.object>InitializeLifetimeService() .<system.object>Invoke <system.delegate>method <system.object[]>args .<autodesk.max.ivalue>LaunchBlank <autodesk.max.ivalue[]>args .[static]Log <autodesk.max.statesets.plugin+logtype>logType <system.string>message .[static]Log <system.string>message <system.boolean>newLine .LogLocal <autodesk.max.statesets.plugin+logtype>logType <system.string>message .PreviewRenderNodeReset() .[static]<system.boolean>ReferenceEquals <system.object>objA <system.object>objB .RegisterAnchorCallbacks() .ReloadConfiguration() .ResetAndDelete() .ResetConfiguration() .ResetNodeEventCallbackMessages() .ShowMainFrame() .<autodesk.max.statesets.entities.statesets.setuprenderoutputs>ShowSetupRenderOutputsPanel() .ToggleMainFrame() .<system.string>ToString() .TriggerNodeEventCallbackMessages() .UnRegisterAnchorCallbacks()true true<p>\n\
<p>showEvents stateSets CameraSequencerModeChanged <system.boolean>obj = ( ... ) CurrentLayerChanged <autodesk.max.iilayer>obj = ( ... ) CurrentStateSetChanged <autodesk.max.statesets.entities.statesets.stateset>obj = ( ... ) ScenePostSave = ( ... ) StateApplied <autodesk.max.statesets.entities.statesets.stateset>arg1 <system.boolean>arg2 = ( ... ) StateRecording <autodesk.max.statesets.entities.statesets.stateset>arg1 <system.boolean>arg2 = ( ... ) StateSetAdded <autodesk.max.statesets.entities.statesets.stateset>obj = ( ... ) StateSetChanged <autodesk.max.statesets.entities.statesets.stateset>obj = ( ... ) StateSetRemoved <autodesk.max.statesets.entities.statesets.stateset>obj = ( ... ) StateSetRenamed <autodesk.max.statesets.entities.statesets.stateset>obj = ( ... ) TimeChange <system.int32>obj = ( ... ) TimeRangeChanged = ( ... ) true<p>\n\
<p>```</p>\n\
<p><strong>Exploring MasterStateSet</strong></p>\n\
<p>``` showProperties stateSets.EntityManager .RootEntity : <autodesk.max.statesets.entities.root> true<p>\n\
<p>showProperties stateSets.EntityManager.RootEntity .AutomaticName : <system.string> .AutomaticTypeName : <system.string> .Children : <system.collections.generic.list`1[autodesk.max.statesets.entities.entity]> .CustomAttributes : <system.collections.hashtable>, read-only .CustomChildren : <system.collections.generic.list`1[autodesk.max.statesets.entities.entity]> .Description : <system.string> .DynamicInsertTarget : <system.boolean> .HierarchyIndex : <system.int32>, read-only .InternalName : <system.string>, read-only .MasterStateSet : <autodesk.max.statesets.entities.statesets.master>, read-only .Name : <system.string> .Parents : <autodesk.max.statesets.entities.entity[]>, read-only .TypeName : <system.string> .UseNameForTypeName : <system.boolean>, read-only .CustomChildrenToken : <system.string>, read-only, static true<p>\n\
<p>showProperties stateSets.EntityManager.RootEntity.MasterStateSet .AutomaticName : <system.string>, read-only .AutomaticTypeName : <system.string> .Children : <system.collections.generic.list`1[autodesk.max.statesets.entities.entity]> .CompositorLinkFilePath : <system.string> .CurrentState : <autodesk.max.statesets.entities.statesets.stateset[]> .CustomAttributes : <system.collections.hashtable>, read-only .CustomChildren : <system.collections.generic.list`1[autodesk.max.statesets.entities.entity]> .DefaultRenderOutputFilePattern : <system.string>, read-only, static .DescendantStateCount : <system.int32>, read-only .Description : <system.string>, read-only .DynamicInsertTarget : <system.boolean> .HierarchyIndex : <system.int32>, read-only .InternalName : <system.string>, read-only .Name : <system.string> .ObjectStateSet : <autodesk.max.statesets.entities.statesets.stateset>, read-only .Parents : <autodesk.max.statesets.entities.entity[]>, read-only .RenderOutputFilePattern : <system.string> .StatesWithErrors : <system.collections.generic.icollection`1[autodesk.max.statesets.entities.statesets.istate]>, read-only .TypeName : <system.string> .UseNameForTypeName : <system.boolean>, read-only .CustomChildrenToken : <system.string>, read-only, static .StateNameToken : <system.string>, read-only, static true<p>\n\
<p>showMethods stateSets.EntityManager.RootEntity.MasterStateSet .<autodesk.max.statesets.entities.entity>AddChild <autodesk.max.statesets.entities.entity>entity <system.boolean>wasAutoGenerated .<autodesk.max.statesets.entities.entity>AddChild <autodesk.max.statesets.entities.entity>entity <system.boolean>wasAutoGenerated <system.boolean>broadcastEvent .AddObjectState() .AddObjectState <system.nullable`1[[system.uint16, mscorlib,=\"\" version=\"4.0.0.0,\" culture=\"neutral,\" publickeytoken=\"b77a5c561934e089]]\">targetViewId .<autodesk.max.statesets.entities.statesets.stateset>AddState() .<autodesk.max.statesets.entities.statesets.stateset>AddState <system.nullable`1[[system.uint16, mscorlib,=\"\" version=\"4.0.0.0,\" culture=\"neutral,\" publickeytoken=\"b77a5c561934e089]]\">targetViewId <system.boolean>addToCompositorView .AssignUniqueName <autodesk.max.statesets.entities.entity>state <system.string>baseName .BeginRecordingStateSet <autodesk.max.statesets.entities.statesets.stateset>stateSet <autodesk.max.statesets.entities.statesets.stateset[]>path .CheckForStateErrors() .CollectDescendantStateSets <system.collections.generic.list`1[[autodesk.max.statesets.entities.statesets.stateset, autodesk.max.statesets,=\"\" version=\"20.0.966.0,\" culture=\"neutral,\" publickeytoken=\"null]]\">destination .CollectDescendantsWithCustomAttribute <system.object>customAttribute <system.collections.generic.list`1[[autodesk.max.statesets.entities.entity, autodesk.max.statesets,=\"\" version=\"20.0.966.0,\" culture=\"neutral,\" publickeytoken=\"null]]\">destination .CreateCompositingView <system.boolean>includeRenderElements .<system.runtime.remoting.objref>CreateObjRef <system.type>requestedType .<autodesk.max.statesets.entities.statesets.iparameter>CreateUserCreatableParameter <system.string>name .DefaultSetup() .Dispose() .<system.boolean>Equals <system.object>obj .[static]<system.boolean>Equals <system.object>objA <system.object>objB .GenerateChildrenForTarget <autodesk.max.statesets.entities.entity>target .<autodesk.max.statesets.entities.entity>GetChild <system.string>name .<t>GetCustomAttribute <system.object>key <t>defaultValue .<system.boolean>GetCustomAttributeBoolean <system.object>key .<autodesk.max.statesets.entities.entity>GetDescendant <system.string>name .<autodesk.max.statesets.entities.entity>GetDescendant <system.collections.generic.list`1[[system.string, mscorlib,=\"\" version=\"4.0.0.0,\" culture=\"neutral,\" publickeytoken=\"b77a5c561934e089]]\">hierarchyIndex .<system.collections.generic.ienumerable`1[autodesk.max.statesets.entities.entity]>GetDescendants() .<system.int32>GetDescendantStateSetIndex <system.collections.generic.ienumerable`1[[autodesk.max.statesets.entities.statesets.stateset, autodesk.max.statesets,=\"\" version=\"20.0.966.0,\" culture=\"neutral,\" publickeytoken=\"null]]\">stateSetPath .<system.collections.generic.list`1[autodesk.max.statesets.entities.statesets.stateset[]]>GetDescendantStateSetPaths <system.boolean>includeObjectStateSet .<system.int32>GetHashCode() .<system.collections.generic.list`1[system.string]>GetHierarchyIndex <autodesk.max.statesets.entities.entity>descendant .<system.object>GetLifetimeService() .GetObjectData <system.runtime.serialization.serializationinfo>info <system.runtime.serialization.streamingcontext>context .<autodesk.max.statesets.entities.statesets.stateset>GetStateById <system.int32>id .<system.type>GetType() .<system.string[]>GetUserCreatableParameterNames() .<system.boolean>HasCustomAttribute <system.object>key .<system.boolean>HasDescendant <autodesk.max.statesets.entities.entity>descendant <system.collections.generic.hashset`1[[autodesk.max.statesets.entities.entity, autodesk.max.statesets,=\"\" version=\"20.0.966.0,\" culture=\"neutral,\" publickeytoken=\"null]]\">ignoreParents .<system.boolean>HasDescendant <autodesk.max.statesets.entities.entity>descendant <autodesk.max.statesets.entities.entity[]>ignoreParents .<system.object>InitializeLifetimeService() .<autodesk.max.statesets.entities.entity>InsertChild <system.int32>index <autodesk.max.statesets.entities.entity>entity .<autodesk.max.statesets.entities.entity>InsertChild <system.int32>index <autodesk.max.statesets.entities.entity>entity <system.boolean>wasAutoGenerated <system.boolean>broadcastEvent .InvalidateChildren() .<system.boolean>IsDescendantOf <autodesk.max.statesets.entities.entity>ancestor .[static]maxnrAssignStateSetJob <system.int32[]>stateSetsHandles <system.int32>numHandles .<system.boolean>OnCreateChildForIndex <system.string>index <autodesk.max.irepresentation>target .[static]<system.boolean>ReferenceEquals <system.object>objA <system.object>objB .Refresh() .RemoveChild <autodesk.max.statesets.entities.entity>entity .RemoveChild <autodesk.max.statesets.entities.entity>entity <system.boolean>entityChange .RemoveChild <autodesk.max.statesets.entities.entity>entity <system.boolean>entityChange <system.boolean>broadcastEvent .RemoveCustomAttribute <system.object>key .<system.boolean>Rename <system.string>newName .RenderAllStates <system.boolean>forceNetworkRender .RenderStates <system.collections.generic.ienumerable`1[[system.collections.generic.ienumerable`1[[autodesk.max.statesets.entities.statesets.stateset, autodesk.max.statesets,=\"\" version=\"20.0.966.0,\" culture=\"neutral,\" publickeytoken=\"null]],\" mscorlib,=\"\" version=\"4.0.0.0,\" culture=\"neutral,\" publickeytoken=\"b77a5c561934e089]]\">stateSetPaths <system.boolean>useNetworkRender .Reset() .ResetCompositingView <system.boolean>includeRenderElements .SetCurrentStateSet <autodesk.max.statesets.entities.statesets.stateset[]>path .SetCustomAttribute <system.object>key <t>value .SetCustomAttributeBoolean <system.object>key <system.boolean>value .SetupRenderOutputsPath <system.string>value .<system.string>ToString() .UpdateHierarchyParents() true<p>\n\
<p>```</p>\n\
</system.string></system.string></system.boolean></system.object></t></system.object></autodesk.max.statesets.entities.statesets.stateset[]></system.boolean></system.boolean></system.collections.generic.ienumerable`1[[system.collections.generic.ienumerable`1[[autodesk.max.statesets.entities.statesets.stateset,></system.boolean></system.string></system.boolean></system.object></system.boolean></system.boolean></autodesk.max.statesets.entities.entity></system.boolean></autodesk.max.statesets.entities.entity></autodesk.max.statesets.entities.entity></system.object></system.object></system.boolean></autodesk.max.irepresentation></system.string></system.boolean></system.int32></system.int32[]></autodesk.max.statesets.entities.entity></system.boolean></system.boolean></system.boolean></autodesk.max.statesets.entities.entity></system.int32></autodesk.max.statesets.entities.entity></autodesk.max.statesets.entities.entity></system.int32></autodesk.max.statesets.entities.entity></system.object></autodesk.max.statesets.entities.entity[]></autodesk.max.statesets.entities.entity></system.boolean></system.collections.generic.hashset`1[[autodesk.max.statesets.entities.entity,></autodesk.max.statesets.entities.entity></system.boolean></system.object></system.boolean></system.string[]></system.type></system.int32></autodesk.max.statesets.entities.statesets.stateset></system.runtime.serialization.streamingcontext></system.runtime.serialization.serializationinfo></system.object></autodesk.max.statesets.entities.entity></system.collections.generic.list`1[system.string]></system.int32></system.boolean></system.collections.generic.list`1[autodesk.max.statesets.entities.statesets.stateset[]]></system.collections.generic.ienumerable`1[[autodesk.max.statesets.entities.statesets.stateset,></system.int32></system.collections.generic.ienumerable`1[autodesk.max.statesets.entities.entity]></system.collections.generic.list`1[[system.string,></autodesk.max.statesets.entities.entity></system.string></autodesk.max.statesets.entities.entity></system.object></system.boolean></t></system.object></t></system.string></autodesk.max.statesets.entities.entity></autodesk.max.statesets.entities.entity></system.object></system.object></system.boolean></system.object></system.boolean></system.string></autodesk.max.statesets.entities.statesets.iparameter></system.type></system.runtime.remoting.objref></system.boolean></system.collections.generic.list`1[[autodesk.max.statesets.entities.entity,></system.object></system.collections.generic.list`1[[autodesk.max.statesets.entities.statesets.stateset,></autodesk.max.statesets.entities.statesets.stateset[]></autodesk.max.statesets.entities.statesets.stateset></system.string></autodesk.max.statesets.entities.entity></system.boolean></system.nullable`1[[system.uint16,></autodesk.max.statesets.entities.statesets.stateset></autodesk.max.statesets.entities.statesets.stateset></system.nullable`1[[system.uint16,></system.boolean></system.boolean></autodesk.max.statesets.entities.entity></autodesk.max.statesets.entities.entity></system.boolean></autodesk.max.statesets.entities.entity></autodesk.max.statesets.entities.entity></system.string></system.string></system.boolean></system.string></system.collections.generic.icollection`1[autodesk.max.statesets.entities.statesets.istate]></system.string></autodesk.max.statesets.entities.entity[]></autodesk.max.statesets.entities.statesets.stateset></system.string></system.string></system.int32></system.boolean></system.string></system.int32></system.string></system.collections.generic.list`1[autodesk.max.statesets.entities.entity]></system.collections.hashtable></autodesk.max.statesets.entities.statesets.stateset[]></system.string></system.collections.generic.list`1[autodesk.max.statesets.entities.entity]></system.string></system.string></system.string></system.boolean></system.string></autodesk.max.statesets.entities.entity[]></system.string></autodesk.max.statesets.entities.statesets.master></system.string></system.int32></system.boolean></system.string></system.collections.generic.list`1[autodesk.max.statesets.entities.entity]></system.collections.hashtable></system.collections.generic.list`1[autodesk.max.statesets.entities.entity]></system.string></system.string></autodesk.max.statesets.entities.root></system.int32></autodesk.max.statesets.entities.statesets.stateset></autodesk.max.statesets.entities.statesets.stateset></autodesk.max.statesets.entities.statesets.stateset></autodesk.max.statesets.entities.statesets.stateset></system.boolean></autodesk.max.statesets.entities.statesets.stateset></system.boolean></autodesk.max.statesets.entities.statesets.stateset></autodesk.max.statesets.entities.statesets.stateset></autodesk.max.iilayer></system.boolean></system.string></autodesk.max.statesets.entities.statesets.setuprenderoutputs></system.object></system.object></system.boolean></system.string></autodesk.max.statesets.plugin+logtype></system.boolean></system.string></system.string></autodesk.max.statesets.plugin+logtype></autodesk.max.ivalue[]></autodesk.max.ivalue></system.object[]></system.delegate></system.object></system.object></system.componentmodel.isynchronizeinvoke></autodesk.max.iglobal></system.int32></system.type></system.object></system.int32></system.object></system.object></system.boolean></system.object></system.boolean></system.iasyncresult></system.object></system.type></system.runtime.remoting.objref></t></system.object[]></system.delegate></system.iasyncresult></ephere.gui.nodeviews.nodeview></autodesk.max.statesets.plugin+accumcallbacktype></system.int32></autodesk.max.statesets.plugin+accumcallbacktype></autodesk.max.statesets.plugin+accumcallbacktype></autodesk.max.statesets.plugin+accumcallbacktype></system.int32></system.int32[]></ephere.gui.nodeviews.nodeview[]></ephere.gui.nodeviews.nodeview></ephere.gui.nodeviews.nodeview></system.componentmodel.isynchronizeinvoke></ephere.gui.nodeviews.skin></ephere.gui.nodeviews.nodeview></autodesk.max.iinode></system.boolean></system.int32></autodesk.max.statesets.plugin+nodeeventcallback></system.drawing.rectangle></system.version></system.boolean></system.boolean></system.boolean></system.boolean></autodesk.max.statesets.plugin></system.boolean></system.drawing.stringformat></autodesk.max.iglobal></autodesk.max.statesets.entities.entitymanager></autodesk.max.statesets.configuration></system.uint16></autodesk.max.statesets.compositorlink.compositorlinksettingscontroller></system.collections.generic.ilist`1[ephere.gui.nodeviews.nodeview+node]></ephere.gui.nodeviews.nodeview></autodesk.max.statesets.classdescmanager></system.collections.generic.dictionary`2[system.int32,autodesk.max.ibitmapinfo]></system.uint16></system.boolean></blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";